@@ -16,6 +16,7 @@ use OCP\Notification\AlreadyProcessedException;
 use OCP\Notification\IManager as NotificationManager;
 use OCP\Notification\INotification;
 use OCP\Notification\INotifier;
+use OCP\Notification\UnknownNotificationException;
 use Psr\Log\LoggerInterface;
 
 class NotificationGenerator implements INotifier {
@@ -38,9 +39,9 @@ class NotificationGenerator implements INotifier {
 		$this->notificationManager->flush();
 	}
 
-	public function sendNotificationForEvent(IEvent $event, int $activityId) {
+	public function sendNotificationForEvent(IEvent $event, int $activityId, ?bool $notificationSetting = null) {
 		$selfAction = $event->getAffectedUser() === $event->getAuthor();
-		$notifySetting = $this->userSettings->getUserSetting($event->getAffectedUser(), 'notification', $event->getType());
+		$notifySetting = $notificationSetting ?? $this->userSettings->getUserSetting($event->getAffectedUser(), 'notification', $event->getType());
 
 		if ($notifySetting && !$selfAction && $event->getGenerateNotification()) {
 			$this->notificationManager->notify($this->getNotificationForEvent($event, $activityId));
@@ -91,17 +92,20 @@ class NotificationGenerator implements INotifier {
 		return $event;
 	}
 
+	#[\Override]
 	public function getID(): string {
 		return 'activity';
 	}
 
+	#[\Override]
 	public function getName(): string {
 		return 'Activity';
 	}
 
+	#[\Override]
 	public function prepare(INotification $notification, string $languageCode): INotification {
 		if ($notification->getObjectType() !== 'activity_notification') {
-			throw new \InvalidArgumentException();
+			throw new UnknownNotificationException();
 		}
 
 		$event = $this->data->getById((int)$notification->getObjectId());
@@ -109,7 +113,7 @@ class NotificationGenerator implements INotifier {
 			throw new AlreadyProcessedException();
 		}
 		if ($event->getAffectedUser() !== $notification->getUser()) {
-			throw new \InvalidArgumentException();
+			throw new AlreadyProcessedException();
 		}
 		$this->activityManager->setCurrentUserId($notification->getUser());
 		$event = $this->populateEvent($event, $languageCode);
