@@ -1,11 +1,14 @@
 OC.L10N.register(
     "app_api",
     {
+    "Cancel" : "Cancel",
     "Delete" : "Läschen",
     "Edit" : "Änneren",
     "Name" : "Numm",
     "Host" : "Host",
     "Enabled" : "Aktivéiert",
+    "Add" : "Dobäisetzen",
+    "Disabled" : "Deaktivéiert",
     "Confirm" : "Konfirméieren",
     "Save" : "Späicheren",
     "Report a bug" : "E Feeler melden",
