@@ -1,6 +1,7 @@
 OC.L10N.register(
     "circles",
     {
+    "Teams" : "Equipos",
     "You created the team {circle}" : "Vde. creou o equipo {circle}",
     "{author} created the team {circle}" : "{author} creou o equipo {circle}",
     "You deleted {circle}" : "Vde. eliminou {circle}",
@@ -51,7 +52,6 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} enviou unha solicitude para unirse a {circle}",
     "You are the new owner of {circle}" : "Vde. é o novo propietario de {circle}",
     "{member} is the new owner of {circle}" : "{member} é o novo propietario de {circle}",
-    "Teams" : "Equipos",
     "On events happening in a <strong>team</strong> of which you are a member" : "En eventos que ocorren nun <strong>equípo</strong> do que  Vde. é membro",
     "Any important event in a <strong>team</strong> you are moderating" : "Calquera evento importante nun <strong>equipo</strong> do que Vde. é o moderador",
     "On global events happening in any <strong>team</strong>" : "En eventos globais que ocorren en calquera <strong>equipo</strong>",
@@ -102,16 +102,16 @@ OC.L10N.register(
     "%s shared multiple files with \"%s\"." : "%s compartiu varios ficheiros con «%s».",
     "%s shared multiple files with you." : "%s compartiu varios ficheiros con Vde.",
     "Boot up" : "Arrancar",
-    "Nextcloud Initialization" : "Preparación de Nextcloud",
-    "Circles App Initialization" : "Preparación da aplicación Círculos",
+    "Nextcloud Initialization" : "Inicialización de Nextcloud",
+    "Circles App Initialization" : "Inicialización da aplicación Círculos",
     "Fresh installation status" : "Estado da nova instalación",
     "Building Local Database" : "Creando a base de datos local",
-    "Testing Basic Team Creation" : "Proba básica de creación de equipos",
+    "Testing Basic Circle Creation" : "Proba básica de creación de círculos",
     "Adding local users and moderators" : "Engadindo usuarios e moderadores locais",
     "Show all teams" : "Amosar todos os equipos",
     "Create a new team" : "Crear un novo equipo",
     "Files" : "Ficheiros",
-    "This feature is not available for personal teams" : "Esta característica non está dispoñíbel para equipos persoais",
+    "This feature is not available for personal circles" : "Esta característica non está dispoñíbel para círculos persoais",
     "The team is not federated" : "O equipo non está federado",
     "You cannot join this team" : "Vde. non pode unirse a este equipo",
     "This member is not a moderator" : "Este membro non é un moderador",
@@ -119,10 +119,10 @@ OC.L10N.register(
     "This member does not exist" : "Non existe este membro",
     "This member is the owner of the team" : "Este membro é o propietario do equipo",
     "Level cannot be changed for this type of member" : "Non é posíbel cambiar o nivel para este tipo de membro",
-    "You are already a member of this team" : "Vde. xa é membro deste equipo",
-    "You have been blocked from this team" : "Vde. foi bloqueado neste equipo",
-    "The account is already a member of this team" : "A conta xa é membro deste equipo",
-    "The account has already been invited into this team" : "A conta xa foi convidada a este equipo",
+    "You are already a member of this circle" : "Vde. xa é membro deste círculo",
+    "You have been blocked from this circle" : "Vde. foi bloqueado neste círculo",
+    "The account is already a member of this circle" : "A conta xa é membro deste círculo",
+    "The account has already been invited into this circle" : "A conta xa foi convidada a este círculo",
     "%s (Team owned by %s)" : "%s (Equipo propiedade de %s)",
     "You are now a member of the Team \"%2$s\"" : "Vde. agora é participante no equipo «%2$s»",
     "You have been invited by %1$s into the Team \"%2$s\"" : "Vde. foi convidado por %1$s ao equipo «%2$s»",
@@ -154,10 +154,15 @@ OC.L10N.register(
     "Loading…" : "Cargando…",
     "More teams" : "Máis equipos",
     "No files in here" : "Aquí non hai ficheiros",
-    "No entries found in this folder" : "Non foi atopada ningunha entrada neste cartafol",
+    "No entries found in this folder" : "Non se atopou ningunha entrada neste cartafol",
     "Name" : "Nome",
     "Size" : "Tamaño",
     "Modified" : "Modificado",
-    "Shared to Circles" : "Compartido con Círculos"
+    "Teams' files" : "Ficheiros dos equipos",
+    "Select team to filter by" : "Seleccione o equipo polo que filtrar",
+    "Please select teams to filter by" : "Seleccione os equipos polos que filtrar",
+    "No files found for the selected teams" : "Non se atopou ningún ficheiro para os equipos seleccionados",
+    "Shared to Circles" : "Compartido con Círculos",
+    "Circle" : "Círculo"
 },
 "nplurals=2; plural=(n != 1);");
