@@ -1,6 +1,7 @@
 OC.L10N.register(
     "circles",
     {
+    "Teams" : "Lag",
     "You created the team {circle}" : "Du opprettet laget {circle}",
     "{author} created the team {circle}" : "{author} opprettet laget {circle}",
     "You deleted {circle}" : "Du slettet {circle}",
@@ -51,7 +52,6 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} sendte et ønske om å få bli med i {circle}",
     "You are the new owner of {circle}" : "Du er den nye eieren av {circle}",
     "{member} is the new owner of {circle}" : "{member} er den nye eieren av {circle}",
-    "Teams" : "Lag",
     "On events happening in a <strong>team</strong> of which you are a member" : "På hendelser som skjer i et <strong>lag</strong> hvor du er medlem",
     "Any important event in a <strong>team</strong> you are moderating" : "Enhver viktig hendelse i et <strong>lag</strong> du modererer",
     "On global events happening in any <strong>team</strong>" : "På globale hendelser som skjer i ethvert <strong>lag</strong>",
@@ -104,10 +104,12 @@ OC.L10N.register(
     "Circles App Initialization" : "Initialisering av Circles App",
     "Fresh installation status" : "Status på fersk installasjon",
     "Building Local Database" : "Bygger lokal database",
+    "Testing Basic Circle Creation" : "Tester opprettelse av grunnleggende sirkel",
     "Adding local users and moderators" : "Legger til lokale brukere og moderatorer",
     "Show all teams" : "Vis alle lag",
     "Create a new team" : "Opprett et nytt lag",
     "Files" : "Filer",
+    "This feature is not available for personal circles" : "Funksjonen er ikke tilgjengelig for personlige sirkler",
     "The team is not federated" : "Laget er ikke sammenknyttet",
     "You cannot join this team" : "Du kan ikke bli med i dette laget",
     "This member is not a moderator" : "Dette medlemmet er ikke en moderator",
@@ -115,13 +117,13 @@ OC.L10N.register(
     "This member does not exist" : "Dette medlemmet finnes ikke",
     "This member is the owner of the team" : "Medlemmet er eieren av laget",
     "Level cannot be changed for this type of member" : "Nivået kan ikke endres for den typen medlem",
+    "You are already a member of this circle" : "Du er allerede medlem av denne sirkelen",
+    "You have been blocked from this circle" : "Du har blitt blokkert fra denne sirkelen",
+    "The account is already a member of this circle" : "Denne kontoren er allerede medlem av sirkelen",
+    "The account has already been invited into this circle" : "Denne kontoen har allerede blitt invitert til denne sirkelen",
     "%s (Team owned by %s)" : "%s (Lag eiet av %s)",
-    "You are now a member of the Team \"%2$s\"" : "Du er nå medlem av laget \"%2$s\"",
-    "You have been invited by %1$s into the Team \"%2$s\"" : "Du har blitt invitert av %1$s til laget \"%2$s\"",
-    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s sendte en forespørsel om å bli medlem av laget \"%2$s\"",
     "Accept" : "Aksepter",
     "Refuse" : "Avvis",
-    "Leave the team" : "Forlat laget",
     "%s" : "%s",
     "Personal team" : "Personlig lag",
     "%s owned by %s" : "%s eid av %s",
@@ -138,15 +140,17 @@ OC.L10N.register(
     "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Lag lar folk lage sine egne grupper av mennesker / kolleger / venner.\nDisse persongruppene kan deretter brukes av en hvilken som helst annen app til delingsformål.",
     "Try again" : "Prøv igjen",
     "No teams found" : "Ingen lag funnet",
-    "Join or create teams to see them here." : "Bli med eller opprett lag for å se dem her.",
-    "Create your first team" : "Opprett ditt første lag",
     "Loading…" : "Laster...",
-    "More teams" : "Flere lag",
     "No files in here" : "Ingen filer her",
     "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
     "Name" : "Navn",
     "Size" : "Størrelse",
     "Modified" : "Endret",
-    "Shared to Circles" : "Delt til Sirkler"
+    "Teams' files" : "Lags filer",
+    "Select team to filter by" : "Velg lag å filtrere etter",
+    "Please select teams to filter by" : "Vennligst velg lag å filtrere etter",
+    "No files found for the selected teams" : "Ingen filer funnet for valgte lag",
+    "Shared to Circles" : "Delt til Sirkler",
+    "Circle" : "Sirkel"
 },
 "nplurals=2; plural=(n != 1);");
