@@ -42,6 +42,8 @@ class ShareWrapperRequest extends ShareWrapperRequestBuilder {
 		$qb = $this->getShareInsertSql();
 		$qb->setValue('attributes', $qb->createNamedParameter($this->formatShareAttributes($share->getAttributes())))
 			->setValue('share_type', $qb->createNamedParameter($share->getShareType()))
+			->setValue('mail_send', $qb->createNamedParameter($share->getMailSend()))
+			->setValue('note', $qb->createNamedParameter($share->getNote()))
 			->setValue('item_type', $qb->createNamedParameter($share->getNodeType()))
 			->setValue('item_source', $qb->createNamedParameter($share->getNodeId()))
 			->setValue('file_source', $qb->createNamedParameter($share->getNodeId()))
@@ -54,7 +56,7 @@ class ShareWrapperRequest extends ShareWrapperRequestBuilder {
 			->setValue('password', $qb->createNamedParameter(''))
 			->setValue('permissions', $qb->createNamedParameter($share->getPermissions()))
 			->setValue('token', $qb->createNamedParameter($share->getToken()))
-			->setValue('stime', $qb->createFunction('UNIX_TIMESTAMP()'));
+			->setValue('stime', (string)$qb->createFunction('UNIX_TIMESTAMP()'));
 
 		if ($parentId > 0) {
 			$qb->setValue('parent', $qb->createNamedParameter($parentId));
