@@ -33,6 +33,7 @@ use OCA\Circles\Tools\IDeserializable;
 use OCA\Circles\Tools\Traits\TArrayTools;
 use OCA\Circles\Tools\Traits\TDeserialize;
 use OCP\Security\IHasher;
+use OCP\Server;
 
 /**
  * Class Circle
@@ -123,7 +124,7 @@ class Circle extends ManagedModel implements IEntity, IDeserializable, IQueryRow
 
 
 	/**
-	 * Note: When editing those values, update lib/AppInfo/Capabilities.php
+	 * Note: When editing those values, update lib/Application/Capabilities.php
 	 *
 	 * @see Capabilities::getCapabilitiesCircleConstants()
 	 * @var array
@@ -133,9 +134,9 @@ class Circle extends ManagedModel implements IEntity, IDeserializable, IQueryRow
 		2 => 'Nextcloud Group',
 		4 => 'Email Address',
 		8 => 'Contact',
-		16 => 'Team',
+		16 => 'Circle',
 		10000 => 'Nextcloud App',
-		10001 => 'Teams App',
+		10001 => 'Circles App',
 		10002 => 'Admin Command Line',
 		11000 => '3rd party app',
 		11010 => 'Collectives App'
@@ -904,10 +905,8 @@ class Circle extends ManagedModel implements IEntity, IDeserializable, IQueryRow
 		// if password is not hashed (pre-22), hash it and update new settings in DB
 		$curr = $this->get('password_single', $this->getSettings());
 		if (strlen($curr) >= 1 && strlen($curr) < 64) {
-			/** @var IHasher $hasher */
-			$hasher = \OC::$server->get(IHasher::class);
-			/** @var CircleRequest $circleRequest */
-			$circleRequest = \OC::$server->get(CircleRequest::class);
+			$hasher = Server::get(IHasher::class);
+			$circleRequest = Server::get(CircleRequest::class);
 
 			$new = $hasher->hash($curr);
 			$settings = $this->getSettings();
