@@ -10,13 +10,18 @@ OC.L10N.register(
     "{author} commented on {file}" : "Ο {author} σχολίασε στο {file}",
     "<strong>Comments</strong> for files" : "<strong>Σχόλια</strong> για αρχεία",
     "Files" : "Αρχεία",
+    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Σας ανέφεραν στο \"{file}\", σε σχόλιο από λογαριασμό που έχει πλέον διαγραφεί",
     "{user} mentioned you in a comment on \"{file}\"" : "Ο/η {user} σας ανέφερε σε σχόλιο στο “{file}”",
-    "Files app plugin to add comments to files" : "Επέκταση της εφαρμογής Αρχεία που επιτρέπει την προσθήκη σχολίων σε αρχεία",
+    "Files app plugin to add comments to files" : "Πρόσθετο εφαρμογής Αρχεία για προσθήκη σχολίων σε αρχεία",
     "Edit comment" : "Επεξεργασία σχολίου",
     "Delete comment" : "Διαγραφή σχολίου",
     "Cancel edit" : "Ακύρωση επεξεργασίας",
     "New comment" : "Νέο σχόλιο",
+    "Write a comment …" : "Γράψτε ένα σχόλιο …",
     "Post comment" : "Αναρτήστε σχόλιο",
+    "@ for mentions, : for emoji, / for smart picker" : "@ για αναφορές, : για emoji, / για έξυπνο επιλογέα",
+    "Could not reload comments" : "Αδυναμία επανάφόρτωσης σχολίων",
+    "Failed to mark comments as read" : "Αποτυχία σήμανσης σχολίων ως αναγνωσμένα",
     "Unable to load the comments list" : "Δεν είναι δυνατή η μεταφόρτωση της λίστας σχολίων.",
     "No comments yet, start the conversation!" : "Δεν υπάρχουν σχόλια, ξεκινήστε την συζήτηση!",
     "No more messages" : "Δεν υπάρχουν άλλα μηνύματα",
