@@ -17,6 +17,7 @@ OC.L10N.register(
     "Delete comment" : "Ezabatu iruzkina",
     "Cancel edit" : "Utzi editatzeari",
     "New comment" : "Iruzkin berria",
+    "Write a comment …" : "Idatzi iruzkin bat ...",
     "Post comment" : "Argitaratu iruzkina",
     "@ for mentions, : for emoji, / for smart picker" : "@ aipamenetarako, : emojientzako, / hautatzaile adimentsurako",
     "Could not reload comments" : "Ezin izan dira iruzkinak freskatu",
@@ -30,7 +31,6 @@ OC.L10N.register(
     "An error occurred while trying to edit the comment" : "Errorea gertatu da iruzkina editatzen saiatzean",
     "Comment deleted" : "Iruzkina ezabatu da",
     "An error occurred while trying to delete the comment" : "Errorea gertatu da iruzkina ezabatzen saiatzean",
-    "An error occurred while trying to create the comment" : "Errorea gertatu da iruzkina sortzen saiatzean",
-    "Write a comment …" : "Idatzi iruzkin bat ..."
+    "An error occurred while trying to create the comment" : "Errorea gertatu da iruzkina sortzen saiatzean"
 },
 "nplurals=2; plural=(n != 1);");
