@@ -10,7 +10,7 @@ OC.L10N.register(
     "{author} commented on {file}" : "{author} a commenté sur {file}",
     "<strong>Comments</strong> for files" : "<strong>Commentaires</strong> sur les fichiers",
     "Files" : "Fichiers",
-    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Vous avez été mentionné sur « {file} », dans un commentaire par un compte qui depuis a été supprimé",
+    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Vous avez été mentionné·e dans « {file} », dans un commentaire d'un compte qui a été supprimé depuis",
     "{user} mentioned you in a comment on \"{file}\"" : "{user} vous a mentionné dans un commentaire sur « {file} »",
     "Files app plugin to add comments to files" : "Plugin Fichiers app pour ajouter des commentaires aux fichiers",
     "Edit comment" : "Modifier le commentaire",
@@ -21,16 +21,16 @@ OC.L10N.register(
     "Post comment" : "Publier le commentaire",
     "@ for mentions, : for emoji, / for smart picker" : "@ pour les mentions, : pour les émojis, / pour le sélecteur intelligent",
     "Could not reload comments" : "Impossible de recharger les commentaires",
+    "Failed to mark comments as read" : "Les commentaires n'ont pas été marqués comme lus",
+    "Unable to load the comments list" : "Impossible de charger la liste des commentaires",
     "No comments yet, start the conversation!" : "Il n'y a aucun commentaire, démarrez la conversation !",
     "No more messages" : "Aucun autre message",
     "Retry" : "Réessayer",
-    "Failed to mark comments as read" : "Les commentaires n'ont pas été marqués comme lus",
-    "Unable to load the comments list" : "Impossible de charger la liste des commentaires",
     "_1 new comment_::_{unread} new comments_" : ["1 nouveau commentaire","{unread} nouveaux commentaires","{unread} nouveaux commentaires"],
     "Comment" : "Commenter",
-    "An error occurred while trying to edit the comment" : "Une erreur s'est produite lors de la tentative de modification du commentaire",
+    "An error occurred while trying to edit the comment" : "Une erreur est survenue lors de la tentative de modification du commentaire",
     "Comment deleted" : "Commentaire supprimé",
-    "An error occurred while trying to delete the comment" : "Une erreur s'est produite lors de la tentative de suppression du commentaire",
-    "An error occurred while trying to create the comment" : "Une erreur s'est produite lors de la tentative de création du commentaire"
+    "An error occurred while trying to delete the comment" : "Une erreur est survenue lors de la tentative de suppression du commentaire",
+    "An error occurred while trying to create the comment" : "Une erreur est survenue lors de la tentative de création du commentaire"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
