@@ -21,17 +21,16 @@ OC.L10N.register(
     "Post comment" : "張貼留言",
     "@ for mentions, : for emoji, / for smart picker" : "@ 表示提及，: 表示表情符號，/ 表示智慧型選取",
     "Could not reload comments" : "無法重新載入留言",
+    "Failed to mark comments as read" : "無法將留言標記為已讀",
+    "Unable to load the comments list" : "無法載入留言列表",
     "No comments yet, start the conversation!" : "尚無留言，開始討論！",
     "No more messages" : "沒有其他訊息",
     "Retry" : "重試",
-    "Failed to mark comments as read" : "無法將留言標記為已讀",
-    "Unable to load the comments list" : "無法載入留言列表",
     "_1 new comment_::_{unread} new comments_" : ["{unread} 則新留言"],
     "Comment" : "留言",
     "An error occurred while trying to edit the comment" : "嘗試編輯留言時發生錯誤",
     "Comment deleted" : "留言已刪除",
     "An error occurred while trying to delete the comment" : "嘗試刪除留言時發生錯誤",
-    "An error occurred while trying to create the comment" : "嘗試建立留言時發生錯誤",
-    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "一位已被刪除的使用者在「{file}」的留言中提到您"
+    "An error occurred while trying to create the comment" : "嘗試建立留言時發生錯誤"
 },
 "nplurals=1; plural=0;");
