@@ -3,13 +3,6 @@ OC.L10N.register(
     {
     "Dashboard" : "대시보드",
     "Dashboard app" : "대시보드 앱",
-    "Customize" : "사용자 지정",
-    "Edit widgets" : "위젯 편집",
-    "Weather service" : "날씨 서비스",
-    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "개인정보 보호를 위해 사용자를 대신해 Nextcloud 서버에서 요청하므로 개인정보를 수신하지 않습니다.",
-    "Weather data from Met.no" : "Met.no의 날씨 데이터",
-    "geocoding with Nominatim" : "Nominatim으로 지오 코딩",
-    "elevation data from OpenTopoData" : "OpenTopoData의 고도 데이터",
     "Weather" : "날씨",
     "Status" : "상태",
     "Good morning" : "좋은 아침입니다.",
@@ -19,6 +12,13 @@ OC.L10N.register(
     "Good evening" : "안녕하세요.",
     "Good evening, {name}" : "안녕하세요, {name}님.",
     "Hello" : "안녕하세요.",
-    "Hello, {name}" : "안녕하세요, {name}님."
+    "Hello, {name}" : "안녕하세요, {name}님.",
+    "Customize" : "사용자 지정",
+    "Edit widgets" : "위젯 편집",
+    "Weather service" : "날씨 서비스",
+    "Weather data from Met.no" : "Met.no의 날씨 데이터",
+    "geocoding with Nominatim" : "Nominatim으로 지오 코딩",
+    "elevation data from OpenTopoData" : "OpenTopoData의 고도 데이터",
+    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "개인정보 보호를 위해 사용자를 대신해 Nextcloud 서버에서 요청하므로 개인정보를 수신하지 않습니다."
 },
 "nplurals=1; plural=0;");
