@@ -19,18 +19,15 @@ use Sabre\Xml\Writer;
 class TagList implements Element {
 	public const NS_OWNCLOUD = 'http://owncloud.org/ns';
 
-	/**
-	 * tags
-	 *
-	 * @var array
-	 */
-	private $tags;
-
 	/**
 	 * @param array $tags
 	 */
-	public function __construct(array $tags) {
-		$this->tags = $tags;
+	public function __construct(
+		/**
+		 * tags
+		 */
+		private array $tags,
+	) {
 	}
 
 	/**
