@@ -45,14 +45,12 @@ OC.L10N.register(
     "Basic encryption module" : "Bazĉifrada modulo",
     "Your private key password no longer matches your log-in password." : "La pasvorto de via privata ŝlosilo ne plu kongruas kun via ensaluta pasvorto.",
     "Set your old private key password to your current log-in password:" : "Agordi la pasvorton de via antaŭa privata ŝlosilo al via nuna ensaluta pasvorto:",
-    " If you don't remember your old password you can ask your administrator to recover your files." : "Se vi ne memoras vian antaŭan pasvorton, vi povas peti al via administranto restaŭri viajn dosierojn.",
     "Old log-in password" : "Malnova ensaluta pasvorto",
     "Current log-in password" : "Nuna ensaluta pasvorto",
     "Update Private Key Password" : "Ĝisdatigi la pasvorton de la malpublika ŝlosilo",
     "Enable password recovery:" : "Ŝalti restaŭron de pasvorto:",
     "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Ŝalti tiun opcion ebligas al vi rehavi aliron al viaj ĉifritaj dosierojn okaze de pasvorta perdo.",
     "Enabled" : "Ŝaltita",
-    "Disabled" : "Malŝaltita",
-    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "La restaŭroŝlosilo estas kroma ĉifroŝlosilo, kiu uziĝas por ĉifri dosierojn. Ĝi ebligas restaŭron el dosieroj de uzanto, se la uzanto forgesas sian pasvorton."
+    "Disabled" : "Malŝaltita"
 },
 "nplurals=2; plural=(n != 1);");
