@@ -66,7 +66,7 @@ OC.L10N.register(
     "Your ownership transfer of {path} was denied by {user}." : "Die Besitzübertragung von {path} wurde von {user} abgelehnt.",
     "Ownership transfer failed" : "Besitzübertragung fehlgeschlagen",
     "Your ownership transfer of {path} to {user} failed." : "Die Besitzübertragung von {path} an {user} ist fehlgeschlagen.",
-    "The ownership transfer of {path} from {user} failed." : "Die Übertragung von {path} von {user} ist fehlgeschlagen.",
+    "The ownership transfer of {path} from {user} failed." : "Die Übertragung von {path} ist fehlgeschlagen.",
     "Ownership transfer done" : "Besitzübertragung abgeschlossen",
     "Your ownership transfer of {path} to {user} has completed." : "Die Besitzübertragung von {path} an {user} wurde fertiggestellt.",
     "The ownership transfer of {path} from {user} has completed." : "Die Besitzübertragung von {path} durch {user} wurde fertiggestellt.",
@@ -108,43 +108,6 @@ OC.L10N.register(
     "Type" : "Typ",
     "Active filters" : "Aktive Filter",
     "Remove filter" : "Filter entfernen",
-    "Appearance" : "Aussehen",
-    "Show hidden files" : "Versteckte Dateien anzeigen",
-    "Show file type column" : "Dateityp-Spalte anzeigen",
-    "Show file extensions" : "Dateierweiterungen anzeigen",
-    "Crop image previews" : "Bildvorschauen zuschneiden",
-    "General" : "Allgemein",
-    "Sort favorites first" : "Favoriten zuerst sortieren",
-    "Sort folders before files" : "Ordner vor Dateien sortieren",
-    "Enable folder tree view" : "Ordnerbaumansicht aktivieren",
-    "Default view" : "Standardansicht",
-    "All files" : "Alle Dateien",
-    "Personal files" : "Persönliche Dateien",
-    "Additional settings" : "Zusätzliche Einstellungen",
-    "Actions" : "Aktionen",
-    "File actions" : "Dateiaktionen",
-    "Selection" : "Auswahl",
-    "Select all files" : "Alle Dateien auswählen",
-    "Deselect all" : "Auswahl aufheben",
-    "Select or deselect" : "Aus- oder abwählen",
-    "Select a range" : "Einen Bereich auswählen",
-    "Navigation" : "Navigation",
-    "Go to parent folder" : "Zum übergeordneten Ordner wechseln",
-    "Go to file above" : "Zur Datei darüber wechseln",
-    "Go to file below" : "Zur Datei darunter wechseln",
-    "Go left in grid" : "Im Raster nach links gehen",
-    "Go right in grid" : "Im Raster nach rechts gehen",
-    "View" : "Ansehen",
-    "Toggle grid view" : "Rasteransicht umschalten",
-    "Open file sidebar" : "Datei-Seitenleiste öffnen",
-    "Show those shortcuts" : "Diese Tastaturkürzel anzeigen",
-    "Warnings" : "Warnungen",
-    "Warn before changing a file extension" : "Vor der Änderung einer Dateierweiterung warnen",
-    "Warn before deleting a file" : "Warnung vor dem Löschen einer Datei",
-    "WebDAV URL" : "WebDAV-URL",
-    "Create an app password" : "Ein App-Passwort erstellen",
-    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Erforderlich für die WebDAV-Authentifizierung, da für dieses Konto die Zwei-Faktor-Authentifizierung aktiviert ist.",
-    "How to access files using WebDAV" : "So greifst du mit WebDAV auf Dateien zu",
     "Total rows summary" : "Zusammenfassung aller Zeilen",
     "Toggle selection for all files and folders" : "Auswahl für alle Dateien und Ordner umschalten",
     "Name" : "Name",
@@ -153,6 +116,7 @@ OC.L10N.register(
     "{displayName}: failed on some elements" : "{displayName}: Ist bei einigen Elementen fehlgeschlagen",
     "{displayName}: done" : "{displayName}: Abgeschlossen",
     "{displayName}: failed" : "{displayName}: Fehlgeschlagen",
+    "Actions" : "Aktionen",
     "(selected)" : "(ausgewählt)",
     "List of files and folders." : "Liste der Dateien und Ordner",
     "You have used your space quota and cannot upload files anymore." : "Dein Speicherplatzkontigent ist aufgebraucht, Du kannst keine weiteren Dateien hochladen.",
@@ -160,8 +124,8 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Diese Liste wird aus Performance-Gründen nicht vollständig angezeigt. Die Dateien werden angezeigt, wenn du durch die Liste navigierst.",
     "File not found" : "Datei nicht gefunden",
     "_{count} selected_::_{count} selected_" : ["{count} ausgewählt","{count} ausgewählt"],
-    "Search everywhere …" : "Überall suchen …",
-    "Search here …" : "Hier suchen …",
+    "Search everywhere …" : "Überall suchen  …",
+    "Search here …" : "Hier suchen …",
     "Search scope options" : "Suchbereichsoptionen",
     "Search here" : "Hier suchen",
     "{usedQuotaByte} used" : "{usedQuotaByte} verwendet",
@@ -180,7 +144,7 @@ OC.L10N.register(
     "Failed to refresh filename sanitization status." : "Der Status der Dateinamenbereinigung konnte nicht aktualisiert werden.",
     "Filename sanitization in progress." : "Dateinamenbereinigung läuft.",
     "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Es wurden bereits {processedUsers} von {totalUsers} Konten bearbeitet.",
-    "Preparing …" : "Bereite vor …",
+    "Preparing …" : "Bereite vor …",
     "Refresh" : "Aktualisieren",
     "All files have been santized for Windows filename support." : "Alle Dateien wurden für die Windows-Dateinamenunterstützung bereinigt.",
     "Some files could not be sanitized, please check your logs." : "Einige Dateien konnten nicht bereinigt werden. Bitte überprüfen Sie Ihre Protokolle.",
@@ -195,7 +159,7 @@ OC.L10N.register(
     "Sanitize filenames" : "Dateinamen bereinigen",
     "(starting)" : "(Starte)",
     "Fill template fields" : "Vorlagenfelder ausfüllen",
-    "Submitting fields …" : "Felder werden übermittelt …",
+    "Submitting fields …" : "Felder werden übermittelt …",
     "Submit" : "Übermitteln",
     "Choose a file or folder to transfer" : "Datei oder Ordner zur Übertragung auswählen",
     "Transfer" : "Übertragen",
@@ -219,7 +183,6 @@ OC.L10N.register(
     "Do not show this dialog again." : "Diesen Dialog nicht mehr anzeigen.",
     "Select file or folder to link to" : "Datei oder Ordner zum Verknüpfen auswählen",
     "Choose {file}" : "{file} auswählen",
-    "Files settings" : "Dateien-Einstellungen",
     "Share" : "Teilen",
     "Shared by link" : "Über einen Link geteilt",
     "Shared" : "Geteilt",
@@ -238,6 +201,63 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Lade Inhalte hoch oder synchronisiere sie mit deinen Geräten!",
     "Go back" : "Zurückgehen",
     "Views" : "Ansichten",
+    "Files settings" : "Dateien-Einstellungen",
+    "Your files" : "Deine Dateien",
+    "Open in files" : "In Dateien öffnen",
+    "File cannot be accessed" : "Auf die Datei kann nicht zugegriffen werden",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Die Datei konnte nicht gefunden werden oder Du hast keine Berechtigung, um sie anzuzeigen. Bitte den Absender, die Datei zu teilen.",
+    "No search results for “{query}”" : "Keine Suchergebnisse für \"{query}\"",
+    "Search for files" : "Nach Dateien suchen",
+    "Clipboard is not available" : "Zwischenablage ist nicht verfügbar",
+    "WebDAV URL copied" : "WebDAV-URL kopiert",
+    "General" : "Allgemein",
+    "Default view" : "Standardansicht",
+    "All files" : "Alle Dateien",
+    "Personal files" : "Persönliche Dateien",
+    "Sort favorites first" : "Favoriten zuerst sortieren",
+    "Sort folders before files" : "Ordner vor Dateien sortieren",
+    "Folder tree" : "Ordnerbaum",
+    "Appearance" : "Aussehen",
+    "Show hidden files" : "Versteckte Dateien anzeigen",
+    "Show file type column" : "Dateityp-Spalte anzeigen",
+    "Show file extensions" : "Dateierweiterungen anzeigen",
+    "Crop image previews" : "Bildvorschauen zuschneiden",
+    "Additional settings" : "Zusätzliche Einstellungen",
+    "WebDAV" : "WebDAV",
+    "WebDAV URL" : "WebDAV-URL",
+    "Copy" : "Kopieren",
+    "How to access files using WebDAV" : "So greifst du mit WebDAV auf Dateien zu",
+    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "Für dein Konto ist die Zwei-Faktor-Authentifizierung aktiviert. Zur Verbindung eines externen WebDAV-Clients ist daher die Verwendung eines App-Passwortes erforderlich.",
+    "Warnings" : "Warnungen",
+    "Warn before changing a file extension" : "Vor der Änderung einer Dateierweiterung warnen",
+    "Warn before deleting files" : "Vor dem Löschen von Dateien warnen",
+    "Keyboard shortcuts" : "Tastaturkürzel",
+    "File actions" : "Dateiaktionen",
+    "Rename" : "Umbenennen",
+    "Delete" : "Löschen",
+    "Add or remove favorite" : "Favorit hinzufügen oder entfernen",
+    "Manage tags" : "Schlagworte verwalten",
+    "Selection" : "Auswahl",
+    "Select all files" : "Alle Dateien auswählen",
+    "Deselect all" : "Auswahl aufheben",
+    "Select or deselect" : "Aus- oder abwählen",
+    "Select a range" : "Einen Bereich auswählen",
+    "Navigation" : "Navigation",
+    "Go to parent folder" : "Zum übergeordneten Ordner wechseln",
+    "Go to file above" : "Zur Datei darüber wechseln",
+    "Go to file below" : "Zur Datei darunter wechseln",
+    "Go left in grid" : "Im Raster nach links gehen",
+    "Go right in grid" : "Im Raster nach rechts gehen",
+    "View" : "Ansehen",
+    "Toggle grid view" : "Rasteransicht umschalten",
+    "Open file sidebar" : "Datei-Seitenleiste öffnen",
+    "Show those shortcuts" : "Diese Tastaturkürzel anzeigen",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Ermöglicht die Einschränkung von Dateinamen, um sicherzustellen, dass Dateien mit allen Clients synchronisiert werden können. Standardmäßig sind alle unter POSIX (z. B. Linux oder macOS) gültigen Dateinamen zulässig.",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Nach Aktivierung der Windows-kompatiblen Dateinamen können vorhandene Dateien nicht mehr geändert, aber von ihrem Besitzer in gültige neue Namen umbenannt werden.",
+    "Failed to toggle Windows filename support" : "Windows Dateinamenunterstützung konnte nicht umgeschaltet werden",
+    "Files compatibility" : "Dateikompatibilität",
+    "Enforce Windows compatibility" : "Windows-Kompatibilität erzwingen",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Dadurch werden Dateinamen blockiert, die auf Windows-Systemen unzulässig sind, z. B. reservierte Namen oder Sonderzeichen. Die Kompatibilität der Groß-/Kleinschreibung wird dadurch jedoch nicht erzwungen.",
     "You" : "Du",
     "Shared multiple times with different people" : "Mehrmals mit verschiedenen Personen geteilt",
     "Unable to change the favorite state of the file" : "Der Favoriten-Status der Datei kann nicht geändert werden",
@@ -246,38 +266,25 @@ OC.L10N.register(
     "Remove from favorites" : "Aus Favoriten entfernen",
     "Add to favorites" : "Zu den Favoriten hinzufügen",
     "Tags" : "Schlagworte",
-    "Your files" : "Deine Dateien",
-    "Open in files" : "In Dateien öffnen",
-    "File cannot be accessed" : "Auf die Datei kann nicht zugegriffen werden",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Die Datei konnte nicht gefunden werden oder Du hast keine Berechtigung, um sie anzuzeigen. Bitte den Absender, die Datei zu teilen.",
-    "No search results for “{query}”" : "Keine Suchergebnisse für \"{query}\"",
-    "Search for files" : "Nach Dateien suchen",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Ermöglicht die Einschränkung von Dateinamen, um sicherzustellen, dass Dateien mit allen Clients synchronisiert werden können. Standardmäßig sind alle unter POSIX (z. B. Linux oder macOS) gültigen Dateinamen zulässig.",
-    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Nach Aktivierung der Windows-kompatiblen Dateinamen können vorhandene Dateien nicht mehr geändert, aber von ihrem Besitzer in gültige neue Namen umbenannt werden.",
-    "Failed to toggle Windows filename support" : "Windows Dateinamenunterstützung konnte nicht umgeschaltet werden",
-    "Files compatibility" : "Dateikompatibilität",
-    "Enforce Windows compatibility" : "Windows-Kompatibilität erzwingen",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Dadurch werden Dateinamen blockiert, die auf Windows-Systemen unzulässig sind, z. B. reservierte Namen oder Sonderzeichen. Die Kompatibilität der Groß-/Kleinschreibung wird dadurch jedoch nicht erzwungen.",
     "Blank" : "Leer",
     "Unable to create new file from template" : "Neue Datei konnte nicht aus Vorlage erstellt werden",
     "Pick a template for {name}" : "Eine Vorlage für {name} wählen",
     "Create a new file with the selected template" : "Eine neue Datei anhand der ausgewählten Vorlage erstellen",
     "Creating file" : "Datei erstellen",
     "Save as {displayName}" : "Speichern als {displayName}",
-    "Save as …" : "Speichern als …",
-    "Converting files …" : "Dateien werden konvertiert …",
+    "Save as …" : "Speichern als …",
+    "Converting files …" : "Dateien werden konvertiert …",
     "Failed to convert files: {message}" : "Fehler beim Konvertieren der Dateien: {message}",
     "All files failed to be converted" : "Alle Dateien konnten nicht konvertiert werden",
     "One file could not be converted: {message}" : "Eine Datei konnte nicht konvertiert werden: {message}",
-    "_%n file could not be converted_::_%n files could not be converted_" : ["%n Datei konnte nicht konvertiert werden","%n Dateien konnten nicht konvertiert werden"],
-    "_%n file converted_::_%n files converted_" : ["%n Datei konvertiert","%n Dateien konvertiert"],
-    "Files converted" : "Dateien konvertiert",
+    "_One file could not be converted_::_%n files could not be converted_" : ["Eine Datei konnte nicht konvertiert werden","%n Dateien konnten nicht konvertiert werden"],
+    "_One file successfully converted_::_%n files successfully converted_" : ["Eine Datei konvertiert","%n Dateien konvertiert"],
+    "Files successfully converted" : "Dateien konvertiert",
     "Failed to convert files" : "Dateien konnten nicht konvertiert werden",
-    "Converting file …" : "Datei wird konvertiert …",
+    "Converting file …" : "Datei wird konvertiert …",
     "File successfully converted" : "Datei konvertiert",
     "Failed to convert file: {message}" : "Fehler beim Konvertieren der Datei: {message}",
     "Failed to convert file" : "Datei konnte nicht konvertiert werden",
-    "Delete" : "Löschen",
     "Leave this share" : "Diese Freigabe verlassen",
     "Leave these shares" : "Diese Freigaben verlassen",
     "Disconnect storage" : "Speicher trennen",
@@ -295,9 +302,8 @@ OC.L10N.register(
     "Download" : "Herunterladen",
     "The requested file is not available." : "Die angeforderte Datei ist nicht verfügbar.",
     "The requested files are not available." : "Die angeforderten Dateien sind nicht verfügbar.",
-    "Add or remove favorite" : "Favorit hinzufügen oder entfernen",
-    "Moving \"{source}\" to \"{destination}\" …" : "Verschiebe \"{source}\" nach \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Kopiere \"{source}\" nach \"{destination}\" …",
+    "Moving \"{source}\" to \"{destination}\" …" : "Verschiebe \"{source}\" nach \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Kopiere \"{source}\" nach \"{destination}\" …",
     "Destination is not a folder" : "Ziel ist kein Ordner",
     "This file/folder is already in that directory" : "Diese Datei oder Ordner ist bereits in diesem Verzeichnis vorhanden",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Eine Datei oder ein Ordner kann nicht auf sich selbst oder in einen Unterordner von sich selbst verschoben werden.",
@@ -308,20 +314,18 @@ OC.L10N.register(
     "The file does not exist anymore" : "Die Datei existiert nicht mehr",
     "Choose destination" : "Ziel wählen",
     "Copy to {target}" : "Nach {target} kopieren",
-    "Copy" : "Kopieren",
     "Move to {target}" : "Nach {target} verschieben",
     "Move" : "Verschieben",
     "Move or copy operation failed" : "Verschiebe- oder Kopieroperation ist fehlgeschlagen.",
     "Move or copy" : "Verschieben oder kopieren",
     "Open folder {displayName}" : "Ordner {displayName} öffnen",
-    "Open in Files" : "In Dateien öffnen",
+    "Open in Files" : "In \"Dateien\" öffnen",
     "Open locally" : "Lokal öffnen",
     "Failed to redirect to client" : "Umleitung zum Client fehlgeschlagen",
     "Open file locally" : "Datei lokal öffnen",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Die Datei sollte sich jetzt auf deinem Gerät öffnen. Wenn dies nicht der Fall ist, überprüfe, ob du die Desktop-App installiert hast.",
     "Retry and close" : "Erneut versuchen und schließen",
     "Open online" : "Online öffnen",
-    "Rename" : "Umbenennen",
     "Details" : "Details",
     "View in folder" : "In Ordner anzeigen",
     "Today" : "Heute",
@@ -359,7 +363,7 @@ OC.L10N.register(
     "Conflicts resolution skipped" : "Konfliktlösung übersprungen",
     "Upload cancelled" : "Hochladen abgebrochen",
     "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" konnte nicht umbenannt werden, da es nicht mehr existiert.",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name \"{newName}\" wird bereits im Ordner \"{dir}\" verwendet. Bitte wähle einen anderen Namen.",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name \"{newName}“ wird bereits im Ordner \"{dir}“ verwendet. Bitte wähle einen anderen Namen.",
     "Could not rename \"{oldName}\"" : "\"{oldName}\" konnte nicht umbenannt werden.",
     "This operation is forbidden" : "Diese Operation ist nicht erlaubt",
     "This folder is unavailable, please try again later or contact the administration" : "Dieser Ordner ist nicht verfügbar. Bitte später erneut versuchen oder an die Administration wenden",
@@ -377,7 +381,6 @@ OC.L10N.register(
     "No favorites yet" : "Noch keine Favoriten vorhanden",
     "Files and folders you mark as favorite will show up here" : "Dateien und Ordner, die als Favoriten markiert werden, erscheinen hier",
     "List of your files and folders." : "Liste deiner Dateien und Ordner",
-    "Folder tree" : "Ordnerbaum",
     "List of your files and folders that are not shared." : "Liste deiner Dateien und Ordner, die nicht geteilt wurden.",
     "No personal files found" : "Keine persönlichen Dateien gefunden",
     "Files that are not shared will show up here." : "Dateien, die nicht geteilt wurden, werden hier angezeigt.",
@@ -391,28 +394,119 @@ OC.L10N.register(
     "Select all" : "Alle auswählen",
     "Upload too large" : "Der Upload ist zu groß",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Die Datei überschreitet die Maximalgröße für Uploads auf diesem Server.",
-    "%1$s (renamed)" : "%1$s (umbenannt)",
-    "renamed file" : "Umbenannte Datei",
+    "File could not be found" : "Datei konnte nicht gefunden werden",
+    "Show list view" : "Listenansicht anzeigen",
+    "Show grid view" : "Kachelansicht anzeigen",
+    "Close" : "Schließen",
+    "Could not create folder \"{dir}\"" : "Der Ordner konnte nicht erstellt werden \"{dir}\"",
+    "This will stop your current uploads." : "Hiermit werden die aktuellen Uploads angehalten.",
+    "Upload cancelled." : "Hochladen abgebrochen.",
+    "Processing files …" : "Dateien werden verarbeitet …",
+    "…" : "…",
+    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Die Datei {filename} kann nicht hochgeladen werden, da sie entweder ein Verzeichnis oder 0 Bytes groß ist",
+    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nicht genügend freier Speicherplatz, du möchtest{size1} hochladen, es sind jedoch nur noch {size2} verfügbar.",
+    "Target folder \"{dir}\" does not exist any more" : "Ziel-Verzeichnis \"{dir}\" existiert nicht mehr",
+    "An unknown error has occurred" : "Es ist ein unbekannter Fehler aufgetreten",
+    "File could not be uploaded" : "Datei konnte nicht hochgeladen werden.",
+    "Uploading …" : "Lade hoch …",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "Lade hoch … ({currentNumber}/{total})",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} von {totalSize} ({bitrate})",
+    "Uploading that item is not supported" : "Hochladen von Daten dieser Art wird nicht unterstützt.",
+    "Error when assembling chunks, status code {status}" : "Fehler beim Zusammenführen der Teile (Chunks), Fehlermeldung {status}",
+    "Choose target folder" : "Zielordner wählen",
+    "Set reminder" : "Erinnerung erstellen",
+    "Edit locally" : "Lokal bearbeiten",
+    "Open" : "Öffnen",
+    "Could not load info for file \"{file}\"" : "Die Informationen zur Datei \"{file}\" konnten nicht geladen werden",
+    "Please select tag(s) to add to the selection" : "Bitte das/die Schlagwort(e) auswählen, das/die zur Auswahl hinzugefügt werden soll(en)",
+    "Apply tag(s) to selection" : "Schlagwort(e) auf die Auswahl anwenden",
+    "Select directory \"{dirName}\"" : "Verzeichnis \"{dirName}\" auswählen",
+    "Select file \"{fileName}\"" : "Datei \"{fileName}\" auswählen",
+    "Unable to determine date" : "Datum konnte nicht ermittelt werden",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Dieses Verzeichnis ist nicht verfügbar, bitte die Logdateien überprüfen oder die Administration kontaktieren.",
+    "Could not move \"{file}\", target exists" : "\"{file}\" konnte nicht verschoben werden, Ziel existiert bereits",
+    "Could not move \"{file}\"" : "\"{file}\" konnte nicht verschoben werden",
+    "copy" : "Kopie",
+    "Could not copy \"{file}\", target exists" : "\"{file}\" konnte nicht kopiert werden, Ziel existiert bereits",
+    "Could not copy \"{file}\"" : "\"{file}\" konnte nicht kopiert werden",
+    "Copied {origin} inside {destination}" : "{origin} wurde nach {destination} kopiert",
+    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} und {nbfiles} weitere Dateien wurden nach {destination} kopiert",
+    "{newName} already exists" : "{newName} existiert bereits",
+    "Could not create file \"{file}\"" : "Die Datei konnte nicht erstellt werden \"{file}\"",
+    "Could not create file \"{file}\" because it already exists" : "Die Datei \"{file}\" konnte nicht erstellt werden, da diese bereits existiert.",
+    "Could not create folder \"{dir}\" because it already exists" : "Der Ordner \"{dir}\" konnte nicht erstellt werden, da dieser bereits existiert",
+    "Could not fetch file details \"{file}\"" : "Details zu \"{file}\" konnten nicht ermittelt werden",
+    "Error deleting file \"{fileName}\"." : "Fehler beim Löschen der Datei \"{fileName}\".",
+    "No search results in other folders for {tag}{filter}{endtag}" : "Keine Suchergebnisse in anderen Ordnern für {tag}{filter}{endtag}",
+    "Enter more than two characters to search in other folders" : "Gib mehr als zwei Zeichen ein, um in anderen Ordnern zu suchen.",
+    "{dirs} and {files}" : "{dirs} und {files}",
+    "_including %n hidden_::_including %n hidden_" : ["%n versteckte eingeschlossen","%n versteckte eingeschlossen"],
+    "You do not have permission to upload or create files here" : "Du hast keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
+    "_Uploading %n file_::_Uploading %n files_" : ["%n Datei wird hochgeladen","%n Dateien werden hochgeladen"],
+    "New" : "Neu",
+    "New file/folder menu" : "Menü für neue Datei/Ordner",
+    "Select file range" : "Dateibereich auswählen",
+    "{used}%" : "{used} %",
+    "{used} used" : "{used} verwendet",
+    "\"{name}\" is an invalid file name." : "\"{name}\" ist kein gültiger Dateiname.",
+    "File name cannot be empty." : "Der Dateiname darf nicht leer sein.",
+    "\"/\" is not allowed inside a file name." : "\"/\" ist innerhalb eines Dateinamens nicht erlaubt.",
+    "\"{name}\" is not an allowed filetype" : "\"{name}\" ist kein erlaubter Dateityp",
+    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Der Speicher von {owner} ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
+    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Gruppenordner \"{mountPoint}\" ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
+    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Externer Speicher \"{mountPoint}\" ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
+    "Your storage is full, files cannot be updated or synced anymore!" : "Dein Speicher ist voll, daher können keine Dateien mehr aktualisiert oder synchronisiert werden!",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Der Speicher von {owner} ist beinahe voll ({usedSpacePercent}%).",
+    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Gruppenordner \"{mountPoint}\" ist beinahe voll ({usedSpacePercent}%).",
+    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Externer Speicher \"{mountPoint}\" ist beinahe voll ({usedSpacePercent}%).",
+    "Your storage is almost full ({usedSpacePercent}%)." : "Dein Speicher ist beinahe voll ({usedSpacePercent}%).",
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["stimmt mit \"{filter}\" überein","stimmen mit \"{filter}\" überein"],
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Direktlink wurde kopiert (funktioniert nur für Personen, die Zugriff auf diese Datei/Ordner haben)",
+    "Path" : "Pfad",
+    "_%n byte_::_%n bytes_" : ["%n Byte","%n Bytes"],
+    "Favored" : "Favorisiert",
+    "Favor" : "Favorisieren",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Direktlink kopieren (funktioniert nur für Personen, die Zugriff auf diese Datei/Ordner haben)",
+    "Upload file" : "Datei hochladen",
+    "Not favored" : "Nicht favorisiert",
+    "An error occurred while trying to update the tags" : "Es ist ein Fehler beim Aktualisieren der Tags aufgetreten",
     "Upload (max. %s)" : "Hochladen (max. %s)",
-    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Nach Aktivierung der Windows-kompatiblen Dateinamen können vorhandene Dateien nicht mehr geändert, aber von ihrem Besitzer in gültige neue Namen umbenannt werden.",
-    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Nach dem Aktivieren dieser Einstellung ist es auch möglich, Dateien automatisch zu migrieren. Weitere Informationen finden sich in der Dokumentation zum \"occ\"-Befehl.",
+    "\"{displayName}\" action executed successfully" : "Aktion \"{displayName}\" ausgeführt",
+    "\"{displayName}\" action failed" : "Aktion \"{displayName}\" fehlgeschlagen",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" ist bei einigen Elementen fehlgeschlagen",
     "\"{displayName}\" batch action executed successfully" : "Stapelaktion \"{displayName}\" ausgeführt",
-    "\"{displayName}\" action failed" : "Aktion \"{displayName}\" fehlgeschlagen",
-    "Submitting fields …" : "Felder werden übermittelt …",
-    "\"{displayName}\" action executed successfully" : "Aktion \"{displayName}\" ausgeführt",
-    "Filter file names …" : "Dateinamen filtern …",
-    "Clipboard is not available" : "Zwischenablage ist nicht verfügbar",
+    "Submitting fields…" : "Felder werden übermittelt…",
+    "Filter filenames…" : "Dateinamen filtern…",
     "WebDAV URL copied to clipboard" : "WebDAV-URL in die Zwischenablage kopiert",
     "Enable the grid view" : "Kachelansicht aktivieren",
     "Enable folder tree" : "Ordnerstruktur aktivieren",
-    "WebDAV" : "WebDAV",
     "Copy to clipboard" : "In die Zwischenablage kopieren",
     "Use this address to access your Files via WebDAV" : "Diese Adresse benutzen, um über WebDAV auf deine Dateien zuzugreifen.",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Wenn du 2FA aktiviert hast, musst du ein neues App-Passwort erstellen und verwenden, indem du hier klickst.",
+    "Deletion cancelled" : "Löschen abgebrochen",
+    "Move cancelled" : "Verschieben abgebrochen",
+    "Cancelled move or copy of \"{filename}\"." : "Verschieben oder Kopieren von \"{filename}\" abgebrochen.",
+    "Cancelled move or copy operation" : "Verschieben oder Kopieren abgebrochen",
+    "Open details" : "Details öffnen",
+    "Photos and images" : "Fotos und Bilder",
+    "New folder creation cancelled" : "Erstellung des neuen Ordners abgebrochen",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} Ordner","{folderCount} Ordner"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} Datei","{fileCount} Dateien"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 Datei und {folderCount} Ordner","1 Datei und {folderCount} Ordner"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} Datei und 1 Ordner","{fileCount} Dateien und 1 Ordner"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} Dateien und {folderCount} Ordner",
+    "All folders" : "Alle Ordner",
+    "Personal Files" : "Persönliche Dateien",
+    "Text file" : "Textdatei",
+    "New text file.txt" : "Neue Textdatei file.txt",
+    "%1$s (renamed)" : "%1$s (umbenannt)",
+    "renamed file" : "Umbenannte Datei",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Nach Aktivierung der Windows-kompatiblen Dateinamen können vorhandene Dateien nicht mehr geändert, aber von ihrem Besitzer in gültige neue Namen umbenannt werden.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Nach dem Aktivieren dieser Einstellung ist es auch möglich, Dateien automatisch zu migrieren. Weitere Informationen finden sich in der Dokumentation zum Befehl „occ“.",
+    "Filter file names …" : "Dateinamen filtern …",
     "Prevent warning dialogs from open or reenable them." : "Öffnen von Warndialogen verhindern oder diese erneut aktivieren.",
     "Show a warning dialog when changing a file extension." : "Beim Ändern einer Dateierweiterung einen Warndialog anzeigen.",
-    "Keyboard shortcuts" : "Tastaturkürzel",
     "Speed up your Files experience with these quick shortcuts." : "Mit diesen Schnellzugriffen schneller mit Dateien arbeiten.",
     "Open the actions menu for a file" : "Aktionsmenü für eine Datei öffnen",
     "Rename a file" : "Eine Datei umbenennen",
@@ -428,24 +522,6 @@ OC.L10N.register(
     "Navigate to the file on the left (in grid mode)" : "Zur Datei links navigieren (in der Kachelansicht)",
     "Navigate to the file on the right (in grid mode)" : "Zur Datei rechts navigieren (in der Kachelansicht)",
     "Toggle the grid view" : "Kachelansicht umschalten",
-    "Open the sidebar for a file" : "Seitenleiste für eine Datei öffnen",
-    "Save as …" : "Speichern als …",
-    "Converting files …" : "Dateien werden konvertiert …",
-    "Converting file …" : "Datei wird konvertiert …",
-    "Deletion cancelled" : "Löschen abgebrochen",
-    "Edit locally" : "Lokal bearbeiten",
-    "Moving \"{source}\" to \"{destination}\" …" : "Verschiebe \"{source}\" nach \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Kopiere \"{source}\" nach \"{destination}\" …",
-    "Move cancelled" : "Verschieben abgebrochen",
-    "Cancelled move or copy of \"{filename}\"." : "Verschieben oder Kopieren von \"{filename}\" abgebrochen.",
-    "Cancelled move or copy operation" : "Verschieben oder Kopieren abgebrochen",
-    "Open details" : "Details öffnen",
-    "Photos and images" : "Fotos und Bilder",
-    "New folder creation cancelled" : "Erstellung des neuen Ordners abgebrochen",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Dieses Verzeichnis ist nicht verfügbar, bitte die Logdateien überprüfen oder die Administration kontaktieren.",
-    "All folders" : "Alle Ordner",
-    "Search everywhere …" : "Überall suchen  …",
-    "Search here …" : "Hier suchen …",
-    "Preparing …" : "Bereite vor …"
+    "Open the sidebar for a file" : "Seitenleiste für eine Datei öffnen"
 },
 "nplurals=2; plural=(n != 1);");
