@@ -13,7 +13,7 @@ OC.L10N.register(
     "Restored by {user}" : "Hersteld door {user}",
     "Renamed by {user}" : "Hernoemd door {user}",
     "Moved by {user}" : "Verplaatst door {user}",
-    "\"remote account\"" : "\"extern account\"",
+    "\"remote account\"" : "\"remote account\"",
     "You created {file}" : "Je creëerde {file}",
     "You created an encrypted file in {file}" : "Je creëerde een versleuteld bestand in {file}",
     "{user} created {file}" : "{user} creëerde {file}",
@@ -51,10 +51,6 @@ OC.L10N.register(
     "You do not have permission to create a file at the specified location" : "Je hebt geen toestemming om een bestand aan te maken op de opgegeven locatie",
     "The file could not be converted." : "Het bestand kon niet worden geconverteerd.",
     "Could not get relative path to converted file" : "Kon geen relatief pad naar geconverteerd bestand achterhalen",
-    "Limit must be a positive integer." : "Limiet moet een positief integer getal zijn.",
-    "The replacement character may only be a single character." : "Het vervangende teken kan alleen maar een enkel teken zijn",
-    "Filename sanitization already started." : "Opschonen bestandsnaam is al actief",
-    "No filename sanitization in progress." : "Opschonen bestandsnaam niet actief",
     "Favorite files" : "Favoriete bestanden",
     "No favorites" : "Geen favorieten",
     "More favorites" : "Meer favorieten",
@@ -108,48 +104,12 @@ OC.L10N.register(
     "Type" : "Type",
     "Active filters" : "Actieve filters",
     "Remove filter" : "Verwijder filter",
-    "Appearance" : "Uiterlijk",
-    "Show hidden files" : "Toon verborgen bestanden",
-    "Show file type column" : "Toon bestandstypekolom",
-    "Show file extensions" : "Laat bestand extensies zien",
-    "Crop image previews" : "Snij afbeeldingvoorbeelden bij",
-    "General" : "Algemeen",
-    "Sort favorites first" : "Sorteer eerst favorieten",
-    "Sort folders before files" : "Sorteer mappen voor bestanden",
-    "Default view" : "Standaardweergave",
-    "All files" : "Alle bestanden",
-    "Personal files" : "Persoonlijke bestanden",
-    "Additional settings" : "Aanvullende instellingen",
-    "Actions" : "Acties",
-    "File actions" : "Bestandsacties",
-    "Selection" : "Selectie",
-    "Select all files" : "Selecteer alle bestanden",
-    "Deselect all" : "Deselecteer alles",
-    "Select or deselect" : "Selecteren of deselecteren",
-    "Select a range" : "Selecteer een bereik",
-    "Navigation" : "Navigatie",
-    "Go to parent folder" : "Ga naar bovenliggende map",
-    "Go to file above" : "Ga naar bovenliggend bestand",
-    "Go to file below" : "Ga naar onderliggend bestand",
-    "Go left in grid" : "Ga naar links in raster",
-    "Go right in grid" : "Ga naar rechts in raster",
-    "View" : "Bekijken",
-    "Toggle grid view" : "Omschakelen roosterweergave",
-    "Open file sidebar" : "Open bestands zijbalk",
-    "Show those shortcuts" : "Toon die snelkoppelingen",
-    "Warnings" : "Waarschuwingen",
-    "Warn before changing a file extension" : "Waarschuw voordat een bestand extensie wordt gewijzigd",
-    "Warn before deleting a file" : "Waarschuwen voor verwijderen bestand",
-    "WebDAV URL" : "WebDAV URL",
-    "How to access files using WebDAV" : "Hoe bestanden te benaderen met WebDAV",
     "Total rows summary" : "Aantal rijen samenvatting",
     "Toggle selection for all files and folders" : "Wijzig selectie voor alle bestanden en mappen",
     "Name" : "Naam",
     "File type" : "Bestandstype",
     "Size" : "Grootte",
-    "{displayName}: failed on some elements" : "{displayName}: sommige onderdelen zijn mislukt",
-    "{displayName}: done" : "{displayName}: compleet",
-    "{displayName}: failed" : "{displayName}: mislukt",
+    "Actions" : "Acties",
     "(selected)" : "(geselecteerd)",
     "List of files and folders." : "Lijst van bestanden en mappen.",
     "You have used your space quota and cannot upload files anymore." : "Je hebt je ruimtequotum gebruikt en kan geen bestanden meer uploaden",
@@ -157,11 +117,7 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "De lijst is niet volledig verwerkt om de prestatie niet te beperken. De bestanden worden verder verwerkt als je door de lijst navigeert.",
     "File not found" : "Bestand niet gevonden",
     "_{count} selected_::_{count} selected_" : ["{count} geselecteerd","{count} geselecteerd"],
-    "Search everywhere …" : "Zoek in alles …",
-    "Search here …" : "Zoek hier …",
     "Search scope options" : "Zoek bereikopties",
-    "Search here" : "Zoek hier",
-    "Owner" : "Eigenaar",
     "{usedQuotaByte} used" : "{usedQuotaByte} gebruikt",
     "{used} of {quota} used" : "{used} van {quota} gebruikt",
     "{relative}% used" : "{relative}% gebruikt",
@@ -174,26 +130,10 @@ OC.L10N.register(
     "This name is already in use." : "De naam is al in gebruik.",
     "Create" : "Aanmaken",
     "Files starting with a dot are hidden by default" : "Bestanden die met een punt beginnen, worden standaard verborgen",
-    "Failed to start filename sanitization." : "Opschonen bestandsnaam is mislukt.",
-    "Failed to refresh filename sanitization status." : "Update van opschonen bestandsnaam status mislukt",
-    "Filename sanitization in progress." : "Opschonen bestandsnaam wordt uitgevoerd.",
-    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "{processedUsers} van {totalUsers} accounts zijn al verwerkt.",
-    "Preparing …" : "Voorbereiden …",
     "Refresh" : "Verversen",
-    "All files have been santized for Windows filename support." : "Alle bestanden zijn opgeschoond voor ondersteuning van Windows bestandsnamen.",
-    "Some files could not be sanitized, please check your logs." : "Enkele bestanden kunnen niet opgeschoond worden, controleer je logs.",
-    "Sanitization errors" : "Opschoon fouten",
-    "Not sanitized filenames" : "Niet opgeschoonde bestanden",
-    "Windows filename support has been enabled." : "Ondersteuning voor Windows bestanden is ingeschakeld",
-    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Ondanks dat dit gebruikers stopt om niet niet ondersteunde bestanden aan te maken, zijn bestaande bestanden nog niet hernoemd en kunnen dus de sync met Windows afbreken.",
-    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Je kan het hernoemen van ongeldige bestandsnamen starten, dit wordt gedaan in de achtergrond en duurt mogelijk even.",
-    "Please note that this may cause high workload on the sync clients." : "Wees gewaarschuwd dat dit een hoge werklast voor het syncen van clients kan opleveren.",
     "Limit" : "Limiet",
-    "This allows to configure how many users should be processed in one background job run." : "Met dit kan je configureren hoeveel gebruikers verwerkt worden tijdens een achtergrond taak. ",
-    "Sanitize filenames" : "Opschonen bestanden",
-    "(starting)" : "(begonnen)",
     "Fill template fields" : "Vul de velden van het sjabloon in",
-    "Submitting fields …" : "Toevoegen velden …",
+    "Submitting fields …" : "Velden verwerken ...",
     "Submit" : "Verwerken",
     "Choose a file or folder to transfer" : "Kies een bestand of map om over te dragen",
     "Transfer" : "Overdragen",
@@ -217,7 +157,6 @@ OC.L10N.register(
     "Do not show this dialog again." : "Laat dit dialoogvenster niet meer zien.",
     "Select file or folder to link to" : "Selecteer een bestand of map om naar te linken",
     "Choose {file}" : "Kies {file}",
-    "Files settings" : "Instellingen voor bestanden",
     "Share" : "Delen",
     "Shared by link" : "Gedeeld via link",
     "Shared" : "Gedeeld",
@@ -236,36 +175,75 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Upload je inhoud of synchroniseer met je apparaten!",
     "Go back" : "Ga terug",
     "Views" : "Bekeken",
-    "Loading …" : "Aan het laden...",
+    "Files settings" : "Instellingen voor bestanden",
     "Your files" : "Jouw bestanden",
     "Open in files" : "Open in bestanden",
     "File cannot be accessed" : "Bestand kan niet worden benaderd",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Dit bestand is niet gevonden of je hebt geen machtigingen om het te bekijken. Vraag de verzender om het met je te delen.",
     "No search results for “{query}”" : "No search results for “{query}”",
     "Search for files" : "Zoeken naar bestanden",
+    "Clipboard is not available" : "Klembord niet beschikbaar",
+    "General" : "Algemeen",
+    "Default view" : "Standaardweergave",
+    "All files" : "Alle bestanden",
+    "Personal files" : "Persoonlijke bestanden",
+    "Sort favorites first" : "Sorteer eerst favorieten",
+    "Sort folders before files" : "Sorteer mappen voor bestanden",
+    "Folder tree" : "Mapboom",
+    "Appearance" : "Uiterlijk",
+    "Show hidden files" : "Toon verborgen bestanden",
+    "Show file type column" : "Toon bestandstypekolom",
+    "Crop image previews" : "Snij afbeeldingvoorbeelden bij",
+    "Additional settings" : "Aanvullende instellingen",
+    "WebDAV" : "WebDAV",
+    "WebDAV URL" : "WebDAV URL",
+    "Copy" : "Kopiëren",
+    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "Tweefactorauthenticatie is ingeschakeld voor jouw account en daarom moet je een app-wachtwoord gebruiken om een externe WebDAV-client aan te sluiten.",
+    "Warnings" : "Waarschuwingen",
+    "Keyboard shortcuts" : "Toetsenbord sneltoetsen",
+    "File actions" : "Bestandsacties",
+    "Rename" : "Naam wijzigen",
+    "Delete" : "Verwijderen",
+    "Manage tags" : "Berichttags",
+    "Selection" : "Selectie",
+    "Select all files" : "Selecteer alle bestanden",
+    "Deselect all" : "Deselecteer alles",
+    "Navigation" : "Navigatie",
+    "View" : "Bekijken",
+    "Toggle grid view" : "Omschakelen roosterweergave",
+    "Show those shortcuts" : "Toon die snelkoppelingen",
     "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Toestaan om bestandsnamen te beperken om te borgen dat bestanden met alle cliënts gesynchroniseerd kunnen worden. Standaard zijn alle bestandsnamen valide die zijn toegestaan op POSIX (zoals Linux en macOS.)",
     "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Na inschakeling van Windows-compatibele bestandsnamen, kunnen bestaande bestanden niet meer worden gewijzigd, maar kunnen ze door de eigenaar worden hernoemd naar geldige nieuwe namen.",
-    "Failed to toggle Windows filename support" : "Omschakelen naar Windows bestand ondersteuning mislukt",
     "Files compatibility" : "Bestandscompatibiliteit",
     "Enforce Windows compatibility" : "Dwing Windows-compatibiliteit af",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Dit zal bestandsnamen blokkeren die niet toegestaan zijn op Windows-systemen, zoals gereserveerde namen of speciale tekens. Dit dwingt niet tot compatibiliteit voor hoofd- en kleine letters.",
+    "You" : "Jij",
+    "Shared multiple times with different people" : "Meerdere keren gedeeld met verschillende mensen",
+    "Unable to change the favorite state of the file" : "Kan de favoriete status van het bestand niet wijzigen",
+    "Error while loading the file data" : "Fout bij het lezen van de bestandsgegevens",
+    "Owner" : "Eigenaar",
+    "Remove from favorites" : "Verwijderen uit favorieten",
+    "Add to favorites" : "Aan favorieten toevoegen",
+    "Tags" : "Tags",
     "Blank" : "Blanco",
     "Unable to create new file from template" : "Kan geen nieuw bestand maken vanuit het sjabloon",
     "Pick a template for {name}" : "Kies een sjabloon voor {name}",
     "Create a new file with the selected template" : "Maak een nieuw bestand met het geselecteerde sjabloon",
     "Creating file" : "Maken bestand",
     "Save as {displayName}" : "Opslaan als {displayName}",
-    "Save as …" : "Bewaar als …",
-    "Converting files …" : "Bestanden converteren …",
+    "Save as …" : "Opslaan als...",
+    "Converting files …" : "Bestanden converteren ...",
     "Failed to convert files: {message}" : "Conversie van bestanden mislukt: {message} ",
     "All files failed to be converted" : "De conversie van alle bestanden is mislukt",
     "One file could not be converted: {message}" : "Een bestand kon niet worden geconverteerd: {message}",
+    "_One file could not be converted_::_%n files could not be converted_" : ["Een bestand kon niet geconverteerd worden","%n bestanden konden niet geconverteerd worden"],
+    "_One file successfully converted_::_%n files successfully converted_" : ["Een bestand succesvol geconverteerd","%n bestanden succesvol geconverteerd"],
+    "Files successfully converted" : "Bestanden succesvol geconverteerd",
     "Failed to convert files" : "Conversie van bestanden mislukt",
-    "Converting file …" : "Bestand converteren …",
+    "Converting file …" : "Bestand converteren ...",
     "File successfully converted" : "Bestand succesvol geconverteerd",
     "Failed to convert file: {message}" : "Conversie van bestand mislukt: {message} ",
     "Failed to convert file" : "Conversie van bestand mislukt",
-    "Delete" : "Verwijderen",
     "Leave this share" : "Verlaat deze share",
     "Leave these shares" : "Verlaat deze shares",
     "Disconnect storage" : "Verbinding met opslag verbreken",
@@ -281,13 +259,8 @@ OC.L10N.register(
     "Confirm deletion" : "Bevestig verwijderen",
     "Cancel" : "Annuleren",
     "Download" : "Downloaden",
-    "The requested file is not available." : "Het gevraagde bestand is niet beschikbaar.",
-    "The requested files are not available." : "De gevraagde bestanden zijn niet beschikbaar.",
-    "Add to favorites" : "Aan favorieten toevoegen",
-    "Remove from favorites" : "Verwijderen uit favorieten",
-    "Add or remove favorite" : "Verwijder of voeg een favoriet toe",
-    "Moving \"{source}\" to \"{destination}\" …" : "Verplaatsen \"{source}\" naar \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Kopieren \"{source}\" naar \"{destination}\" …",
+    "Moving \"{source}\" to \"{destination}\" …" : "Verplaatsen \"{source}\" naar \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Kopiëren \"{source}\" naar \"{destination}\" …",
     "Destination is not a folder" : "Bestemming is geen map",
     "This file/folder is already in that directory" : "Dit bestand/deze map staat al in die map",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Je kan een bestand/map niet verplaatsen naar zichzelf of naar een subfolder van zichzelf.",
@@ -298,12 +271,10 @@ OC.L10N.register(
     "The file does not exist anymore" : "Dit bestand bestaat niet meer",
     "Choose destination" : "Kies bestemming",
     "Copy to {target}" : "Kopieer naar {target}",
-    "Copy" : "Kopiëren",
     "Move to {target}" : "Verplaats naar {target}",
     "Move" : "Verplaatsen",
     "Move or copy operation failed" : "Verplaatsen of kopiëren mislukt",
     "Move or copy" : "Verplaats of kopieer",
-    "Open folder" : "Open map",
     "Open folder {displayName}" : "Open map {displayName}",
     "Open in Files" : "Open in Bestanden",
     "Open locally" : "Lokaal openen",
@@ -312,7 +283,6 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Het bestand zou nu moeten openen op je apparaat. Als dat niet het geval is, controleer dan of je de desktop app geïnstalleerd hebt.",
     "Retry and close" : "Probeer opnieuw en sluiten",
     "Open online" : "Open online",
-    "Rename" : "Naam wijzigen",
     "Details" : "Details",
     "View in folder" : "Bekijken in map",
     "Today" : "Vandaag",
@@ -353,7 +323,6 @@ OC.L10N.register(
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "De naam \"{newName}\" bestaat al in map \"{dir}\". Kies een andere naam.",
     "Could not rename \"{oldName}\"" : "Kon \"{oldName}\" niet hernoemen",
     "This operation is forbidden" : "Deze taak is verboden",
-    "This folder is unavailable, please try again later or contact the administration" : "Deze map is niet beschikbaar, probeer het later nog eens of neem contact op met de beheerder",
     "Storage is temporarily not available" : "Opslag is tijdelijk niet beschikbaar",
     "Unexpected error: {error}" : "Onverwachte fout: {error}",
     "_%n file_::_%n files_" : ["%n bestand","%n bestanden"],
@@ -368,7 +337,6 @@ OC.L10N.register(
     "No favorites yet" : "Nog geen favorieten",
     "Files and folders you mark as favorite will show up here" : "Bestanden en mappen die je als favoriet aanmerkt, worden hier getoond",
     "List of your files and folders." : "Lijst van je bestanden en mappen.",
-    "Folder tree" : "Mapboom",
     "List of your files and folders that are not shared." : "Lijst van je bestanden en mappen die niet gedeeld zijn.",
     "No personal files found" : "Geen persoonlijke bestanden gevonden",
     "Files that are not shared will show up here." : "Niet-gedeelde bestanden worden hier getoond.",
@@ -382,28 +350,119 @@ OC.L10N.register(
     "Select all" : "Alles selecteren",
     "Upload too large" : "Upload is te groot",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "De bestanden die je probeert te uploaden zijn groter dan de maximaal toegestane  bestandsgrootte voor deze server.",
-    "%1$s (renamed)" : "%1$s (hernoemd)",
-    "renamed file" : "bestand hernoemd",
+    "File could not be found" : "Bestand kon niet worden gevonden",
+    "Show list view" : "Toon lijstweergave",
+    "Show grid view" : "Toon roosterweergave",
+    "Close" : "Sluiten",
+    "Could not create folder \"{dir}\"" : "Kon map \"{dir}\" niet aanmaken",
+    "This will stop your current uploads." : "Dit beëindigt onderhanden uploads",
+    "Upload cancelled." : "Uploaden geannuleerd.",
+    "Processing files …" : "Verwerken bestanden ...",
+    "…" : "...",
+    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan {filename} niet uploaden omdat het een map is of 0 bytes groot is",
+    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Niet genoeg vrije ruimte. Je uploadt {size1}, maar er is slechts {size2} beschikbaar",
+    "Target folder \"{dir}\" does not exist any more" : "Doelmap \"{dir}\" bestaat niet meer",
+    "An unknown error has occurred" : "Er trad een onbekende fout op.",
+    "File could not be uploaded" : "Bestand kon niet geüpload worden",
+    "Uploading …" : "Uploaden …",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "Uploaden … ({currentNumber}/{total})",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} van {totalSize} ({bitrate})",
+    "Uploading that item is not supported" : "Uploaden van dat object is niet ondersteund",
+    "Error when assembling chunks, status code {status}" : "Fout tijdens samenvoegen van brokken, status code {status}",
+    "Choose target folder" : "Kies doelmap…",
+    "Set reminder" : "Herinnering instellen",
+    "Edit locally" : "Lokaal bewerken",
+    "Open" : "Openen",
+    "Could not load info for file \"{file}\"" : "Kon geen informatie laden voor bestand \"{file}\"",
+    "Please select tag(s) to add to the selection" : "Selecteer alsjeblieft tag(s) om aan de selectie toe te voegen",
+    "Apply tag(s) to selection" : "Pas tag(s) toe voor selectie",
+    "Select directory \"{dirName}\"" : "Kies map \"{dirName}\"",
+    "Select file \"{fileName}\"" : "Kies bestand \"{fileName}\"",
+    "Unable to determine date" : "Kon datum niet vaststellen",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Deze map is niet beschikbaar. Verifieer de logs of neem contact op met de beheerder",
+    "Could not move \"{file}\", target exists" : "Kon \"{file}\" niet verplaatsen, doel bestaat al",
+    "Could not move \"{file}\"" : "Kon \"{file}\" niet verplaatsen",
+    "copy" : "kopie",
+    "Could not copy \"{file}\", target exists" : "Kon \"{file}\" niet kopiëren, het doel bestaat",
+    "Could not copy \"{file}\"" : "Kon \"{file}\" niet kopiëren",
+    "Copied {origin} inside {destination}" : "Kopieerde {origin} binnen {destination}",
+    "Copied {origin} and {nbfiles} other files inside {destination}" : "Heeft {origin} en {nbfiles} andere bestanden in {destination} gekopieerd",
+    "{newName} already exists" : "{newName} bestaat al",
+    "Could not create file \"{file}\"" : "Kon \"{file}\" niet aanmaken",
+    "Could not create file \"{file}\" because it already exists" : "Kon \"{file}\" niet aanmaken, omdat het al bestaat",
+    "Could not create folder \"{dir}\" because it already exists" : "Kon map \"{dir}\" niet aanmaken, omdat die al bestaat",
+    "Could not fetch file details \"{file}\"" : "Kon details van \"{file}\" niet ophalen",
+    "Error deleting file \"{fileName}\"." : "Fout bij verwijderen bestand \"{fileName}\".",
+    "No search results in other folders for {tag}{filter}{endtag}" : "Geen zoekresultaten voor {tag}{filter}{endtag} in andere mappen",
+    "Enter more than two characters to search in other folders" : "Voer meer dan twee tekens in om in andere mappen te zoeken",
+    "{dirs} and {files}" : "{dirs} en {files}",
+    "_including %n hidden_::_including %n hidden_" : ["inclusief %n verborgen","inclusief %n verborgen"],
+    "You do not have permission to upload or create files here" : "Je hebt geen toestemming om hier te uploaden of bestanden aan te maken",
+    "_Uploading %n file_::_Uploading %n files_" : ["%n bestand aan het uploaden","%n bestanden aan het uploaden"],
+    "New" : "Nieuw",
+    "New file/folder menu" : "Nieuw bestand/map menu",
+    "Select file range" : "Kies een reeks bestanden",
+    "{used}%" : "{used}%",
+    "{used} used" : "{used} gebruikt",
+    "\"{name}\" is an invalid file name." : "\"{name}\" is een ongeldige bestandsnaam.",
+    "File name cannot be empty." : "Bestandsnaam kan niet leeg zijn.",
+    "\"/\" is not allowed inside a file name." : "\"/\" is niet toegestaan binnen een bestandsnaam.",
+    "\"{name}\" is not an allowed filetype" : "\"{name}\" bestandstype is een niet toegestaande",
+    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Opslagruimte van {owner} zit vol, bestanden kunnen niet meer worden geüpload of gesynchroniseerd!",
+    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Groepsmap \"{mountPoint}\" is vol, bestanden kunnen niet meer gewijzigd of gesynchroniseerd worden!",
+    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Externe opslag \"{mountPoint}\" is vol, bestanden kunnen niet meer gewijzigd of gesynchroniseerd worden!",
+    "Your storage is full, files cannot be updated or synced anymore!" : "Je opslagruimte zit vol. Bestanden kunnen niet meer worden gewijzigd of gesynchroniseerd!",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Opslagruimte van {owner} zit bijna vol ({usedSpacePercent}%)",
+    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Groepsmap \"{mountPoint}\" is bijna vol ({usedSpacePercent}%).",
+    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Externe opslag \"{mountPoint}\" is bijna vol ({usedSpacePercent}%).",
+    "Your storage is almost full ({usedSpacePercent}%)." : "Je opslagruimte zit bijna vol ({usedSpacePercent}%)",
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["komt overeen met \"{filter}\"","komen overeen met \"{filter}\""],
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Directe link is gekopieerd (werkt alleen voor gebruikers met toegang tot map/bestand)",
+    "Path" : "Pad",
+    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
+    "Favored" : "Favorieten",
+    "Favor" : "Favoriet",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Kopieer Directe link (werkt alleen voor gebruikers met toegang tot map/bestand)",
+    "Upload file" : "Bestand uploaden",
+    "Not favored" : "Geen favoriet",
+    "An error occurred while trying to update the tags" : "Er trad een fout op bij je poging om de tags bij te werken",
     "Upload (max. %s)" : "Upload (max. %s)",
-    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Na inschakeling van Windows-compatibele bestandsnamen, kunnen bestaande bestanden niet meer worden gewijzigd, maar kunnen ze door de eigenaar worden hernoemd naar geldige nieuwe namen.",
-    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Het is ook mogelijk om bestanden automatisch te migreren nadat deze instelling is ingeschakeld. Raadpleeg de documentatie over het occ-commando.",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" actie succesvol uitgevoerd",
+    "\"{displayName}\" action failed" : "\"{displayName}\" actie mislukt",
     "\"{displayName}\" failed on some elements" : "“{displayName}” mislukt op sommige elementen",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" batchactie succesvol uitgevoerd",
-    "\"{displayName}\" action failed" : "\"{displayName}\" actie mislukt",
-    "Submitting fields …" : "Velden verwerken ...",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\" actie succesvol uitgevoerd",
-    "Filter file names …" : "Bestandsnamen filteren ...",
-    "Clipboard is not available" : "Klembord niet beschikbaar",
+    "Submitting fields…" : "Verzenden velden ...",
+    "Filter filenames…" : "Filter bestandsnamen...",
     "WebDAV URL copied to clipboard" : "WebDAV URL naar klembord gekopieerd",
     "Enable the grid view" : "Roosterweergave inschakelen",
     "Enable folder tree" : "Mappenboom inschakelen",
-    "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Kopiëren naar het klembord",
     "Use this address to access your Files via WebDAV" : "Gebruik dit adres om je bestanden via WebDAV te benaderen",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Als je 2FA hebt ingeschakeld moet je een app wachtwoord maken en gebruiken door hier te klikken.",
+    "Deletion cancelled" : "Verwijderen geannulleerd",
+    "Move cancelled" : "Verplaatsen geannuleerd",
+    "Cancelled move or copy of \"{filename}\"." : "Verplaatsen of kopiëren van \"¨{filename}\" geannuleerd.",
+    "Cancelled move or copy operation" : "Verplaatsen of kopiëren geannuleerd.",
+    "Open details" : "Details openen",
+    "Photos and images" : "Foto's en afbeeldingen",
+    "New folder creation cancelled" : "Maken van nieuwe map geannuleerd",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} map","{folderCount} mappen"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} bestand","{fileCount} bestanden"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 bestand en {folderCount} map","1 bestand en {folderCount} mappen"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} bestand en 1 map","{fileCount} bestanden en 1 map"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} bestanden en {folderCount} mappen",
+    "All folders" : "Alle mappen",
+    "Personal Files" : "Persoonlijke bestanden",
+    "Text file" : "Tekstbestand",
+    "New text file.txt" : "Nieuw tekstbestand.txt",
+    "%1$s (renamed)" : "%1$s (hernoemd)",
+    "renamed file" : "bestand hernoemd",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Na inschakeling van Windows-compatibele bestandsnamen, kunnen bestaande bestanden niet meer worden gewijzigd, maar kunnen ze door de eigenaar worden hernoemd naar geldige nieuwe namen.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Het is ook mogelijk om bestanden automatisch te migreren nadat deze instelling is ingeschakeld. Raadpleeg de documentatie over het occ-commando.",
+    "Filter file names …" : "Bestandsnamen filteren ...",
     "Prevent warning dialogs from open or reenable them." : "Voorkom dat waarschuwingsvensters worden geopend of schakel ze opnieuw in.",
     "Show a warning dialog when changing a file extension." : "Een waarschuwingsvenster tonen bij het wijzigen van een bestandsextensie.",
-    "Keyboard shortcuts" : "Toetsenbord sneltoetsen",
     "Speed up your Files experience with these quick shortcuts." : "Verbeter je interactie met bestanden met deze snelkoppelingen.",
     "Open the actions menu for a file" : "Open het actiemenu voor een bestand",
     "Rename a file" : "Een bestand hernoemen",
@@ -419,29 +478,6 @@ OC.L10N.register(
     "Navigate to the file on the left (in grid mode)" : "Navigeer naar het bestand aan de linkerkant (in rastermodus)",
     "Navigate to the file on the right (in grid mode)" : "Navigeer naar het bestand aan de rechterkant (in rastermodus)",
     "Toggle the grid view" : "Rasterweergave omschakelen",
-    "Open the sidebar for a file" : "Open de zijbalk voor een bestand",
-    "You" : "Jij",
-    "Shared multiple times with different people" : "Meerdere keren gedeeld met verschillende mensen",
-    "Unable to change the favorite state of the file" : "Kan de favoriete status van het bestand niet wijzigen",
-    "Error while loading the file data" : "Fout bij het lezen van de bestandsgegevens",
-    "Tags" : "Tags",
-    "Save as …" : "Opslaan als...",
-    "Converting files …" : "Bestanden converteren ...",
-    "Converting file …" : "Bestand converteren ...",
-    "Deletion cancelled" : "Verwijderen geannulleerd",
-    "Edit locally" : "Lokaal bewerken",
-    "Moving \"{source}\" to \"{destination}\" …" : "Verplaatsen \"{source}\" naar \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Kopiëren \"{source}\" naar \"{destination}\" …",
-    "Move cancelled" : "Verplaatsen geannuleerd",
-    "Cancelled move or copy of \"{filename}\"." : "Verplaatsen of kopiëren van \"¨{filename}\" geannuleerd.",
-    "Cancelled move or copy operation" : "Verplaatsen of kopiëren geannuleerd.",
-    "Open details" : "Details openen",
-    "Photos and images" : "Foto's en afbeeldingen",
-    "New folder creation cancelled" : "Maken van nieuwe map geannuleerd",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Deze map is niet beschikbaar. Verifieer de logs of neem contact op met de beheerder",
-    "All folders" : "Alle mappen",
-    "Search everywhere …" : "Zoek in alles...",
-    "Search here …" : "Zoek hier ...",
-    "Preparing …" : "Voorbereiden ..."
+    "Open the sidebar for a file" : "Open de zijbalk voor een bestand"
 },
 "nplurals=2; plural=(n != 1);");
