@@ -51,7 +51,7 @@ OC.L10N.register(
     "You do not have permission to create a file at the specified location" : "Belirtilen konumda bir dosya oluşturma izniniz yok",
     "The file could not be converted." : "Dosya dönüştürülemedi.",
     "Could not get relative path to converted file" : "Dönüştürülen dosyanın yolu göreli yolu alınamadı",
-    "Limit must be a positive integer." : "Sınır değeri bir pozitif tam sayı olmalıdır.",
+    "Limit must be a positive integer." : "Sınır değeri bir pozitif tamsayı olmalıdır.",
     "The replacement character may only be a single character." : "Değiştirilecek karakter yalnızca tek bir karakter olabilir.",
     "Filename sanitization already started." : "Dosya adı sadeleştirme işlemi zaten başlatılmış.",
     "No filename sanitization in progress." : "İşlenen bir dosya sadeleştirmesi yok.",
@@ -108,39 +108,6 @@ OC.L10N.register(
     "Type" : "Tür",
     "Active filters" : "Etkin süzgeçler",
     "Remove filter" : "Süzgeci kaldır",
-    "Appearance" : "Görünüm",
-    "Show hidden files" : "Gizli dosyaları görüntüle",
-    "Show file type column" : "Dosya türü sütunu görüntülensin",
-    "Show file extensions" : "Dosya uzantıları görüntülensin",
-    "Crop image previews" : "Görsel ön izlemeleri kırpılsın",
-    "General" : "Genel",
-    "Sort favorites first" : "Sık kullanılanlar üstte sıralansın",
-    "Sort folders before files" : "Klasörler dosyaların üzerinde sıralansın",
-    "Default view" : "Varsayılan görünüm",
-    "All files" : "Tüm dosyalar",
-    "Personal files" : "Kişisel dosyalar",
-    "Additional settings" : "Ek ayarlar",
-    "Actions" : "İşlemler",
-    "File actions" : "Dosya işlemleri",
-    "Selection" : "Seçim",
-    "Select all files" : "Tüm dosyaları seçer",
-    "Deselect all" : "Tümünü bırak",
-    "Select or deselect" : "Seç ya da bırak",
-    "Select a range" : "Bir aralık seçin",
-    "Navigation" : "Gezinme",
-    "Go to parent folder" : "Üst klasöre git",
-    "Go to file above" : "Yukarıdaki dosyaya git",
-    "Go to file below" : "Aşağıdaki dosyaya git",
-    "Go left in grid" : "Izgarada sola git",
-    "Go right in grid" : "Izgarada sağa git",
-    "View" : "Görüntüle",
-    "Toggle grid view" : "Tablo görünümünü aç/kapat",
-    "Open file sidebar" : "Dosya kenar çubuğunu aç",
-    "Show those shortcuts" : "Bu kısayolları görüntüler",
-    "Warnings" : "Uyarılar",
-    "Warn before changing a file extension" : "Dosya uzantıları değiştirilmeden önce uyarı görüntülensin",
-    "WebDAV URL" : "WebDAV adresi",
-    "How to access files using WebDAV" : "WebDAV ile dosyalara nasıl erişilir",
     "Total rows summary" : "Toplam satır özeti",
     "Toggle selection for all files and folders" : "Tüm dosyaları ve klasörleri seç/bırak",
     "Name" : "Ad",
@@ -149,6 +116,7 @@ OC.L10N.register(
     "{displayName}: failed on some elements" : "{displayName}: Bazı bileşenlerde tamamlanamadı",
     "{displayName}: done" : "{displayName}: Tamamlandı",
     "{displayName}: failed" : "{displayName}: Tamamlanamadı",
+    "Actions" : "İşlemler",
     "(selected)" : "(seçilmiş)",
     "List of files and folders." : "Dosya ve klasörlerin listesi.",
     "You have used your space quota and cannot upload files anymore." : "Depolama alanınızın tümünü kullandığınız için başka dosya yüklemezsiniz.",
@@ -156,8 +124,8 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Başarımı olumsuz etkilememek için listenin tümü görüntülenmiyor. Listede ilerledikçe dosyalar görüntülenecek.",
     "File not found" : "Dosya bulunamadı",
     "_{count} selected_::_{count} selected_" : ["{count} seçilmiş","{count} seçilmiş"],
-    "Search everywhere …" : "Her yerde ara…",
-    "Search here …" : "Burada ara…",
+    "Search everywhere …" : "Her yerde ara…",
+    "Search here …" : "Burada ara…",
     "Search scope options" : "Arama kapsamı seçenekleri",
     "Search here" : "Burada ara",
     "{usedQuotaByte} used" : "{usedQuotaByte} kullanılmış",
@@ -176,7 +144,7 @@ OC.L10N.register(
     "Failed to refresh filename sanitization status." : "Dosya adı sadeleştirmesi durumu yenilenemedi.",
     "Filename sanitization in progress." : "Dosya adı sadeleştirmesi işleniyor.",
     "Currently {processedUsers} of {totalUsers} accounts are already processed." : "{processedUsers} / {totalUsers} hesap zaten işlenmiş.",
-    "Preparing …" : "Hazırlanıyor…",
+    "Preparing …" : "Hazırlanıyor…",
     "Refresh" : "Yenlle",
     "All files have been santized for Windows filename support." : "Tüm dosya adları Windows dosya adı desteğine göre temizlendi.",
     "Some files could not be sanitized, please check your logs." : "Bazı dosya adları sadeleştirilemedi. Lütfen günlük kayıtlarına bakın.",
@@ -191,7 +159,7 @@ OC.L10N.register(
     "Sanitize filenames" : "Dosya adlarını sadeleştir",
     "(starting)" : "(başlatılıyor)",
     "Fill template fields" : "Kalıp alanlarını doldur",
-    "Submitting fields …" : "Alanlar gönderiliyor…",
+    "Submitting fields …" : "Alanlar gönderiliyor…",
     "Submit" : "Gönder",
     "Choose a file or folder to transfer" : "Sahipliği aktarılacak bir dosya ya da klasör seçin",
     "Transfer" : "Sahipliği aktar",
@@ -215,7 +183,6 @@ OC.L10N.register(
     "Do not show this dialog again." : "Bu ileti bir daha görüntülenmesin.",
     "Select file or folder to link to" : "Bağlantı verilecek dosya ya da klasörü seçin",
     "Choose {file}" : "{file} seçin",
-    "Files settings" : "Dosyalar ayarları",
     "Share" : "Paylaş",
     "Shared by link" : "Bağlantı ile paylaşılmış",
     "Shared" : "Paylaşılan",
@@ -234,6 +201,63 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Bir şeyler yükleyin ya da aygıtlarınızla eşitleyin!",
     "Go back" : "Geri dön",
     "Views" : "Görünümler",
+    "Files settings" : "Dosyalar ayarları",
+    "Your files" : "Dosyalarınız",
+    "Open in files" : "Dosyalar uygulamasında aç",
+    "File cannot be accessed" : "Dosyaya erişilemedi",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Dosya bulunamadı ya da görüntüleme izniniz olmayabilir. Gönderenden paylaşmasını isteyin",
+    "No search results for “{query}”" : "“{query}” için bir arama sonucu bulunamadı",
+    "Search for files" : "Dosya ara",
+    "Clipboard is not available" : "Pano kullanılamıyor",
+    "WebDAV URL copied" : "WebDAV adresi kopyalandı",
+    "General" : "Genel",
+    "Default view" : "Varsayılan görünüm",
+    "All files" : "Tüm dosyalar",
+    "Personal files" : "Kişisel dosyalar",
+    "Sort favorites first" : "Sık kullanılanlar üstte sıralansın",
+    "Sort folders before files" : "Klasörler dosyaların üzerinde sıralansın",
+    "Folder tree" : "Klasör ağacı",
+    "Appearance" : "Görünüm",
+    "Show hidden files" : "Gizli dosyaları görüntüle",
+    "Show file type column" : "Dosya türü sütunu görüntülensin",
+    "Show file extensions" : "Dosya uzantıları görüntülensin",
+    "Crop image previews" : "Görsel ön izlemeleri kırpılsın",
+    "Additional settings" : "Ek ayarlar",
+    "WebDAV" : "WebDAV",
+    "WebDAV URL" : "WebDAV adresi",
+    "Copy" : "Kopyala",
+    "How to access files using WebDAV" : "WebDAV ile dosyalara nasıl erişilir",
+    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "Hesabınızda iki adımlı doğrulama açık. Bu nedenle bir dış WebDAV istemcisini bağlamak için bir uygulama parolası kullanmanız gerekir.",
+    "Warnings" : "Uyarılar",
+    "Warn before changing a file extension" : "Dosya uzantıları değiştirilmeden önce uyarı görüntülensin",
+    "Warn before deleting files" : "Dosyalar silinmeden önce uyarı görüntülensin",
+    "Keyboard shortcuts" : "Kısayol tuşları",
+    "File actions" : "Dosya işlemleri",
+    "Rename" : "Yeniden adlandır",
+    "Delete" : "Sil",
+    "Add or remove favorite" : "Sık kullanılanlara ekle ya da kaldır",
+    "Manage tags" : "Etiket yönetimi",
+    "Selection" : "Seçim",
+    "Select all files" : "Tüm dosyaları seçer",
+    "Deselect all" : "Tümünü bırak",
+    "Select or deselect" : "Seç ya da bırak",
+    "Select a range" : "Bir aralık seçin",
+    "Navigation" : "Gezinme",
+    "Go to parent folder" : "Üst klasöre git",
+    "Go to file above" : "Yukarıdaki dosyaya git",
+    "Go to file below" : "Aşağıdaki dosyaya git",
+    "Go left in grid" : "Izgarada sola git",
+    "Go right in grid" : "Izgarada sağa git",
+    "View" : "Görüntüle",
+    "Toggle grid view" : "Tablo görünümünü aç/kapat",
+    "Open file sidebar" : "Dosya kenar çubuğunu aç",
+    "Show those shortcuts" : "Bu kısayolları görüntüler",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Dosyaların tüm istemcilerle eşitlenebilmesi için dosya adlarının kısıtlanmasını sağlar. Varsayılan olarak POSIX içinde geçerli olan tüm dosya adlarına (Linux veya macOS) izin verilir.",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows uyumlu dosya adları açıldıktan sonra, var olan dosyalar artık değiştirilemez. Ancak sahipleri tarafından geçerli yeni adlarla yeniden adlandırılabilir.",
+    "Failed to toggle Windows filename support" : "Windows dosya adları desteğinin durumu değiştirilemedi",
+    "Files compatibility" : "Dosyalar uygulaması uyumluluğu",
+    "Enforce Windows compatibility" : "Windows uyumluluğu zorunlu kılınsın",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Ayrılmış adlar veya özel karakterler kullanmak gibi Windows sistemlerinde geçerli olmayan dosya adlarını engeller. Ancak büyük/küçük harf duyarlılığı uyumluluğunu zorunlu kılmaz.",
     "You" : "Siz",
     "Shared multiple times with different people" : "Farklı kişilerle birkaç kez paylaşılmış",
     "Unable to change the favorite state of the file" : "Dosyanın sık kullanılan durumu değiştirilemedi",
@@ -242,35 +266,25 @@ OC.L10N.register(
     "Remove from favorites" : "Sık kullanılanlardan kaldır",
     "Add to favorites" : "Sık kullanılanlara ekle",
     "Tags" : "Etiketler",
-    "Your files" : "Dosyalarınız",
-    "Open in files" : "Dosyalar uygulamasında aç",
-    "File cannot be accessed" : "Dosyaya erişilemedi",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Dosya bulunamadı ya da görüntüleme izniniz olmayabilir. Gönderenden paylaşmasını isteyin",
-    "No search results for “{query}”" : "“{query}” için bir arama sonucu bulunamadı",
-    "Search for files" : "Dosya ara",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Dosyaların tüm istemcilerle eşitlenebilmesi için dosya adlarının kısıtlanmasını sağlar. Varsayılan olarak POSIX içinde geçerli olan tüm dosya adlarına (Linux veya macOS) izin verilir.",
-    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows uyumlu dosya adları açıldıktan sonra, var olan dosyalar artık değiştirilemez. Ancak sahipleri tarafından geçerli yeni adlarla yeniden adlandırılabilir.",
-    "Failed to toggle Windows filename support" : "Windows dosya adları desteğinin durumu değiştirilemedi",
-    "Files compatibility" : "Dosyalar uygulaması uyumluluğu",
-    "Enforce Windows compatibility" : "Windows uyumluluğu zorunlu kılınsın",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Ayrılmış adlar veya özel karakterler kullanmak gibi Windows sistemlerinde geçerli olmayan dosya adlarını engeller. Ancak büyük/küçük harf duyarlılığı uyumluluğunu zorunlu kılmaz.",
     "Blank" : "Boş",
     "Unable to create new file from template" : "Kalıptan yeni dosya eklenemedi",
     "Pick a template for {name}" : "{name} için bir kalıp seçin",
     "Create a new file with the selected template" : "Seçilmiş kalıp ile yeni bir dosya ekle",
     "Creating file" : "Dosya ekleniyor",
     "Save as {displayName}" : "{displayName} olarak kaydet",
-    "Save as …" : "Farklı kaydet…",
-    "Converting files …" : "Dosyalar dönüştürülüyor…",
+    "Save as …" : "Farklı kaydet…",
+    "Converting files …" : "Dosyalar dönüştürülüyor…",
     "Failed to convert files: {message}" : "Dosyalar dönüştürülemedi: {message}",
     "All files failed to be converted" : "Tüm dosyalar dönüştürülemedi",
     "One file could not be converted: {message}" : "Bir dosya dönüştürülemedi: {message}",
+    "_One file could not be converted_::_%n files could not be converted_" : ["Bir dosya dönüştürülemedi","%n dosya dönüştürülemedi"],
+    "_One file successfully converted_::_%n files successfully converted_" : ["Bir dosya dönüştürüldü","%n dosya dönüştürüldü"],
+    "Files successfully converted" : "Dosyalar dönüştürüldü",
     "Failed to convert files" : "Dosyalar dönüştürülemedi",
-    "Converting file …" : "Dosya dönüştürülüyor…",
+    "Converting file …" : "Dosya dönüştürülüyor…",
     "File successfully converted" : "Dosya dönüştürüldü",
     "Failed to convert file: {message}" : "Dosya dönüştürülemedi: {message}",
     "Failed to convert file" : "Dosya dönüştürülemedi",
-    "Delete" : "Sil",
     "Leave this share" : "Bu paylaşımdan ayrıl",
     "Leave these shares" : "Bu paylaşımlardan ayrıl",
     "Disconnect storage" : "Depolama bağlantısını kes",
@@ -288,9 +302,8 @@ OC.L10N.register(
     "Download" : "İndir",
     "The requested file is not available." : "İstenilen dosya kullanılamıyor.",
     "The requested files are not available." : "İstenilen dosyalar kullanılamıyor.",
-    "Add or remove favorite" : "Sık kullanılanlara ekle ya da kaldır",
-    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\", \"{destination}\" üzerine taşınıyor…",
-    "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\", \"{destination}\" üzerine kopyalanıyor…",
+    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\", \"{destination}\" hedefine taşınıyor…",
+    "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\", \"{destination}\" hedefine kopyalanıyor…",
     "Destination is not a folder" : "Hedef bir klasör değil",
     "This file/folder is already in that directory" : "Dosya ya da klasör bu klasörde zaten var",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Bir dosyayı ya da klasörü kendi üzerine veya kendisinin alt klasörüne taşıyamazsınız",
@@ -301,7 +314,6 @@ OC.L10N.register(
     "The file does not exist anymore" : "Dosya artık yok",
     "Choose destination" : "Hedefi seçin",
     "Copy to {target}" : "{target} içine kopyala",
-    "Copy" : "Kopyala",
     "Move to {target}" : "{target} içine taşı",
     "Move" : "Taşı",
     "Move or copy operation failed" : "Taşıma ya da kopyalama yapılamadı",
@@ -314,7 +326,6 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Dosya artık aygıtınızda açılmalıdır. Açılmazsa lütfen bilgisayar uygulamasının kurulu olduğundan emin olun.",
     "Retry and close" : "Yeniden deneyip kapat",
     "Open online" : "Çevrim içi aç",
-    "Rename" : "Yeniden adlandır",
     "Details" : "Ayrıntılar",
     "View in folder" : "Klasörde görüntüle",
     "Today" : "Bugün",
@@ -370,7 +381,6 @@ OC.L10N.register(
     "No favorites yet" : "Henüz sık kullanılan bir öge yok",
     "Files and folders you mark as favorite will show up here" : "Sık kullanılanlara eklediğiniz dosya ve klasörler burada görüntülenir",
     "List of your files and folders." : "Dosya ve klasörlerinizin listesi",
-    "Folder tree" : "Klasör ağacı",
     "List of your files and folders that are not shared." : "Paylaşılmayan dosya ve klasörlerinizin listesi.",
     "No personal files found" : "Herhangi bir kişisel dosya bulunamadı",
     "Files that are not shared will show up here." : "Paylaşımayan dosyalar burada görüntülenir.",
@@ -384,28 +394,119 @@ OC.L10N.register(
     "Select all" : "Tümünü seç",
     "Upload too large" : "Yükleme boyutu çok büyük",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Yüklemeye çalıştığınız dosyalar bu sunucuya yüklenmesine izin verilen en büyük dosya boyutunu aşıyor.",
-    "%1$s (renamed)" : "%1$s (yeniden adlandırıldı)",
-    "renamed file" : "dosyayı yeniden adlandırdı",
+    "File could not be found" : "Dosya bulunamadı",
+    "Show list view" : "Liste görünümüne geç",
+    "Show grid view" : "Tablo görünümüne geç",
+    "Close" : "Kapat",
+    "Could not create folder \"{dir}\"" : "\"{dir}\" klasörü oluşturulamadı",
+    "This will stop your current uploads." : "Bu işlem geçerli yüklemeleri durduracak.",
+    "Upload cancelled." : "Yükleme iptal edildi.",
+    "Processing files …" : "Dosyalar işleniyor …",
+    "…" : "…",
+    "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename} bir klasör ya da 0 bayt boyutunda olduğundan yüklenemedi",
+    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Yeterli boş alan yok. Yüklemek istediğiniz boyut {size1} ancak yalnızca {size2} boş alan var",
+    "Target folder \"{dir}\" does not exist any more" : "\"{dir}\" hedef klasörü artık yok",
+    "An unknown error has occurred" : "Bilinmeyen bir sorun çıktı",
+    "File could not be uploaded" : "Dosya yüklenemedi",
+    "Uploading …" : "Yükleniyor …",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "Yükleniyor… ({currentNumber}/{total})",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
+    "Uploading that item is not supported" : "Bu ögenin yüklenmesi desteklenmiyor",
+    "Error when assembling chunks, status code {status}" : "Kümeler oluşturulurken sorun çıktı, durum kodu {status}",
+    "Choose target folder" : "Hedef klasörü seçin",
+    "Set reminder" : "Anımsatıcı ayarla",
+    "Edit locally" : "Yerel olarak düzenle",
+    "Open" : "Aç",
+    "Could not load info for file \"{file}\"" : "\"{file}\" dosyasının bilgileri alınamadı",
+    "Please select tag(s) to add to the selection" : "Seçime eklemek için etiketleri seçin",
+    "Apply tag(s) to selection" : "Etiketleri seçime uygula",
+    "Select directory \"{dirName}\"" : "\"{dirName}\" klasörünü seçin",
+    "Select file \"{fileName}\"" : "\"{fileName}\" dosyasını seçin",
+    "Unable to determine date" : "Tarih belirlenemedi",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Bu klasör yazılabilir değil. Lütfen günlük kayıtlarına bakın ya da BT yöneticiniz ile görüşün",
+    "Could not move \"{file}\", target exists" : "\"{file}\" taşınamadı, hedef zaten var",
+    "Could not move \"{file}\"" : "\"{file}\" taşınamadı",
+    "copy" : "kopya",
+    "Could not copy \"{file}\", target exists" : "\"{file}\" dosyası kopyalanamadı, hedef zaten var",
+    "Could not copy \"{file}\"" : "\"{file}\" kopyalanamadı",
+    "Copied {origin} inside {destination}" : "{origin} dosyası, {destination} içine kopyalandı",
+    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} ve diğer {nbfiles} dosya, {destination} içine kopyalandı",
+    "{newName} already exists" : "{newName} zaten var",
+    "Could not create file \"{file}\"" : "\"{file}\" dosyası oluşturulamadı",
+    "Could not create file \"{file}\" because it already exists" : "\"{file}\" dosyası zaten var olduğundan oluşturulamadı",
+    "Could not create folder \"{dir}\" because it already exists" : "\"{dir}\" klasörü zaten var olduğundan oluşturulamadı",
+    "Could not fetch file details \"{file}\"" : "\"{file}\" dosyasının ayrıntıları alınamadı",
+    "Error deleting file \"{fileName}\"." : "\"{fileName}\" dosyası silinirken sorun çıktı.",
+    "No search results in other folders for {tag}{filter}{endtag}" : "{tag}{filter}{endtag} için diğer klasörlerde herhangi bir arama sonucu yok",
+    "Enter more than two characters to search in other folders" : "Diğer klasörlerde aramak için iki karakterden fazla yazın",
+    "{dirs} and {files}" : "{dirs} ve {files}",
+    "_including %n hidden_::_including %n hidden_" : ["%n gizli ile birlikte","%n gizli ile birlikte"],
+    "You do not have permission to upload or create files here" : "Buraya dosya yükleme ya da ekleme izniniz yok",
+    "_Uploading %n file_::_Uploading %n files_" : ["%n dosya yükleniyor","%n dosya yükleniyor"],
+    "New" : "Yeni",
+    "New file/folder menu" : "Yeni dosya/klasör menüsü",
+    "Select file range" : "Dosya aralığını seçin",
+    "{used}%" : "%{used}",
+    "{used} used" : "{used} kullanılmış",
+    "\"{name}\" is an invalid file name." : "\"{name}\" geçersiz bir dosya adı.",
+    "File name cannot be empty." : "Dosya adı boş olamaz.",
+    "\"/\" is not allowed inside a file name." : "Dosya adında \"/\" kullanılamaz.",
+    "\"{name}\" is not an allowed filetype" : "\"{name}\" dosya türüne izin verilmiyor",
+    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} için boş depolama alanı kalmadı. Artık dosyalar güncellenmeyecek ya da eşitlenmeyecek!",
+    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "\"{mountPoint}\" grup klasöründe boş alan kalmadı. Artık güncellenemeyecek ya da eşitlenemeyecek!",
+    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "\"{mountPoint}\" dış depolamasında boş alan kalmadı. Artık güncellenemeyecek ya da eşitlenemeyecek!",
+    "Your storage is full, files cannot be updated or synced anymore!" : "Boş depolama alanınız kalmadı. Artık dosyalar güncellenmeyecek ya da eşitlenmeyecek!",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} boş depolama alanı bitmek üzere ({usedSpacePercent}%).",
+    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "\"{mountPoint}\" grup klasöründeki boş alan bitmek üzere ({usedSpacePercent}%).",
+    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "\"{mountPoint}\" dış depolamasındaki boş alan bitmek üzere ({usedSpacePercent}%).",
+    "Your storage is almost full ({usedSpacePercent}%)." : "Boş depolama alanınız bitmek üzere ({usedSpacePercent}%).",
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["\"{filter}\" ile eşleşiyor","\"{filter}\" ile eşleşiyor"],
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Doğrudan bağlantı kopyalandı (yalnızca bu dosya ya da klasöre erişim izni olan kişiler kullanabilir)",
+    "Path" : "Yol",
+    "_%n byte_::_%n bytes_" : ["%n bayt","%n bayt"],
+    "Favored" : "Sık kullanılanlara eklenmiş",
+    "Favor" : "Sık kullanılanlara ekle",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Doğrudan bağlantıyı kopyala (yalnızca bu dosya ya da klasöre erişim izni olan kişiler için)",
+    "Upload file" : "Dosya yükle",
+    "Not favored" : "Sık kullanılanlara eklenmemiş",
+    "An error occurred while trying to update the tags" : "Etiketler güncellenirken bir sorun çıktı",
     "Upload (max. %s)" : "Yükle (en büyük: %s)",
-    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows uyumlu dosya adları açıldıktan sonra, var olan dosyalar artık değiştirilemez. Ancak sahipleri tarafından geçerli yeni adlarla yeniden adlandırılabilir.",
-    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Bu ayarı açtıktan sonra dosyaları otomatik olarak da aktarılabilir. Lütfen occ komutuyla ilgili belgelere bakın.",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" işlemi tamamlandı",
+    "\"{displayName}\" action failed" : "\"{displayName}\" işlemi tamamlanamadı",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" bazı bileşenlerde tamamlanamadı",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" toplu işlemi tamamlandı",
-    "\"{displayName}\" action failed" : "\"{displayName}\" işlemi tamamlanamadı",
-    "Submitting fields …" : "Alanlar gönderiliyor…",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\" işlemi tamamlandı",
-    "Filter file names …" : "Dosya adlarını süz…",
-    "Clipboard is not available" : "Pano kullanılamıyor",
+    "Submitting fields…" : "Alanlar gönderiliyor…",
+    "Filter filenames…" : "Dosya adlarını süz…",
     "WebDAV URL copied to clipboard" : "WebDAV adresi panoya kopyalandı",
     "Enable the grid view" : "Tablo görünümü kullanılsın",
     "Enable folder tree" : "Klasör ağacını aç",
-    "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Panoya kopyala",
     "Use this address to access your Files via WebDAV" : "Dosyalarınıza WebDAV üzerinden erişmek için bu adresi kullanın",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "İki adımlı doğrulamayı açtıysanız buraya tıklayarak yeni bir uygulama parolası oluşturmalısınız.",
+    "Deletion cancelled" : "Silme iptal edildi",
+    "Move cancelled" : "Taşıma iptal edildi",
+    "Cancelled move or copy of \"{filename}\"." : "\"{filename}\" dosyasını taşıma ya da kopyalama işlemi iptal edildi",
+    "Cancelled move or copy operation" : "Taşıma ya da kopyalama işlemi iptal edildi",
+    "Open details" : "Ayrıntıları aç",
+    "Photos and images" : "Fotoğraflar ve görseller",
+    "New folder creation cancelled" : "Yeni klasör oluşturma işlemi iptal edildi",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} klasör","{folderCount} klasör"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} dosya","{fileCount} dosya"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 dosya ve {folderCount} klasör","1 dosya ve {folderCount} klasör"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} dosya ve 1 klasör","{fileCount} dosya ve 1 klasör"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} dosya ve {folderCount} klasör",
+    "All folders" : "Tüm klasörler",
+    "Personal Files" : "Kişisel dosyalar",
+    "Text file" : "Yazı dosyası",
+    "New text file.txt" : "Yeni yazı dosyası.txt",
+    "%1$s (renamed)" : "%1$s (yeniden adlandırıldı)",
+    "renamed file" : "dosyayı yeniden adlandırdı",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows uyumlu dosya adları açıldıktan sonra, var olan dosyalar artık değiştirilemez. Ancak sahipleri tarafından geçerli yeni adlarla yeniden adlandırılabilir.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Bu ayarı açtıktan sonra dosyaları otomatik olarak da aktarılabilir. Lütfen occ komutuyla ilgili belgelere bakın.",
+    "Filter file names …" : "Dosya adlarını süz…",
     "Prevent warning dialogs from open or reenable them." : "Uyarı pencerelerinin görüntülenmesini açın ya da kapatın.",
     "Show a warning dialog when changing a file extension." : "Dosya uzantısı değiştirilirken uyarı penceresi görüntülensin.",
-    "Keyboard shortcuts" : "Kısayol tuşları",
     "Speed up your Files experience with these quick shortcuts." : "Şu kısayol tuşlarını kullanarak Dosyalar deneyiminizi hızlandırabilirsiniz.",
     "Open the actions menu for a file" : "Bir dosyanın işlemler menüsünü açar",
     "Rename a file" : "Bir dosyayı yeniden adlandırır",
@@ -421,24 +522,6 @@ OC.L10N.register(
     "Navigate to the file on the left (in grid mode)" : "Soldaki dosyaya gider (ızgara görünümünde)",
     "Navigate to the file on the right (in grid mode)" : "Sağdaki dosyaya gider (ızgara görünümünde)",
     "Toggle the grid view" : "Izgara görünümünü açar ya da kapatır",
-    "Open the sidebar for a file" : "Bir dosyanın kenar çubuğunu açar",
-    "Save as …" : "Farklı kaydet…",
-    "Converting files …" : "Dosyalar dönüştürülüyor…",
-    "Converting file …" : "Dosya dönüştürülüyor…",
-    "Deletion cancelled" : "Silme iptal edildi",
-    "Edit locally" : "Yerel olarak düzenle",
-    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\", \"{destination}\" hedefine taşınıyor…",
-    "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\", \"{destination}\" hedefine kopyalanıyor…",
-    "Move cancelled" : "Taşıma iptal edildi",
-    "Cancelled move or copy of \"{filename}\"." : "\"{filename}\" dosyasını taşıma ya da kopyalama işlemi iptal edildi",
-    "Cancelled move or copy operation" : "Taşıma ya da kopyalama işlemi iptal edildi",
-    "Open details" : "Ayrıntıları aç",
-    "Photos and images" : "Fotoğraflar ve görseller",
-    "New folder creation cancelled" : "Yeni klasör oluşturma işlemi iptal edildi",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Bu klasör yazılabilir değil. Lütfen günlük kayıtlarına bakın ya da BT yöneticiniz ile görüşün",
-    "All folders" : "Tüm klasörler",
-    "Search everywhere …" : "Her yerde ara…",
-    "Search here …" : "Burada ara…",
-    "Preparing …" : "Hazırlanıyor…"
+    "Open the sidebar for a file" : "Bir dosyanın kenar çubuğunu açar"
 },
 "nplurals=2; plural=(n > 1);");
