@@ -13,11 +13,9 @@ OC.L10N.register(
     "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["1 remaining download allowed","{count} remaining downloads allowed"],
     "Download limit" : "Download limit",
     "Configure the default download limit for external shares." : "Configure the default download limit for external shares.",
-    "Default download limit for external shares" : "Default download limit for external shares",
     "Set default download limit" : "Set default download limit",
     "You have reached the maximum amount of downloads allowed" : "You have reached the maximum amount of downloads allowed",
     "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "This share has a limited number of downloads. Are you sure you want to trigger a new download?",
-    "Failed to set default download limit" : "Failed to set default download limit",
-    "Failed to remove default download limit" : "Failed to remove default download limit"
+    "Failed to set default download limit" : "Failed to set default download limit"
 },
 "nplurals=2; plural=(n != 1);");
