@@ -11,11 +11,11 @@ OC.L10N.register(
     "Set download limit" : "Establecer el límite de descarga",
     "Setting a new limit will reset the download count" : "Establecer un nuevo límite reinicializara el conteo de descargas",
     "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["Queda 1 descarga permitida","Quedan {count} descargas permitidas","Quedan {count} descargas permitidas"],
-    "Failed to set default download limit" : "Fallo al establecer el límite predeterminado de descargas",
     "Download limit" : "Límite de descargas",
     "Configure the default download limit for external shares." : "Configurar el límite prederterminado de descargas para los recursos compartidos mediante enlace externo.",
     "Set default download limit" : "Establecer el límite de descargas prederterminado",
     "You have reached the maximum amount of downloads allowed" : "Ha llegado al máximo de descargas permitidas",
-    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Este recurso compartido tiene un número limitado de descargas. ¿Está seguro de que quiere activar una nueva descarga?"
+    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Este recurso compartido tiene un número limitado de descargas. ¿Está seguro de que quiere activar una nueva descarga?",
+    "Failed to set default download limit" : "Fallo al establecer el límite predeterminado de descargas"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
