@@ -104,13 +104,13 @@ OC.L10N.register(
     "Password" : "Slaptažodis",
     "Generate a new password" : "Generuoti naują slaptažodį",
     "Automatically copying failed, please copy the share link manually" : "Nepavyko automatiškai nukopijuoti, nukopijuokite nuorodą rankiniu būdu",
-    "Link copied to clipboard" : "Nuoroda nukopijuota į iškarpinę",
+    "Link copied" : "Nuoroda nukopijuota",
     "Email already added" : "El. paštas jau pridėtas",
     "Invalid email address" : "Neteisingas el. pašto adresas",
     "_{count} email address already added_::_{count} email addresses already added_" : ["Jau pridėtas {count} el. pašto adresas","Jau pridėti {count} el. pašto adresai","Jau pridėta {count} el. pašto adresų","Jau pridėtas {count} el. pašto adresas"],
     "_{count} email address added_::_{count} email addresses added_" : ["Pridėtas {count} el. pašto adresas","Pridėti {count} el. pašto adresai","Pridėta {count} el. pašto adresų","Pridėtas {count} el. pašto adresas"],
     "Share link" : "Viešinio nuoroda",
-    "Copy to clipboard" : "Kopijuoti į iškarpinę",
+    "Copy" : "Kopijuoti",
     "Send link via email" : "Siųsti nuorodą el. paštu",
     "Enter an email address or paste a list" : "Įveskite el. pašto adresą arba įdėkite sąrašą",
     "Remove email" : "Šalinti el. paštą",
@@ -144,8 +144,7 @@ OC.L10N.register(
     "Via “{folder}”" : "Per \"{folder}\"",
     "Unshare" : "Nustoti bendrinti",
     "Cannot copy, please copy the link manually" : "Nepavyksta nukopijuoti, nukopijuokite nuorodą rankiniu būdu",
-    "Copy internal link to clipboard" : "Kopijuoti vidinę nuorodą į iškarpinę",
-    "Link copied" : "Nuoroda nukopijuota",
+    "Copy internal link" : "Kopijuoti vidinę nuorodą",
     "Internal link" : "Vidinė nuoroda",
     "Shared via link by {initiator}" : "{initiator} bendrina per nuorodą",
     "Share link ({label})" : "Viešinio nuoroda ({label})",
@@ -169,7 +168,6 @@ OC.L10N.register(
     "Name, email, or Federated Cloud ID …" : "Vardas, el. paštas ar federacinės debesijos ID…",
     "Searching …" : "Ieškoma…",
     "No elements found." : "Nerasta jokių elementų.",
-    "Search globally" : "Ieškoti visuotiniu mastu",
     "Guest" : "Svečias",
     "Group" : "Grupė",
     "Email" : "El. paštas",
@@ -178,7 +176,6 @@ OC.L10N.register(
     "Note:" : "Pastaba:",
     "File drop" : "Failų įkėlimas",
     "Terms of service" : "Naudojimosi sąlygos",
-    "Share with {userName}" : "Bendrinti su {userName}",
     "Share with email {email}" : "Bendrinti su el. pašto adresu {email}",
     "Share with group" : "Bendrinti su grupe",
     "Share in conversation" : "Bendrinti pokalbyje",
@@ -221,7 +218,6 @@ OC.L10N.register(
     "Link to a file" : "Nuoroda į failą",
     "Shared" : "Bendrinama",
     "Shared by {ownerDisplayName}" : "Bendrina {ownerDisplayName}",
-    "Show sharing options" : "Rodyti bendrinimo parinktis",
     "Shared with others" : "Bendrinama su kitais",
     "Public share" : "Viešasis viešinys",
     "Overview of shared files." : "Bendrinamų failų apžvalga.",
@@ -247,23 +243,11 @@ OC.L10N.register(
     "Share label saved" : "Viešinio etiketė įrašyta",
     "Share password saved" : "Viešinio slaptažodis įrašytas",
     "Share permissions saved" : "Viešinio leidimai įrašyti",
-    "Shared by" : "Bendrina",
-    "Shared with" : "Bendrinama su",
     "Password created successfully" : "Slaptažodis sėkmingai sukurtas",
     "Shared with you and the group {group} by {owner}" : "{owner} pradėjo bendrinti su jumis ir grupe {group}",
     "Shared with you and {circle} by {owner}" : "{owner} pradėjo bendrinti su jumis ir {circle}",
     "Shared with you and the conversation {conversation} by {owner}" : "{owner} pasidalino su jumis ir pokalbiu {conversation}",
     "Shared with you in a conversation by {owner}" : "{owner} pasidalino su jumis pokalbyje",
-    "Share note" : "Pasidalinimo pastaba",
-    "Show list view" : "Rodyti sąrašo rodinį",
-    "Show grid view" : "Rodyti tinklelio rodinį",
-    "Upload files to %s" : "Įkelkite failus į %s",
-    "%s shared a folder with you." : "%s pradėjo bendrinti su jumis aplanką.",
-    "Note" : "Pastaba",
-    "Select or drop files" : "Pasirinkite arba vilkite failus",
-    "Uploading files" : "Įkeliami failai",
-    "Uploaded files:" : "Įkelti failai:",
-    "By uploading files, you agree to the %1$sterms of service%2$s." : "Įkeldami failus, sutinkate su %1$snaudojimosi sąlygomis%2$s.",
     "Share not found" : "Viešinys nerastas",
     "Back to %s" : "Atgal į %s",
     "Add to your Nextcloud" : "Pridėti į savo Nextcloud",
@@ -273,15 +257,33 @@ OC.L10N.register(
     "This will stop your current uploads." : "Tai sustabdys dabartinius įkėlimus.",
     "Move or copy" : "Perkelti ar kopijuoti",
     "You can upload into this folder" : "Galite įkelti į šį aplanką",
+    "Show list view" : "Rodyti sąrašo rodinį",
+    "Show grid view" : "Rodyti tinklelio rodinį",
     "No compatible server found at {remote}" : "Nerasta jokio suderinamo serverio ties {remote}",
     "Invalid server URL" : "Neteisingas serverio URL adresas",
     "Failed to add the public link to your Nextcloud" : "Nepavyko pridėti viešosios nuorodos į jūsų Nextcloud",
     "Download all files" : "Atsisiųsti visus failus ",
+    "Link copied to clipboard" : "Nuoroda nukopijuota į iškarpinę",
     "_1 email address already added_::_{count} email addresses already added_" : ["Jau pridėtas 1 el. pašto adresas","Jau pridėti {count} el. pašto adresai","Jau pridėta {count} el. pašto adresų","Jau pridėtas {count} el. pašto adresas"],
     "_1 email address added_::_{count} email addresses added_" : ["Pridėtas 1 el. pašto adresas","Pridėti {count} el. pašto adresai","Pridėta {count} el. pašto adresų","Pridėtas {count} el. pašto adresas"],
+    "Copy to clipboard" : "Kopijuoti į iškarpinę",
+    "Copy internal link to clipboard" : "Kopijuoti vidinę nuorodą į iškarpinę",
+    "Search globally" : "Ieškoti visuotiniu mastu",
     "Search for share recipients" : "Ieškoti viešinio gavėjų",
     "No recommendations. Start typing." : "Rekomendacijų nėra. Pradėkite rašyti.",
     "Enter your name" : "Įveskite savo vardą",
+    "Share with {userName}" : "Bendrinti su {userName}",
+    "Show sharing options" : "Rodyti bendrinimo parinktis",
+    "Shared by" : "Bendrina",
+    "Shared with" : "Bendrinama su",
+    "Share note" : "Pasidalinimo pastaba",
+    "Upload files to %s" : "Įkelkite failus į %s",
+    "%s shared a folder with you." : "%s pradėjo bendrinti su jumis aplanką.",
+    "Note" : "Pastaba",
+    "Select or drop files" : "Pasirinkite arba vilkite failus",
+    "Uploading files" : "Įkeliami failai",
+    "Uploaded files:" : "Įkelti failai:",
+    "By uploading files, you agree to the %1$sterms of service%2$s." : "Įkeldami failus, sutinkate su %1$snaudojimosi sąlygomis%2$s.",
     "Name" : "Pavadinimas",
     "Filename must not be empty." : "Failo pavadinimas negali būti tuščias."
 },
