@@ -3,25 +3,9 @@
 declare(strict_types=1);
 
 /**
- * @copyright Copyright (c) 2023, Joas Schilling <coding@schilljs.com>
- * @copyright Copyright (c) 2016, ownCloud, Inc.
- *
- * @author Joas Schilling <coding@schilljs.com>
- *
- * @license AGPL-3.0
- *
- * This code is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
- *
+ * SPDX-FileCopyrightText: 2023 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2016 ownCloud, Inc.
+ * SPDX-License-Identifier: AGPL-3.0-only
  */
 
 namespace OCA\Notifications;
@@ -34,23 +18,14 @@ use OCP\Notification\IManager;
 use OCP\Notification\INotification;
 
 class Handler {
-	/** @var IDBConnection */
-	protected $connection;
-
-	/** @var IManager */
-	protected $manager;
-
-	public function __construct(IDBConnection $connection,
-		IManager $manager) {
-		$this->connection = $connection;
-		$this->manager = $manager;
+	public function __construct(
+		protected IDBConnection $connection,
+		protected IManager $manager,
+	) {
 	}
 
 	/**
 	 * Add a new notification to the database
-	 *
-	 * @param INotification $notification
-	 * @return int
 	 */
 	public function add(INotification $notification): int {
 		$sql = $this->connection->getQueryBuilder();
@@ -63,9 +38,6 @@ class Handler {
 
 	/**
 	 * Count the notifications matching the given Notification
-	 *
-	 * @param INotification $notification
-	 * @return int
 	 */
 	public function count(INotification $notification): int {
 		$sql = $this->connection->getQueryBuilder();
@@ -75,7 +47,7 @@ class Handler {
 		$this->sqlWhere($sql, $notification);
 
 		$statement = $sql->executeQuery();
-		$count = (int) $statement->fetchOne();
+		$count = (int)$statement->fetchOne();
 		$statement->closeCursor();
 
 		return $count;
@@ -84,7 +56,6 @@ class Handler {
 	/**
 	 * Delete the notifications matching the given Notification
 	 *
-	 * @param INotification $notification
 	 * @return array A Map with all deleted notifications [user => [notifications]]
 	 */
 	public function delete(INotification $notification): array {
@@ -103,10 +74,10 @@ class Handler {
 			}
 
 			$deleted[$row['user']][] = [
-				'id' => (int) $row['notification_id'],
+				'id' => (int)$row['notification_id'],
 				'app' => $row['app'],
 			];
-			$notifications[(int) $row['notification_id']] = $this->notificationFromRow($row);
+			$notifications[(int)$row['notification_id']] = $this->notificationFromRow($row);
 		}
 		$statement->closeCursor();
 
@@ -141,15 +112,12 @@ class Handler {
 
 	/**
 	 * Delete the notification of a given user
-	 *
-	 * @param string $user
-	 * @return bool
 	 */
 	public function deleteByUser(string $user): bool {
 		$notification = $this->manager->createNotification();
 		try {
 			$notification->setUser($user);
-		} catch (\InvalidArgumentException $e) {
+		} catch (\InvalidArgumentException) {
 			return false;
 		}
 		return !empty($this->delete($notification));
@@ -158,10 +126,6 @@ class Handler {
 	/**
 	 * Delete the notification matching the given id
 	 *
-	 * @param int $id
-	 * @param string $user
-	 * @param INotification|null $notification
-	 * @return bool
 	 * @throws NotificationNotFoundException
 	 */
 	public function deleteById(int $id, string $user, ?INotification $notification = null): bool {
@@ -175,7 +139,7 @@ class Handler {
 		$sql->delete('notifications')
 			->where($sql->expr()->eq('notification_id', $sql->createNamedParameter($id)))
 			->andWhere($sql->expr()->eq('user', $sql->createNamedParameter($user)));
-		return (bool) $sql->executeStatement();
+		return (bool)$sql->executeStatement();
 	}
 
 	/**
@@ -193,9 +157,6 @@ class Handler {
 	/**
 	 * Get the notification matching the given id
 	 *
-	 * @param int $id
-	 * @param string $user
-	 * @return INotification
 	 * @throws NotificationNotFoundException
 	 */
 	public function getById(int $id, string $user): INotification {
@@ -214,7 +175,7 @@ class Handler {
 
 		try {
 			return $this->notificationFromRow($row);
-		} catch (\InvalidArgumentException $e) {
+		} catch (\InvalidArgumentException) {
 			throw new NotificationNotFoundException('Could not create notification from database row');
 		}
 	}
@@ -222,9 +183,8 @@ class Handler {
 	/**
 	 * Confirm that the notification ids still exist for the user
 	 *
-	 * @param string $user
-	 * @param int[] $ids
-	 * @return int[]
+	 * @param list<int> $ids
+	 * @return list<int>
 	 */
 	public function confirmIdsForUser(string $user, array $ids): array {
 		$query = $this->connection->getQueryBuilder();
@@ -236,7 +196,7 @@ class Handler {
 
 		$existing = [];
 		while ($row = $result->fetch()) {
-			$existing[] = (int) $row['notification_id'];
+			$existing[] = (int)$row['notification_id'];
 		}
 		$result->closeCursor();
 
@@ -246,9 +206,6 @@ class Handler {
 	/**
 	 * Get the notifications after (and excluding) the given id
 	 *
-	 * @param int $startAfterId
-	 * @param string $userId
-	 * @param int $limit
 	 * @return array<int, INotification> [notification_id => INotification]
 	 */
 	public function getAfterId(int $startAfterId, string $userId, int $limit = 25): array {
@@ -265,7 +222,7 @@ class Handler {
 		while ($row = $statement->fetch()) {
 			try {
 				$notifications[(int)$row['notification_id']] = $this->notificationFromRow($row);
-			} catch (\InvalidArgumentException $e) {
+			} catch (\InvalidArgumentException) {
 				continue;
 			}
 		}
@@ -277,11 +234,9 @@ class Handler {
 	/**
 	 * Return the notifications matching the given Notification
 	 *
-	 * @param INotification $notification
-	 * @param int $limit
 	 * @return array [notification_id => INotification]
 	 */
-	public function get(INotification $notification, $limit = 25): array {
+	public function get(INotification $notification, int $limit = 25): array {
 		$sql = $this->connection->getQueryBuilder();
 		$sql->select('*')
 			->from('notifications')
@@ -295,7 +250,7 @@ class Handler {
 		while ($row = $statement->fetch()) {
 			try {
 				$notifications[(int)$row['notification_id']] = $this->notificationFromRow($row);
-			} catch (\InvalidArgumentException $e) {
+			} catch (\InvalidArgumentException) {
 				continue;
 			}
 		}
@@ -306,9 +261,6 @@ class Handler {
 
 	/**
 	 * Add where statements to a query builder matching the given notification
-	 *
-	 * @param IQueryBuilder $sql
-	 * @param INotification $notification
 	 */
 	protected function sqlWhere(IQueryBuilder $sql, INotification $notification) {
 		if ($notification->getApp() !== '') {
@@ -343,9 +295,6 @@ class Handler {
 
 	/**
 	 * Turn a notification into an input statement
-	 *
-	 * @param IQueryBuilder $sql
-	 * @param INotification $notification
 	 */
 	protected function sqlInsert(IQueryBuilder $sql, INotification $notification) {
 		$actions = [];
@@ -375,24 +324,21 @@ class Handler {
 
 	/**
 	 * Turn a database row into a INotification
-	 *
-	 * @param array $row
-	 * @return INotification
 	 * @throws \InvalidArgumentException
 	 */
 	protected function notificationFromRow(array $row): INotification {
 		$dateTime = new \DateTime();
-		$dateTime->setTimestamp((int) $row['timestamp']);
+		$dateTime->setTimestamp((int)$row['timestamp']);
 
 		$notification = $this->manager->createNotification();
 		$notification->setApp($row['app'])
 			->setUser($row['user'])
 			->setDateTime($dateTime)
 			->setObject($row['object_type'], $row['object_id'])
-			->setSubject($row['subject'], (array) json_decode($row['subject_parameters'], true));
+			->setSubject($row['subject'], (array)json_decode($row['subject_parameters'], true));
 
 		if ($row['message'] !== '' && $row['message'] !== null) {
-			$notification->setMessage($row['message'], (array) json_decode($row['message_parameters'], true));
+			$notification->setMessage($row['message'], (array)json_decode($row['message_parameters'], true));
 		}
 		if ($row['link'] !== '' && $row['link'] !== null) {
 			$notification->setLink($row['link']);
@@ -401,7 +347,7 @@ class Handler {
 			$notification->setIcon($row['icon']);
 		}
 
-		$actions = (array) json_decode($row['actions'], true);
+		$actions = (array)json_decode($row['actions'], true);
 		foreach ($actions as $actionData) {
 			$action = $notification->createAction();
 			$action->setLabel($actionData['label'])
