@@ -21,6 +21,9 @@ OC.L10N.register(
     "Mark selection as favorite" : "Označit vybrané jako oblíbené",
     "Add selection to favorites" : "Přidat vybrané do oblíbených",
     "Remove selection from favorites" : "Odebrat vybrané z oblíbených",
+    "This name is already in use." : "Tento název už je využíván.",
+    "\"{char}\" is not allowed inside a filename." : "„{char}“ není v názvu souboru možné použít.",
+    "Invalid filename." : "Neplatný název souboru.",
     "Name of the album" : "Název alba",
     "Location of the album" : "Umístění alba",
     "Back" : "Zpět",
@@ -39,8 +42,6 @@ OC.L10N.register(
     "Add people or groups who can edit your album" : "Přidejte uživatele či skupiny, kteří mohou album upravovat",
     "Search people or groups" : "Hledat uživatele nebo skupiny",
     "No recommendations. Start typing." : "Žádná doporučení. Pište.",
-    "Group" : "Skupina",
-    "Remove {collaboratorLabel} from the collaborators list" : "Odebrat {collaboratorLabel} ze seznamu spolupracujících",
     "Copy the public link" : "Zkopírovat veřejný odkaz",
     "Public link copied!" : "Veřejný odkaz zkopírován!",
     "Copy public link" : "Zkopírovat veřejný odkaz",
@@ -60,9 +61,10 @@ OC.L10N.register(
     "Select image {imageName}" : "Vybrat obrázek {imageName}",
     "Open the \"{name}\" folder" : "Otevřít složku „{name}“",
     "Go back" : "Jít zpět",
-    "Date range" : "Datumové rozmezí",
+    "Select a custom date range" : "Vyberte uživatelsky určené datumové rozmezí",
     "Select a date range" : "Vybrat datumové rozmezí",
-    "Select places" : "Vybrat místa",
+    "Date range" : "Datumové rozmezí",
+    "Select filters" : "Vybrat filtry",
     "Dates" : "Data",
     "Jump to specific date in list" : "Přejít na konkrétní datum v seznamu",
     "Jump to {date}" : "Přejít na {date}",
@@ -88,7 +90,6 @@ OC.L10N.register(
     "Choose the folder where photos and albums are uploaded to." : "Zvolte složku do které nahrávat fotky a alba.",
     "_%n photo_::_%n photos_" : ["%n fotka","%n fotky","%n fotek","%n fotky"],
     "Unselect all" : "Zrušit výběr všeho",
-    "Toggle filter" : "Vyp/zap. filtr",
     "Add photos to this album" : "Přidat fotky do tohoto alba",
     "Manage collaborators for this album" : "Spravovat spolupracující pro toto album",
     "Open actions menu" : "Otevřít nabídku akcí",
@@ -118,7 +119,7 @@ OC.L10N.register(
     "This might take some time depending on the size of your photo library." : "Toto může zabrat nějakou dobu v závislosti na velikosti vaší knihovny fotek.",
     "Recognized people will show up here" : "Rozpoznaní lidé se zobrazí zde",
     "This folder does not exist" : "Tato složka neexistuje",
-    "Loading folders …" : "Načítání složek…",
+    "Loading folders…" : "Načítání složek…",
     "No photos in here" : "Tady nejsou žádné fotky",
     "Taken on {date} at {time}" : "Pořízeno {date} v {time}",
     "This place does not have any photos or videos yet!" : "Toto umístění zatím nemá ještě žádné fotky nebo videa!",
@@ -150,6 +151,9 @@ OC.L10N.register(
     "Tagged photos" : "Oštítkované fotky",
     "Tagged photo {title}" : "Fotka {title} opatřena štítkem",
     "{title}'s face" : "Obličej {title}",
+    "Last week" : "Uplynulý týden",
+    "Last Month" : "Uplynulý měsíc",
+    "Custom…" : "Uživatelsky určené…",
     "{startDate} to {endDate}" : "{startDate} až {endDate}",
     "Details" : "Podrobnosti",
     "Failed to add {fileBaseName} to collection {collectionFileName}" : "Nepodařilo se přidat {fileBaseName} do sbírky {collectionFileName}",
@@ -167,8 +171,11 @@ OC.L10N.register(
     "Failed to set favorite state for {fileId}" : "Nepodařilo se nastavit stav zařazení mezi oblíbené pro {fileId}",
     "Failed to set favorite state for {fileName}" : "Nepodařilo se nastavit stav zařazení mezi oblíbené pro {fileName}",
     "Could not load photos folder" : "Nepodařilo se načíst složku s fotkami",
+    "Group" : "Skupina",
+    "Remove {collaboratorLabel} from the collaborators list" : "Odebrat {collaboratorLabel} ze seznamu spolupracujících",
     "Back to {folder}" : "Zpět do {folder}",
     "Share this folder" : "Sdílet tuto složku",
+    "Loading folders …" : "Načítání složek…",
     "One of the source folders does not exists" : "Jedna ze zdrojových složek neexistuje",
     "Add" : "Přidat"
 },
