@@ -42,7 +42,7 @@ OC.L10N.register(
     "Add people or groups who can edit your album" : "Tilføj personer eller grupper, der kan redigere dit album",
     "Search people or groups" : "Søg efter personer eller grupper",
     "No recommendations. Start typing." : "Ingen anbefalinger. Begynd at skrive.",
-    "Copy the public link" : "Kopiér det offentlige link",
+    "Copy the public link" : "Kopier det offentlige link",
     "Public link copied!" : "Offentlig link kopieret!",
     "Copy public link" : "Kopier offentligt link",
     "Delete the public link" : "Slet det offentlige link",
@@ -72,18 +72,22 @@ OC.L10N.register(
     "The destination folder is owned by {owner}" : "Destinationsmappen ejes af {owner}",
     "There are no photos or videos yet!" : "Der er endnu ingen fotos eller videoer!",
     "_{years} year ago_::_{years} years ago_" : ["{years} år siden","{years} år siden"],
+    "Enable squared photos view" : "Aktiver kvadratisk fotovisning",
     "Delete source directory" : "Slet kildemappe",
     "Pick folder" : "Vælg mappe",
     "Select a source folder for your media" : "Vælg en kildemappe til dine medier",
-    "Media folders" : "Mediemapper",
-    "Choose the folders from where photos and videos are shown." : "Vælg de mapper, hvorfra billeder og videoer vises.",
     "All folders" : "Alle mapper",
     "Add a Photos source for the timelines" : "Tilføj en fotokilde til tidslinjer",
     "Add folder" : "Tilføj mappe",
-    "Home" : "Hjemme",
     "Select the default upload location for your media" : "Vælg standard uploadplacering til dine medier",
+    "Home" : "Hjemme",
+    "Choose default Photos upload and Albums location" : "Vælg standard fotoupload og albumplacering",
+    "Choose a different folder" : "Vælg en anden mappe",
+    "View" : "Vis",
+    "Media folders" : "Mediemapper",
+    "Choose the folders from where photos and videos are shown." : "Vælg de mapper, hvorfra billeder og videoer vises.",
     "Upload folder" : "Uploadmappe",
-    "General" : "Generelt",
+    "Choose the folder where photos and albums are uploaded to." : "Vælg mappen som fotos og albummer uploades til.",
     "_%n photo_::_%n photos_" : [" %n fotos"," %n fotos"],
     "Unselect all" : "Fravælg alle",
     "Add photos to this album" : "Tilføj fotos til dette album",
@@ -171,12 +175,8 @@ OC.L10N.register(
     "Remove {collaboratorLabel} from the collaborators list" : "Fjern {collaboratorLabel} fra listen over samarbejdspartnere",
     "Back to {folder}" : "Tilbage til {folder}",
     "Share this folder" : "Del denne mappe",
-    "Enable squared photos view" : "Aktiver kvadratisk fotovisning",
-    "Choose default Photos upload and Albums location" : "Vælg standard fotoupload og albumplacering",
-    "Choose a different folder" : "Vælg en anden mappe",
-    "View" : "Vis",
-    "Choose the folder where photos and albums are uploaded to." : "Vælg mappen som fotos og albummer uploades til.",
     "Loading folders …" : "Indlæser mapper..",
+    "One of the source folders does not exists" : "En af kildemapperne eksisterer ikke",
     "Add" : "Tilføj"
 },
 "nplurals=2; plural=(n != 1);");
