@@ -21,6 +21,9 @@ OC.L10N.register(
     "Mark selection as favorite" : "Означи ги селектираните како омилени",
     "Add selection to favorites" : "Означи ги селектираните како омилени",
     "Remove selection from favorites" : "Отстрани ги селектираните од омилени",
+    "This name is already in use." : "Името е веќе во употреба.",
+    "\"{char}\" is not allowed inside a filename." : "\"{char}\" не е дозволен во името на датотеката.",
+    "Invalid filename." : "Невалидно име.",
     "Name of the album" : "Име на албумот",
     "Location of the album" : "Локација на албумот",
     "Back" : "Назад",
@@ -39,8 +42,6 @@ OC.L10N.register(
     "Add people or groups who can edit your album" : "Додади корисник кој ќе може да го ажурира твојот албум",
     "Search people or groups" : "Пребарувај луѓе и групи",
     "No recommendations. Start typing." : "Нема препораки. Започнете со пишување.",
-    "Group" : "Група",
-    "Remove {collaboratorLabel} from the collaborators list" : "Избриши {collaboratorLabel} од листата на соработници",
     "Copy the public link" : "Копирај јавен линк",
     "Public link copied!" : "Јавниот линк е копиран!",
     "Copy public link" : "Копирај јавен линк",
@@ -60,9 +61,9 @@ OC.L10N.register(
     "Select image {imageName}" : "Избери слика {imageName}",
     "Open the \"{name}\" folder" : "Отвори ја папката на \"{name}\"",
     "Go back" : "Назад",
-    "Date range" : "Опсег",
     "Select a date range" : "Избери опсег",
-    "Select places" : "Избери места",
+    "Date range" : "Опсег",
+    "Select filters" : "Избери филтри",
     "Dates" : "Датуми",
     "Jump to specific date in list" : "Оди го одреден датум на листата",
     "Jump to {date}" : "Оди до {date}",
@@ -85,7 +86,6 @@ OC.L10N.register(
     "Choose the folder where photos and albums are uploaded to." : "Изберете ги папките од каде што се прикачуваат фотографиите и албумите.",
     "_%n photo_::_%n photos_" : ["%n фотографија","%n фотографии"],
     "Unselect all" : "Од-означи се",
-    "Toggle filter" : "Вклучи филтри",
     "Add photos to this album" : "Додади фотографии во овој албум",
     "Manage collaborators for this album" : "Уреди соработници за овој албум",
     "Open actions menu" : "Отвори Мени со акции",
@@ -114,7 +114,7 @@ OC.L10N.register(
     "This might take some time depending on the size of your photo library." : "Ова може да потрае некое време во зависност од големината на вашата збирка со фотографии.",
     "Recognized people will show up here" : "Препознатите луѓе ќе се појават овде",
     "This folder does not exist" : "Папката не постои",
-    "Loading folders …" : "Се вчитуваат папките…",
+    "Loading folders…" : "Се вчитуваат папките…",
     "No photos in here" : "Овде нема фотографии",
     "Taken on {date} at {time}" : "Направена на {date} во {time}",
     "This place does not have any photos or videos yet!" : "Ова место сеуште нема фотографии и видеа!",
@@ -144,10 +144,15 @@ OC.L10N.register(
     "Tagged photos" : "Означени фотографии",
     "Tagged photo {title}" : "Означена фотографија {title}",
     "{title}'s face" : "Лицето на {title}",
+    "Last week" : "Минатата недела",
+    "Last Month" : "Минатиот месец",
     "{startDate} to {endDate}" : "{startDate} до {endDate}",
     "Details" : "Детали",
+    "Group" : "Група",
+    "Remove {collaboratorLabel} from the collaborators list" : "Избриши {collaboratorLabel} од листата на соработници",
     "Back to {folder}" : "Назад кон {folder}",
     "Share this folder" : "Сподели ја оваа папка",
+    "Loading folders …" : "Се вчитуваат папките…",
     "One of the source folders does not exists" : "Една од папките на постои",
     "Add" : "Додади"
 },
