@@ -72,18 +72,22 @@ OC.L10N.register(
     "The destination folder is owned by {owner}" : "Целевая папка принадлежит пользователю {owner}",
     "There are no photos or videos yet!" : "Пока не содержит ни одной фотографии или видео.",
     "_{years} year ago_::_{years} years ago_" : ["{years} год назад","{years} лет назад","{years} лет назад","{years} лет назад"],
+    "Enable squared photos view" : "Включить квадратный просмотр фотографий",
     "Delete source directory" : "Удалить исходный каталог",
     "Pick folder" : "Выберите папку",
     "Select a source folder for your media" : "Выберите исходную папку для ваших медиафайлов",
-    "Media folders" : "Медиа папки",
-    "Choose the folders from where photos and videos are shown." : "Выберите папки, из которых будут отображаться фотографии и видео.",
     "All folders" : "Все папки",
     "Add a Photos source for the timelines" : "Добавьте источник фотографий для временных шкал",
     "Add folder" : "Добавить папку",
-    "Home" : "Главная страница",
     "Select the default upload location for your media" : "Выберите место загрузки по умолчанию для ваших медиафайлов",
+    "Home" : "Главная страница",
+    "Choose default Photos upload and Albums location" : "Выберите местоположение загрузки фотографий и альбомов по умолчанию",
+    "Choose a different folder" : "Выбрать другую папку",
+    "View" : "Просмотр",
+    "Media folders" : "Медиа папки",
+    "Choose the folders from where photos and videos are shown." : "Выберите папки, из которых будут отображаться фотографии и видео.",
     "Upload folder" : "Папка для загрузки",
-    "General" : "Основные",
+    "Choose the folder where photos and albums are uploaded to." : "Выберите папку, в которую загружаются фотографии и альбомы.",
     "_%n photo_::_%n photos_" : ["%n фотография","%n фотографии","%n фотографий","%n фотографии"],
     "Unselect all" : "Отменить выделение для всех",
     "Add photos to this album" : "Добавить фотографии в альбом",
@@ -158,8 +162,6 @@ OC.L10N.register(
     "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Не удалось переименовать {currentCollectionFileName} в {newCollectionFileName}",
     "Failed to update properties of {collectionFileName} with {properties}" : "Не удалось обновить свойства {collectionFileName} следующими параметрами: {properties}",
     "Failed to delete {collectionFileName}" : "Не удалось удалить {collectionFileName}",
-    "Cancel" : "Cancel",
-    "Confirm" : "Подтвердить",
     "Failed to move {fileBaseName} to person {faceName}" : "Не удалось переместить {fileBaseName} к {faceName}",
     "Failed to remove {fileBaseName}" : "Не удалось удалить {fileBaseName}",
     "Failed to rename {oldName} to {faceName}" : "Не удалось переименовать {oldName} в {faceName}",
@@ -173,12 +175,8 @@ OC.L10N.register(
     "Remove {collaboratorLabel} from the collaborators list" : "Убрать {collaboratorLabel} из списка соавторов ",
     "Back to {folder}" : "Вернуться в {folder}",
     "Share this folder" : "Опубликовать эту папку",
-    "Enable squared photos view" : "Включить квадратный просмотр фотографий",
-    "Choose default Photos upload and Albums location" : "Выберите местоположение загрузки фотографий и альбомов по умолчанию",
-    "Choose a different folder" : "Выбрать другую папку",
-    "View" : "Просмотр",
-    "Choose the folder where photos and albums are uploaded to." : "Выберите папку, в которую загружаются фотографии и альбомы.",
     "Loading folders …" : "Выполняется загрузка папок…",
+    "One of the source folders does not exists" : "Одна из исходных папок не существует",
     "Add" : "Добавить"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
