@@ -21,6 +21,9 @@ OC.L10N.register(
     "Mark selection as favorite" : "Označiť vybrané ako obľúbené",
     "Add selection to favorites" : "Pridať vybrané ako obľúbené",
     "Remove selection from favorites" : "Odstrániť vybrané z obľúbených",
+    "This name is already in use." : "Toto meno je už používané.",
+    "\"{char}\" is not allowed inside a filename." : "Znak \"{char}\" nie je povolený v názve súboru.",
+    "Invalid filename." : "Chybný názov súboru.",
     "Name of the album" : "Názov albumu",
     "Location of the album" : "Umiestnenie albumu",
     "Back" : "Späť",
@@ -39,8 +42,6 @@ OC.L10N.register(
     "Add people or groups who can edit your album" : "Pridať užívateľov alebo skupiny ktoré môžu upravovať váš album",
     "Search people or groups" : "Vyhľadať užívateľov alebo skupiny",
     "No recommendations. Start typing." : "Žiadne odporúčania. Môžete začať písať.",
-    "Group" : "Skupina",
-    "Remove {collaboratorLabel} from the collaborators list" : "Odobrať {collaboratorLabel} zo zoznamu spolupracovníkov",
     "Copy the public link" : "Kopírovať verejný odkaz",
     "Public link copied!" : "Verejný odkaz bol skopírovaný!",
     "Copy public link" : "Kopírovať verejný odkaz",
@@ -114,7 +115,7 @@ OC.L10N.register(
     "This might take some time depending on the size of your photo library." : "Toto môže chvíľu trvať v závislosti od veľkosti vašej knižnice fotografií.",
     "Recognized people will show up here" : "Rozpoznané osoby sa zobrazia tu",
     "This folder does not exist" : "Tento priečinok neexistuje",
-    "Loading folders …" : "Načítavanie priečinkov ...",
+    "Loading folders…" : "Načítavanie priečinkov…",
     "No photos in here" : "Nie sú tu žiadne fotografie",
     "Taken on {date} at {time}" : "Vytvorené dňa {date} o {time}",
     "This place does not have any photos or videos yet!" : "Tento miesto zatiaľ neobsahuje žiadne fotky alebo videá!",
@@ -145,6 +146,7 @@ OC.L10N.register(
     "Tagged photos" : "Fotografie so štítkom",
     "Tagged photo {title}" : "Fotografia so štítkom {title}",
     "{title}'s face" : "Tvár {title}",
+    "Last week" : "Minulý týždeň",
     "{startDate} to {endDate}" : "{startDate} do {endDate}",
     "Details" : "Podrobnosti",
     "Failed to delete {fileBaseName}" : "Nepodarilo sa vymazať {fileBaseName}",
@@ -157,8 +159,11 @@ OC.L10N.register(
     "Failed to set favorite state for {fileId}" : "Nepodarilo sa nastaviť obľúbený stav pre {fileId}",
     "Failed to set favorite state for {fileName}" : "Nepodarilo sa nastaviť obľúbený stav pre {fileName}",
     "Could not load photos folder" : "Nepodarilo sa načítať priečinok s fotkami",
+    "Group" : "Skupina",
+    "Remove {collaboratorLabel} from the collaborators list" : "Odobrať {collaboratorLabel} zo zoznamu spolupracovníkov",
     "Back to {folder}" : "Späť do {folder}",
     "Share this folder" : "Zdieľať tento priečinok",
+    "Loading folders …" : "Načítavanie priečinkov ...",
     "One of the source folders does not exists" : "Jeden zo zdrojových priečinkov neexistuje",
     "Add" : "Pridať"
 },
