@@ -72,19 +72,22 @@ OC.L10N.register(
     "The destination folder is owned by {owner}" : "目標資料夾為 {owner} 擁有",
     "There are no photos or videos yet!" : "還沒有照片或影片！",
     "_{years} year ago_::_{years} years ago_" : ["{years} 年前"],
-    "Squared photos view" : "方形照片檢視",
+    "Enable squared photos view" : "啟用方形照片檢視",
     "Delete source directory" : "刪除來源目錄",
     "Pick folder" : "挑選資料夾",
     "Select a source folder for your media" : "選取您媒體的來源資料夾",
-    "Media folders" : "媒體資料夾",
-    "Choose the folders from where photos and videos are shown." : "選擇顯示照片與影片的資料夾。",
     "All folders" : "所有資料夾",
     "Add a Photos source for the timelines" : "新增時間軸的照片來源",
     "Add folder" : "新增資料夾",
-    "Home" : "家庭",
     "Select the default upload location for your media" : "選取您媒體的預設上傳位置",
+    "Home" : "家庭",
+    "Choose default Photos upload and Albums location" : "選擇預設照片上傳與相簿位置",
+    "Choose a different folder" : "選擇其他資料夾",
+    "View" : "檢視",
+    "Media folders" : "媒體資料夾",
+    "Choose the folders from where photos and videos are shown." : "選擇顯示照片與影片的資料夾。",
     "Upload folder" : "上傳資料夾",
-    "General" : "一般",
+    "Choose the folder where photos and albums are uploaded to." : "選擇照片與相簿上傳到的資料夾。",
     "_%n photo_::_%n photos_" : ["%n 張照片"],
     "Unselect all" : "取消全選",
     "Add photos to this album" : "新增照片至此相簿",
@@ -158,12 +161,7 @@ OC.L10N.register(
     "Failed to create {collectionFileName}" : "建立 {collectionFileName} 失敗",
     "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "無法將 {currentCollectionFileName} 重新命名為 {newCollectionFileName}",
     "Failed to update properties of {collectionFileName} with {properties}" : "無法使用 {properties} 更新 {collectionFileName} 的屬性",
-    "Delete collection" : "刪除收藏",
-    "Leave shared album" : "離開已分享的相簿",
-    "Are you sure you want to delete {collectionName}? This action cannot be undone." : "您確定您想要刪除 {collectionName} 嗎？此動作無法還原。",
     "Failed to delete {collectionFileName}" : "刪除 {collectionFileName} 失敗",
-    "Cancel" : "取消",
-    "Confirm" : "確認",
     "Failed to move {fileBaseName} to person {faceName}" : "將 {fileBaseName} 移動到人物 {faceName} 失敗",
     "Failed to remove {fileBaseName}" : "移除 {fileBaseName} 失敗",
     "Failed to rename {oldName} to {faceName}" : "無法將 {oldName} 重新命名為 {faceName}",
@@ -177,12 +175,8 @@ OC.L10N.register(
     "Remove {collaboratorLabel} from the collaborators list" : "從協作者清單移除 {collaboratorLabel}",
     "Back to {folder}" : "回到 {folder}",
     "Share this folder" : "分享此資料夾",
-    "Enable squared photos view" : "啟用方形照片檢視",
-    "Choose default Photos upload and Albums location" : "選擇預設照片上傳與相簿位置",
-    "Choose a different folder" : "選擇其他資料夾",
-    "View" : "檢視",
-    "Choose the folder where photos and albums are uploaded to." : "選擇照片與相簿上傳到的資料夾。",
     "Loading folders …" : "正在載入資料夾……",
+    "One of the source folders does not exists" : "其中一個來源資料夾不存在",
     "Add" : "新增"
 },
 "nplurals=1; plural=0;");
