@@ -1,29 +1,32 @@
 OC.L10N.register(
     "settings",
     {
+    "Private" : "Прыватна",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Бачна толькі людзям, якія супалі праз інтэграцыю нумара тэлефона з дапамогай Talk на мабільным тэлефоне",
+    "Local" : "Лакальна",
+    "Only visible to people on this instance and guests" : "Бачна толькі карыстальнікам гэтага сервера і гасцям",
+    "Federated" : "Федэратыўны",
+    "Only synchronize to trusted servers" : "Сінхранізацыя толькі з даверанымі серверамі",
+    "Published" : "Апублікавана",
+    "Synchronize to trusted servers and the global and public address book" : "Сінхранізацыя з даверанымі серверамі і глабальнай і публічнай адраснай кнігай",
+    "Verify" : "Спраўдзіць",
+    "Verifying …" : "Спраўджанне …",
     "Unable to change password" : "Немагчыма змяніць пароль",
     "Very weak password" : "Вельмі слабы пароль",
     "Weak password" : "Слабы пароль",
     "So-so password" : "Абы-які пароль",
     "Good password" : "Файны пароль",
     "Strong password" : "Моцны пароль",
+    "Groups" : "Групы",
+    "Group list is empty" : "Спіс груп пусты",
     "{actor} added you to group {group}" : "{actor} дадаў(-ла) вас у групу {group}",
     "You added {user} to group {group}" : "Вы дадалі {user} у групу {group}",
     "{actor} added {user} to group {group}" : "{actor} дадаў(-ла) {user} у групу {group}",
     "An administrator added you to group {group}" : "Адміністратар дадаў вас у групу {group}",
     "An administrator added {user} to group {group}" : "Адміністратар дадаў {user} у групу {group}",
-    "{actor} removed you from group {group}" : "{actor} выдаліў(-ла) вас з групы {group}",
-    "You removed {user} from group {group}" : "Вы выдалілі {user} з групы {group}",
-    "{actor} removed {user} from group {group}" : "{actor} выдаліў(-ла) {user} з групы {group}",
-    "An administrator removed you from group {group}" : "Адміністратар выдаліў вас з групы {group}",
-    "An administrator removed {user} from group {group}" : "Адміністратар выдаліў {user} з групы {group}",
-    "{actor} changed your password" : "{actor} змяніў(-ла) ваш пароль",
     "You changed your password" : "Вы змянілі свой пароль.",
-    "Your password was reset by an administrator" : "Адміністратар скінуў ваш пароль ",
+    "Your password was reset by an administrator" : "Ваш пароль быў скінуты адміністратарам",
     "Your password was reset" : "Ваш пароль быў скінуты",
-    "{actor} changed your email address" : "{actor} змяніў(-ла) ваш адрас электроннай пошты",
-    "You changed your email address" : "Вы змянілі свой адрас электроннай пошты",
-    "Your email address was changed by an administrator" : "Адміністратар змяніў ваш адрас электроннай пошты",
     "You created an app password for a session named \"{token}\"" : "Вы стварылі пароль праграмы для сеанса пад назвай \"{token}\"",
     "An administrator created an app password for a session named \"{token}\"" : "Адміністратар стварыў пароль праграмы для сеанса пад назвай \"{token}\"",
     "You deleted app password \"{token}\"" : "Вы выдалілі пароль праграмы \"{token}\"",
@@ -35,7 +38,6 @@ OC.L10N.register(
     "Could not remove app." : "Не ўдалося выдаліць праграму.",
     "Could not update app." : "Не ўдалося абнавіць праграму.",
     "Wrong password" : "Няправільны пароль",
-    "Unable to change personal password" : "Немагчыма змяніць асабісты пароль",
     "Saved" : "Захавана",
     "Authentication error" : "Памылка аўтэнтыфікацыі",
     "Recently active" : "Нядаўна актыўныя",
@@ -48,7 +50,7 @@ OC.L10N.register(
     "Install Client" : "Усталяваць кліент",
     "Apps" : "Праграмы",
     "Personal" : "Асабістыя",
-    "Administration" : "Адміністраванне",
+    "Administration" : "Адміністратар",
     "Users" : "Карыстальнікі",
     "Additional settings" : "Дадатковыя налады",
     "Assistant" : "Памочнік",
@@ -64,8 +66,6 @@ OC.L10N.register(
     "User's email account" : "Уліковы запіс электроннай пошты карыстальніка",
     "System email account" : "Сістэмны ўліковы запіс электроннай пошты",
     "Verifying" : "Спраўджанне",
-    "Verifying …" : "Спраўджанне …",
-    "Verify" : "Спраўдзіць",
     "Your remote address could not be determined." : "Не ўдалося вызначыць ваш аддалены адрас.",
     "Cron errors" : "Памылкі cron",
     "Cron last run" : "Апошні запуск cron",
@@ -93,14 +93,11 @@ OC.L10N.register(
     "Unknown database platform" : "Невядомая платформа базы даных",
     "Architecture" : "Архітэктура",
     "64-bit" : "64-бітная",
-    "_No scheduled tasks in the last day._::_No scheduled tasks in the last %n days._" : ["Няма запланаваных заданняў за апошні дзень.","Няма запланаваных заданняў за апошнія %n дні.","Няма запланаваных заданняў за апошніх %n дзён.","Няма запланаваных заданняў за апошніх %n дзён."],
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Ваша база даных не працуе з узроўнем ізаляцыі транзакцый \"READ COMMITTED\". Гэта можа выклікаць праблемы пры паралельным выкананні некалькіх дзеянняў.",
     "Font file loading" : "Загрузка файла шрыфту",
     "Profile information" : "Звесткі профілю",
     "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Аватар профілю, поўнае імя, адрас электроннай пошты, нумар тэлефона, адрас, вэб-сайт, Twitter, арганізацыя, роля, загаловак, біяграфія і ці ўключаны ваш профіль",
     "Nextcloud settings" : "Налады Nextcloud",
-    "Unified task processing" : "Уніфікаваная апрацоўка заданняў",
-    "AI tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Заданні ШІ могуць выконвацца рознымі праграмамі. Тут вы можаце задаць, якую праграму трэба выкарыстоўваць для якога задання.",
     "Enable" : "Уключыць",
     "Machine translation" : "Машынны пераклад",
     "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Машынны пераклад можа быць рэалізаваны рознымі праграмамі. Тут вы можаце вызначыць прыярытэт праграм машыннага перакладу, якія ў вас усталяваны ў дадзены момант.",
@@ -108,8 +105,6 @@ OC.L10N.register(
     "Image generation can be implemented by different apps. Here you can set which app should be used." : "Генерацыя відарысаў можа быць рэалізавана рознымі праграмамі. Тут вы можаце задаць, якую праграму трэба выкарыстоўваць.",
     "None of your currently installed apps provide image generation functionality" : "Ніводная з усталяваных праграм не прадугледжвае функцыі генерацыі відарысаў",
     "Text processing" : "Апрацоўка тэксту",
-    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Заданні апрацоўкі тэксту могуць выконвацца рознымі праграмамі. Тут вы можаце задаць, якую праграму трэба выкарыстоўваць для якога задання.",
-    "Task:" : "Заданне:",
     "Here you can decide which group can access certain sections of the administration settings." : "Тут вы можаце вызначыць, якая група мае доступ да пэўных раздзелаў налад адміністравання.",
     "Unable to modify setting" : "Немагчыма змяніць наладу",
     "None" : "Няма",
@@ -119,7 +114,6 @@ OC.L10N.register(
     "Allow apps to use the Share API" : "Дазволіць праграмам выкарыстоўваць API абагульвання",
     "Allow users to share via link and emails" : "Дазволіць карыстальнікам абагульваць праз спасылку і электронную пошту",
     "Allow public uploads" : "Дазволіць публічныя запампоўванні",
-    "Allow public shares to be added to other clouds by federation." : "Дазволіць абагульваць рэсурсы ў іншыя воблакі праз федэрацыю.",
     "Always ask for a password" : "Заўсёды пытацца пароль",
     "Exclude groups from password requirements" : "Выключыць групы з патрабаванняў да пароляў",
     "Exclude groups from creating link shares" : "Выключыць групы з магчымасці стварэння абагуленых спасылак",
@@ -134,7 +128,7 @@ OC.L10N.register(
     "Excluded groups" : "Выключаныя групы",
     "Save changes" : "Захаваць змены",
     "Default" : "Прадвызначаныя",
-    "Update to {update}" : "Абнавіць да {update}",
+    "Update to {update}" : "Абнаўленне да {update}",
     "Remove" : "Выдаліць",
     "Disable all" : "Адключыць усе",
     "Download and enable all" : "Спампаваць і уключыць усе",
@@ -146,11 +140,10 @@ OC.L10N.register(
     "Actions" : "Дзеянні",
     "Results from other categories" : "Вынікі з іншых катэгорый",
     "No apps found for your version" : "Для вашай версіі праграм не знойдзена",
-    "_%n app has an update available_::_%n apps have an update available_" : ["Даступна абнаўленне для %n праграмы","Даступны абнаўленні для %n праграм","Даступны абнаўленні для %n праграм","Даступны абнаўленні для %n праграм"],
+    "_%n app has an update available_::_%n apps have an update available_" : ["Дастыпна абнаўленне для %n праграмы","Дастыпны абнаўленні для %n праграм","Дастыпны абнаўленні для %n праграм","Дастыпны абнаўленні для %n праграм"],
     "_Update_::_Update all_" : ["Абнавіць","Абнавіць усе","Абнавіць усе","Абнавіць усе"],
     "Failed to load groups" : "Не атрымалася загрузіць групы",
     "Failed to create group" : "Не атрымалася стварыць групу",
-    "Groups" : "Групы",
     "Creating group…" : "Стварэнне групы…",
     "Create group" : "Стварыць групу",
     "Group name" : "Назва групы",
@@ -173,8 +166,7 @@ OC.L10N.register(
     "Details" : "Падрабязнасці",
     "All" : "Усе",
     "No results" : "Няма вынікаў",
-    "Update to {version}" : "Абнавіць да {version}",
-    "Delete data on remove" : "Ачысціць даныя пры выдаленні",
+    "Update to {version}" : "Абнаўленне да {version}",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Гэта праграма не можа быць усталявана, бо не выкананы наступныя залежнасці:",
     "Latest updated" : "Апошняе абнаўленне",
     "Author" : "Аўтар",
@@ -242,30 +234,22 @@ OC.L10N.register(
     "You are using {s}{usage}{/s}" : "Вы выкарыстоўваеце {s}{usage}{/s}",
     "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Вы выкарыстоўваеце {s}{usage}{/s} з {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
     "Your full name" : "Ваша поўнае імя",
-    "Unable to delete additional email address" : "Немагчыма выдаліць дадатковую электронную пошту",
     "No email address set" : "Адрас электроннай пошты не зададзены",
-    "Options for additional email address {index}" : "Параметры дадатковай электроннай пошты {index}",
-    "This address is not confirmed" : "Гэты адрас не пацверджаны",
-    "Additional email address {index}" : "Дадатковая электронная пошта {index}",
-    "Unable to add additional email address" : "Немагчыма дадаць дадатковую электронную пошту",
-    "Unable to update additional email address" : "Немагчыма абнавіць дадатковую электронную пошту",
-    "Primary email for password reset and notifications" : "Асноўны адрас для скіду пароля і апавяшчэнняў",
     "Derived from your locale ({weekDayName})" : "Паходзіць з вашай лакалі ({weekDayName})",
     "Unable to update first day of week" : "Немагчыма абнавіць першы дзень тыдня",
     "Day to use as the first day of week" : "Дзень, які выкарыстоўваецца ў якасці першага дня тыдня",
     "Your headline" : "Ваш загаловак",
-    "No language set" : "Мова не зададзена",
     "Unable to update language" : "Немагчыма абнавіць мову",
     "Languages" : "Мовы",
     "Help translate" : "Дапамагчы з перакладам",
-    "No locale set" : "Лакаль не зададзена",
+    "No language set" : "Мова не зададзена",
     "Unable to update locale" : "Немагчыма абнавіць лакаль",
     "Locales" : "Лакалі",
     "Week starts on {firstDayOfWeek}" : "Тыдзень пачынаецца з {firstDayOfWeek}",
+    "No locale set" : "Лакаль не зададзена",
     "Your city" : "Ваш горад",
     "Your organisation" : "Ваша арганізацыя",
     "Your phone number" : "Ваш нумар тэлефона",
-    "Edit your Profile visibility" : "Змяніць бачнасць профілю",
     "Enable profile" : "Уключыць профіль",
     "she/her" : "яна",
     "he/him" : "ён",
@@ -274,7 +258,6 @@ OC.L10N.register(
     "Your role" : "Ваша роля",
     "Timezone" : "Часавы пояс",
     "Your website" : "Ваш вэб-сайт",
-    "Add additional email" : "Дадаць дадатковы адрас электроннай пошты",
     "Add" : "Дадаць",
     "Create" : "Стварыць",
     "Change" : "Змяніць",
@@ -288,29 +271,23 @@ OC.L10N.register(
     "Personal use" : "Асабістае выкарыстанне",
     "Default language" : "Прадвызначаная мова",
     "Other languages" : "Іншыя мовы",
-    "Password change is disabled because the master key is disabled" : "Змена пароля адключана, бо адключаны галоўны ключ",
     "No accounts" : "Няма ўліковых запісаў",
-    "Loading accounts …" : "Загрузка ўліковых запісаў …",
+    "Loading accounts …" : "Загрузка ўліковых запісаў …",
     "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "Спіс уліковых запісаў. Гэты спіс не апрацоўваецца цалкам з меркаванняў прадукцыйнасці. Уліковыя запісы будуць апрацоўвацца па меры навігацыі па спісе.",
     "Manager" : "Менеджар",
-    "Set line manager" : "Задаць лінейнага менеджара",
     "Account name will be autogenerated" : "Імя ўліковага запісу будзе згенерыравана аўтаматычна",
     "Account name (required)" : "Імя ўліковага запісу (абавязкова)",
-    "Failed to search groups" : "Не атрымалася знайсці групы",
     "New account" : "Новы ўліковы запіс",
     "Display name" : "Імя для паказу",
-    "Either password or email is required" : "Патрабуецца пароль або адрас электроннай пошты",
     "Password (required)" : "Пароль (абавязкова)",
     "Email (required)" : "Электронная пошта (абавязкова)",
     "Email" : "Электронная пошта",
-    "Admin of the following groups" : "Адміністратар наступных груп",
-    "Set account as admin for …" : "Задаць уліковы запіс у якасці адміністратара для …",
+    "Set account as admin for …" : "Задаць уліковы запіс у якасці адміністратара для …",
     "Quota" : "Квота",
     "Set account quota" : "Задаць квоту ўліковага запісу",
     "Language" : "Мова",
     "Set default language" : "Задаць прадвызначаную мову",
-    "Add new account" : "Дадаць новы ўліковы запіс",
-    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} уліковы запіс …","{userCount} уліковыя запісы …","{userCount} уліковых запісаў …","{userCount} уліковых запісаў …"],
+    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} уліковы запіс …","{userCount} уліковыя запісы …","{userCount} уліковых запісаў …","{userCount} уліковых запісаў …"],
     "_{userCount} account_::_{userCount} accounts_" : ["{userCount} уліковы запіс","{userCount} уліковыя запісы","{userCount} уліковых запісаў","{userCount} уліковых запісаў"],
     "Total rows summary" : "Зводка па ўсіх радках",
     "Avatar" : "Аватар",
@@ -319,10 +296,9 @@ OC.L10N.register(
     "Delete account" : "Выдаліць уліковы запіс",
     "Disable account" : "Адключыць уліковы запіс",
     "Enable account" : "Уключыць уліковы запіс",
-    "Failed to update line manager" : "Не ўдалося абнавіць лінейнага менеджара",
     "Account deletion" : "Выдаленне ўліковага запісу",
     "Display name was successfully changed" : "Імя для паказу паспяхова зменена",
-    "Loading account …" : "Загрузка ўліковага запісу …",
+    "Loading account …" : "Загрузка ўліковага запісу …",
     "Change display name" : "Змяніць імя для паказу",
     "Set new password" : "Задаць новы пароль",
     "Add account to group" : "Дадаць уліковы запіс у групу",
@@ -341,7 +317,7 @@ OC.L10N.register(
     "Default quota" : "Прадвызначаная квота",
     "Select default quota" : "Выберыце прадвызначаную квоту",
     "Add WebAuthn device" : "Дадаць прыладу WebAuthn",
-    "Adding your device …" : "Дадаванне вашай прылады …",
+    "Adding your device …" : "Дадаванне вашай прылады …",
     "Unnamed device" : "Прылада без назвы",
     "No devices configured." : "Няма сканфігураваных прылад.",
     "Your browser does not support WebAuthn." : "Ваш браўзер не падтрымлівае WebAuthn.",
@@ -363,7 +339,6 @@ OC.L10N.register(
     "About" : "Пра сябе",
     "Date of birth" : "Дата нараджэння",
     "Full name" : "Поўнае імя",
-    "Additional email" : "Дадатковая электронная пошта",
     "Headline" : "Загаловак",
     "Organisation" : "Арганізацыя",
     "Phone number" : "Нумар тэлефона",
@@ -372,18 +347,9 @@ OC.L10N.register(
     "X (formerly Twitter)" : "X (былы Twitter)",
     "Bluesky" : "Bluesky",
     "Website" : "Вэб-сайт",
-    "Profile visibility" : "Бачнасць профілю",
     "Locale" : "Лакаль",
     "First day of week" : "Першы дзень тыдня",
     "timezone" : "часавы пояс",
-    "Private" : "Прыватна",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Бачна толькі людзям, якія супалі праз інтэграцыю нумара тэлефона з дапамогай Talk на мабільным тэлефоне",
-    "Local" : "Лакальна",
-    "Only visible to people on this instance and guests" : "Бачна толькі карыстальнікам гэтага сервера і гасцям",
-    "Federated" : "Федэратыўны",
-    "Only synchronize to trusted servers" : "Сінхранізацыя толькі з даверанымі серверамі",
-    "Published" : "Апублікавана",
-    "Synchronize to trusted servers and the global and public address book" : "Сінхранізацыя з даверанымі серверамі і глабальнай і публічнай адраснай кнігай",
     "Your apps" : "Вашы праграмы",
     "Active apps" : "Актыўныя праграмы",
     "Disabled apps" : "Адключаныя праграмы",
@@ -391,8 +357,7 @@ OC.L10N.register(
     "App bundles" : "Наборы праграм",
     "Featured apps" : "Папулярныя праграмы",
     "Supported apps" : "Праграмы, якія падтрымліваюцца",
-    "Show to everyone" : "Паказваць усім",
-    "Show to logged in accounts only" : "Паказваць толькі ўліковым запісам у сістэме",
+    "Show to everyone" : "Паказаць усім",
     "Hide" : "Схаваць",
     "Download and enable" : "Спампаваць і ўключыць",
     "Disable" : "Адключыць",
@@ -425,13 +390,10 @@ OC.L10N.register(
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Распрацоўваецца {communityopen}супольнасцю Nextcloud{linkclose}, {githubopen}зыходны код{linkclose} распаўсюджваецца па ліцэнзіі {licenseopen}AGPL{linkclose}.",
     "Check out our blog" : "Азнаёмцеся з нашым блогам",
     "Subscribe to our newsletter" : "Падпішыцеся на нашу рассылку",
-    "Group list is empty" : "Спіс груп пусты",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Гэтай праграме не прызначана мінімальная версія Nextcloud. У будучыні гэта будзе памылкай.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Гэтай праграме не прызначана максімальная версія Nextcloud. У будучыні гэта будзе памылкай.",
-    "Loading accounts …" : "Загрузка ўліковых запісаў …",
-    "Set account as admin for …" : "Задаць уліковы запіс у якасці адміністратара для …",
-    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} уліковы запіс …","{userCount} уліковыя запісы …","{userCount} уліковых запісаў …","{userCount} уліковых запісаў …"],
-    "Loading account …" : "Загрузка ўліковага запісу …",
-    "Adding your device …" : "Дадаванне вашай прылады …"
+    "Your biography" : "Ваша біяграфія",
+    "You are using <strong>{usage}</strong>" : "Вы выкарыстоўваеце <strong>{usage}</strong>",
+    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Вы выкарыстоўваеце <strong>{usage}</strong> з <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
