@@ -1,12 +1,20 @@
 OC.L10N.register(
     "settings",
     {
+    "Private" : "Privado",
+    "Local" : "Local",
+    "Federated" : "Federado",
+    "Verify" : "Verificar",
+    "Verifying …" : "Verificando ...",
     "Unable to change password" : "No fue posible cambiar la contraseña",
     "Very weak password" : "Contraseña muy débil",
     "Weak password" : "Contraseña débil",
     "So-so password" : "Contraseña aceptable",
     "Good password" : "Buena contraseña",
     "Strong password" : "Contraseña fuerte",
+    "Groups" : "Grupos",
+    "Group list is empty" : "La lista de grupos esta vacía",
+    "Unable to retrieve the group list" : "No fue posible recuperar la lista del gurpo",
     "{actor} changed your password" : "{actor} ha cambiado tu contraseña",
     "You changed your password" : "Cambiaste tu contraseña",
     "Your password was reset by an administrator" : "Tu contraseña ha sido restablecida por un adminsitrador",
@@ -69,8 +77,6 @@ OC.L10N.register(
     "Background jobs" : "Trabajos en segundo plano",
     "Unlimited" : "Ilimitado",
     "Verifying" : "Verificando",
-    "Verifying …" : "Verificando ...",
-    "Verify" : "Verificar",
     "Disabled" : "Deshabilitado",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La función de PHP \"set_time_limit\" no está disponible. Esto podría generar que la ejecución de scripts se detenga, rompiendo su instalación. Se recomienda ámpliamente habilitar esta función. ",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Tu PHP no cuenta con soporte FreeType, lo que resulta en fallas en la imagen de perfil y la interface de configuraciones. ",
@@ -98,7 +104,6 @@ OC.L10N.register(
     "Level" : "Nivel",
     "Actions" : "Acciones",
     "No apps found for your version" : "No se encontraron aplicaciones para tu versión",
-    "Groups" : "Grupos",
     "Group name" : "Nombre del grupo",
     "Loading" : "Cargando",
     "Daemon" : "Demonio",
@@ -189,9 +194,6 @@ OC.L10N.register(
     "Full name" : "Nombre completo",
     "Phone number" : "Número de teléfono",
     "Website" : "Sitio web",
-    "Private" : "Privado",
-    "Local" : "Local",
-    "Federated" : "Federado",
     "Your apps" : "Tus aplicaciones",
     "Disabled apps" : "Aplicaciones deshabilitadas",
     "Updates" : "Actualizaciones",
@@ -221,9 +223,8 @@ OC.L10N.register(
     "Like our Facebook page" : "Da un Like a nuestra página de Facebook",
     "Check out our blog" : "Visita nuestro blog",
     "Subscribe to our newsletter" : "Suscribete a nuestro boletín",
-    "Group list is empty" : "La lista de grupos esta vacía",
-    "Unable to retrieve the group list" : "No fue posible recuperar la lista del gurpo",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro."
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
+    "You are using <strong>{usage}</strong>" : "Estás usando<strong>{usage}</strong>"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
