@@ -1,12 +1,25 @@
 OC.L10N.register(
     "settings",
     {
+    "Private" : "Privado",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Solo visible para las personas que coinciden a través de la integración del número de teléfono mediante Talk en dispositivos móviles",
+    "Local" : "Local",
+    "Only visible to people on this instance and guests" : "Solo visible para las personas en esta instancia y los invitados",
+    "Federated" : "Federado",
+    "Only synchronize to trusted servers" : "Solo sincronizar con servidores de confianza",
+    "Published" : "Publicado",
+    "Synchronize to trusted servers and the global and public address book" : "Sincronizar con servidores de confianza y la libreta de direcciones global y pública",
+    "Verify" : "Verificar",
+    "Verifying …" : "Verificando ...",
     "Unable to change password" : "No fue posible cambiar la contraseña",
     "Very weak password" : "Contraseña muy débil",
     "Weak password" : "Contraseña débil",
     "So-so password" : "Contraseña aceptable",
     "Good password" : "Buena contraseña",
     "Strong password" : "Contraseña fuerte",
+    "Groups" : "Grupos",
+    "Group list is empty" : "La lista de grupos esta vacía",
+    "Unable to retrieve the group list" : "No fue posible recuperar la lista del gurpo",
     "{actor} added you to group {group}" : "{actor} te agregó al grupo {group}",
     "You added {user} to group {group}" : "Agregaste a {user} al grupo {group}",
     "{actor} added {user} to group {group}" : "{actor} agregó a {user} al grupo {group}",
@@ -101,8 +114,6 @@ OC.L10N.register(
     "Background jobs" : "Trabajos en segundo plano",
     "Unlimited" : "Ilimitado",
     "Verifying" : "Verificando",
-    "Verifying …" : "Verificando ...",
-    "Verify" : "Verificar",
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Su directorio de datos y sus archivos probablemente sean accesibles desde Internet. El archivo .htaccess no está funcionando. Se recomienda encarecidamente que configure su servidor web de manera que el directorio de datos ya no sea accesible, o mueva el directorio de datos fuera de la raíz del documento del servidor web.",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "A la base de datos le faltan algunas columnas opcionales. Debido a que agregar columnas en tablas grandes puede llevar tiempo, no se agregaron automáticamente cuando pueden ser opcionales. Al ejecutar \"occ db:add-missing-columns\", se pueden agregar manualmente esas columnas faltantes mientras la instancia sigue funcionando. Una vez que se agregan las columnas, algunas características pueden mejorar la capacidad de respuesta o la usabilidad.",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "A la base de datos le faltan algunas claves principales. Debido a que agregar claves principales en tablas grandes puede llevar tiempo, no se agregaron automáticamente. Al ejecutar \"occ db:add-missing-primary-keys\", se pueden agregar manualmente esas claves principales faltantes mientras la instancia sigue funcionando.",
@@ -164,7 +175,6 @@ OC.L10N.register(
     "No apps found for your version" : "No se encontraron aplicaciones para tu versión",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n aplicación tiene una actualización disponible","%n aplicaciones tienen una actualización disponible","%n aplicaciones tienen una actualización disponible"],
     "_Update_::_Update all_" : ["Actualizar","Actualizar todo","Actualizar todo"],
-    "Groups" : "Grupos",
     "Group name" : "Nombre del grupo",
     "Loading groups…" : "Cargando grupos...",
     "Loading" : "Cargando",
@@ -245,7 +255,6 @@ OC.L10N.register(
     "This is the final warning: Do you really want to enable encryption?" : "Esta es la advertencia final: ¿Realmente deseas habilitar la encripción?",
     "Submit" : "Enviar",
     "Rename group" : "Renombrar grupo",
-    "Delete group" : "Eliminar grupo",
     "Current password" : "Contraseña actual",
     "New password" : "Nueva contraseña",
     "Choose your profile picture" : "Elige tu foto de perfil",
@@ -264,9 +273,6 @@ OC.L10N.register(
     "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Ten en cuenta que puede tomar hasta 24 horas para que tu foto de perfil se actualice en todos lados.",
     "You are a member of the following groups:" : "Eres miembro de los siguientes grupos:",
     "Your full name" : "Tu nombre completo",
-    "Unable to update primary email address" : "No se pudo actualizar la dirección de correo electrónico principal",
-    "Unable to delete additional email address" : "No se pudo eliminar la dirección de correo electrónico adicional",
-    "No email address set" : "No se ha establecido la dirección de correo electrónico",
     "Email options" : "Opciones de correo electrónico",
     "Remove primary email" : "Eliminar correo electrónico principal",
     "Delete email" : "Eliminar correo electrónico",
@@ -275,17 +281,20 @@ OC.L10N.register(
     "Set as primary email" : "Establecer como correo electrónico principal",
     "Additional email address {index}" : "Dirección de correo electrónico adicional {index}",
     "Unable to delete primary email address" : "No se pudo eliminar la dirección de correo electrónico principal",
+    "Unable to update primary email address" : "No se pudo actualizar la dirección de correo electrónico principal",
     "Unable to add additional email address" : "No se pudo agregar la dirección de correo electrónico adicional",
     "Unable to update additional email address" : "No se pudo actualizar la dirección de correo electrónico adicional",
+    "Unable to delete additional email address" : "No se pudo eliminar la dirección de correo electrónico adicional",
     "Primary email for password reset and notifications" : "Correo electrónico principal para restablecimiento de contraseña y notificaciones",
+    "No email address set" : "No se ha establecido la dirección de correo electrónico",
     "Your handle" : "Nombre de usuario/a",
     "Your headline" : "Título",
-    "No language set" : "No se ha configurado ningún idioma",
     "Unable to update language" : "No se pudo actualizar el idioma",
     "Help translate" : "Ayuda a traducir",
-    "No locale set" : "No se ha configurado ninguna configuración regional",
+    "No language set" : "No se ha configurado ningún idioma",
     "Unable to update locale" : "No se pudo actualizar la configuración regional",
     "Week starts on {firstDayOfWeek}" : "La semana comienza el {firstDayOfWeek}",
+    "No locale set" : "No se ha configurado ninguna configuración regional",
     "Your city" : "Tu ciudad",
     "Your organisation" : "Tu organización",
     "Your phone number" : "Su número telefónico",
@@ -358,6 +367,7 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "La autenticación sin contraseña requiere una conexión segura.",
     "Add WebAuthn device" : "Agregar dispositivo WebAuthn",
     "Please authorize your WebAuthn device." : "Autoriza tu dispositivo WebAuthn.",
+    "Adding your device …" : "Agregando tu dispositivo ...",
     "Unnamed device" : "Dispositivo sin nombre",
     "Passwordless Authentication" : "Autenticación sin contraseña",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Configura tu cuenta para la autenticación sin contraseña siguiendo el estándar FIDO2.",
@@ -388,15 +398,7 @@ OC.L10N.register(
     "Website" : "Sitio web",
     "Profile visibility" : "Visibilidad del perfil",
     "Locale" : "Configuración regional",
-    "Private" : "Privado",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Solo visible para las personas que coinciden a través de la integración del número de teléfono mediante Talk en dispositivos móviles",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "No disponible, ya que esta propiedad es necesaria para la funcionalidad básica, incluyendo el intercambio de archivos y las invitaciones de calendario.",
-    "Local" : "Local",
-    "Only visible to people on this instance and guests" : "Solo visible para las personas en esta instancia y los invitados",
-    "Federated" : "Federado",
-    "Only synchronize to trusted servers" : "Solo sincronizar con servidores de confianza",
-    "Published" : "Publicado",
-    "Synchronize to trusted servers and the global and public address book" : "Sincronizar con servidores de confianza y la libreta de direcciones global y pública",
     "Your apps" : "Tus aplicaciones",
     "Active apps" : "Aplicaciones activas",
     "Disabled apps" : "Aplicaciones deshabilitadas",
@@ -448,12 +450,15 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Esta versión comunitaria de Nextcloud no cuenta con soporte y las notificaciones instantáneas no están disponibles.",
     "Use a second factor besides your password to increase security for your account." : "Utiliza un segundo factor además de tu contraseña para aumentar la seguridad de tu cuenta.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Si utilizas aplicaciones de terceros para conectarte a Nextcloud, asegúrate de crear y configurar una contraseña de aplicación para cada una antes de habilitar la autenticación de segundo factor.",
-    "Group list is empty" : "La lista de grupos esta vacía",
-    "Unable to retrieve the group list" : "No fue posible recuperar la lista del gurpo",
+    "Set default expiration date for shares" : "Establecer fecha de vencimiento predeterminada para los compartidos",
+    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Si se habilita el autocompletado \"mismo grupo\" y \"integración de números de teléfono\", es suficiente una coincidencia en cualquiera de los dos para mostrar el usuario.",
+    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Permitir autocompletado al ingresar el nombre completo o la dirección de correo electrónico (ignorando la falta de coincidencia en la libreta de direcciones y estar en el mismo grupo)",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
+    "Your biography" : "Tu biografía",
+    "You are using <strong>{usage}</strong>" : "Estás usando <strong>{usage}</strong>",
+    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Estás usando <strong>{usage}</strong> de <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "En caso de pérdida del dispositivo o salida de la organización, esto puede borrar de forma remota los datos de Nextcloud de todos los dispositivos asociados con {userid}. Solo funciona si los dispositivos están conectados a Internet.",
-    "Adding your device …" : "Agregando tu dispositivo ...",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Esta aplicación no está marcada como compatible con tu versión de Nextcloud. Si continúas, aún podrás instalar la aplicación. Ten en cuenta que es posible que la aplicación no funcione como se espera.",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Es importante para la seguridad y el rendimiento de tu instancia que todo esté configurado correctamente. Para ayudarte con eso, realizamos algunas comprobaciones automáticas. Consulta la documentación enlazada para obtener más información.",
     "Checking for system and security issues." : "Comprobando problemas del sistema y de seguridad.",
