@@ -1,12 +1,25 @@
 OC.L10N.register(
     "settings",
     {
+    "Private" : "Privado",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Sólo visible para las personas que coinciden a través de la integración del número de teléfono mediante Talk en dispositivos móviles",
+    "Local" : "Local",
+    "Only visible to people on this instance and guests" : "Sólo visible para las personas de esta instancia e invitados",
+    "Federated" : "Federado",
+    "Only synchronize to trusted servers" : "Sólo sincronizar con servidores de confianza",
+    "Published" : "Publicado",
+    "Synchronize to trusted servers and the global and public address book" : "Sincronizar con servidores de confianza y la libreta de direcciones global y pública",
+    "Verify" : "Verificar",
+    "Verifying …" : "Verificando ...",
     "Unable to change password" : "No fue posible cambiar la contraseña",
     "Very weak password" : "Contraseña muy débil",
     "Weak password" : "Contraseña débil",
     "So-so password" : "Contraseña aceptable",
     "Good password" : "Buena contraseña",
     "Strong password" : "Contraseña fuerte",
+    "Groups" : "Grupos",
+    "Group list is empty" : "La lista de Grupo está vacía",
+    "Unable to retrieve the group list" : "No fue posible recuperar la lista del gurpo",
     "{actor} added you to group {group}" : "{actor} te ha añadido al grupo {group}",
     "You added {user} to group {group}" : "Tú has añadido a {user} al grupo {group}",
     "{actor} added {user} to group {group}" : "{actor} ha añadido a {user} al grupo {group}",
@@ -116,8 +129,6 @@ OC.L10N.register(
     "Background jobs" : "Trabajos en segundo plano",
     "Unlimited" : "Ilimitado",
     "Verifying" : "Verificando",
-    "Verifying …" : "Verificando ...",
-    "Verify" : "Verificar",
     "Allowed admin IP ranges" : "Rangos de IP permitidos para administración",
     "Admin IP filtering is correctly configured." : "El filtro de IP de administración está configurado correctamente.",
     "App directories owner" : "Propietario de los directorios de aplicaciones",
@@ -336,7 +347,6 @@ OC.L10N.register(
     "_%n app has an update available_::_%n apps have an update available_" : ["%n aplicación tiene una actualización disponible","%n aplicaciones tienen una actualización disponible","%n aplicaciones tienen una actualización disponible"],
     "_Update_::_Update all_" : ["Actualizar","Actualizar todo","Actualizar todo"],
     "Failed to create group" : "No se pudo crear el grupo",
-    "Groups" : "Grupos",
     "Creating group…" : "Creando grupo...",
     "Create group" : "Crear grupo",
     "Group name" : "Nombre del grupo",
@@ -482,9 +492,6 @@ OC.L10N.register(
     "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Estás usando {s}{usage}{/s} de {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
     "You are a member of the following groups:" : "Usted es miembro de los siguientes grupos:",
     "Your full name" : "Su nombre completo",
-    "Unable to update primary email address" : "No se pudo actualizar la dirección de correo electrónico principal",
-    "Unable to delete additional email address" : "No se pudo eliminar la dirección de correo electrónico adicional",
-    "No email address set" : "No se ha establecido la dirección de correo electrónico",
     "Email options" : "Opciones de correo electrónico",
     "Options for additional email address {index}" : "Opciones para direcciones de correo electrónico adicionales {index}",
     "Remove primary email" : "Eliminar correo electrónico principal",
@@ -494,22 +501,25 @@ OC.L10N.register(
     "Set as primary email" : "Establecer como correo electrónico principal",
     "Additional email address {index}" : "Dirección de correo electrónico adicional {index}",
     "Unable to delete primary email address" : "No se pudo eliminar la dirección de correo electrónico principal",
+    "Unable to update primary email address" : "No se pudo actualizar la dirección de correo electrónico principal",
     "Unable to add additional email address" : "No se pudo agregar la dirección de correo electrónico adicional",
     "Unable to update additional email address" : "No se pudo actualizar la dirección de correo electrónico adicional",
+    "Unable to delete additional email address" : "No se pudo eliminar la dirección de correo electrónico adicional",
     "Primary email for password reset and notifications" : "Correo electrónico principal para restablecer la contraseña y notificaciones",
+    "No email address set" : "No se ha establecido la dirección de correo electrónico",
     "Your handle" : "Su identificador",
     "Derived from your locale ({weekDayName})" : "Deducido de tu locale ({weekDayName})",
     "Unable to update first day of week" : "No se pudo modificar el primer día de la semana",
     "Day to use as the first day of week" : "Primer día de la semana",
     "Your headline" : "Su titular",
-    "No language set" : "No se ha establecido ningún idioma",
     "Unable to update language" : "No se pudo actualizar el idioma",
     "Languages" : "Idiomas",
     "Help translate" : "Ayuda a traducir",
-    "No locale set" : "No se ha configurado ninguna configuración regional",
+    "No language set" : "No se ha establecido ningún idioma",
     "Unable to update locale" : "No se pudo actualizar la configuración regional",
     "Locales" : "Configuración regional",
     "Week starts on {firstDayOfWeek}" : "La semana empieza el {firstDayOfWeek}",
+    "No locale set" : "No se ha configurado ninguna configuración regional",
     "Your city" : "Su ciudad",
     "Your organisation" : "Su organización",
     "Your phone number" : "Su número telefónico",
@@ -542,6 +552,7 @@ OC.L10N.register(
     "Other languages" : "Otros idiomas",
     "Password change is disabled because the master key is disabled" : "El cambio de contraseña está deshabilitado porque la llave maestra está deshabilitada",
     "No accounts" : "Sin cuentas",
+    "Loading accounts …" : "Cargando cuentas ...",
     "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "Lista de usuarios. Esta lista no se muestra completa por razones de rendimiento. Los usuarios se mostrarán a medida que navegue por la lista.",
     "Manager" : "Administrador",
     "Set line manager" : "Establecer el administrador",
@@ -557,6 +568,7 @@ OC.L10N.register(
     "Member of the following groups" : "Miembro de los siguientes grupos",
     "Set account groups" : "Configurar grupos de la cuenta",
     "Admin of the following groups" : "Administrador de los siguientes grupos",
+    "Set account as admin for …" : "Establecer cuenta como administrador de ...",
     "Quota" : "Cuota",
     "Set account quota" : "Definir cuota de la cuenta",
     "Language" : "Idioma",
@@ -589,6 +601,7 @@ OC.L10N.register(
     "Password was successfully changed" : "Se cambió correctamente la contraseña",
     "Email was successfully changed" : "Se cambió correctamente el correo electrónico",
     "Welcome mail sent!" : "¡Correo de bienvenida enviado!",
+    "Loading account …" : "Cargando cuenta ...",
     "Change display name" : "Cambiar el nombre a mostrar",
     "Set new password" : "Establecer nueva contraseña",
     "You do not have permissions to see the details of this account" : "No tiene los permisos para ver los detalles de este usuario",
@@ -620,6 +633,7 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "La autentificación sin contraseña requiere una conexión segura.",
     "Add WebAuthn device" : "Añadir dispositivo WebAuthn",
     "Please authorize your WebAuthn device." : "Por favor, autorice su dispositivo WebAuthn.",
+    "Adding your device …" : "Añadiendo su dispositivo ...",
     "Unnamed device" : "Dispositivo sin nombre",
     "Passwordless Authentication" : "Autentificación sin contraseña",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Configure su cuenta para autentificación sin contraseña siguiendo el estándar FIDO2.",
@@ -663,16 +677,8 @@ OC.L10N.register(
     "Profile visibility" : "Visibilidad del perfil",
     "Locale" : "Configuración regional",
     "First day of week" : "Primer día de la semana",
-    "Private" : "Privado",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Sólo visible para las personas que coinciden a través de la integración del número de teléfono mediante Talk en dispositivos móviles",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "No disponible, ya que esta propiedad es necesaria para la funcionalidad básica, incluyendo el compartir archivos y las invitaciones de calendario.",
-    "Local" : "Local",
-    "Only visible to people on this instance and guests" : "Sólo visible para las personas de esta instancia e invitados",
-    "Federated" : "Federado",
-    "Only synchronize to trusted servers" : "Sólo sincronizar con servidores de confianza",
     "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "No disponible, ya que la federación ha sido deshabilitada para su cuenta, contacte a su administrador del sistema si tiene alguna pregunta",
-    "Published" : "Publicado",
-    "Synchronize to trusted servers and the global and public address book" : "Sincronizar con servidores de confianza y la libreta de direcciones global y pública",
     "Not available as publishing account specific data to the lookup server is not allowed, contact your system administration if you have any questions" : "No disponible, ya que no se permite la publicación de datos específicos de usuario en el servidor de búsqueda, póngase en contacto con el administrador del sistema si tiene alguna duda",
     "Discover" : "Descubrir",
     "Your apps" : "Tus aplicaciones",
@@ -685,6 +691,8 @@ OC.L10N.register(
     "Show to everyone" : "Mostrar a todos",
     "Show to logged in accounts only" : "Mostrar únicamente a usuarios conectados",
     "Hide" : "Ocultar",
+    "{progress}% Deploying …" : "{progress}% Desplegando...",
+    "{progress}% Initializing …" : "{progress}% Inicializando...",
     "Health checking" : "Revisión de salud del servidor",
     "Deploy and Enable" : "Desplegar y activar",
     "Download and enable" : "Descargar y habilitar",
@@ -742,18 +750,20 @@ OC.L10N.register(
     "Subscribe to our newsletter" : "Suscribete a nuestro boletín",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "El lanzamiento de esta versión para la comunidad de Nextcloud no cuenta con soporte y las notificaciones instantáneas no están disponibles.",
     "Use a second factor besides your password to increase security for your account." : "Use un segundo factor además de su contraseña para incrementar la seguridad de su cuenta. ",
-    "Group list is empty" : "La lista de Grupo está vacía",
-    "Unable to retrieve the group list" : "No fue posible recuperar la lista del gurpo",
     "Logged in account must be a subadmin" : "El usuario conectado debe ser un subadministrador",
+    "File locking" : "Bloqueo de archivos",
+    "The PHP memory limit is below the recommended value of %s." : "El límite de memoria de PHP está por debajo del valor recomendado de %s.",
+    "for WebAuthn passwordless login" : "para el inicio de sesión sin contraseña de WebAuthn",
+    "for WebAuthn passwordless login, and SFTP storage" : "para el inicio de sesión sin contraseña de WebAuthn y el almacenamiento SFTP",
+    "Set default expiration date for shares" : "Establecer fecha de caducidad predeterminada para compartidos",
+    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Si se habilita el autocompletado de \"mismo grupo\" e \"integración de números de teléfono\", es suficiente una coincidencia en cualquiera de los dos para mostrar el usuario.",
+    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Permitir el autocompletado al ingresar el nombre completo o la dirección de correo electrónico (ignorando la falta de coincidencia en el directorio telefónico y estar en el mismo grupo)",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
-    "Loading accounts …" : "Cargando cuentas ...",
-    "Set account as admin for …" : "Establecer cuenta como administrador de ...",
+    "Your biography" : "Su biografía",
+    "You are using <strong>{usage}</strong>" : "Está usando <strong>{usage}</strong>",
+    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Está usando <strong>{usage}</strong> de <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "En caso de pérdida del dispositivo o salida de la organización, esto puede borrar de forma remota los datos de Nextcloud de todos los dispositivos asociados con {userid}. Solo funciona si los dispositivos están conectados a Internet.",
-    "Loading account …" : "Cargando cuenta ...",
-    "Adding your device …" : "Añadiendo su dispositivo ...",
-    "{progress}% Deploying …" : "{progress}% Desplegando...",
-    "{progress}% Initializing …" : "{progress}% Inicializando...",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Esta app no está marcada como compatible con tu versión de Nextcloud. Si continúas podrás instalar la app, pero ten en cuenta que podría no funcionar según lo esperado.",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Es importante para la seguridad y rendimiento de su instancia que todo esté correctamente configurado. Para ayudarle en ello estamos haciendo algunas comprobaciones automáticas. Para más información, por favor compruebe la documentación enlazada.",
     "Checking for system and security issues." : "Comprobando problemas del sistema y seguridad.",
