@@ -121,8 +121,6 @@ OC.L10N.register(
     "All" : "Todos",
     "No results" : "No hay resultados",
     "Update to {version}" : "Actualizar a {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicación no puede ser instalada porque las siguientes dependencias no están satisfechas:",
     "Categories" : "Categorías",
     "Resources" : "Recursos",
@@ -133,6 +131,7 @@ OC.L10N.register(
     "Rate" : "Calificar",
     "Changelog" : "Bitácora de cambios",
     "Google Chrome for Android" : "Google Chrome para Android",
+    "{productName} Android app" : "{productName} aplicación Android",
     "This session" : "Esta sesión",
     "Allow filesystem access" : "Permitir acceso al sistema de archivos",
     "Rename" : "Renombrar",
@@ -146,6 +145,7 @@ OC.L10N.register(
     "Create new app password" : "Crear una nueva contraseña de aplicación",
     "Login" : "Iniciar sesión",
     "Password" : "Contraseña",
+    "Password confirmation is required" : "Se requiere la confirmación de la contraseña",
     "Server-side encryption" : "Encripción del lado del servidor",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "La encripción del lado del servidor hace posible encriptar archivos que serán cargados a este servidor. Esto trae consigo algunas limitaciónes como penalizaciones en el desemeño, asi que habilítalo sólo si es necesario. ",
     "Enable server-side encryption" : "Habilitar encripción del lado del servidor",
@@ -160,19 +160,16 @@ OC.L10N.register(
     "Submit" : "Enviar",
     "Current password" : "Contraseña actual",
     "New password" : "Nueva contraseña",
-    "Change password" : "Cambiar contraseña",
     "Picture provided by original account" : "Imagen proporcionada por la cuenta original ",
     "No email address set" : "No se ha establecido la dirección de correo electrónico",
     "Help translate" : "Ayuda a traducir",
     "Your phone number" : "Su número telefónico",
+    "Timezone" : "Zona horaria",
     "Your website" : "Tu sitio web",
-    "Add" : "Agregar",
-    "Create" : "Crear",
+    "Add" : "Guardar",
     "Change" : "Cambiar",
     "Delete" : "Borrar",
-    "Display name" : "Nombre a desplegar",
     "Email" : "Correo electrónico",
-    "Quota" : "Cuota",
     "Language" : "Idioma",
     "Avatar" : "Avatar",
     "Group admin for" : "Administrador del grupo para",
@@ -181,13 +178,16 @@ OC.L10N.register(
     "Account actions" : "Acciones de la cuenta",
     "{size} used" : "{size} usado",
     "Delete account" : "Borrar cuenta",
-    "Done" : "Terminado",
     "Edit" : "Editar",
     "Show last login" : "Mostrar último inicio de sesión",
     "Send email" : "Enviar correo electrónico",
     "Default quota" : "Cuota predeterminada",
     "Unnamed device" : "Dispositivo sin nombre",
+    "Security & setup warnings" : "Advertencias de seguridad y configuración",
+    "Try again" : "Reintentar",
+    "All checks passed." : "Pasaron todas las verificaciones. ",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador, puedes hacer ajustes finos al comportamiento de compartir. Por favor consulta la documentación para más información. ",
+    "Apply" : "Aplicar",
     "Admins" : "Administradores",
     "Sending…" : "Enviando...",
     "Email sent" : "Correo electrónico enviado",
@@ -222,14 +222,12 @@ OC.L10N.register(
     "Credentials" : "Credenciales",
     "SMTP Password" : "Contraseña SMTP",
     "Save" : "Guardar",
-    "Security & setup warnings" : "Advertencias de seguridad y configuración",
-    "All checks passed." : "Pasaron todas las verificaciones. ",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desarrollado por la  {communityopen}comunidad Nextcloud {linkclose}, el {githubopen}código fuente {linkclose} está licenciado bajo  {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Da un Like a nuestra página de Facebook",
     "Check out our blog" : "Visita nuestro blog",
     "Subscribe to our newsletter" : "Suscribete a nuestro boletín",
-    "Username" : "Usuario",
-    "User backend" : "Backend del usuario",
-    "Follow us on Twitter" : "Síguenos en Twitter"
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
+    "You are using <strong>{usage}</strong>" : "Estás usando<strong>{usage}</strong>"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
