@@ -1,12 +1,25 @@
 OC.L10N.register(
     "settings",
     {
+    "Private" : "Privado",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Visível apenas a pessoas cujo acesso é realizado através de número de telefone, na app Talk em dispositivos móveis.",
+    "Local" : "Local",
+    "Only visible to people on this instance and guests" : "Visível apenas a pessoas nesta instância e a convidados",
+    "Federated" : "Federada",
+    "Only synchronize to trusted servers" : "Apenas sincronizar em servidores confiáveis",
+    "Published" : "Publicado",
+    "Synchronize to trusted servers and the global and public address book" : "Sincronizar a servidor confiável e global e lista de endereço público",
+    "Verify" : "Verificar",
+    "Verifying …" : "A verificar...",
     "Unable to change password" : "Não é possível alterar a sua palavra-passe ",
     "Very weak password" : "Palavra-passe muito fraca",
     "Weak password" : "Palavra-passe fraca",
     "So-so password" : "Palavra-passe aceitável",
     "Good password" : "Palavra-passe boa",
     "Strong password" : "Palavra-passe forte",
+    "Groups" : "Grupos",
+    "Group list is empty" : "Lista de grupo vazia",
+    "Unable to retrieve the group list" : "Não foi possível recolher a lista de grupo",
     "An administrator added you to group {group}" : "Um administrador adicionou-o ao grupo {group}",
     "An administrator added {user} to group {group}" : "Um administrador adicionou {user} ao grupo {group}",
     "{actor} removed you from group {group}" : "{actor} removeu-o do grupo {group}",
@@ -21,13 +34,10 @@ OC.L10N.register(
     "Security" : "Segurança",
     "You successfully logged in using two-factor authentication (%1$s)" : "Autenticado com sucesso utilizando autenticação de dois fatores (%1$s)",
     "A login attempt using two-factor authentication failed (%1$s)" : "Tentativa falhada de autenticação utilizando dois fatores (%1$s)",
-    "Remote wipe was started on %1$s" : "Eliminação remota iniciada em %1$s ",
-    "Remote wipe has finished on %1$s" : "Eliminação remota terminou em %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "A <strong>password</strong> ou <strong>email</strong> foram modificados",
     "Settings" : "Configurações",
     "Could not remove app." : "Não foi possível remover a aplicação",
     "Could not update app." : "Não foi possível atualizar a aplicação",
-    "QR Code login" : "Iniciar sessão com código QR",
     "Wrong password" : "Palavra-passe errada",
     "Unable to change personal password" : "Não foi possível mudar a palavra-passe pessoal",
     "Saved" : "Guardado",
@@ -42,16 +52,11 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "Se recebeu este email, a configuração do serviço de email deverá estar correta.",
     "Email could not be sent. Check your mail server log" : "O email não pode ser enviado. Por favor verifique os logs do seu servidor de e-mail.",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ocorreu um problema ao enviar o e-mail. Por favor verifique as suas definições. (Erro: %s)",
-    "Recently active" : "Ativo recentemente",
-    "Disabled accounts" : "Contas desativadas",
     "Invalid account" : "Conta inválida",
     "Invalid mail address" : "Endereço de correio eletrónico inválido",
     "Settings saved" : "Definições guardadas",
     "Unable to change full name" : "Não foi possível alterar o seu nome completo",
     "Unable to change email address" : "Não foi possível alterar o seu endereço de e-mail",
-    "Unable to set invalid phone number" : "Número de telefone inválido",
-    "Unable to set invalid website" : "Website inválido",
-    "Some account data was invalid" : "Alguns dados são inválidos",
     "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Por forma a validar a sua conta de Twitter, por favor publique o seguinte Twitter ( garanta que a publicação não contém quebras de linha):",
     "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Por forma de validar o Website, por favor publique o conteúdo seguinte na sua raiz em 'well-known/CloudIdVerificationCode.txt' (garanta que o texto completo se encontra numa única linha):",
     "%1$s changed your password on %2$s." : "%1$s modificou a sua senha em %2$s.",
@@ -69,7 +74,6 @@ OC.L10N.register(
     "Welcome aboard" : "Bem-vindo a bordo",
     "Welcome aboard %s" : "Bem-vindo a bordo %s",
     "Welcome to your %s account, you can add, protect, and share your data." : "Bem-vindo à conta %s, aqui pode adicionar, proteger e partilhar os seus dados.",
-    "Your Login is: %s" : "O seu Login é: %s",
     "Set your password" : "Escolher senha",
     "Go to %s" : "Ir para %s",
     "Install Client" : "Instalar Cliente",
@@ -91,8 +95,6 @@ OC.L10N.register(
     "Background jobs" : "Tarefas de segundo plano",
     "Unlimited" : "Ilimitado",
     "Verifying" : "A verificar",
-    "Verifying …" : "A verificar...",
-    "Verify" : "Verificar",
     "Internet connectivity" : "Conetividade da Internet",
     "Internet connectivity is disabled in configuration file." : "A conetividade da Internet está desativada no ficheiro de configuração.",
     "Disabled" : "Desativado",
@@ -113,7 +115,6 @@ OC.L10N.register(
     "Allow public uploads" : "Permitir Envios Públicos",
     "Always ask for a password" : "Pedir sempre a senha",
     "Enforce password protection" : "Forçar proteção por palavra-passe",
-    "Set default expiration date for internal shares" : "Defina a data de expiração predefinida para as partilhas internas.",
     "Enforce expiration date" : "Forçar a data de expiração",
     "This text will be shown on the public link upload page when the file list is hidden." : "Este texto será exibido na página de carregamento de ligações públicas quando a lista de ficheiros estiver oculta. ",
     "Limit to groups" : "Limitado a grupos",
@@ -132,7 +133,6 @@ OC.L10N.register(
     "Results from other categories" : "Resultados de outras categorias",
     "No apps found for your version" : "Nenhuma aplicação encontrada para a sua versão",
     "_Update_::_Update all_" : ["Atualizar","Atualizar todos","Atualizar todos"],
-    "Groups" : "Grupos",
     "Group name" : "Nome do grupo",
     "Loading" : "A carregar",
     "Type" : "Tipo",
@@ -142,7 +142,6 @@ OC.L10N.register(
     "Description" : "Descrição",
     "View in store" : "Ver na loja",
     "Visit website" : "Visitar o website",
-    "Usage documentation" : "Documentação de utilização",
     "Admin documentation" : "Documentação de administrador",
     "Developer documentation" : "Documentação de programador",
     "Details" : "Detalhes",
@@ -194,8 +193,6 @@ OC.L10N.register(
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "É sempre bom criar cópias de segurança regulares dos seus dados, em caso de encriptação tenha a certeza de que faz cópia das chaves de encriptação em conjunto com os seus dados.",
     "This is the final warning: Do you really want to enable encryption?" : "Este é o aviso final: quer mesmo ativar a encriptação?",
     "Submit" : "Submeter",
-    "Rename group" : "Renomear grupo",
-    "Delete group" : "Apagar grupo",
     "Current password" : "Palavra-passe atual",
     "New password" : "Nova palavra-passe",
     "Choose your profile picture" : "Escolher imagem de perfil",
@@ -212,24 +209,19 @@ OC.L10N.register(
     "Set as profile picture" : "Definir como imagem de perfil",
     "You are a member of the following groups:" : "Membro dos seguintes grupos:",
     "Your full name" : "Nome completo",
-    "No email address set" : "Nenhum endereço de email estabelecido",
     "Email options" : "Opções de correio eletrónico",
     "Remove primary email" : "Remoção de correio eletrónico principal",
     "Delete email" : "Apagar correio eletrónico",
     "Unset as primary email" : "Remove atribuição de correio eletrónico como principal",
+    "No email address set" : "Nenhum endereço de email estabelecido",
     "Help translate" : "Ajude a traduzir",
     "Week starts on {firstDayOfWeek}" : "Semana começa em {firstDayOfWeek}",
     "Your phone number" : "O seu número de telefone",
-    "Edit your Profile visibility" : "Editar a visibilidade do seu Perfil",
-    "Enable profile" : "Ativar perfil",
     "Add" : "Adicionar",
     "Create" : "Criar",
     "Change" : "Mudar",
     "Delete" : "Eliminar",
     "Reshare" : "Partilhar novamente",
-    "Enabled applications" : "Aplicações ativadas",
-    "Disabled applications" : "Aplicações desativadas",
-    "Setup warnings" : "Configurar avisos",
     "Display name" : "Nome a exibir",
     "Email" : "Email",
     "Quota" : "Quota",
@@ -241,20 +233,14 @@ OC.L10N.register(
     "Storage location" : "Localização do armazenamento",
     "Last login" : "Último início de sessão",
     "{size} used" : "{size} utilizado",
-    "Delete account" : "Remover conta",
-    "Disable account" : "Desativar conta",
-    "Enable account" : "Ativar conta",
     "Done" : "Concluído",
     "Edit" : "Editar",
     "Visibility" : "Visibilidade",
     "Show last login" : "Mostrar último início de sessão",
-    "Sorting" : "Ordenação",
     "Send email" : "Enviar email",
     "Default quota" : "Quota padrão",
-    "Please double check the {linkStartInstallationGuides}installation guides{linkEnd}, and check for any errors or warnings in the {linkStartLog}log{linkEnd}." : "Por favor verifique novamente os\n{linkStartInstallationGuides}guias de instalação\n{linkEnd} e verifique se há erros ou avisos no \n{linkStartLog}registo{linkEnd}.",
     "Security & setup warnings" : "Avisos de configuração e segurança",
     "All checks passed." : "Todas as verificações passaram.",
-    "There are some warnings regarding your setup." : "Existem alguns avisos referentes à sua configuração.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador pode afinar o comportamento de partilha. Por favor veja a documentação para mais informação.",
     "Apply" : "Aplicar",
     "Admins" : "Administrador",
@@ -269,14 +255,6 @@ OC.L10N.register(
     "Phone number" : "Número de telefone",
     "Role" : "Função",
     "Website" : "Website",
-    "Private" : "Privado",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Visível apenas a pessoas cujo acesso é realizado através de número de telefone, na app Talk em dispositivos móveis.",
-    "Local" : "Local",
-    "Only visible to people on this instance and guests" : "Visível apenas a pessoas nesta instância e a convidados",
-    "Federated" : "Federada",
-    "Only synchronize to trusted servers" : "Apenas sincronizar em servidores confiáveis",
-    "Published" : "Publicado",
-    "Synchronize to trusted servers and the global and public address book" : "Sincronizar a servidor confiável e global e lista de endereço público",
     "Your apps" : "As suas apps",
     "Disabled apps" : "Apps desativadas",
     "Updates" : "Atualizações",
@@ -309,20 +287,13 @@ OC.L10N.register(
     "Credentials" : "Credenciais",
     "SMTP Password" : "Palavra-passe SMTP",
     "Save" : "Guardar",
-    "Test and verify email settings" : "Testar e verificar as definições de e-mail",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desenvolvido pela [communityopen]Comunidade Nextcloud[linkclose]. O [githubcode]código fonte[/linkclose] está licenciado sob [licenseopen]AGPL[linkclose].",
     "Like our Facebook page" : "Deixe um Gosto na nossa página do Facebook",
     "Check out our blog" : "Veja o nosso blog",
     "Subscribe to our newsletter" : "Subscreva as nossas notícias",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Este lançamento comunitário do Nextcloud não é compatível e as notificações instantâneas não estão disponíveis.",
-    "Group list is empty" : "Lista de grupo vazia",
-    "Unable to retrieve the group list" : "Não foi possível recolher a lista de grupo",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta app não tem a versão mínima do Nextcloud atribuída. Isto será um erro no futuro.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta app não tem a versão máxima do Nextcloud atribuída. Isto será um erro no futuro.",
-    "Loading accounts …" : "A carregar contas ...",
-    "Loading account …" : "A carregar a conta ...",
-    "Adding your device …" : "A adicionar o seu dispositivo ...",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Por favor, verifique novamente os <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">guias de instalação ↗</a> e procure erros ou avisos no <a href=\"%2$s\">registo</a>.",
-    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Verificar a segurança do seu Nextcloud através da nossa <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">ferramenta de análise de segurança</a>. "
+    "Your biography" : "Biografia"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
