@@ -1,6 +1,16 @@
 OC.L10N.register(
     "settings",
     {
+    "Private" : "Zasebno",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Vidno le uporabnikom povezanimi s programom Talk prek telefonske številke.",
+    "Local" : "Krajevno",
+    "Only visible to people on this instance and guests" : "Vidno le krajevnim uporabnikom in povezanim gostom",
+    "Federated" : "Zvezno",
+    "Only synchronize to trusted servers" : "Usklajuj le z zaupanja vrednimi strežniki",
+    "Published" : "Objavljeno",
+    "Synchronize to trusted servers and the global and public address book" : "Usklajuj z varnimi strežniki in splošnimi in javnimi imeniki",
+    "Verify" : "Overi",
+    "Verifying …" : "Poteka overjanje ...",
     "Unable to change password" : "Ni mogoče spremeniti gesla",
     "Very weak password" : "Zelo šibko geslo",
     "Weak password" : "Slabo geslo",
@@ -113,8 +123,6 @@ OC.L10N.register(
     "Background jobs" : "Opravila v ozadju",
     "Unlimited" : "Neomejeno",
     "Verifying" : "Preverjanje",
-    "Verifying …" : "Poteka overjanje ...",
-    "Verify" : "Overi",
     "Allowed admin IP ranges" : "Dovoljeni skrbniški obsegi naslovov IP",
     "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "Nastavitveni ključ »%1$s« zahteva podatkovno polje (zaznano je %2$s). Skrbniško preverjanje obsega naslovov IP ne bo uveljavljeno.",
     "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "Nastavitveni ključ »%1$s« vsebuje neveljaven obseg naslovov IP: »%2$s«",
@@ -432,9 +440,6 @@ OC.L10N.register(
     "Enter your date of birth" : "Vpišite datum rojstva",
     "You are a member of the following groups:" : "Omogočeno je članstvo v skupinah:",
     "Your full name" : "Polno ime",
-    "Unable to update primary email address" : "Ni mogoče posodobiti osnovnega elektronskega naslova",
-    "Unable to delete additional email address" : "Ni mogoče izbrisati dodatnega elektronskega naslova",
-    "No email address set" : "Poštni naslov ni nastavljen",
     "Email options" : "Možnosti elektronske pošte",
     "Options for additional email address {index}" : "Dodatni elektronski naslov {index}",
     "Remove primary email" : "Odstrani osnovni elektronski naslov",
@@ -444,19 +449,22 @@ OC.L10N.register(
     "Set as primary email" : "Nastavi kot osnovni elektronski naslov",
     "Additional email address {index}" : "Dodatni elektronski naslov {index}",
     "Unable to delete primary email address" : "Ni mogoče izbrisati osnovnega elektronskega naslova",
+    "Unable to update primary email address" : "Ni mogoče posodobiti osnovnega elektronskega naslova",
     "Unable to add additional email address" : "Ni mogoče dodati dodatnega elektronskega naslova",
     "Unable to update additional email address" : "Ni mogoče posodobiti dodatnega elektronskega naslova",
+    "Unable to delete additional email address" : "Ni mogoče izbrisati dodatnega elektronskega naslova",
     "Primary email for password reset and notifications" : "Osnovni elektronski naslov za obnavljanje gesla in obvestila",
+    "No email address set" : "Poštni naslov ni nastavljen",
     "Your handle" : "Ročnik",
     "Your headline" : "Vaš naslov",
-    "No language set" : "Jezik ni nastavljen",
     "Unable to update language" : "Ni mogoče posodobiti jezika",
     "Languages" : "Jeziki",
     "Help translate" : "Sodelujte pri prevajanju",
-    "No locale set" : "Ni določenih jezikovnih nastavitev",
+    "No language set" : "Jezik ni nastavljen",
     "Unable to update locale" : "Ni mogoče posodobiti jezikovnih nastavitev",
     "Locales" : "Jezikovne nastavitve",
     "Week starts on {firstDayOfWeek}" : "Prvi dan tedna je {firstDayOfWeek}",
+    "No locale set" : "Ni določenih jezikovnih nastavitev",
     "Your city" : "Kraj bivanja",
     "Your organisation" : "Ustanova",
     "Your phone number" : "Osebna telefonska številka",
@@ -486,6 +494,7 @@ OC.L10N.register(
     "Other languages" : "Drugi jeziki",
     "Password change is disabled because the master key is disabled" : "Spreminjanje gesla je onemogočeno, ker je onemogočen tudi glavni šifrirni ključ",
     "No accounts" : "Ni računov",
+    "Loading accounts …" : "Poteka nalaganje računov ...",
     "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "Seznam računov. Seznam zaradi zmogljivosti sistema ni v celoti prikazan. Podatki uporabnikov se nalagajo med pomikanjem po seznamu.",
     "Manager" : "Upravljalnik",
     "Account name will be autogenerated" : "iME RAČUNA bo samodejno ustvarjeno",
@@ -499,11 +508,13 @@ OC.L10N.register(
     "Member of the following groups" : "Član navedenih skupin",
     "Set account groups" : "Nastavi skupine računov",
     "Admin of the following groups" : "Skrbnik navedenih skupin",
+    "Set account as admin for …" : "Nastavi račun kot skrbniški za ...",
     "Quota" : "Količinska omejitev",
     "Set account quota" : "Nastavi količinsko omejitev računa",
     "Language" : "Jezik",
     "Set default language" : "Nastavi privzeti jezik",
     "Add new account" : "Dodaj nov račun",
+    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} račun ...","{userCount} računa ...","{userCount} računi ...","{userCount} računov ..."],
     "_{userCount} account_::_{userCount} accounts_" : ["{userCount} račun ...","{userCount} računa ...","{userCount} računi ...","{userCount} računov ..."],
     "Total rows summary" : "Skupni povzetek vrstic",
     "Scroll to load more rows" : "Podrsajte za nalaganje več vrstic",
@@ -531,6 +542,7 @@ OC.L10N.register(
     "Password was successfully changed" : "Geslo je uspešno spremenjeno",
     "Email was successfully changed" : "Elektronski naslov je uspešno spremenjen",
     "Welcome mail sent!" : "Potrditveno sporočilo je poslano!",
+    "Loading account …" : "Poteka nalaganje računa ...",
     "Change display name" : "Spremeni prikazno ime",
     "Set new password" : "Nastavi novo geslo",
     "You do not have permissions to see the details of this account" : "Ni ustreznih dovoljenj za pregled podrobnosti tega računa",
@@ -561,6 +573,7 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "Brezgeselna overitev zahteva varno povezavo.",
     "Add WebAuthn device" : "Dodaj napravo WebAuthn",
     "Please authorize your WebAuthn device." : "Overite napravo WebAuthn",
+    "Adding your device …" : "Poteka dodajanje naprave ..",
     "Unnamed device" : "Neimenovana naprava",
     "Passwordless Authentication" : "Brezgeselna overitev",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Nastavitev račun za brezgeselno overitev dostopa po standardu FIDO2.",
@@ -601,14 +614,6 @@ OC.L10N.register(
     "Profile visibility" : "Vidnost profila",
     "Locale" : "Jezikovne nastavitve",
     "First day of week" : "Prvi dan tedna",
-    "Private" : "Zasebno",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Vidno le uporabnikom povezanimi s programom Talk prek telefonske številke.",
-    "Local" : "Krajevno",
-    "Only visible to people on this instance and guests" : "Vidno le krajevnim uporabnikom in povezanim gostom",
-    "Federated" : "Zvezno",
-    "Only synchronize to trusted servers" : "Usklajuj le z zaupanja vrednimi strežniki",
-    "Published" : "Objavljeno",
-    "Synchronize to trusted servers and the global and public address book" : "Usklajuj z varnimi strežniki in splošnimi in javnimi imeniki",
     "Discover" : "Predstavitve",
     "Your apps" : "Vsi programi",
     "Active apps" : "Zagnani programi",
@@ -675,15 +680,20 @@ OC.L10N.register(
     "Use a second factor besides your password to increase security for your account." : "Ob geslu je priporočljivo uporabiti tudi drugo-stopenjsko overitev za večjo varnost računa.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Če uporabljate za povezavo z oblakom Nextcloud programe tretjih oseb, najprej ustvarite in nastavite gesla za vsak program, preden omogočite dvostopenjsko overitev.",
     "Logged in account must be a subadmin" : "Račun prijave mora imeti dovoljenja podpornega skrbnika",
+    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Če želite omogočiti izvajanje tega preverjanja, je treba zagotoviti, da se spletni strežnik lahko poveže sam s seboj. Zato mora biti nastavljen za povezovanje z vsaj eno od določenih »varnih domen« (trusted_domains) ali naslovov za prepis »vmesnika ukazne vrstice« (overwrite.cli.url). Spodletelo preverjanje je lahko posledica neujemanja imen DNS na strani strežnika oziroma pravila požarnega zidu.",
+    "File locking" : "Zaklepanje datotek",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "Zaklepanje datotek je onemogočeno, kar lahko privede do različnih težav. V izogib zapletom je priporočljivo omogočiti možnost »filelocking.enabled« v datoteki config.php.",
+    "The PHP memory limit is below the recommended value of %s." : "Omejitev pomnilnika PHP je pod priporočeno mejo %s.",
     "- The `%1$s` HTTP header does not contain `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "– Glava HTTP »%1$s« ne vključuje vrednosti »%2$s«. To predstavlja potencialno varnostno ali zasebnostno tveganje, zato je priporočljivo prilagoditi nastavitve.",
+    "Set default expiration date for shares" : "Nastavi privzeti datuma poteka za mesta souporabe",
+    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Če je omogočeno samodejno dopolnjevanje »v isti skupini«, ali pa »po telefonskem imeniku«, se zadetek pokaže, če je uporabnik v katerikoli od teh zbirk.",
+    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Dovoli samodejno dokončanje pri vnosu polnega imena ali elektronskega naslova (brez upoštevanja manjkajočega ujemanja s telefonskim imenikom in pripadnosti isti skupini)",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Program nima določene omejitve različice okolja Nextcloud. V prihodnosti se bo manjkajoči podatek pokazal kot napaka.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Program nima določene omejitve različice okolja Nextcoud. V prihodnosti se bo manjkajoči podatek pokazal kot napaka.",
-    "Loading accounts …" : "Poteka nalaganje računov ...",
-    "Set account as admin for …" : "Nastavi račun kot skrbniški za ...",
-    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} račun ...","{userCount} računa ...","{userCount} računi ...","{userCount} računov ..."],
+    "Your biography" : "Biografija",
+    "You are using <strong>{usage}</strong>" : "Uporabljate <strong>{usage}</strong>",
+    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Uporabljate <strong>{usage}</strong> od <strong>{totalSpace}</strong> (<strong>{usageRelative} %</strong>)",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Možnost omogoča varnostno brisanje podatkov Nextcloud z vseh naprav, povezanih z uporabniškim računom {userid}. Možnost deluje le, če so naprave povezane v spletno omrežje. Brisanje z oddaljenih naprav je uporabno v primeru izgubljene naprave, ali na primer prekinitve sodelovanja v neki skupini.",
-    "Loading account …" : "Poteka nalaganje računa ...",
-    "Adding your device …" : "Poteka dodajanje naprave ..",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ta program ni označen kot skladen z nameščeno različico oblaka Nextcloud. Če nameravate nadaljevati, boste program lahko namestili, vendar ta morda ne bo deloval po pričakovanjih, ali pa bo vplival na stabilnost sistema.",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Zaradi varnosti in optimizacije delovanja je nujno, da je sistem posodobljen in pravilno nastavljen. Preverjanje poteka tako, da se nekateri preizkusi izvajajo sproti in samodejno. Več podrobnosti je zabeleženih v dokumentaciji. ",
     "Checking for system and security issues." : "Preverjanje sistemskih in varnostnih nastavitev.",
