@@ -1,12 +1,25 @@
 OC.L10N.register(
     "settings",
     {
+    "Private" : "Privat",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Endast synlig för personer matchade via telefonnummer integration via Talk i mobilen",
+    "Local" : "Lokal",
+    "Only visible to people on this instance and guests" : "Endast synlig för personer på denna instansen och gäster",
+    "Federated" : "Federerad",
+    "Only synchronize to trusted servers" : "Synkronisera endast med betrodda servrar",
+    "Published" : "Publicerad",
+    "Synchronize to trusted servers and the global and public address book" : "Synkronisera med betrodda servrar och den globala och offentliga adressboken",
+    "Verify" : "Verifiera",
+    "Verifying …" : "Verifierar ...",
     "Unable to change password" : "Kunde inte ändra lösenord",
     "Very weak password" : "Väldigt svagt lösenord",
     "Weak password" : "Svagt lösenord",
     "So-so password" : "Okej lösenord",
     "Good password" : "Bra lösenord",
     "Strong password" : "Starkt lösenord",
+    "Groups" : "Grupper",
+    "Group list is empty" : "Grupplistan är tom",
+    "Unable to retrieve the group list" : "Kan inte hämta grupplistan",
     "{actor} added you to group {group}" : "{actor} adderade dig till gruppen {group}",
     "You added {user} to group {group}" : "Du adderade {user} till gruppen {group}",
     "{actor} added {user} to group {group}" : "{actor} adderade {user} till gruppen {group}",
@@ -117,8 +130,6 @@ OC.L10N.register(
     "Background jobs" : "Bakgrundsjobb",
     "Unlimited" : "Obegränsat",
     "Verifying" : "Verifiera",
-    "Verifying …" : "Verifierar ...",
-    "Verify" : "Verifiera",
     "Allowed admin IP ranges" : "Tillåten IP-rymd för administratörer",
     "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "Konfigurationsnyckel \"%1$s\" förväntar sig en array (%2$s hittades). Validering av IP-intervall för administratörer tillämpas inte.",
     "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "Konfigurationsnyckel \"%1$s\" innehåller ogiltiga IP-intervall: \"%2$s\"",
@@ -243,9 +254,6 @@ OC.L10N.register(
     "Enforce password protection" : "Tillämpa lösenordskydd",
     "Exclude groups from password requirements" : "Exkludera grupper från lösenordskrav",
     "Exclude groups from creating link shares" : "Exkludera grupper från att skapa länkdelningar",
-    "Allow users to set custom share link tokens" : "Tillåt användare att anpassa delningslänkar",
-    "Shares with custom tokens will continue to be accessible after this setting has been disabled" : "Delningar med anpassade länkar kommer fortsätta vara tillgängliga även efter att denna inställning avaktiverats",
-    "Shares with guessable tokens may be accessed easily" : "Delningar med länkar som går att gissa blir lättillgängliga",
     "Limit sharing based on groups" : "Begränsa delning baserat på grupper",
     "Allow sharing for everyone (default)" : "Tillåt delning för alla (standard)",
     "Exclude some groups from sharing" : "Uteslut vissa grupper från att dela",
@@ -269,7 +277,6 @@ OC.L10N.register(
     "This text will be shown on the public link upload page when the file list is hidden." : "Denna text kommer att visa på den offentliga uppladdnings-sidan när fil-listan är gömd.",
     "Default share permissions" : "Standardrättigheter för delning",
     "Two-Factor Authentication" : "Tvåfaktorsautentisering",
-    "Two-factor authentication can be enforced for all accounts and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Tvåfaktorsautentisering kan krävas för alla konton eller specifika grupper. Om de inte har någon tvåfaktorsautentisering konfigurerad kommer de inte kunna logga in.",
     "Enforce two-factor authentication" : "Påtvinga tvåfaktorsautentisering",
     "Limit to groups" : "Begränsa till grupper",
     "Enforcement of two-factor authentication can be set for certain groups only." : "Påtvingad tvåfaktorsautentisering kan bara aktiveras för vissa grupper.",
@@ -299,7 +306,6 @@ OC.L10N.register(
     "_Update_::_Update all_" : ["Uppdatera","Uppdatera alla"],
     "Failed to load groups" : "Kunde inte läsa in grupper",
     "Failed to create group" : "Det gick inte att skapa gruppen",
-    "Groups" : "Grupper",
     "Creating group…" : "Skapar grupp...",
     "Create group" : "Skapa grupp",
     "Group name" : "Gruppnamn",
@@ -400,7 +406,7 @@ OC.L10N.register(
     "Failed to save setting" : "Kunde inte spara inställning",
     "Unable to update server side encryption config" : "Kunde inte uppdatera serversidans krypteringskonfiguration",
     "Server-side encryption" : "Serverkryptering",
-    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Kryptering på servern-sidan möjliggör kryptering av filer som är uppladdade till servern. Detta innebär vissa begränsningar som prestandaförluster, så aktivera bara om det behövs.",
+    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Kryptering från servern möjliggör kryptering av filer som är uppladdade till servern. Detta innebär vissa begränsningar som prestandaförluster, så aktivera bara om det behövs.",
     "Enable server-side encryption" : "Aktivera kryptering på server.",
     "No encryption module loaded, please enable an encryption module in the app menu." : "Ingen krypteringsmodul inläst, aktivera krypteringsmodulen i applikationsmenyn.",
     "Select default encryption module:" : "Välj krypteringsmodul:",
@@ -439,9 +445,6 @@ OC.L10N.register(
     "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Du använder {s}{usage}{/s} av {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
     "You are a member of the following groups:" : "Du är medlem i följande grupper:",
     "Your full name" : "Ditt fullständiga namn",
-    "Unable to update primary email address" : "Kunde inte uppdatera primär e-postadress",
-    "Unable to delete additional email address" : "Kunde inte ta bort ytterligare e-postadress",
-    "No email address set" : "Ingen e-postadress angiven",
     "Email options" : "E-postinställningar",
     "Options for additional email address {index}" : "Alternativ för ytterligare e-postadress {index}",
     "Remove primary email" : "Ta bort primär e-postadress",
@@ -451,22 +454,25 @@ OC.L10N.register(
     "Set as primary email" : "Välj som primär e-post",
     "Additional email address {index}" : "Ytterligare e-postadress {index}",
     "Unable to delete primary email address" : "Kunde inte ta bort primär e-postadress",
+    "Unable to update primary email address" : "Kunde inte uppdatera primär e-postadress",
     "Unable to add additional email address" : "Kunde inte lägga till ytterligare e-postadress",
     "Unable to update additional email address" : "Kunde inte uppdatera ytterligare e-postadress",
+    "Unable to delete additional email address" : "Kunde inte ta bort ytterligare e-postadress",
     "Primary email for password reset and notifications" : "Primär e-postadress för notifikationer och återställning av lösenord",
+    "No email address set" : "Ingen e-postadress angiven",
     "Your handle" : "Ditt kontonamn",
     "Derived from your locale ({weekDayName})" : "Härledd från din plats ({weekDayName})",
     "Unable to update first day of week" : "Kunde inte uppdatera första veckodagen",
     "Day to use as the first day of week" : "Dag att använda som första veckodag",
     "Your headline" : "Din rubrik",
-    "No language set" : "Inget språk angivet",
     "Unable to update language" : "Kunde inte uppdatera språk",
     "Languages" : "Språk",
     "Help translate" : "Hjälp till med översättningarna",
-    "No locale set" : "Inget språk angivet",
+    "No language set" : "Inget språk angivet",
     "Unable to update locale" : "Det gick inte att uppdatera språk",
     "Locales" : "Platser",
     "Week starts on {firstDayOfWeek}" : "Veckan börjar med {firstDayOfWeek}",
+    "No locale set" : "Inget språk angivet",
     "Your city" : "Din stad",
     "Your organisation" : "Din organisation",
     "Your phone number" : "Ditt telefonnummer",
@@ -478,7 +484,6 @@ OC.L10N.register(
     "she/her" : "hon/henne",
     "he/him" : "han/honom",
     "they/them" : "de/dem",
-    "Your pronouns. E.g. {pronounsExample}" : "Dina pronomen. T.ex. {pronounsExample}",
     "Your role" : "Din roll",
     "Timezone" : "Tidszon",
     "Your X (formerly Twitter) handle" : "Ditt användarnamn på X (tidigare Twitter)",
@@ -501,6 +506,7 @@ OC.L10N.register(
     "Other languages" : "Andra språk",
     "Password change is disabled because the master key is disabled" : "Lösenordsbyte är inaktiverat eftersom huvudnyckeln är inaktiverad",
     "No accounts" : "Inga konton",
+    "Loading accounts …" : "Laddar konton ...",
     "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "Lista över konton. Denna lista är inte helt återgiven av prestandaskäl. Konton kommer att renderas när du navigerar genom listan.",
     "Manager" : "Chef",
     "Set line manager" : "Ange linjechef",
@@ -517,11 +523,13 @@ OC.L10N.register(
     "Member of the following groups" : "Medlem i följande grupper",
     "Set account groups" : "Ställ in kontogrupper",
     "Admin of the following groups" : "Administratör för följande grupper",
+    "Set account as admin for …" : "Ange konto som administratör för ...",
     "Quota" : "Kvot",
     "Set account quota" : "Ställ in kvot för konto",
     "Language" : "Språk",
     "Set default language" : "Ställ in standardspråk",
     "Add new account" : "Lägg till nytt konto",
+    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} konto …","{userCount} konton …"],
     "_{userCount} account_::_{userCount} accounts_" : ["{userCount} konto","{userCount} konton"],
     "Total rows summary" : "Sammanfattning antal rader",
     "Scroll to load more rows" : "Bläddra för att ladda fler rader",
@@ -552,6 +560,7 @@ OC.L10N.register(
     "Email can't be empty" : "E-post får inte vara tomt",
     "Email was successfully changed" : "E-postadressen har ändrats",
     "Welcome mail sent!" : "Välkomstmeddelande skickat via e-post!",
+    "Loading account …" : "Laddar konto ...",
     "Change display name" : "Ändra visningsnamn",
     "Set new password" : "Ange nytt lösenord",
     "You do not have permissions to see the details of this account" : "Du har inte behörighet att se detaljerna för detta konto.",
@@ -582,6 +591,7 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "Lösenordsfri autentisering kräver en säker anslutning.",
     "Add WebAuthn device" : "Lägg till WebAuthn-enhet",
     "Please authorize your WebAuthn device." : "Godkänn din WebAuthn-enhet.",
+    "Adding your device …" : "Lägger till din enhet ....",
     "Unnamed device" : "Namnlös enhet",
     "Passwordless Authentication" : "Lösenordsfri autentisering",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Ställ in ditt konto för lösenordsfri autentisering som följer FIDO2-standarden.",
@@ -593,14 +603,13 @@ OC.L10N.register(
     "All checks passed." : "Alla kontroller lyckades!",
     "There are some errors regarding your setup." : "Det finns några fel angående din inställning.",
     "There are some warnings regarding your setup." : "Det finns några varningar angående din inställning.",
-    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Som administratör kan du finjustera delningsbeteendet. Vänligen se dokumentationen för mer information.",
+    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Som administratör kan du fininställa delningsbeteendet. Vänligen se dokumentationen för mer information.",
     "You need to enable the File sharing App." : "Du måste aktivera fildelnings-appen.",
     "App Store" : "App Store",
     "Loading app list" : "Laddar applista",
     "Loading categories" : "Laddar kategorier",
     "Developer documentation ↗" : "Utvecklardokumentation ↗",
     "Version {version}, {license}-licensed" : "Version {version}, {license}-licensierad",
-    "Version {version}" : "Version {version}",
     "Apply" : "Tillämpa",
     "All accounts" : "Alla konton",
     "Admins" : "Administratörer",
@@ -626,16 +635,8 @@ OC.L10N.register(
     "Profile visibility" : "Profilsynlighet",
     "Locale" : "Plats",
     "First day of week" : "Första dagen i veckan",
-    "Private" : "Privat",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Endast synlig för personer matchade via telefonnummer integration via Talk i mobilen",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Inte tillgänglig då denna inställning krävs för essentiell funktionalitet såsom fildelning och kalenderinbjudningar",
-    "Local" : "Lokal",
-    "Only visible to people on this instance and guests" : "Endast synlig för personer på denna instansen och gäster",
-    "Federated" : "Federerad",
-    "Only synchronize to trusted servers" : "Synkronisera endast med betrodda servrar",
     "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "Ej tillgängligt eftersom federation har inaktiverats för ditt konto, kontakta din systemadministratör om du har några frågor",
-    "Published" : "Publicerad",
-    "Synchronize to trusted servers and the global and public address book" : "Synkronisera med betrodda servrar och den globala och offentliga adressboken",
     "Discover" : "Upptäck",
     "Your apps" : "Dina appar",
     "Active apps" : "Aktiva appar",
@@ -702,17 +703,20 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Denna community-release av Nextcloud stöds inte och direktnotifikationer är inte tillgängliga.",
     "Use a second factor besides your password to increase security for your account." : "Använd en andra faktor utöver ditt lösenord för att öka säkerheten för ditt konto.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Om du använder tredje-parts applikationer för att ansluta till Nextcloud vänligen skapa och konfigurera ett applösenord för varje innan två-faktor autentisering aktiveras.",
-    "Group list is empty" : "Grupplistan är tom",
-    "Unable to retrieve the group list" : "Kan inte hämta grupplistan",
     "Logged in account must be a subadmin" : "Inloggat konto måste vara en underadministratör",
+    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "För att denna kontroll ska kunna köra måste du se till att webbservern kan ansluta till sig själv. Den måste alltså kunna finna och ansluta till minst en av sina \"trusted_domains\" eller \"overwrite.cli.url\":en. Detta misslyckande kan vara resultatet av en DNS missmatch på serversidan eller utgående brandväggs-regler.",
+    "File locking" : "Fillåsning",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "Transaktionsbaserad fillåsning är inaktiverad, detta kan leda till problem med konflikter. Aktivera \"filelocking.enabled\" i config.php för att undvika dessa problem.",
+    "The PHP memory limit is below the recommended value of %s." : "Minnesgränsen för PHP är under det rekommenderade värdet på %s.",
+    "Set default expiration date for shares" : "Ställ in standardutgångsdatum för delningar",
+    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Om komplettering för \"samma grupp\" och \"telefonnummerintegration\" är aktiverade räcker det med en matchning i en av dem för att visa användaren.",
+    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Tillåt autokomplettering när du anger hela namnet eller e-postadressen (ignorera saknad telefonboksmatchning och att vara i samma grupp)",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Denna app har ingen lägsta Nextcloud-version tilldelad. Detta kommer att innebära ett problem i framtiden.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Denna app har ingen minimum Nextcloud-version tilldelad. Detta kommer att innebära ett problem i framtiden.",
-    "Loading accounts …" : "Laddar konton ...",
-    "Set account as admin for …" : "Ange konto som administratör för ...",
-    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} konto …","{userCount} konton …"],
+    "Your biography" : "Din biografi",
+    "You are using <strong>{usage}</strong>" : "Du använder <strong>{usage}</strong>",
+    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Du använder <strong>{usage}</strong> av <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Om användaren förlorar sin enhet eller lämnar organisationen, kan all Nextcloud-data fjärrensas från alla enheter associerade med {userid}. Fungerar bara om enheterna är anslutna till internet.",
-    "Loading account …" : "Laddar konto ...",
-    "Adding your device …" : "Lägger till din enhet ....",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Den här appen är inte markerad som kompatibel med din Nextcloud-version. Om du fortsätter kan du fortfarande installera appen. Observera att appen kanske inte fungerar som förväntat.",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Det är viktigt för säkerhet och prestanda av din instans att allt är korrekt konfigurerat. För att hjälpa dig med det gör vi några automatiska kontroller. Se den länkade dokumentationen för mer information.",
     "Checking for system and security issues." : "Kontrollerar system och säkerhetsproblem.",
