@@ -56,6 +56,7 @@ OC.L10N.register(
     "Failed to delete tag" : "Αποτυχία διαγραφής ετικέτας",
     "Create or edit tags" : "Δημιουργία ή επεξεργασία ετικετών",
     "Search for a tag to edit" : "Αναζήτηση ετικέτας για επεξεργασία",
+    "Collaborative tags …" : "Συνεργατικές ετικέτες…",
     "No tags to select" : "Δεν υπάρχουν διαθέσιμες ετικέτες για επιλογή",
     "Tag name" : "Όνομα ετικέτας",
     "Tag level" : "Επίπεδο ετικέτας",
@@ -63,7 +64,7 @@ OC.L10N.register(
     "Update" : "Ενημέρωση",
     "Delete" : "Διαγραφή",
     "Reset" : "Επαναφορά",
-    "Loading …" : "Φόρτωση …",
+    "Loading …" : "Γίνεται φόρτωση…",
     "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["Η ετικέτα {tag1} θα οριστεί και η ετικέτα {tag2} θα αφαιρεθεί από 1 αρχείο.","Η ετικέτα {tag1} θα οριστεί και η ετικέτα {tag2} θα αφαιρεθεί από {count} αρχεία."],
     "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["Η ετικέτα {tag} θα οριστεί σε 1 αρχείο.","Η ετικέτα {tag} θα οριστεί σε {count} αρχεία."],
     "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["Η ετικέτα {tag} θα αφαιρεθεί από 1 αρχείο.","Η ετικέτα {tag} θα αφαιρεθεί από {count} αρχεία."],
@@ -82,10 +83,11 @@ OC.L10N.register(
     "Choose tags for the selected files" : "Επιλογή ετικετών για τα επιλεγμένα αρχεία",
     "Cancel" : "Ακύρωση",
     "Apply" : "Εφαρμογή",
-    "Failed to load selected tags" : "Αποτυχία φόρτωσης των επιλεγμένων ετικετών",
     "Failed to load tags" : "Απέτυχε η φόρτωση ετικετών",
+    "Failed to load selected tags" : "Αποτυχία φόρτωσης των επιλεγμένων ετικετών",
     "Failed to select tag" : "Αποτυχία επιλογής ετικέτας",
     "System admin disabled tag creation. You can only use existing ones." : "Ο διαχειριστής του συστήματος απενεργοποίησε τη δημιουργία ετικετών. Μπορείτε να χρησιμοποιείτε μόνο τις υπάρχουσες.",
+    "Loading collaborative tags …" : "Φόρτωση συνεργατικών ετικετών…",
     "Search or create collaborative tags" : "Αναζήτηση ή δημιουργία συνεργατικών ετικετών",
     "No tags to select, type to create a new tag" : "Δεν υπάρχουν διαθέσιμες ετικέτες για επιλογή, πληκτρολογήστε για να δημιουργήσετε μια νέα",
     "Unable to update setting" : "Αδυναμία ενημέρωσης ρύθμισης",
@@ -107,12 +109,9 @@ OC.L10N.register(
     "Failed to load tags for file" : "Αποτυχία φόρτωσης ετικετών για το αρχείο",
     "Failed to set tag for file" : "Αποτυχία ορισμού ετικέτας για το αρχείο",
     "Failed to delete tag for file" : "Αποτυχία διαγραφής ετικέτας για το αρχείο",
-    "Collaborative tags …" : "Συνεργατικές ετικέτες…",
-    "Loading …" : "Γίνεται φόρτωση…",
     "File tags modification canceled" : "Η τροποποίηση ετικετών αρχείου ακυρώθηκε",
     "Select or create tags to apply to all selected files" : "Επιλέξτε ή δημιουργήστε ετικέτες για εφαρμογή σε όλα τα επιλεγμένα αρχεία",
     "Select tags to apply to all selected files" : "Επιλέξτε ετικέτες για εφαρμογή σε όλα τα επιλεγμένα αρχεία",
-    "Apply changes" : "Εφαρμογή αλλαγών",
-    "Loading collaborative tags …" : "Φόρτωση συνεργατικών ετικετών…"
+    "Apply changes" : "Εφαρμογή αλλαγών"
 },
 "nplurals=2; plural=(n != 1);");
