@@ -11,11 +11,14 @@ OC.L10N.register(
     "Italic" : "Italig",
     "Link" : "Dolen",
     "Undo" : "Dadwneud",
+    "Cancel" : "Cancel",
     "URL" : "URL",
     "to" : "at",
+    "Upload" : "Llwytho i fyny",
     "Edit" : "Golygu",
     "Source code" : "Cod ffynhonnell",
     "Details" : "Manylion",
+    "Choose" : "Dewisa",
     "Info" : "Info",
     "Warning" : "Rhybudd"
 },
