@@ -46,6 +46,7 @@ OC.L10N.register(
     "Style" : "Стил",
     "Syntax" : "Синтакса",
     "Keyboard shortcuts" : "Кратенки преку тастатура",
+    "Enter" : "Ентер",
     "Shift" : "Shift",
     "Bold" : "Болд",
     "Bold text" : "Болдиран текст",
@@ -62,6 +63,7 @@ OC.L10N.register(
     "Some code" : "Некој код",
     "Link" : "Линк",
     "Insert emoji" : "Вметни емотикон",
+    "Action" : "Акција",
     "Undo" : "Назад",
     "Redo" : "Напред",
     "Alt" : "Alt",
