@@ -6,7 +6,12 @@ OC.L10N.register(
     "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Presente as fotos e vídeos das súas vacacións como nos filmes, amose un adianto da súa novela directamente desde a súa nube, escolla as mellores imaxes GIF da súa colección grazas á vista previa dos seus ficheiros favoritos, e moito máis!",
     "Your browser does not support audio." : "O seu navegador non admite son.",
     "Error loading {name}" : "Produciuse un erro ao cargar {name}",
+    "You are about to overwrite the original file. Are you sure you want to continue?" : "Está a piques de sobrescribir o ficheiro orixinal. Confirma que quere continuar?",
+    "A file with this name already exists. Do you want to overwrite it?" : "Xa existe un ficheiro con este nome. Quere sobrescribilo?",
+    "Confirm overwrite" : "Confirmar a sobrescritura",
     "Cancel" : "Cancelar",
+    "Overwrite" : "Sobrescribir",
+    "An error occurred while trying to confirm the file overwrite." : "Produciuse un erro ao tentar confirmar a sobrescritura do ficheiro.",
     "Image saved" : "Imaxe gardada",
     "Error saving image" : "Produciuse un erro ao gardar a imaxe",
     "Play the live photo" : "Reproducir Live Photo",
