@@ -27,21 +27,21 @@ OC.L10N.register(
     "%s accessed %s" : "%s přistoupeno k %s",
     "%s renamed %s" : "%s přejmenováno %s",
     "%s copied %s" : "%s zkopírováno %s",
-    "%1$s assigned %2$s to %3$s" : "%1$s přiřazeno %2$s k %3$s",
+    "%s assigned %s to %s" : "%s přiřazeno %s k %s",
     "Operation #%s does not exist" : "Operace č. %s neexistuje",
-    "Entity %s is invalid" : "Entita %s není platná",
     "Entity %s does not exist" : "Entita %s neexistuje",
+    "Entity %s is invalid" : "Entita %s není platná",
     "No events are chosen." : "Nejsou zvolené žádné události",
     "Entity %s has no event %s" : "Entita %s nemá žádnou událost %s",
-    "The provided operation data is too long" : "Data zadané operace jsou příliš objemná",
-    "Operation %s is invalid" : "Operace %s není platná",
     "Operation %s does not exist" : "Operace %s neexistuje",
+    "Operation %s is invalid" : "Operace %s není platná",
     "At least one check needs to be provided" : "Je třeba poskytnou alespoň jednu kontrolu",
+    "The provided operation data is too long" : "Data zadané operace jsou příliš objemná",
     "Invalid check provided" : "Zadána neplatná kontrola",
-    "The provided check value is too long" : "Zadaná hodnota kontroly je příliš dlouhá",
-    "Check %s is invalid" : "Kontrola %s není platná",
     "Check %s does not exist" : "Kontrola %s neexistuje",
+    "Check %s is invalid" : "Kontrola %s není platná",
     "Check %s is not allowed with this entity" : "Zaškrtnutí %s není u této entity povoleno",
+    "The provided check value is too long" : "Zadaná hodnota kontroly je příliš dlouhá",
     "Check #%s does not exist" : "Kontrola č. %s neexistuje",
     "Check %s is invalid or does not exist" : "Kontrola %s není platná, nebo neexistuje",
     "Flow" : "Tok",
@@ -56,6 +56,7 @@ OC.L10N.register(
     "PDF documents" : "PDF dokumenty",
     "Video" : "Video",
     "Custom MIME type" : "Uživatelsky určený MIME typ",
+    "Custom mimetype" : "Uživatelsky určený mimetyp",
     "Select a file type" : "Vybrat typ souboru",
     "e.g. httpd/unix-directory" : "např. httpd/unix-directory",
     "Please enter a valid time span" : "Zadejte platné časové rozmezí",
@@ -70,7 +71,7 @@ OC.L10N.register(
     "Select a user agent" : "Vyberte user agent",
     "Select groups" : "Vybrat skupiny",
     "Groups" : "Skupiny",
-    "Type to search for group …" : "Skupinu vyhledáte psaním …",
+    "Type to search for group …" : "Skupinu vyhledáte psaním…",
     "Select a trigger" : "Vybrat spouštěč",
     "At least one event must be selected" : "Je třeba vybrat alespoň jednu událost",
     "Add new flow" : "Přidat nový tok",
@@ -119,7 +120,6 @@ OC.L10N.register(
     "Request user agent" : "User agent požadavku",
     "Group membership" : "Členství ve skupinách",
     "is member of" : "je členem",
-    "is not member of" : "není členem",
-    "Type to search for group …" : "Skupinu vyhledáte psaním …"
+    "is not member of" : "není členem"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
