@@ -49,42 +49,44 @@ OC.L10N.register(
     "Select a filter" : "Filter auswählen",
     "Select a comparator" : "Wähle einen Komparator",
     "Remove filter" : "Filter entfernen",
-    "Select a file type" : "Dateityp auswählen",
-    "e.g. httpd/unix-directory" : "z. B. httpd/unix-directory",
+    "Audio" : "Audio",
     "Folder" : "Ordner",
     "Images" : "Bilder",
     "Office documents" : "Office Dokumente",
     "PDF documents" : "PDF-Dokumente",
+    "Video" : "Benötigt keine Übersetzung. Hier wird nur die formelle Übersetzung verwendet (de_DE).",
     "Custom MIME type" : "Benutzerdefinierter MIME Typ",
     "Custom mimetype" : "Benutzerdefinierter Mime-Typ",
+    "Select a file type" : "Dateityp auswählen",
+    "e.g. httpd/unix-directory" : "z. B. httpd/unix-directory",
     "Please enter a valid time span" : "Bitte einen gültigen Zeitraum angeben",
-    "Select a request URL" : "Wähle eine Anforderungs-URL aus",
     "Files WebDAV" : "WebDAV für Dateien",
     "Custom URL" : "Benutzerdefinierte URL",
-    "Select a user agent" : "User-Agenten auswählen",
+    "Select a request URL" : "Wähle eine Anforderungs-URL aus",
     "Android client" : "Android-Client",
     "iOS client" : "iOS-Client",
     "Desktop client" : "Desktop-Client",
     "Thunderbird & Outlook addons" : "Thunderbird & Outlook Add-ons",
     "Custom user agent" : "Benutzerdefinierter User-Agent",
+    "Select a user agent" : "User-Agenten auswählen",
     "Select groups" : "Gruppen auswählen",
     "Groups" : "Gruppen",
     "Type to search for group …" : "Tippen um nach einer Gruppe zu suchen …",
     "Select a trigger" : "Einen Auslöser auswählen",
     "At least one event must be selected" : "Mindestens ein Ereignis muss ausgewählt werden",
     "Add new flow" : "Neuen Ablauf hinzufügen",
+    "The configuration is invalid" : "Die Konfiguration ist ungültig",
+    "Active" : "Aktiv",
+    "Save" : "Speichern",
     "When" : "Wenn",
     "and" : "und",
     "Add a new filter" : "Neuen Filter hinzufügen",
     "Cancel" : "Abbrechen",
     "Delete" : "Löschen",
-    "The configuration is invalid" : "Die Konfiguration ist ungültig",
-    "Active" : "Aktiv",
-    "Save" : "Speichern",
     "Available flows" : "Verfügbare Abläufe",
-    "For details on how to write your own flow, check out the development documentation." : "Informationen zur Erstellung eigener Abläufe findest du in der Entwickler-Dokumentation.",
+    "For details on how to write your own flow, check out the development documentation." : "Informationen zur Erstellung eigener Abläufe finden sich in der Entwickler-Dokumentation.",
     "No flows installed" : "Keine Abläufe installiert",
-    "Ask your administrator to install new flows." : "Bitte deinen Administrator, neue Abläufe zu installieren.",
+    "Ask your administrator to install new flows." : "Bitte deine Administration, neue Abläufe zu installieren.",
     "More flows" : "Weitere Abläufe",
     "Browse the App Store" : "App-Store durchsuchen",
     "Show less" : "Weniger anzeigen",
@@ -118,7 +120,6 @@ OC.L10N.register(
     "Request user agent" : "User-Agent",
     "Group membership" : "Gruppenmitgliedschaft",
     "is member of" : "ist Mitglied von",
-    "is not member of" : "ist kein Mitglied von",
-    "User group membership" : "Benutzergruppen-Mitgliedschaft"
+    "is not member of" : "ist kein Mitglied von"
 },
 "nplurals=2; plural=(n != 1);");
