@@ -49,10 +49,12 @@ OC.L10N.register(
     "Select a filter" : "Seleccione un filtro",
     "Select a comparator" : "Seleccione un comparador",
     "Remove filter" : "Quitar filtro",
+    "Audio" : "Audio",
     "Folder" : "Carpeta",
     "Images" : "Imágenes",
     "Office documents" : "Documentos de oficina",
     "PDF documents" : "Documentos PDF",
+    "Video" : "Vídeo",
     "Custom MIME type" : "Tipo MIME personalizado",
     "Custom mimetype" : "Tipo MIME (mimetype) personalizado",
     "Select a file type" : "Selecciona un tipo de archivo",
