@@ -27,6 +27,7 @@ OC.L10N.register(
     "%s accessed %s" : "%s が %s にアクセス",
     "%s renamed %s" : "%s が %s をリネーム",
     "%s copied %s" : "%s を %s に複製",
+    "%s assigned %s to %s" : "%s が %s を %s に割り当て",
     "Operation #%s does not exist" : "#%s 操作は存在しません",
     "Entity %s does not exist" : "エンティティー %s がありません",
     "Entity %s is invalid" : "エンティティー %s が間違っています",
@@ -55,6 +56,7 @@ OC.L10N.register(
     "PDF documents" : "PDFドキュメント",
     "Video" : "ビデオ",
     "Custom MIME type" : "カスタムMIMEタイプ",
+    "Custom mimetype" : "カスタムMIMEタイプ",
     "Select a file type" : "ファイルタイプを指定",
     "e.g. httpd/unix-directory" : "例: httpd/unix-directory",
     "Please enter a valid time span" : "正しい間隔を指定してください",
@@ -69,6 +71,7 @@ OC.L10N.register(
     "Select a user agent" : "ユーザーエージェントを選択",
     "Select groups" : "グループを選択",
     "Groups" : "グループ",
+    "Type to search for group …" : "グループを検索するためのタイプ",
     "Select a trigger" : "トリガーを選択",
     "At least one event must be selected" : "少なくともイベントを一つ指定してください",
     "Add new flow" : "新しいフローを追加",
@@ -117,7 +120,6 @@ OC.L10N.register(
     "Request user agent" : "リクエスト時のユーザーエージェント",
     "Group membership" : "グループメンバー",
     "is member of" : "が次のグループのメンバーである",
-    "is not member of" : "が次のグループのメンバーではない",
-    "Type to search for group …" : "グループを検索するためのタイプ"
+    "is not member of" : "が次のグループのメンバーではない"
 },
 "nplurals=1; plural=0;");
