@@ -27,7 +27,7 @@ OC.L10N.register(
     "%s accessed %s" : "%s acessou %s",
     "%s renamed %s" : "%s renomeado %s",
     "%s copied %s" : "%s copiou %s",
-    "%1$s assigned %2$s to %3$s" : "%1$s designou %2$s para %3$s",
+    "%s assigned %s to %s" : "%s atribuiu %s para %s",
     "Operation #%s does not exist" : "Operação #%s não existe",
     "Entity %s does not exist" : "Entidade %s não existe",
     "Entity %s is invalid" : "Entidade %s é inválida",
@@ -56,6 +56,7 @@ OC.L10N.register(
     "PDF documents" : "Documentos PDF",
     "Video" : "Vídeo",
     "Custom MIME type" : "Tipo MIME personalizado",
+    "Custom mimetype" : "Mimetype personalizado",
     "Select a file type" : "Selecionar um tipo de arquivo",
     "e.g. httpd/unix-directory" : "por ex. httpd/unix-directory",
     "Please enter a valid time span" : "Digite um período de tempo válido",
@@ -70,7 +71,7 @@ OC.L10N.register(
     "Select a user agent" : "Selecione um agente de usuário",
     "Select groups" : "Selecione grupos",
     "Groups" : "Grupos",
-    "Type to search for group …" : "Digite para pesquisar por grupo …",
+    "Type to search for group …" : "Digite para pesquisar um grupo …",
     "Select a trigger" : "Selecione um gatilho",
     "At least one event must be selected" : "É necessário selecionar ao menos um evento",
     "Add new flow" : "Adicionar novo fluxo",
@@ -119,7 +120,6 @@ OC.L10N.register(
     "Request user agent" : "Agente de usuário da requisição",
     "Group membership" : "Associação ao grupo",
     "is member of" : "é membro de",
-    "is not member of" : "não é membro de",
-    "Type to search for group …" : "Digite para pesquisar um grupo …"
+    "is not member of" : "não é membro de"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
