@@ -27,6 +27,7 @@ OC.L10N.register(
     "%s accessed %s" : "%s erişildi %s",
     "%s renamed %s" : "%s yeniden adlandırıldı%s",
     "%s copied %s" : "%s kopyalandı%s",
+    "%s assigned %s to %s" : "%s atandı %s => %s",
     "Operation #%s does not exist" : "#%s işlemi bulunamadı",
     "Entity %s does not exist" : "%s varlığı bulunamadı",
     "Entity %s is invalid" : "%s varlığı geçersiz",
@@ -55,6 +56,7 @@ OC.L10N.register(
     "PDF documents" : "PDF belgeleri",
     "Video" : "Video",
     "Custom MIME type" : "Özel MIME türü",
+    "Custom mimetype" : "Özel MIME türü",
     "Select a file type" : "Bir dosya türü seçin",
     "e.g. httpd/unix-directory" : "örnek httpd/unix-directory",
     "Please enter a valid time span" : "Lütfen geçerli bir tarih aralığı seçin",
@@ -69,7 +71,7 @@ OC.L10N.register(
     "Select a user agent" : "Bir kullanıcı uygulaması seçin",
     "Select groups" : "Grupları seçin",
     "Groups" : "Gruplar",
-    "Type to search for group …" : "Grup aramak için yazmaya başlayın…",
+    "Type to search for group …" : "Grup aramak için yazmaya başlayın…",
     "Select a trigger" : "Bir tetikleyici seçin",
     "At least one event must be selected" : "En az bir etkinlik seçilmelidir",
     "Add new flow" : "Akış ekle",
@@ -118,7 +120,6 @@ OC.L10N.register(
     "Request user agent" : "Kullanıcı uygulaması istensin",
     "Group membership" : "Grup üyeliği",
     "is member of" : "şunun üyesi olan",
-    "is not member of" : "şunun üyesi olmayan",
-    "Type to search for group …" : "Grup aramak için yazmaya başlayın…"
+    "is not member of" : "şunun üyesi olmayan"
 },
 "nplurals=2; plural=(n > 1);");
