@@ -27,21 +27,21 @@ OC.L10N.register(
     "%s accessed %s" : "%s 存取 %s",
     "%s renamed %s" : "%s 重新命名 %s",
     "%s copied %s" : "%s 複製 %s",
-    "%1$s assigned %2$s to %3$s" : "%1$s 指派了 %2$s 給 %3$s",
+    "%s assigned %s to %s" : "%s 分派 %s 給 %s",
     "Operation #%s does not exist" : "操作 #%s 不存在",
-    "Entity %s is invalid" : "實體 %s 無效",
     "Entity %s does not exist" : "實體 %s 不存在",
+    "Entity %s is invalid" : "實體 %s 無效",
     "No events are chosen." : "未選擇事件。",
     "Entity %s has no event %s" : "實體 %s 沒有事件 %s",
-    "The provided operation data is too long" : "指定的操作數據太長",
-    "Operation %s is invalid" : "操作 #%s 無效",
     "Operation %s does not exist" : "操作 %s 不存在",
+    "Operation %s is invalid" : "操作 #%s 無效",
     "At least one check needs to be provided" : "至少需要提供一個檢查規則",
+    "The provided operation data is too long" : "指定的操作數據太長",
     "Invalid check provided" : "提供了無效的檢查規則",
-    "The provided check value is too long" : "指定的檢查數據太長",
-    "Check %s is invalid" : "檢查 %s 無效",
     "Check %s does not exist" : "檢查 %s 不存在",
+    "Check %s is invalid" : "檢查 %s 無效",
     "Check %s is not allowed with this entity" : "此實體不允許使用檢查規則 %s",
+    "The provided check value is too long" : "指定的檢查數據太長",
     "Check #%s does not exist" : "檢查 #%s 不存在",
     "Check %s is invalid or does not exist" : "檢查 %s 無效或不存在",
     "Flow" : "流程",
@@ -54,8 +54,9 @@ OC.L10N.register(
     "Images" : "圖片",
     "Office documents" : "Microsoft Office 文件",
     "PDF documents" : "PDF 文件",
-    "Video" : "視像",
+    "Video" : "影片",
     "Custom MIME type" : "自訂 MIME 類型",
+    "Custom mimetype" : "自訂 mimetype",
     "Select a file type" : "選擇檔案類型",
     "e.g. httpd/unix-directory" : "例如 httpd/unix-directory",
     "Please enter a valid time span" : "請輸入有效的時間跨度",
@@ -70,7 +71,7 @@ OC.L10N.register(
     "Select a user agent" : "選擇用戶 agent",
     "Select groups" : "選擇群組",
     "Groups" : "群組",
-    "Type to search for group …" : "輸入以搜尋群組 …",
+    "Type to search for group …" : "輸入以搜尋群組 …",
     "Select a trigger" : "選擇觸發條件",
     "At least one event must be selected" : "必須選擇至少一個活動",
     "Add new flow" : "添加新流程",
@@ -119,7 +120,6 @@ OC.L10N.register(
     "Request user agent" : "索取 user agent",
     "Group membership" : "群組成員身分",
     "is member of" : "是以下群組的成員：",
-    "is not member of" : "非以下群組的成員：",
-    "Type to search for group …" : "輸入以搜尋群組 …"
+    "is not member of" : "非以下群組的成員："
 },
 "nplurals=1; plural=0;");
