@@ -17,9 +17,11 @@ use OCP\AppFramework\Http\Attribute\AnonRateLimit;
 use OCP\AppFramework\Http\Attribute\ApiRoute;
 use OCP\AppFramework\Http\Attribute\BruteForceProtection;
 use OCP\AppFramework\Http\Attribute\NoAdminRequired;
+use OCP\AppFramework\Http\Attribute\PublicPage;
 use OCP\AppFramework\Http\Attribute\UserRateLimit;
 use OCP\AppFramework\Http\DataResponse;
 use OCP\AppFramework\Http\FileDisplayResponse;
+use OCP\AppFramework\OCSController;
 use OCP\DB\Exception;
 use OCP\Files\NotFoundException;
 use OCP\IL10N;
@@ -33,7 +35,7 @@ use OCP\TextToImage\Task;
 /**
  * @psalm-import-type CoreTextToImageTask from ResponseDefinitions
  */
-class TextToImageApiController extends \OCP\AppFramework\OCSController {
+class TextToImageApiController extends OCSController {
 	public function __construct(
 		string $appName,
 		IRequest $request,
@@ -52,7 +54,7 @@ class TextToImageApiController extends \OCP\AppFramework\OCSController {
 	 *
 	 * 200: Returns availability status
 	 */
-	#[NoAdminRequired]
+	#[PublicPage]
 	#[ApiRoute(verb: 'GET', url: '/is_available', root: '/text2image')]
 	public function isAvailable(): DataResponse {
 		return new DataResponse([
@@ -73,13 +75,11 @@ class TextToImageApiController extends \OCP\AppFramework\OCSController {
 	 * 200: Task scheduled successfully
 	 * 412: Scheduling task is not possible
 	 */
-	#[NoAdminRequired]
+	#[PublicPage]
 	#[UserRateLimit(limit: 20, period: 120)]
+	#[AnonRateLimit(limit: 5, period: 120)]
 	#[ApiRoute(verb: 'POST', url: '/schedule', root: '/text2image')]
 	public function schedule(string $input, string $appId, string $identifier = '', int $numberOfImages = 8): DataResponse {
-		if (strlen($input) > 64_000) {
-			return new DataResponse(['message' => $this->l->t('Input text is too long')], Http::STATUS_PRECONDITION_FAILED);
-		}
 		$task = new Task($input, $appId, $numberOfImages, $this->userId, $identifier);
 		try {
 			try {
@@ -111,7 +111,7 @@ class TextToImageApiController extends \OCP\AppFramework\OCSController {
 	 * 200: Task returned
 	 * 404: Task not found
 	 */
-	#[NoAdminRequired]
+	#[PublicPage]
 	#[BruteForceProtection(action: 'text2image')]
 	#[ApiRoute(verb: 'GET', url: '/task/{id}', root: '/text2image')]
 	public function getTask(int $id): DataResponse {
@@ -143,7 +143,7 @@ class TextToImageApiController extends \OCP\AppFramework\OCSController {
 	 * 200: Image returned
 	 * 404: Task or image not found
 	 */
-	#[NoAdminRequired]
+	#[PublicPage]
 	#[BruteForceProtection(action: 'text2image')]
 	#[ApiRoute(verb: 'GET', url: '/task/{id}/image/{index}', root: '/text2image')]
 	public function getImage(int $id, int $index): DataResponse|FileDisplayResponse {
