@@ -76,6 +76,14 @@ OC.L10N.register(
     "Already up to date" : "Yá s'anovó",
     "Unknown" : "Desconocí­u",
     "PNG image" : "Imaxe PNG",
+    "unknown text" : "testu desconocíu",
+    "Hello world!" : "¡Hola, mundu!",
+    "sunny" : "soleyero",
+    "Hello {name}, the weather is {weather}" : "Nola {name}, ta {weather}",
+    "Hello {name}" : "Hola, {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Equí tienes los resultaos de la busca<script>alert(1)</script></strong>",
+    "new" : "novedá",
+    "_download %n file_::_download %n files_" : ["baxar %n ficheru","baxar %n ficheros"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "L'anovamientu ta en cursu. Ye posible qu'al colar d'esta páxina s'interrumpa'l procesu en dalgunos entornos.",
     "Update to {version}" : "Anovar a la versión {version}",
     "An error occurred." : "Prodúxose un error.",
@@ -84,15 +92,12 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "L'anovamientu nun foi correutu. Informa d'esti problema na <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidá de Nextcloud</a>.",
     "Continue to {productName}" : "Siguir con «{productName}»",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["L'anovamientu foi correutu. Va redirixísete a {productName} en %n segundu.","L'anovamientu foi correutu. Va redirixísete a {productName} en %n segundos."],
-    "Done" : "Fecho",
     "Applications menu" : "Menú d'aplicaciones",
     "Apps" : "Aplicaciones",
     "More apps" : "Más aplicaciones",
     "_{count} notification_::_{count} notifications_" : ["{count} avisu","{count} avisos"],
     "No" : "Non",
     "Yes" : "Sí",
-    "App password" : "Contraseña de l'aplicación",
-    "Grant access" : "Conceder l'accesu",
     "Failed to add the public link to your Nextcloud" : "Nun se pue amestar l'enllaz públicu a esta instancia de Nextcloud",
     "Federated user" : "Usuariu federáu",
     "Create share" : "Crear l'elementu compartíu",
@@ -100,6 +105,7 @@ OC.L10N.register(
     "Pick start date" : "Escoyer la data de comienzu",
     "Pick end date" : "Escoyer la data de fin",
     "Search in date range" : "Buscar nun intervalu de dates",
+    "Searching …" : "Buscando…",
     "Start typing to search" : "Comienza a escribir pa buscar",
     "No matching results" : "Nun hai nengún resultáu que concasare",
     "Today" : "Güei",
@@ -118,9 +124,11 @@ OC.L10N.register(
     "Load more results" : "Cargar más resultaos",
     "Search in" : "Buscar en",
     "Log in" : "Aniciar la sesión",
+    "Logging in …" : "Aniciando la sesión…",
     "Log in to {productName}" : "Aniciar la sesión en: {productName}",
     "Wrong login or password." : "El nomatu o la contraseña nun son correutos.",
     "This account is disabled" : "Esta cuenta ta desactivada",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Dende la to IP, detectemos múltiples intentos d'aniciar la sesión que son inválidos. Poro, el próximu aniciu de la sesión va tardar 30 segundos.",
     "Account name or email" : "Nome o direición de corréu de la cuenta",
     "Server side authentication failed!" : "¡L'autenticación de llau del sirvidor falló!",
     "Please contact your administrator." : "Ponte en contautu cola alministración.",
@@ -149,23 +157,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documentos, fueyes de cálculu y presentaciones collaboratives, fechos con Collabora Online.",
     "Distraction free note taking app." : "Una aplicación pa tomar notes ensin distraiciones.",
     "Recommended apps" : "Aplicaciones aconseyaes",
+    "Loading apps …" : "Cargando les aplicaciones…",
     "Could not fetch list of apps from the App Store." : "Nun se pudo dir en cata de la llista d'aplicaciones de la tienda d'aplicaciones",
     "App download or installation failed" : "La descarga o instalación d'aplicaciones falló",
     "Cannot install this app because it is not compatible" : "Nun se pue instalar esta aplicación porque nun ye compatible",
     "Cannot install this app" : "Nun se pue instalar esta aplicación",
     "Skip" : "Saltar",
+    "Installing apps …" : "Instalando les aplicaciones…",
     "Install recommended apps" : "Instalar les aplicaciones aconseyaes",
-    "Online" : "En llinia",
-    "Away" : "Ausente",
-    "Busy" : "Ocupáu",
-    "Do not disturb" : "Nun molestar",
-    "Mute all notifications" : "Desactivar tolos avisos",
-    "Invisible" : "Invisible",
-    "Appear offline" : "Apaecer desconectáu",
     "Avatar of {displayName}" : "Avatar de: {displayName}",
     "Settings menu" : "Menú de configuración",
+    "Loading your contacts …" : "Cargando los contautos…",
+    "Looking for {term} …" : "Buscando {term}…",
     "Search contacts" : "Buscar contautos",
     "Reset search" : "Reaniciar la busca",
+    "Search contacts …" : "Buscar contautos…",
     "Could not load your contacts" : "Nun se pudieron cargar los contautos",
     "No contacts found" : "Nun s'atopó nengun contautu",
     "Show all contacts" : "Amostar tolos contautos",
@@ -177,20 +183,14 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Prodúxose un error mentanto se buscaba «{type}»",
     "Search starts once you start typing and results may be reached with the arrow keys" : "La busca comienza namás que comiences a escribir y pues seleicionar los resultaos coles tecles del cursor",
     "Search for {name} only" : "Buscar «{name}» namás",
+    "Loading more results …" : "Cargando más resultaos…",
     "Forgot password?" : "¿Escaeciesti la contraseña?",
     "Back to login form" : "Volver al formulariu p'aniciar la sesión",
     "Back" : "Atrás",
     "Login form is disabled." : "El formulariu p'aniciar la sesión ta desactiváu.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "El formulariu p'aniciar la sesión de Nextcloud ta desactiváu. Usa otra opción p'aniciar la sesión si ta disponible o ponte en contautu cola alministración.",
-    "Connect to your account" : "Conectase cola to cuenta",
-    "Security warning" : "Alvertencia de seguranza",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si nun tas tentando de configurar un preséu o aplicación nuevos, daquién tenta d'engañate pa que-y concedas l'accesu a los tos datos. Nesi casu nun sigas y ponte en contautu cola alministración.",
-    "Alternative log in using app password" : "Aniciu de la sesión alternativu cola contraseña de l'aplicación",
-    "Account connected" : "Cuenta conectada",
-    "Your client should now be connected!" : "¡La cuenta habría tar conectada!",
-    "You can close this window." : "Pues zarrar esta ventana.",
-    "Account access" : "Accesu a la cuenta",
     "More actions" : "Más aiciones",
+    "Security warning" : "Alvertencia de seguranza",
     "Storage & database" : "Almacenamientu y base de datos",
     "Data folder" : "Carpeta de datos",
     "Install and activate additional PHP modules to choose other database types." : "Instala y activa los módulos PHP adicionales pa escoyer otros tipos de bases de datos.",
@@ -205,6 +205,7 @@ OC.L10N.register(
     "Database tablespace" : "Espaciu de tabla de la base de datos",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Especifica'l númberu de puertu xunto col nome del agospiador (por exemplu, localhost:5432)",
     "Database host" : "Agospiador de la base de datos",
+    "Installing …" : "Instalando…",
     "Install" : "Instalar",
     "Need help?" : "¿Precises ayuda?",
     "See the documentation" : "Mira la documentación",
@@ -213,6 +214,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "El restolador nun ye compatible. Anuévalu o instala una versión compatible.",
     "Continue with this unsupported browser" : "SIguir con esti restolador incompatible",
     "Supported versions" : "Versiones compatibles",
+    "Search {types} …" : "Buscar «{types}»…",
     "Choose {file}" : "Escoyer «{file}»",
     "Choose" : "Escoyer",
     "Copy to {target}" : "Copiar a {target}",
@@ -232,9 +234,7 @@ OC.L10N.register(
     "(all selected)" : "(seleicionóse too)",
     "({count} selected)" : "({count} na seleición)",
     "Error loading file exists template" : "Hebo un error al cargar la plantía de ficheru esistente",
-    "Groups" : "Grupos",
-    "Group list is empty" : "La llista de grupos ta balera",
-    "Unable to retrieve the group list" : "Nun ye posible recuperar la llista de grupos",
+    "Saving …" : "Guardando…",
     "seconds ago" : "hai segundos",
     "Connection to server lost" : "Perdióse la conexón col sirividor",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Hebo un problema al cargar la páxina, va volver cargase en %n segundu","Hebo un problema al cargar la páxina, va volver cargase en %n segundos"],
@@ -249,6 +249,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "Escribi pa buscar proyeutos esistentes",
     "New in" : "Novedá en",
     "View changelog" : "Ver el rexistru de cambeos",
+    "No action available" : "Nun hai nenguna aición disponible",
+    "Error fetching contact actions" : "Hebo un error al dir en cata de les aiciones del contautu",
     "Close \"{dialogTitle}\" dialog" : "Zarrar el diálogu «{dialogTitle}»",
     "Email length is at max (255)" : "La llongura de la direición de corréu electrónicu ye la máxima (255)",
     "Personal" : "Personal",
@@ -282,6 +284,18 @@ OC.L10N.register(
     "Skip to navigation of app" : "Saltar a la navegación de l'aplicación",
     "Go to %s" : "Dir a «%s»",
     "Get your own free account" : "Consigui la to cuenta gratuíta",
+    "Connect to your account" : "Conectase cola to cuenta",
+    "Please log in before granting %1$s access to your %2$s account." : "Anicia la sesión enantes de conceder l'accesu de %1$s na cuenta %2$s.",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si nun tas tentando de configurar un preséu o aplicación nuevos, daquién tenta d'engañate pa que-y concedas l'accesu a los tos datos. Nesi casu nun sigas y ponte en contautu cola alministración.",
+    "App password" : "Contraseña de l'aplicación",
+    "Grant access" : "Conceder l'accesu",
+    "Alternative log in using app password" : "Aniciu de la sesión alternativu cola contraseña de l'aplicación",
+    "Account access" : "Accesu a la cuenta",
+    "Currently logged in as %1$s (%2$s)." : "Aniciesti la sesión como %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Tas a piques de conceder a «%1$s» l'accesu a la cuenta %2$s.",
+    "Account connected" : "Cuenta conectada",
+    "Your client should now be connected!" : "¡La cuenta habría tar conectada!",
+    "You can close this window." : "Pues zarrar esta ventana.",
     "Previous" : "Anterior",
     "This share is password-protected" : "Esti secrete ta protexíu con una contraseña",
     "The password is wrong or expired. Please try again or request a new one." : "La contraseña ye incorreuta o caducó. Volvi tentalo o solicita una nueva.",
@@ -321,50 +335,38 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia de %s ta nel mou de caltenimientu y pue talo un tiempu",
     "This page will refresh itself when the instance is available again." : "Esta páxina va anovase sola cuando la instancia vuelva tar disponible.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Ponte en contautu cola alministración del sistema si esti mensaxe sigue apaeciendo o apaez inesperadamente.",
+    "No temporary profile picture available, try again" : "Nun hai nenguna semeya temporal pal perfil. Volvi tentalo",
+    "No crop data provided" : "Nun se fornió nengún datu de recorte",
+    "No valid crop data provided" : "Nun se fornió nengún datu de recorte válidu",
+    "Crop is not square" : "El recorte nun ye cuadráu",
     "Error occurred while checking server setup" : "Prodúxose un error mentanto se revisaba la configuración del sirvidor",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Pa consiguir más detalles, consulta la {linkstart}documentación ↗{linkend}.",
-    "unknown text" : "testu desconocíu",
-    "Hello world!" : "¡Hola, mundu!",
-    "sunny" : "soleyero",
-    "Hello {name}, the weather is {weather}" : "Nola {name}, ta {weather}",
-    "Hello {name}" : "Hola, {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Equí tienes los resultaos de la busca<script>alert(1)</script></strong>",
-    "new" : "novedá",
-    "_download %n file_::_download %n files_" : ["baxar %n ficheru","baxar %n ficheros"],
-    "Searching …" : "Buscando…",
-    "Logging in …" : "Aniciando la sesión…",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Dende la to IP, detectemos múltiples intentos d'aniciar la sesión que son inválidos. Poro, el próximu aniciu de la sesión va tardar 30 segundos.",
-    "Loading apps …" : "Cargando les aplicaciones…",
-    "Installing apps …" : "Instalando les aplicaciones…",
-    "Loading your contacts …" : "Cargando los contautos…",
-    "Looking for {term} …" : "Buscando {term}…",
-    "Search contacts …" : "Buscar contautos…",
-    "Loading more results …" : "Cargando más resultaos…",
-    "Search {types} …" : "Buscar «{types}»…",
-    "Saving …" : "Guardando…",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Charres, videollamaes, compartición de pantalla, reuniones en llinia y conferencies web; nel restolador y coles aplicaciones móviles.",
+    "You have not added any info yet" : "Nun amestesti nenguna información",
+    "{user} has not added any info yet" : "{user} nun amestó nenguna información",
+    "Error opening the user status modal, try hard refreshing the page" : "Hebo un error al abrir el diálogu modal del estáu d'usuariu, prueba a anovar la páxina",
+    "Edit Profile" : "Editar el perfil",
+    "The headline and about sections will show up here" : "Equí apaecen la testera y les seiciones d'información",
     "Very weak password" : "La contraseña ye mui poco segura",
     "Weak password" : "La contraseña ye poco segura",
     "So-so password" : "La contraseña ye normal",
     "Good password" : "La contraseña ye segura",
     "Strong password" : "La contraseña ye mui segura",
-    "No action available" : "Nun hai nenguna aición disponible",
-    "Error fetching contact actions" : "Hebo un error al dir en cata de les aiciones del contautu",
     "Non-existing tag #{tag}" : "Etiqueta inesistente #{tag}",
     "Restricted" : "Restrinxóse",
+    "Invisible" : "Invisible",
     "Delete" : "Desaniciar",
     "Rename" : "Renomar",
     "Collaborative tags" : "Etiquetes collaboratives",
     "No tags found" : "Nun s'atopó nenguna etiqueta",
+    "Profile not found" : "Nun s'atopó'l perfil",
+    "The profile does not exist." : "El perfil nun esiste.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ye probable que'l to direutoriu de datos y los ficheros seyan accesibles dende internet porque'l ficheru .htaccess nun funciona.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pa consiguir más información tocante a cómo configurar afayadizamente'l sirvidor, mira la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentación</a>.",
     "Show password" : "Amosar la contraseña",
     "Toggle password visibility" : "Alternar la visibilidá de la contraseña",
     "Configure the database" : "Configurar la base de datos",
     "Only %s is available." : "Namás hai disponible %s.",
-    "Database account" : "Cuenta de la base de datos",
-    "Installing …" : "Instalando…",
-    "Please log in before granting %1$s access to your %2$s account." : "Anicia la sesión enantes de conceder l'accesu de %1$s na cuenta %2$s.",
-    "Currently logged in as %1$s (%2$s)." : "Aniciesti la sesión como %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Tas a piques de conceder a «%1$s» l'accesu a la cuenta %2$s."
+    "Database account" : "Cuenta de la base de datos"
 },
 "nplurals=2; plural=(n != 1);");
