@@ -33,12 +33,12 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Націсніце кнопку ніжэй, каб скінуць пароль. Калі вы не запытвалі скід пароля, праігнаруйце гэты ліст.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Націсніце спасылку ніжэй, каб скінуць пароль. Калі вы не запытвалі скід пароля, праігнаруйце гэты ліст.",
     "Reset your password" : "Скінуць пароль",
-    "Task not found" : "Заданне не знойдзена",
+    "Task not found" : "Задача не знойдзена",
     "Internal error" : "Унутраная памылка",
     "Not found" : "Не знойдзена",
     "Node is locked" : "Вузел заблакаваны",
     "Bad request" : "Няправільны запыт",
-    "Requested task type does not exist" : "Запытаны тып задання не існуе",
+    "Requested task type does not exist" : "Запытаны тып задачы не існуе",
     "Necessary language model provider is not available" : "Неабходны пастаўшчык моўнай мадэлі недаступны",
     "No text to image provider is available" : "Няма даступных пастаўшчыкоў паслуг пераўтварэння тэксту ў відарыс",
     "Image not found" : "Відарыс не знойдзены",
@@ -47,8 +47,6 @@ OC.L10N.register(
     "Unable to translate" : "Немагчыма перакласці",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Nextcloud Server" : "Сервер Nextcloud",
-    "Some of your link shares have been removed" : "Некаторыя з вашых абагуленых спасылак былі выдалены",
-    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "З-за памылкі бяспекі нам давялося выдаліць некаторыя з вашых абагуленых спасылак. Больш падрабязную інфармацыю глядзіце па спасылцы.",
     "Learn more ↗" : "Больш падрабязна ↗",
     "Preparing update" : "Падрыхтоўка абнаўлення",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Скарыстайцеся абнаўленнем праз камандны радок, бо абнаўленне праз браўзер адключана ў вашым config.php.",
@@ -184,12 +182,17 @@ OC.L10N.register(
     "Matroska video" : "Відэа Matroska",
     "Windows Media video" : "Відэа Windows Media",
     "AVI video" : "Відэа AVI",
+    "unknown text" : "невядомы тэкст",
+    "Hello world!" : "Hello world!",
+    "sunny" : "сонечна",
+    "Hello {name}, the weather is {weather}" : "Вітаем, {name}, на дварэ сёння {weather}",
+    "Hello {name}" : "Вітаем, {name}",
+    "new" : "новы",
+    "_download %n file_::_download %n files_" : ["спампаваць %n файл","спампаваць %n файлы","спампаваць %n файлаў","спампаваць %n файлаў"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Абнаўленне яшчэ ідзе. У некаторых асяроддзях, калі пакінуць гэтую старонку, працэс можа быць перапынены.",
-    "Update to {version}" : "Абнавіць да {version}",
+    "Update to {version}" : "Абнаўленне да {version}",
     "An error occurred." : "Узнікла памылка.",
     "Please reload the page." : "Перазагрузіце старонку.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Абнаўленне было няўдалым. Дадатковая інфармацыя – у прысвечаным гэтаму пытанню паведамленні на <a href=\"{url}\">нашым форуме</a>.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Абнаўленне было няўдалым. Паведаміце пра гэту праблему <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">супольнасці Nextcloud</a>.",
     "Applications menu" : "Меню праграм",
     "Apps" : "Праграмы",
     "More apps" : "Болей праграм",
@@ -199,7 +202,6 @@ OC.L10N.register(
     "The remote URL must include the user." : "Аддалены URL-адрас павінен уключаць карыстальніка.",
     "Invalid remote URL." : "Памылковы аддалены URL.",
     "Failed to add the public link to your Nextcloud" : "Не ўдалося дадаць публічную спасылку ў ваш Nextcloud",
-    "Federated user" : "Федэратыўны карыстальнік",
     "user@your-nextcloud.org" : "user@your-nextcloud.org",
     "Direct link copied" : "Прамая спасылка скапіявана",
     "Please copy the link manually:" : "Скапіюйце спасылку ўручную:",
@@ -210,7 +212,7 @@ OC.L10N.register(
     "Search in current app" : "Пошук у бягучай праграме",
     "Clear search" : "Ачысціць пошук",
     "Search everywhere" : "Шукаць усюды",
-    "Searching …" : "Пошук …",
+    "Searching …" : "Пошук …",
     "Start typing to search" : "Пачніце ўводзіць тэкст для пошуку",
     "Minimum search length is {minSearchLength} characters" : "Мінімальная даўжыня радка для пошуку складае {minSearchLength} сімвалаў",
     "No matching results" : "Няма адпаведных вынікаў",
@@ -220,7 +222,6 @@ OC.L10N.register(
     "This year" : "Гэты год",
     "Last year" : "Мінулы год",
     "Between {startDate} and {endDate}" : "Паміж {startDate} і {endDate}",
-    "Unified search" : "Уніфікаваны пошук",
     "Search apps, files, tags, messages" : "Пошук праграм, файлаў, тэгаў, паведамленняў",
     "Places" : "Месцы",
     "Date" : "Дата",
@@ -230,7 +231,7 @@ OC.L10N.register(
     "Load more results" : "Загрузіць больш вынікаў",
     "Search in" : "Пошук у",
     "Log in" : "Увайсці",
-    "Logging in …" : "Уваход …",
+    "Logging in …" : "Уваход …",
     "Log in to {productName}" : "Увайсці ў {productName}",
     "Wrong login or password." : "Няправільны лагін або пароль.",
     "This account is disabled" : "Гэты ўліковы запіс адключаны.",
@@ -262,21 +263,21 @@ OC.L10N.register(
     "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Чаты, відэавыклікі, дэманстрацыя экрана, анлайн-сустрэчы і вэб-канферэнцыі — у вашым браўзеры і з дапамогай мабільных праграм.",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Супольныя дакументы, электронныя табліцы і прэзентацыі, створаныя ў Collabora Online.",
     "Recommended apps" : "Рэкамендаваныя праграмы",
-    "Loading apps …" : "Загрузка праграм …",
+    "Loading apps …" : "Загрузка праграм …",
     "Could not fetch list of apps from the App Store." : "Не ўдалося атрымаць спіс праграм з App Store.",
     "App download or installation failed" : "Не ўдалося спампаваць або ўсталяваць праграму",
     "Cannot install this app because it is not compatible" : "Немагчыма ўсталяваць гэту праграму, бо яна несумяшчальная",
     "Cannot install this app" : "Немагчыма ўсталяваць гэту праграму",
     "Skip" : "Прапусціць",
-    "Installing apps …" : "Усталяванне праграм …",
+    "Installing apps …" : "Усталяванне праграм …",
     "Install recommended apps" : "Усталяваць рэкамендаваныя праграмы",
     "Avatar of {displayName}" : "Аватар карыстальніка {displayName}",
     "Settings menu" : "Меню налад",
-    "Loading your contacts …" : "Загрузка вашых кантактаў …",
-    "Looking for {term} …" : "Пошук {term} …",
+    "Loading your contacts …" : "Загрузка вашых кантактаў …",
+    "Looking for {term} …" : "Пошук {term} …",
     "Search contacts" : "Пошук кантактаў",
     "Reset search" : "Скінуць пошук",
-    "Search contacts …" : "Пошук кантактаў …",
+    "Search contacts …" : "Пошук кантактаў …",
     "Could not load your contacts" : "Не ўдалося загрузіць вашы кантакты",
     "No contacts found" : "Кантакты не знойдзены",
     "Show all contacts" : "Паказаць усе кантакты",
@@ -287,8 +288,7 @@ OC.L10N.register(
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Увядзіце хаця б {minSearchLength} сімвал для пошуку","Увядзіце хаця б {minSearchLength} сімвалы для пошуку","Увядзіце хаця б {minSearchLength} сімвалаў для пошуку","Увядзіце хаця б {minSearchLength} сімвалаў для пошуку"],
     "An error occurred while searching for {type}" : "Падчас пошуку {type} адбылася памылка",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Пошук пачынаецца, як толькі вы пачынаеце ўводзіць тэкст, і вынікаў можна дасягнуць з дапамогай клавіш са стрэлкамі",
-    "Search for {name} only" : "Шукаць толькі {name}",
-    "Loading more results …" : "Загрузка дадатковых вынікаў …",
+    "Loading more results …" : "Загрузка дадатковых вынікаў …",
     "Forgot password?" : "Забылі пароль?",
     "Back to login form" : "Назад да формы ўваходу",
     "Back" : "Назад",
@@ -315,7 +315,6 @@ OC.L10N.register(
     "Storage & database" : "Сховішча і база даных",
     "Data folder" : "Папка з данымі",
     "Database configuration" : "Канфігурацыя базы даных",
-    "Database type" : "Тып базы даных",
     "Only {firstAndOnlyDatabase} is available." : "Даступна толькі {firstAndOnlyDatabase}.",
     "Install and activate additional PHP modules to choose other database types." : "Усталюйце і актывуйце дадатковыя модулі PHP, каб выбраць іншы тып базы даных.",
     "For more details check out the documentation." : "Для атрымання больш падрабязнай інфармацыі азнаёмцеся з дакументацыяй.",
@@ -329,7 +328,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Укажыце нумар порта разам з хостам (напрыклад, localhost:5432).",
     "Database host" : "Хост базы даных",
     "localhost" : "localhost",
-    "Installing …" : "Усталяванне …",
+    "Installing …" : "Усталяванне …",
     "Install" : "Усталяваць",
     "Need help?" : "Патрэбна дапамога?",
     "See the documentation" : "Глядзіце дакументацыю",
@@ -338,7 +337,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Ваш браўзер не падтрымліваецца. Абнавіце яго да новай версіі або да той, якая падтрымліваецца.",
     "Continue with this unsupported browser" : "Працягнуць выкарыстанне гэтага браўзера, які не падтрымліваецца",
     "Supported versions" : "Версіі, якія падтрымліваюцца",
-    "Search {types} …" : "Пошук {types} …",
+    "Search {types} …" : "Пошук {types} …",
     "Choose {file}" : "Выбраць {file}",
     "Choose" : "Выбраць",
     "Copy to {target}" : "Капіяваць у {target}",
@@ -358,7 +357,7 @@ OC.L10N.register(
     "(all selected)" : "(усе выбраны)",
     "({count} selected)" : "(выбрана {count})",
     "Error loading file exists template" : "Памылка загрузкі шаблона",
-    "Saving …" : "Захаванне …",
+    "Saving …" : "Захаванне …",
     "seconds ago" : "с таму",
     "Connection to server lost" : "Злучэнне з серверам страчана",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Праблема з загрузкай старонкі, перазагрузка праз %n секунду","Праблема з загрузкай старонкі, перазагрузка праз %n секунды","Праблема з загрузкай старонкі, перазагрузка праз %n секунд","Праблема з загрузкай старонкі, перазагрузка праз %n секунд"],
@@ -371,6 +370,7 @@ OC.L10N.register(
     "Failed to add the item to the project" : "Не ўдалося дадаць элемент у праект",
     "New in" : "Новае ў",
     "View changelog" : "Праглядзець спіс змяненняў",
+    "No action available" : "Няма даступных дзеянняў",
     "Close \"{dialogTitle}\" dialog" : "Закрыць дыялогавае акно \"{dialogTitle}\"",
     "Clipboard not available, please copy manually" : "Буфер абмену недаступны, скапіюйце ўручную",
     "Personal" : "Асабістыя",
@@ -411,7 +411,6 @@ OC.L10N.register(
     "Currently logged in as %1$s (%2$s)." : "Вы ўвайшлі як %1$s (%2$s).",
     "You are about to grant %1$s access to your %2$s account." : "Вы збіраецеся даць %1$s доступ да вашага ўліковага запісу %2$s.",
     "You can close this window." : "Вы можаце закрыць гэта акно.",
-    "Previous" : "Папярэдняя",
     "The password is wrong or expired. Please try again or request a new one." : "Пароль няправільны або скончыўся тэрмін яго дзеяння. Паспрабуйце яшчэ раз або запытайце новы.",
     "Please type in your email address to request a temporary password" : "Увядзіце свой адрас электроннай пошты, каб запытаць часовы пароль",
     "Email address" : "Адрас электроннай пошты",
@@ -431,38 +430,28 @@ OC.L10N.register(
     "Update needed" : "Неабходна абнаўленне",
     "Maintenance mode" : "Рэжым тэхнічнага абслугоўвання",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Звярніцеся да сістэмнага адміністратара, калі гэта паведамленне працягвае з'яўляцца або з'явілася нечакана.",
+    "No temporary profile picture available, try again" : "Няма даступных часовых аватараў профілю, паспрабуйце яшчэ раз",
+    "Crop is not square" : "Абрэзка не квадратная",
     "Error occurred while checking server setup" : "Падчас праверкі налад сервера адбылася памылка",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Больш падрабязную інфармацыю глядзіце ў {linkstart}дакументацыі ↗{linkend}",
-    "unknown text" : "невядомы тэкст",
-    "Hello world!" : "Hello world!",
-    "sunny" : "сонечна",
-    "Hello {name}, the weather is {weather}" : "Вітаем, {name}, на дварэ сёння {weather}",
-    "Hello {name}" : "Вітаем, {name}",
-    "new" : "новы",
-    "_download %n file_::_download %n files_" : ["спампаваць %n файл","спампаваць %n файлы","спампаваць %n файлаў","спампаваць %n файлаў"],
-    "Direct link copied to clipboard" : "Прамая спасылка скапіявана ў буфер абмену",
-    "Searching …" : "Пошук …",
-    "Logging in …" : "Уваход …",
-    "Loading apps …" : "Загрузка праграм …",
-    "Installing apps …" : "Усталяванне праграм …",
-    "Loading your contacts …" : "Загрузка вашых кантактаў …",
-    "Looking for {term} …" : "Пошук {term} …",
-    "Search contacts …" : "Пошук кантактаў …",
-    "Loading more results …" : "Загрузка дадатковых вынікаў …",
-    "Search {types} …" : "Пошук {types} …",
-    "Saving …" : "Захаванне …",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Чаты, відэавыклікі, дэманстрацыя экрана, анлайн-сустрэчы і вэб-канферэнцыі — у вашым браўзеры і з дапамогай мабільных праграм.",
+    "You have not added any info yet" : "Вы пакуль не дадалі ніякай інфармацыі",
+    "{user} has not added any info yet" : "{user} пакуль не дадаў(-ла) ніякай інфармацыі",
+    "Error opening the user status modal, try hard refreshing the page" : "Памылка пры адкрыцці статусу карыстальніка, паспрабуйце абнавіць старонку",
+    "Edit Profile" : "Рэдагаваць профіль",
     "Very weak password" : "Вельмі слабы пароль",
     "Weak password" : "Слабы пароль",
     "So-so password" : "Абы-які пароль",
     "Good password" : "Файны пароль",
     "Strong password" : "Моцны пароль",
-    "No action available" : "Няма даступных дзеянняў",
     "Non-existing tag #{tag}" : "Неіснуючы тэг #{tag}",
     "Invisible" : "Нябачны",
     "Delete" : "Выдаліць",
     "Rename" : "Перайменаваць",
     "Collaborative tags" : "Супольныя тэгі",
     "No tags found" : "Тэгі не знойдзены",
+    "Profile not found" : "Профіль не знойдзены",
+    "The profile does not exist." : "Профіль не існуе.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ваш каталог даных і файлы, верагодна, даступныя з Інтэрнэту, таму што файл .htaccess не працуе.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Каб даведацца, як правільна наладзіць сервер, глядзіце <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">дакументацыю</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Стварыць ўліковы запіс адміністратара</strong>",
@@ -470,9 +459,8 @@ OC.L10N.register(
     "New admin password" : "Пароль новага адіміністратара",
     "Show password" : "Паказаць пароль",
     "Toggle password visibility" : "Пераключыць бачнасць пароля",
-    "Configure the database" : "Наладзіць базу даных",
     "Only %s is available." : "Даступна толькі %s.",
     "Database account" : "Уліковы запіс базы даных",
-    "Installing …" : "Усталяванне …"
+    "Direct link copied to clipboard" : "Прамая спасылка скапіявана ў буфер абмену"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
