@@ -42,7 +42,6 @@ OC.L10N.register(
     "Not found" : "Nenalezeno",
     "Node is locked" : "Uzel je uzamčen",
     "Bad request" : "Chybný požadavek",
-    "Input text is too long" : "Vstupní text je příliš dlouhý",
     "Requested task type does not exist" : "Požadovaný typ úkolu neexistuje",
     "Necessary language model provider is not available" : "Nezbytný poskytovatel jazykového modelu není k dsipozici",
     "No text to image provider is available" : "Není k dispozici žádný poskytovatel převodu textu na obrázek",
@@ -198,6 +197,14 @@ OC.L10N.register(
     "Matroska video" : "Matroska video",
     "Windows Media video" : "Windows Media video",
     "AVI video" : "AVI video",
+    "unknown text" : "neznámý text",
+    "Hello world!" : "Dobrý den světe!",
+    "sunny" : "slunečno",
+    "Hello {name}, the weather is {weather}" : "Dobrý den {name}, počasí je {weather}",
+    "Hello {name}" : "Dobrý den {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Toto výsledky pro vaše hledání<script>alert(1)</script></strong>",
+    "new" : "nový",
+    "_download %n file_::_download %n files_" : ["stáhnout %n soubor","stáhnout %n soubory","stáhnout %n souborů","stáhnout %n souborů"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Probíhá aktualizace – opuštění této stránky může v některých prostředích proces přerušit.",
     "Update to {version}" : "Aktualizovat na {version}",
     "An error occurred." : "Došlo k chybě.",
@@ -227,7 +234,7 @@ OC.L10N.register(
     "Search in current app" : "Hledat ve stávající aplikaci",
     "Clear search" : "Vyčistit hledání",
     "Search everywhere" : "Hledat všude",
-    "Searching …" : "Hledání …",
+    "Searching …" : "Hledání…",
     "Start typing to search" : "Hledejte psaním",
     "Minimum search length is {minSearchLength} characters" : "Nejkratší možná délka vyhledávaného řetězce je {minSearchLength} znaků",
     "No matching results" : "Žádné odpovídající výsledky",
@@ -249,7 +256,7 @@ OC.L10N.register(
     "Load more results" : "Načíst další výsledky",
     "Search in" : "Hledat v",
     "Log in" : "Přihlásit",
-    "Logging in …" : "Přihlašování …",
+    "Logging in …" : "Přihlašování…",
     "Log in to {productName}" : "Přihlásit se do {productName}",
     "Wrong login or password." : "Nesprávné přihlašovací jméno nebo heslo",
     "This account is disabled" : "Účet je znepřístupněn",
@@ -263,7 +270,6 @@ OC.L10N.register(
     "An internal error occurred." : "Došlo k vnitřní chybě.",
     "Please try again or contact your administrator." : "Zkuste to znovu nebo se obraťte na správce.",
     "Password" : "Heslo",
-    "Remember me" : "Zapamatovat si mne",
     "Log in with a device" : "Přihlásit se pomocí zařízení",
     "Login or email" : "Přihlašovací jméno nebo e-mail",
     "Your account is not setup for passwordless login." : "Váš účet nemá nastavené přihlašování se bez hesla.",
@@ -287,28 +293,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Dokumenty, tabulky a prezentace pro spolupráci, založené na Collabora Online.",
     "Distraction free note taking app." : "Aplikace pro psaní poznámek bez rozptylování.",
     "Recommended apps" : "Doporučené aplikace",
-    "Loading apps …" : "Načítání aplikací …",
+    "Loading apps …" : "Načítání aplikací…",
     "Could not fetch list of apps from the App Store." : "Nedaří se získat seznam aplikací z katalogu.",
     "App download or installation failed" : "Stažení aplikace nebo její instalace se nezdařilo",
     "Cannot install this app because it is not compatible" : "Tuto aplikaci nelze nainstalovat, protože není kompatibilní",
     "Cannot install this app" : "Tuto aplikaci nelze nainstalovat",
     "Skip" : "Přeskočit",
-    "Installing apps …" : "Instalace aplikací …",
+    "Installing apps …" : "Instalace aplikací…",
     "Install recommended apps" : "Nainstalovat doporučené aplikace",
-    "Online" : "Online",
-    "Away" : "Pryč",
-    "Busy" : "Zaneprázdněn(a)",
-    "Do not disturb" : "Nerušit",
-    "Mute all notifications" : "Ztlumit veškerá upozornění",
-    "Invisible" : "Není vidět",
-    "Appear offline" : "Jevit se offline",
     "Avatar of {displayName}" : "Zástupný obrázek {displayName}",
     "Settings menu" : "Nabídka nastavení",
-    "Loading your contacts …" : "Načítání vašich kontaktů …",
-    "Looking for {term} …" : "Hledání {term} …",
+    "Loading your contacts …" : "Načítání vašich kontaktů…",
+    "Looking for {term} …" : "Hledání {term}…",
     "Search contacts" : "Hledat v kontaktech",
     "Reset search" : "Resetovat hledání",
-    "Search contacts …" : "Hledat v kontaktech …",
+    "Search contacts …" : "Hledat v kontaktech…",
     "Could not load your contacts" : "Nedaří se načíst vaše kontakty",
     "No contacts found" : "Nenalezeny žádné kontakty",
     "Show all contacts" : "Zobrazit všechny kontakty",
@@ -320,7 +319,7 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Došlo k chybě při hledání pro {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Hledání začne jakmile začnete psát a mezi výsledky je možné se pohybovat pomocí klávesami šipka nahoru/dolů",
     "Search for {name} only" : "Hledat pouze {name}",
-    "Loading more results …" : "Načítání dalších výsledků …",
+    "Loading more results …" : "Načítání dalších výsledků…",
     "Forgot password?" : "Zapomněli jste heslo?",
     "Back to login form" : "Zpět na formulář pro přihlášení",
     "Back" : "Zpět",
@@ -350,7 +349,6 @@ OC.L10N.register(
     "Storage & database" : "Úložiště a databáze",
     "Data folder" : "Složka s daty",
     "Database configuration" : "Nastavení databáze",
-    "Database type" : "Typ databáze",
     "Only {firstAndOnlyDatabase} is available." : "K dispozici je pouze {firstAndOnlyDatabase}.",
     "Install and activate additional PHP modules to choose other database types." : "Pokud chcete vybrat jiné typy databáze, je třeba nainstalovat a povolit dodatečné PHP moduly.",
     "For more details check out the documentation." : "Podrobnosti naleznete v dokumentaci.",
@@ -358,7 +356,6 @@ OC.L10N.register(
     "You chose SQLite as database." : "Zvolíte jako databázi SQLite.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite by mělo být použito pouze pro instance, které slouží jen pro vývoj nebo ty obhospodařující opravdu velmi málo dat a uživatelů. Pro jakékoli produkční použití doporučujeme použít robustnější databázové řešení.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Pokud používáte klienty pro synchronizaci souborů, je použití SQLite silně nedoporučeno.",
-    "Database connection" : "Spojení do databáze",
     "Database user" : "Uživatel databáze",
     "Database password" : "Heslo do databáze",
     "Database name" : "Název databáze",
@@ -366,7 +363,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Zadejte port spolu s názvem hostitele (t. j., localhost:5432).",
     "Database host" : "Stroj na kterém se nachází databáze",
     "localhost" : "localhost",
-    "Installing …" : "Instalace …",
+    "Installing …" : "Instalace…",
     "Install" : "Nainstalovat",
     "Need help?" : "Potřebujete nápovědu?",
     "See the documentation" : "Viz dokumentace",
@@ -375,7 +372,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Vámi využívaný webový prohlížeč není podporován. Přejděte na novější verzi nebo na nějaký podporovaný.",
     "Continue with this unsupported browser" : "Pokračovat s tímto zastaralým prohlížečem",
     "Supported versions" : "Podporované verze",
-    "Search {types} …" : "Hledat {types} …",
+    "Search {types} …" : "Hledat {types}…",
     "Choose {file}" : "Zvolit {file}",
     "Choose" : "Vybrat",
     "Copy to {target}" : "Zkopírovat do {target}",
@@ -395,7 +392,7 @@ OC.L10N.register(
     "(all selected)" : "(vše vybrané)",
     "({count} selected)" : "(vybráno {count})",
     "Error loading file exists template" : "Chyba při načítání šablony existence souboru",
-    "Saving …" : "Ukládání …",
+    "Saving …" : "Ukládání…",
     "seconds ago" : "před několika sekundami",
     "Connection to server lost" : "Připojení k serveru ztraceno",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problém s načítáním stránky, obnovení za %n sekundu","Problém s načítáním stránky, obnovení za %n sekundy","Problém s načítáním stránky, obnovení za %n sekund","Problém s načítáním stránky, obnovení za %n sekund"],
@@ -410,6 +407,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "Psaním vyhledávejte existující projekty",
     "New in" : "Nové v",
     "View changelog" : "Zobrazit souhrn změn",
+    "No action available" : "Není dostupná žádná akce",
+    "Error fetching contact actions" : "Chyba při získávání akcí kontaktů",
     "Close \"{dialogTitle}\" dialog" : "Zavřít „{dialogTitle}“ dialog",
     "Email length is at max (255)" : "Délka e-mailu je na maximu (255)",
     "Clipboard not available, please copy manually" : "Schránka není k dispozici – zkopírujte ručně",
@@ -497,40 +496,32 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Tato instance %s se právě nachází v režimu údržby a ta může chvíli trvat.",
     "This page will refresh itself when the instance is available again." : "Tato stránka se automaticky znovu načte, jakmile bude tato instance opět dostupná.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Pokud se tato zpráva objevuje trvale nebo nečekaně, obraťte se na správce systému.",
+    "No temporary profile picture available, try again" : "Není k dispozici žádný dočasný profilový obrázek – zkuste to znovu",
+    "No crop data provided" : "Nezadáno, jak má být obrázek oříznut",
+    "No valid crop data provided" : "Neposkytnuta platná data pro oříznutí obrázku",
+    "Crop is not square" : "Ořez není čtvercový",
     "Error occurred while checking server setup" : "Při ověřování nastavení serveru došlo k chybě",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Podrobnosti naleznete v {linkstart}dokumentaci ↗{linkend}.",
-    "unknown text" : "neznámý text",
-    "Hello world!" : "Dobrý den světe!",
-    "sunny" : "slunečno",
-    "Hello {name}, the weather is {weather}" : "Dobrý den {name}, počasí je {weather}",
-    "Hello {name}" : "Dobrý den {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Toto výsledky pro vaše hledání<script>alert(1)</script></strong>",
-    "new" : "nový",
-    "_download %n file_::_download %n files_" : ["stáhnout %n soubor","stáhnout %n soubory","stáhnout %n souborů","stáhnout %n souborů"],
-    "Direct link copied to clipboard" : "Přímý odkaz zkopírován do schránky",
-    "Searching …" : "Hledání …",
-    "Logging in …" : "Přihlašování …",
-    "Loading apps …" : "Načítání aplikací …",
-    "Installing apps …" : "Instalace aplikací …",
-    "Loading your contacts …" : "Načítání vašich kontaktů …",
-    "Looking for {term} …" : "Hledání {term} …",
-    "Search contacts …" : "Hledat v kontaktech …",
-    "Loading more results …" : "Načítání dalších výsledků …",
-    "Search {types} …" : "Hledat {types} …",
-    "Saving …" : "Ukládání …",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatování, videohovory, sdílení obrazovky, schůze na dálku a webové konference – ve webovém prohlížeči a mobilních aplikacích.",
+    "You have not added any info yet" : "Zatím jste nezadali žádné informace",
+    "{user} has not added any info yet" : "{user} uživatel zatím nezadal žádné informace",
+    "Error opening the user status modal, try hard refreshing the page" : "Chyba při otevírání dialogu stavu uživatele, pokus o opětovné načtení stránky",
+    "Edit Profile" : "Upravit profil",
+    "The headline and about sections will show up here" : "Nadpis a sekce o uživatelích se zobrazí zde",
     "Very weak password" : "Velmi snadno prolomitelné heslo",
     "Weak password" : "Snadno prolomitelné heslo",
     "So-so password" : "Ještě použitelné heslo",
     "Good password" : "Dobré heslo",
     "Strong password" : "Odolné heslo",
-    "No action available" : "Není dostupná žádná akce",
-    "Error fetching contact actions" : "Chyba při získávání akcí kontaktů",
     "Non-existing tag #{tag}" : "Neexistující štítek #{tag}",
     "Restricted" : "Omezeno",
+    "Invisible" : "Není vidět",
     "Delete" : "Smazat",
     "Rename" : "Přejmenovat",
     "Collaborative tags" : "Štítky pro spolupráci",
     "No tags found" : "Nenalezeny žádné štítky",
+    "Profile not found" : "Profil nenalezen",
+    "The profile does not exist." : "Profil neexistuje.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Váš adresář data a soubory jsou přístupné z Internetu, protože soubor .htaccess nefunguje.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informace o tom, jak správně nastavit svůj server, naleznete v <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaci</a>.",
     "<strong>Create an admin account</strong>" : "</strong>Vytvořit účet správce</strong>",
@@ -541,6 +532,6 @@ OC.L10N.register(
     "Configure the database" : "Nastavit databázi",
     "Only %s is available." : "Je k dispozici pouze %s.",
     "Database account" : "Účet do databáze",
-    "Installing …" : "Instalace …"
+    "Direct link copied to clipboard" : "Přímý odkaz zkopírován do schránky"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
