@@ -71,6 +71,14 @@ OC.L10N.register(
     "The following apps have been disabled: %s" : "La jenaj aplikaĵoj estis malŝatitaj: %s",
     "Already up to date" : "Jam aktuala",
     "Unknown" : "Nekonata",
+    "unknown text" : "nekonata teksto",
+    "Hello world!" : "Saluton, mondo!",
+    "sunny" : "suna",
+    "Hello {name}, the weather is {weather}" : "Saluton {name}, la vetero estas {weather}",
+    "Hello {name}" : "Saluton {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Jen via serĉ-rezultoj<script>alert(1)</script></strong>",
+    "new" : "nova",
+    "_download %n file_::_download %n files_" : ["elŝuti %n dosieron","elŝuti %n dosierojn"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Ĝisdatigo estas farata; forirado de la paĝo povas kelkfoje interrompi la agon.",
     "Update to {version}" : "Ĝisdatigi al {version}",
     "An error occurred." : "Eraro okazis.",
@@ -88,6 +96,7 @@ OC.L10N.register(
     "Pick start date" : "Elekti komencan daton",
     "Pick end date" : "Elekti finan daton",
     "Search in date range" : "Serĉi en data periodo",
+    "Searching …" : "Serĉado ...",
     "Start typing to search" : "Ektajpu por serĉi",
     "No matching results" : "Neniuj kongruaj rezultoj",
     "Today" : "Hodiaŭ",
@@ -101,6 +110,7 @@ OC.L10N.register(
     "Filter in current view" : "Filtrilo en ĉi vido",
     "Search in" : "Serĉi en",
     "Log in" : "Ensaluti",
+    "Logging in …" : "Ensaluti...",
     "Log in to {productName}" : "Saluti al {productName}",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Ni eltrovis plurajn nevalidajn provojn ensaluti el via IP-adreso. Do, oni prokrastis vian sekvantan ensaluton dum ĝis 30 sekundoj.",
     "Account name or email" : "Kontonomo aŭ retpoŝta adreso",
@@ -121,13 +131,18 @@ OC.L10N.register(
     "I know what I'm doing" : "Mi scias, kion mi faras",
     "Resetting password" : "Restarigo de la pasvorto",
     "Recommended apps" : "Rekomendataj aplikaĵoj",
+    "Loading apps …" : "Ŝargado de aplikaĵoj...",
     "App download or installation failed" : "Elŝuto aŭ instalado de la aplikaĵo malsukcesis",
     "Cannot install this app" : "La instalado de tiu aplikaĵo ne eblas",
     "Skip" : "Preterpasi",
+    "Installing apps …" : "Instalado de aplikaĵoj...",
     "Install recommended apps" : "Instali rekomendatajn aplikaĵojn",
     "Avatar of {displayName}" : "Avataro de {displayName}",
     "Settings menu" : "Menuo de agordo",
+    "Loading your contacts …" : "Ŝargo de viaj kontaktoj...",
+    "Looking for {term} …" : "Serĉo de {term}…",
     "Reset search" : "Restarigi serĉon",
+    "Search contacts …" : "Serĉi kontaktojn…",
     "Could not load your contacts" : "Ne eblis ŝargi viajn kontaktojn",
     "No contacts found" : "Neniu kontakto troviĝis",
     "Install the Contacts app" : "Instali la Kontakto-aplikaĵon",
@@ -151,6 +166,7 @@ OC.L10N.register(
     "Database tablespace" : "Datumbaza tabelospaco",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Bv. entajpi la pordan numeron kune kun la gastiga nomo (ekzemple: localhost:5432).",
     "Database host" : "Datumbaza gastigo",
+    "Installing …" : "Instalante…",
     "Install" : "Instali",
     "Need help?" : "Ĉu necesas helpo?",
     "See the documentation" : "Vidi la dokumentaron",
@@ -177,6 +193,7 @@ OC.L10N.register(
     "(all selected)" : "(ĉiuj elektitaj)",
     "({count} selected)" : "({count} elektitaj)",
     "Error loading file exists template" : "Eraris ŝargo de ŝablono pri ekzistanta dosiero",
+    "Saving …" : "Konservado...",
     "seconds ago" : "sekundoj antaŭe",
     "Connection to server lost" : "Konekto al servilo perdita",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problemo dum ŝargo de paĝo, reŝargo en %n sekundo","Problemo dum ŝargo de paĝo, reŝargo en %n sekundoj"],
@@ -191,6 +208,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "Entajpi por serĉi jam ekzistantajn projektojn",
     "New in" : "Nova en",
     "View changelog" : "Vidi ŝanĝoprotokolon",
+    "No action available" : "Neniu ago disponebla",
+    "Error fetching contact actions" : "Eraro dum serĉo de kontakt-agoj",
     "Close \"{dialogTitle}\" dialog" : "Fermi la dialogon \"{dialogTitle}\"",
     "Personal" : "Persona",
     "Accounts" : "Kontoj",
@@ -270,31 +289,18 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "La servilo %s estas nun en reĝimo de prizorgado, tio eble daŭros longatempe.",
     "This page will refresh itself when the instance is available again." : "Tiu ĉi paĝo aktualiĝos mem, kiam la servilo redisponeblos.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktu vian administranton, se tiu ĉi mesaĝo daŭras aŭ aperas neatendite.",
+    "No temporary profile picture available, try again" : "Neniu provizora profilbildo disponeblas, bv. reprovi",
+    "No crop data provided" : "Neniu stucdatumo provizita",
+    "No valid crop data provided" : "Neniu valida stucdatumo provizita",
+    "Crop is not square" : "Stuca elekto ne estas kvadrata",
     "Error occurred while checking server setup" : "Eraro dum kontrolo de servila agordo",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Por pliaj detaloj, vidu la {linkstart}dokumentaron ↗{linkend}.",
-    "unknown text" : "nekonata teksto",
-    "Hello world!" : "Saluton, mondo!",
-    "sunny" : "suna",
-    "Hello {name}, the weather is {weather}" : "Saluton {name}, la vetero estas {weather}",
-    "Hello {name}" : "Saluton {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Jen via serĉ-rezultoj<script>alert(1)</script></strong>",
-    "new" : "nova",
-    "_download %n file_::_download %n files_" : ["elŝuti %n dosieron","elŝuti %n dosierojn"],
-    "Searching …" : "Serĉado ...",
-    "Logging in …" : "Ensaluti...",
-    "Loading apps …" : "Ŝargado de aplikaĵoj...",
-    "Installing apps …" : "Instalado de aplikaĵoj...",
-    "Loading your contacts …" : "Ŝargo de viaj kontaktoj...",
-    "Looking for {term} …" : "Serĉo de {term}…",
-    "Search contacts …" : "Serĉi kontaktojn…",
-    "Saving …" : "Konservado...",
+    "Edit Profile" : "Modifi profilon",
     "Very weak password" : "Tre malforta pasvorto",
     "Weak password" : "Malforta pasvorto",
     "So-so password" : "Mezbona pasvorto",
     "Good password" : "Bona pasvorto",
     "Strong password" : "Forta pasvorto",
-    "No action available" : "Neniu ago disponebla",
-    "Error fetching contact actions" : "Eraro dum serĉo de kontakt-agoj",
     "Non-existing tag #{tag}" : "Ne ekzistas etikedo #{tag}",
     "Restricted" : "Limigita",
     "Invisible" : "Nevidebla",
@@ -302,13 +308,14 @@ OC.L10N.register(
     "Rename" : "Alinomi",
     "Collaborative tags" : "Kunlaboraj etikedoj",
     "No tags found" : "Neniu etikedo troviĝis ",
+    "Profile not found" : "Profilo ne troviĝis",
+    "The profile does not exist." : "La profilo ne ekzistas.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Via datumdosierujo kaj dosieroj estas probable elireblaj el la interreto, ĉar la dosiero „.htaccess“ ne funkcias.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Por pli da informoj pri kielo agordi vian retservilon, bv. vidi la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaron</a>.",
     "Show password" : "Montri pasvorton",
     "Toggle password visibility" : "Ŝanĝi videblecon de pasvorto",
     "Configure the database" : "Agordi la datumbazon",
     "Only %s is available." : "Nur %s disponeblas.",
-    "Database account" : "Datumbaza konto",
-    "Installing …" : "Instalante…"
+    "Database account" : "Datumbaza konto"
 },
 "nplurals=2; plural=(n != 1);");
