@@ -25,7 +25,7 @@ OC.L10N.register(
     "Your login token is invalid or has expired" : "Sinu sisselogimise tunnusluba on kas vigane või aegunud",
     "Please use original client" : "Palun kasuta algupärast klienti",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "See Nextcloudi kogukonnaversioon pole toetatud ja tõuketeenuste kasutatavus on piiratud.",
-    "Login" : "Kasutajanimi",
+    "Login" : "Logi sisse",
     "Unsupported email length (>255)" : "E-kirja pikkus pole toetatud (>255)",
     "Password reset is disabled" : "Salasõna lähtestamine on välja lülitatud",
     "Could not reset password because the token is expired" : "Kuna tunnusluba on aegunud, siis salasõna lähtestamine pole võimalik",
@@ -42,7 +42,6 @@ OC.L10N.register(
     "Not found" : "Ei leidu",
     "Node is locked" : "Sõlm on lukus",
     "Bad request" : "Vigane päring",
-    "Input text is too long" : "Sisendtekst on liiga pikk",
     "Requested task type does not exist" : "Küsitud ülesannete tüüpi ei leidu",
     "Necessary language model provider is not available" : "Vajaliku keelemudeli teenusepakkuja pole saadaval",
     "No text to image provider is available" : "Ühtegi optilise tekstituvastuse teenusepakkujat pole saadaval",
@@ -181,7 +180,7 @@ OC.L10N.register(
     "Rich Text document" : "Vormindatud tekstidokument",
     "Electronic business card" : "Elektrooniline visiitkaart",
     "C++ source code" : "C++ lähtekood",
-    "LDIF address book" : "LDIF-i aadressiraamat",
+    "LDIF address book" : "LDIF-i aaddressiraamat",
     "NFO document" : "NFO-dokument",
     "PHP source" : "PHP lähtekood",
     "Python script" : "Pythoni skript",
@@ -198,6 +197,14 @@ OC.L10N.register(
     "Matroska video" : "Matroska video",
     "Windows Media video" : "Windows Media video",
     "AVI video" : "AVI video",
+    "unknown text" : "tundmatu tekst",
+    "Hello world!" : "Tere maailm!",
+    "sunny" : "päikeseline",
+    "Hello {name}, the weather is {weather}" : "Tere {name}, ilm on {weather}",
+    "Hello {name}" : "Tere, {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Need on sinu otsingutulemused: <script>alert(1)</script></strong>",
+    "new" : "uus",
+    "_download %n file_::_download %n files_" : ["laadi alla %n fail","laadi alla %n faili"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Uuendamine on pooleli, sellelt lehelt lahkumine võib mõnes keskkonnas protsessi katkestada.",
     "Update to {version}" : "Uuenda versioonile {version}",
     "An error occurred." : "Tekkis viga.",
@@ -206,18 +213,12 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Uuendamine ebaõnnestus. Palun teavita probleemist <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloudi kogukonda</a>.",
     "Continue to {productName}" : "Jätka siit: {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Uuendamine õnnestus. Sind suunatakse tagasi {productName} juurde %n sekundi pärast.","Uuendamine õnnestus. Sind suunatakse tagasi {productName} juurde %n sekundi pärast."],
-    "Done" : "Valmis",
-    "Scan QR code to log in" : "Sisselogimiseks skaneeri QR-koodi",
-    "Use {productName} mobile client you want to connect to scan the code" : "Skaneeri seda koode {productName}i mobiilikliendiga, mida soovid kasutada",
-    "Code will expire {timeCountdown} or after use" : "Kood aegub peale kasutamist või {timeCountdown}",
     "Applications menu" : "Rakenduste menüü",
     "Apps" : "Rakendused",
     "More apps" : "Veel rakendusi",
     "_{count} notification_::_{count} notifications_" : ["{count} teavitus","{count} teavitust"],
     "No" : "Ei",
     "Yes" : "Jah",
-    "App password" : "Rakenduse salasõna",
-    "Grant access" : "Anna ligipääs",
     "The remote URL must include the user." : "Kaugserveri võrguaadressis peab leiduma kasutajanimi",
     "Invalid remote URL." : "Vigane kaugserveri võrguaadress",
     "Failed to add the public link to your Nextcloud" : "Avaliku lingi lisamine sinu Nextcloudi ei õnnestunud",
@@ -233,7 +234,7 @@ OC.L10N.register(
     "Search in current app" : "Otsi sellest rakendusest",
     "Clear search" : "Tühjenda otsing",
     "Search everywhere" : "Otsi kõikjalt",
-    "Searching …" : "Otsin...",
+    "Searching …" : "Otsin...",
     "Start typing to search" : "Otsimiseks alusta kirjutamist",
     "Minimum search length is {minSearchLength} characters" : "Otsingusõna väikseim pikkus on {minSearchLength} tähemärki",
     "No matching results" : "Otsinguvastuseid ei leidu",
@@ -254,13 +255,12 @@ OC.L10N.register(
     "Results" : "Tulemused",
     "Load more results" : "Laadi veel tulemusi",
     "Search in" : "Otsi siin:",
-    "Partial matches" : "Osaline vaste",
     "Log in" : "Logi sisse",
-    "Logging in …" : "Sisselogimisel...",
+    "Logging in …" : "Sisselogimisel...",
     "Log in to {productName}" : "Logi sisse: {productName}",
     "Wrong login or password." : "Vale kasutajanimi või salasõna.",
     "This account is disabled" : "See konto pole kasutusel",
-    "Too many incorrect login attempts. Please try again in 30 seconds." : "Liiga palju vigaseid sisselogimiskatseid. Palun proovi uuesti 30 sekundi pärast.",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Me tuvastasime sinu IP-aadressilt palju ebaõnnestunud sisselogimiskatseid. Seetõttu on su järgmine sisselogimine ootel kuni 30 sekundit.",
     "Account name or email" : "Konto nimi või e-posti aadress",
     "Account name" : "Kasutajakonto nimi",
     "Server side authentication failed!" : "Serveripoolne autentimine ebaõnnestus!",
@@ -270,7 +270,6 @@ OC.L10N.register(
     "An internal error occurred." : "Tekkis sisemine viga.",
     "Please try again or contact your administrator." : "Palun proovi uuesti või võta ühendust oma peakasutajaga.",
     "Password" : "Salasõna",
-    "Remember me" : "Jäta mind meelde",
     "Log in with a device" : "Logi sisse seadmega",
     "Login or email" : "Kasutajanimi või e-posti aadress",
     "Your account is not setup for passwordless login." : "Su konto ei ole seadistatud salasõnata sisenemise jaoks.",
@@ -294,28 +293,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Kaastöö dokumentide, tabelite ja presentatsioonidega, kasutades Collabora Online'i.",
     "Distraction free note taking app." : "Müravaba märkmete rakendus.",
     "Recommended apps" : "Soovitatud rakendused",
-    "Loading apps …" : "Laadin rakendusi…",
+    "Loading apps …" : "Rakenduste laadimine …",
     "Could not fetch list of apps from the App Store." : "Rakenduste loendi laadimine App Store'st ebaõnnestus.",
     "App download or installation failed" : "Rakenduse allalaadimine või paigaldamine ebaõnnestus",
     "Cannot install this app because it is not compatible" : "Seda rakendust ei saa paigaldada, kuna see pole ühilduv",
     "Cannot install this app" : "Seda rakendust ei saa paigaldada",
     "Skip" : "Jäta vahele",
-    "Installing apps …" : "Paigaldan rakendusi…",
+    "Installing apps …" : "Rakenduste paigaldamine …",
     "Install recommended apps" : "Paigalda soovitatud rakendused",
-    "Online" : "Võrgus",
-    "Away" : "Eemal",
-    "Busy" : "Hõivatud",
-    "Do not disturb" : "Ära sega",
-    "Mute all notifications" : "Sellega summutad teavitused",
-    "Invisible" : "Nähtamatu",
-    "Appear offline" : "Sellega paistad olema võrgust väljas",
     "Avatar of {displayName}" : "Kasutaja „{displayName}“ tunnuspilt",
     "Settings menu" : "Seadistuste menüü",
-    "Loading your contacts …" : "Laadin sinu kontakte…",
-    "Looking for {term} …" : "Otsin märksõna {term}…",
+    "Loading your contacts …" : "Sinu kontaktide laadimine ...",
+    "Looking for {term} …" : "Otsin {term} …",
     "Search contacts" : "Otsi kontakte",
     "Reset search" : "Lähtesta otsing",
-    "Search contacts …" : "Otsi kontakte…",
+    "Search contacts …" : "Otsi kontakte …",
     "Could not load your contacts" : "Sinu kontaktide laadimine ebaõnnestus",
     "No contacts found" : "Kontakte ei leitud",
     "Show all contacts" : "Näita kõiki kontakte",
@@ -327,24 +319,16 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "„{type}“ otsimisel tekkis viga",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Otsing algab kohe, kui sa midagi trükid, ja tulemustele saab ligi nooleklahvidega",
     "Search for {name} only" : "Otsi vaid otsisõna „{name}“",
-    "Loading more results …" : "Laadin veel tulemusi…",
+    "Loading more results …" : "Laadin veel tulemusi…",
     "Forgot password?" : "Unustasid salasõna?",
     "Back to login form" : "Tagasi sisselogimise lehele",
     "Back" : "Tagasi",
     "Login form is disabled." : "Sisselogimise leht on keelatud.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloudi sisselogimisvorm on kasutusel eemaldatud. Kui mõni muu sisselogimisviis on saadaval, siis kasuta seda või küsi lisateavet oma süsteemihaldajalt.",
-    "Connect to your account" : "Ühenda oma kasutajakontoga",
-    "Security warning" : "Turvahoiatus",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Kui sa just hetkel ei ole seadistamas uut seadet või rakendust, siis võib keegi sind proovida petta eesmärgiga saada ligipääs sinu andmetele. Sel juhul palun ära jätka ja võta ühendust oma süsteemihaldajaga.",
-    "Alternative log in using app password" : "Alternatiivne sisselogimisvõimalus rakenduse salasõnaga",
-    "Account connected" : "Konto ühendatud",
-    "Your client should now be connected!" : "Su klient peaks nüüd olema ühendatud!",
-    "You can close this window." : "Võid selle akna sulgeda.",
-    "Account access" : "Konto ligipääs",
     "More actions" : "Täiendavad tegevused",
     "User menu" : "Kasutajamenüü",
     "Your guest name: {user}" : "Sinu külalisnimi: {user}",
-    "You are currently not identified." : "Sa oled hetkel tuvastamata.",
+    "You are currently not identified." : "Sa pole hetkel tuvastatud",
     "Set public name" : "Lisa avalik nimi",
     "Change public name" : "Muuda avalikku nime",
     "Password is too weak" : "Salasõna on liiga nõrk",
@@ -358,13 +342,13 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Serveri õigeks seadistamiseks {linkStart}leiad teavet dokumentatsioonist{linkEnd}",
     "Autoconfig file detected" : "Tuvastasin autoconfig faili",
     "The setup form below is pre-filled with the values from the config file." : "Järgnev paigaldusvorm on eeltäidetud sellest failist leitud andmetega.",
+    "Security warning" : "Turvahoiatus",
     "Create administration account" : "Loo peakasutaja konto",
     "Administration account name" : "Peakasutaja konto nimi",
     "Administration account password" : "Peakasutaja konto salasõna",
     "Storage & database" : "Andmehoidla ja andmebaas",
     "Data folder" : "Andmekaust",
     "Database configuration" : "Andmebaasi seadistused",
-    "Database type" : "Andmebaasi tüüp",
     "Only {firstAndOnlyDatabase} is available." : "Ainult {firstAndOnlyDatabase} on saadaval.",
     "Install and activate additional PHP modules to choose other database types." : "Paigalda ja aktiveeri täiendavaid PHP mooduleid, et teisi andmebaasi tüüpe valida.",
     "For more details check out the documentation." : "Lisainfot vaata dokumentatsioonist.",
@@ -372,7 +356,6 @@ OC.L10N.register(
     "You chose SQLite as database." : "Sa valisid SQLite andmebaasi.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite sobib kasutamiseks ainult arenduseks ja väikesemahulistes serverites. Toodangu jaoks soovitame teist andmebaasilahendust.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Kui kasutad Nextcloudi kliente, mis sünkroniseerivad faile, siis SQLite ei ole sobilik andmebaas.",
-    "Database connection" : "Andmebaasi ühendus",
     "Database user" : "Andmebaasi kasutaja",
     "Database password" : "Andmebaasi salasõna",
     "Database name" : "Andmebaasi nimi",
@@ -380,7 +363,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Palun sisesta hostinimega koos pordi number (nt. localhost:5432).",
     "Database host" : "Andmebaasi host",
     "localhost" : "localhost",
-    "Installing …" : "Paigaldan…",
+    "Installing …" : "Paigaldan…",
     "Install" : "Paigalda",
     "Need help?" : "Vajad abi?",
     "See the documentation" : "Vaata dokumentatsiooni",
@@ -389,7 +372,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Sinu brauser ei ole toetatud. Palun uuenda see uuema versiooni peale või vaheta toetatud brauseri vastu.",
     "Continue with this unsupported browser" : "Jätka selle mittetoetatud brauseriga",
     "Supported versions" : "Toetatud versioonid",
-    "Search {types} …" : "Otsi „{types}“…",
+    "Search {types} …" : "Otsi „{types}“…",
     "Choose {file}" : "Vali „{file}“",
     "Choose" : "Vali",
     "Copy to {target}" : "Kopeeri kausta {target}",
@@ -409,10 +392,7 @@ OC.L10N.register(
     "(all selected)" : "(kõik valitud)",
     "({count} selected)" : "({count} valitud)",
     "Error loading file exists template" : "Viga faili olemasolu malli laadimisel",
-    "Saving …" : "Salvestan…",
-    "Groups" : "Grupid",
-    "Group list is empty" : "Gruppide loend on tühi",
-    "Unable to retrieve the group list" : "Gruppide loendi pärimine ebaõnnestus",
+    "Saving …" : "Salvestamine …",
     "seconds ago" : "sekundit tagasi",
     "Connection to server lost" : "Ühendus serveriga katkes",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Tõrge lehe laadimisel, värskendamine %n sekundi pärast","Tõrge lehe laadimisel, värskendamine %n sekundi pärast"],
@@ -427,6 +407,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "Olemasolevate projektide otsimiseks kirjuta midagi",
     "New in" : "Mida on uut",
     "View changelog" : "Vaata muudatuste logi",
+    "No action available" : "Ühtegi tegevust pole saadaval",
+    "Error fetching contact actions" : "Viga kontakti toimingute laadimisel",
     "Close \"{dialogTitle}\" dialog" : "Sulge „{dialogTitle}“ vaade",
     "Email length is at max (255)" : "E-kirja pikkus on jõudnud lubatud piirini (255)",
     "Clipboard not available, please copy manually" : "Lõikelaud pole saadaval. Palun kopeeri käsitsi",
@@ -463,8 +445,20 @@ OC.L10N.register(
     "Skip to navigation of app" : "Mine rakenduse asukohtade juurde",
     "Go to %s" : "Mine %s",
     "Get your own free account" : "Tee endale tasuta kasutajakonto",
+    "Connect to your account" : "Ühenda oma kasutajakontoga",
+    "Please log in before granting %1$s access to your %2$s account." : "Enne rakendusele %1$s oma %2$s kontole ligipääsu andmist logi sisse.",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Kui sa just hetkel ei ole seadistamas uut seadet või rakendus, siis võib keegi sind proovida petta eesmärgiks ligipääsu saamine sinu andmetele. Sel juhul palun ära jätka ja võta ühendust oma süsteemihaldajaga.",
+    "App password" : "Rakenduse salasõna",
+    "Grant access" : "Anna ligipääs",
+    "Alternative log in using app password" : "Alternatiivne sisselogimisvõimalus rakenduse salasõnaga",
+    "Account access" : "Konto ligipääs",
+    "Currently logged in as %1$s (%2$s)." : "Hetkel sisselogitus kasutajana %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Oled andmas rakendusele %1$s ligipääsu oma %2$s kontole.",
+    "Account connected" : "Konto ühendatud",
+    "Your client should now be connected!" : "Su klient peaks nüüd olema ühendatud!",
+    "You can close this window." : "Võid selle akna sulgeda.",
     "Previous" : "Eelmine",
-    "This share is password-protected" : "See jaoskaust on kaitstud salasõnaga",
+    "This share is password-protected" : "See jaoskaust on salasõnaga kaitstud",
     "The password is wrong or expired. Please try again or request a new one." : "Salasõna on vale või aegunud. Palun proovi uuesti või taotle uut salasõna.",
     "Please type in your email address to request a temporary password" : "Palun sisesta oma e-posti aadress ajutise salasõna taotlemiseks",
     "Email address" : "E-posti aadress",
@@ -502,41 +496,32 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "See %s server on hetkel hooldusrežiimis, mis võib kesta mõnda aega.",
     "This page will refresh itself when the instance is available again." : "See leht värskendab ennast ise, kui instants jälle saadaval on.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Võta ühendust administraatoriga, kui see teade püsib või on tekkinud ootamatult.",
+    "No temporary profile picture available, try again" : "Ühtegi ajutist profiilipilti pole saadaval, proovi uuesti",
+    "No crop data provided" : "Lõikeandmeid ei leitud",
+    "No valid crop data provided" : "Kehtivaid lõikeandmeid ei leitud",
+    "Crop is not square" : "Lõikamine pole ruudukujuline",
     "Error occurred while checking server setup" : "Serveri seadete kontrolimisel tekkis viga",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Lisateavet leiad {linkstart}dokumentatsioonist ↗{linkend}.",
-    "unknown text" : "tundmatu tekst",
-    "Hello world!" : "Tere maailm!",
-    "sunny" : "päikeseline",
-    "Hello {name}, the weather is {weather}" : "Tere {name}, ilm on {weather}",
-    "Hello {name}" : "Tere, {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Need on sinu otsingutulemused: <script>alert(1)</script></strong>",
-    "new" : "uus",
-    "_download %n file_::_download %n files_" : ["laadi alla %n fail","laadi alla %n faili"],
-    "Direct link copied to clipboard" : "Otselink on lõikelauale kopeeritud",
-    "Searching …" : "Otsin...",
-    "Logging in …" : "Sisselogimisel...",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Me tuvastasime sinu IP-aadressilt palju ebaõnnestunud sisselogimiskatseid. Seetõttu on su järgmine sisselogimine ootel kuni 30 sekundit.",
-    "Loading apps …" : "Rakenduste laadimine …",
-    "Installing apps …" : "Rakenduste paigaldamine …",
-    "Loading your contacts …" : "Sinu kontaktide laadimine ...",
-    "Looking for {term} …" : "Otsin {term} …",
-    "Search contacts …" : "Otsi kontakte …",
-    "Loading more results …" : "Laadin veel tulemusi…",
-    "Search {types} …" : "Otsi „{types}“…",
-    "Saving …" : "Salvestamine …",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Vestlused, videokõned, ekraanijagamine, online kohtumised ja veebikonverentsid – sinu brauseris ja mobiilirakendustes.",
+    "You have not added any info yet" : "Sa pole veel mingit infot lisanud",
+    "{user} has not added any info yet" : "{user} pole veel mitte mingit infot lisanud",
+    "Error opening the user status modal, try hard refreshing the page" : "Kasutaja staatuse modaaldialoogi avamine ebaõnnestus, proovi lehte värskendada",
+    "Edit Profile" : "Muuda profiili",
+    "The headline and about sections will show up here" : "Alapealkirja ja teabe lõigud saavad olema nähtavad siin",
     "Very weak password" : "Väga nõrk salasõna",
     "Weak password" : "Nõrk salasõna",
     "So-so password" : "Enam-vähem sobiv salasõna",
     "Good password" : "Hea salasõna",
     "Strong password" : "Väga hea salasõna",
-    "No action available" : "Ühtegi tegevust pole saadaval",
-    "Error fetching contact actions" : "Viga kontakti toimingute laadimisel",
     "Non-existing tag #{tag}" : "Olematu silt #{tag}",
     "Restricted" : "Piiratud",
+    "Invisible" : "Nähtamatu",
     "Delete" : "Kustuta",
     "Rename" : "Muuda nime",
     "Collaborative tags" : "Koostöö sildid",
     "No tags found" : "Silte ei leitud",
+    "Profile not found" : "Profiili ei leitud",
+    "The profile does not exist." : "Profiili ei eksisteeri",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su andmekataloog ja failid on tõenäoliselt internetist vabalt ligipääsetavad, kuna .htaccess fail ei toimi.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Serveri õigeks seadistamiseks leiad infot <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentatsioonist</a>.",
     "<strong>Create an admin account</strong>" : "Loo <strong>peakasutaja konto</strong>",
@@ -547,9 +532,6 @@ OC.L10N.register(
     "Configure the database" : "Seadista andmebaasi",
     "Only %s is available." : "Ainult %s on saadaval.",
     "Database account" : "Andmebaasi kasutajakonto",
-    "Installing …" : "Paigaldan…",
-    "Please log in before granting %1$s access to your %2$s account." : "Enne rakendusele %1$s oma %2$s kontole ligipääsu andmist logi sisse.",
-    "Currently logged in as %1$s (%2$s)." : "Hetkel sisselogitus kasutajana %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Oled andmas rakendusele %1$s ligipääsu oma %2$s kontole."
+    "Direct link copied to clipboard" : "Otselink on lõikelauale kopeeritud"
 },
 "nplurals=2; plural=(n != 1);");
