@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Fitxategi mota ezezaguna",
     "An error occurred. Please contact your admin." : "Errore bat gertatu da, jarri zure administratzailearekin harremanetan.",
     "Invalid image" : "Baliogabeko irudia",
-    "No temporary profile picture available, try again" : "Ez dago behin-behineko profil irudirik erabilgarri, saiatu berriro",
-    "No crop data provided" : "Ez da mozketa daturik eman",
-    "No valid crop data provided" : "Ez da baliozko mozketa daturik eman",
-    "Crop is not square" : "Mozketa ez da karratua",
     "State token does not match" : "Egoera-tokena ez dator bat",
     "Invalid app password" : "Aplikazio pasahitz baliogabea",
     "Could not complete login" : "Ezin izan da saioa hasi",
@@ -412,13 +408,6 @@ OC.L10N.register(
     "Error fetching contact actions" : "Errorea kontaktu-ekintzak eskuratzean",
     "Close \"{dialogTitle}\" dialog" : "Itxi \"{dialogTitle}\" elkarrizketa",
     "Email length is at max (255)" : "Posta elektronikoaren luzera gehienez (255) da",
-    "Non-existing tag #{tag}" : "#{tag} ez da existitzen",
-    "Restricted" : "Mugatua",
-    "Invisible" : "Ikusezina",
-    "Delete" : "Ezabatu",
-    "Rename" : "Berrizendatu",
-    "Collaborative tags" : "Elkarlaneko etiketak",
-    "No tags found" : "Ez da etiketarik aurkitu",
     "Clipboard not available, please copy manually" : "Arbela ez dago eskuragarri, mesedez kopiatu eskuz",
     "Personal" : "Pertsonala",
     "Accounts" : "Kontuak",
@@ -447,7 +436,7 @@ OC.L10N.register(
     "Line: %s" : "Lerroa: %s",
     "Trace" : "Aztarna",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Badirudi zure Nextcloud berrinstalatu nahian ari zarela. Hala ere CAN_INSTALL fitxategia falta da zure config direktorioan. Mesedez sor ezazu CAN_INSTALL fitxategia zure config karpetan jarraitu ahal izateko.",
-    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Ezin izan da CAN_INSTALL fitxategia config karpetatik ezabatu. Mesedez ezaba ezazu fitxategi hau eskuz.",
+    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Ezin izan da CAN_INSTALL fitxategia config karpetatik kendu. Mesedez kendu ezazu fitxategi hau eskuz.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aplikazio honek JavaScript eskatzen du ondo funtzionatzeko. Mesedez {linkstart}JavaScript gaitu{linkend} eta webgunea birkargatu.",
     "Skip to main content" : "Salto eduki nagusira",
     "Skip to navigation of app" : "Salto aplikazioaren nabigaziora",
@@ -504,6 +493,10 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "%s instantzia hau mantentze moduan dago une honetan, honek denbora tarte bat iraun dezake.",
     "This page will refresh itself when the instance is available again." : "Instantzia berriz ere erabilgarri dagoenean orri hau freskatuko da.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Jarri harremanetan zure sistema administratzailearekin mezu honek irauten badu edo ezustean agertu bada.",
+    "No temporary profile picture available, try again" : "Ez dago behin-behineko profil irudirik erabilgarri, saiatu berriro",
+    "No crop data provided" : "Ez da mozketa daturik eman",
+    "No valid crop data provided" : "Ez da baliozko mozketa daturik eman",
+    "Crop is not square" : "Mozketa ez da karratua",
     "Error occurred while checking server setup" : "Errorea gertatu da zerbitzariaren konfigurazioa egiaztatzean",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Xehetasun gehiago lortzeko, ikusi {linkstart}dokumentazioa ↗{linkend}.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Txata, bideo-deiak, pantaila partekatzea, lineako bilerak eta web konferentziak - zure nabigatzailean eta mugikorrerako aplikazioekin.",
@@ -517,6 +510,13 @@ OC.L10N.register(
     "So-so password" : "Hala moduzko pasahitza",
     "Good password" : "Pasahitz ona",
     "Strong password" : "Pasahitz sendoa",
+    "Non-existing tag #{tag}" : "#{tag} ez da existitzen",
+    "Restricted" : "Mugatua",
+    "Invisible" : "Ikusezina",
+    "Delete" : "Ezabatu",
+    "Rename" : "Berrizendatu",
+    "Collaborative tags" : "Elkarlaneko etiketak",
+    "No tags found" : "Ez da etiketarik aurkitu",
     "Profile not found" : "Profila ez da aurkitu",
     "The profile does not exist." : "Profila ez da existitzen",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Zure datuen karpeta eta fitxategiak interneten bidez eskuragarri egon daitezke .htaccess fitxategia ez delako funtzionatzen ari.",
