@@ -195,6 +195,14 @@ OC.L10N.register(
     "Matroska video" : "ویدیوی Matroska.",
     "Windows Media video" : "ویدیوی Windows Media.",
     "AVI video" : "ویدیوی AVI.",
+    "unknown text" : "متن نامعلوم",
+    "Hello world!" : "سلام دنیا!",
+    "sunny" : "آفتابی",
+    "Hello {name}, the weather is {weather}" : "سلام {name}, هوا  {weather} است",
+    "Hello {name}" : "سلام {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>این نتایج جستجوی شماست <script>alert(1)</script> </strong>",
+    "new" : "جدید",
+    "_download %n file_::_download %n files_" : ["دانلود %n فایل","دانلود %n فایل"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "به روز رسانی در حال انجام است، این صفحه ممکن است روند در برخی از محیط ها را قطع کند.",
     "Update to {version}" : "بروزرسانی به  {version}",
     "An error occurred." : "یک خطا رخ‌داده است.",
@@ -203,15 +211,12 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "به روزرسانی ناموفق بود. لطفا این مسئله را در <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">جامعه Nextcloud</a> گزارش دهید",
     "Continue to {productName}" : "به {productName} ادامه دهید.",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["به روزرسانی موفقیت آمیز بود. شما در %n ثانیه به {productName} هدایت می‌شوید.","به روزرسانی موفقیت آمیز بود. شما در %n ثانیه به {productName} هدایت می‌شوید."],
-    "Done" : "Done",
     "Applications menu" : "منو برنامه‌ها.",
     "Apps" : "  برنامه ها",
     "More apps" : "برنامه های بیشتر",
     "_{count} notification_::_{count} notifications_" : ["{count} اعلان.","{count} اعلان."],
     "No" : "نه",
     "Yes" : "بله",
-    "App password" : "گذرواژه برنامه",
-    "Grant access" : " مجوز اعطا دسترسی",
     "The remote URL must include the user." : "آدرس URL راه دور باید شامل کاربر باشد.",
     "Invalid remote URL." : "آدرس URL راه دور نامعتبر است.",
     "Failed to add the public link to your Nextcloud" : "خطا در افزودن آدرس عمومی به نکست‌کلود شما.",
@@ -226,7 +231,7 @@ OC.L10N.register(
     "Search in current app" : "جستجو در برنامه فعلی.",
     "Clear search" : "پاک کردن جستجو.",
     "Search everywhere" : "جستجو در هر کجا.",
-    "Searching …" : "درحال جستجو",
+    "Searching …" : "جستجوکردن …",
     "Start typing to search" : "برای جستجو شروع به تایپ کنید.",
     "No matching results" : "نتیجه مطابق یافت نشد.",
     "Today" : "امروز.",
@@ -245,9 +250,11 @@ OC.L10N.register(
     "Load more results" : "بار کردن نتایج بیشتر.",
     "Search in" : "جستجو در.",
     "Log in" : "ورود",
+    "Logging in …" : "ورود به سیستم ...",
     "Log in to {productName}" : "ورود به {productName}.",
     "Wrong login or password." : "نام کاربری یا رمز عبور اشتباه است.",
     "This account is disabled" : "این حساب کاربری غیرفعال است.",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "از این آی پی چندین بار تلاش ناموفق برای ورود انجام شده است فلذا برای ورود مجدد حداقل ۳۰ ثانیه باید صبر کنید.",
     "Account name or email" : "نام کاربری یا آدرس ایمیل.",
     "Account name" : "نام حساب.",
     "Server side authentication failed!" : "تأیید هویت از سوی سرور انجام نشد!",
@@ -280,23 +287,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "اسناد، صفحات گسترده و ارائه‌های مشترک، بر اساس Collabora Online ساخته شده‌اند.",
     "Distraction free note taking app." : "برنامه یادداشت‌برداری بدون حواس‌پرتی.",
     "Recommended apps" : "برنامه‌های پیشنهادی.",
+    "Loading apps …" : "در حال بارگذاری برنامه ها... .",
     "Could not fetch list of apps from the App Store." : "امکان دریافت لیست برنامه ها از App Store وجود نداشت.",
     "App download or installation failed" : "دانلود یا نصب برنامه ناموفق بود.",
     "Cannot install this app because it is not compatible" : "نمی توان این برنامه را نصب کرد زیرا سازگار نیست.",
     "Cannot install this app" : "نمی توان این برنامه را نصب کرد.",
     "Skip" : "پرش.",
+    "Installing apps …" : "در حال نصب برنامه.",
     "Install recommended apps" : "نصب کاره‌های پیشنهادی.",
-    "Online" : "برخط",
-    "Away" : "دور از دسترس",
-    "Busy" : "مشغول",
-    "Do not disturb" : "مزاحم نشوید",
-    "Mute all notifications" : "خاموش کردن همه اعلانات",
-    "Invisible" : "غیر قابل مشاهده",
-    "Appear offline" : "نمایش آفلاین",
     "Avatar of {displayName}" : "نمایه {displayName}.",
     "Settings menu" : "فهرست تنظیمات.",
+    "Loading your contacts …" : "بارگیری مخاطبین شما ...",
+    "Looking for {term} …" : "به دنبال {term} …",
     "Search contacts" : "جستجوی مخاطبین.",
     "Reset search" : "بازنشانی جستجو.",
+    "Search contacts …" : "جستجو مخاطبین ...",
     "Could not load your contacts" : "امکان بارگذاری مخاطبین شما وجود نداشت.",
     "No contacts found" : "مخاطبین یافت نشد",
     "Show all contacts" : "نمایش تمام مخاطبین.",
@@ -308,19 +313,12 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "خطایی در هنگام جستجو برای {type} رخ داد.",
     "Search starts once you start typing and results may be reached with the arrow keys" : "جستجو با شروع تایپ آغاز می‌شود و نتایج را می‌توان با کلیدهای جهت‌نما مشاهده کرد.",
     "Search for {name} only" : "فقط {name} را جستجو کنید.",
+    "Loading more results …" : "در حال بارگذاری نتایج بیشتر ... .",
     "Forgot password?" : "رمز فراموش شده؟",
     "Back to login form" : "بازگشت به فرم ورود.",
     "Back" : "بازگشت.",
     "Login form is disabled." : "فرم ورود غیرفعال است.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "فرم ورود Nextcloud غیرفعال است. در صورت امکان از گزینه ورود دیگری استفاده کنید یا با مدیریت خود تماس بگیرید.",
-    "Connect to your account" : "به حساب کاربری خود متصل شوید",
-    "Security warning" : "اخطار امنیتی",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "اگر قصد راه‌اندازی دستگاه یا برنامه جدیدی را ندارید، شخصی در تلاش است تا شما را فریب دهد تا به داده‌هایتان دسترسی پیدا کند. در این صورت ادامه ندهید و به جای آن با مدیر سیستم خود تماس بگیرید.",
-    "Alternative log in using app password" : "ورود جایگزین با استفاده از گذرواژه برنامه",
-    "Account connected" : "حساب کاربری متصل شد",
-    "Your client should now be connected!" : "اکنون مشتری شما باید متصل شده باشد!",
-    "You can close this window." : "می‌توانید این پنجره را ببندید.",
-    "Account access" : "دسترسی به حساب",
     "More actions" : "اقدامات بیشتر.",
     "Password is too weak" : "رمز عبور بسیار ضعیف است.",
     "Password is weak" : "رمز عبور ضعیف است.",
@@ -333,6 +331,7 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "برای اطلاعات بیشتر در مورد نحوه پیکربندی صحیح سرور خود، لطفاً {linkStart}مستندات را ببینید{linkEnd}.",
     "Autoconfig file detected" : "فایل تنظیم خودکار شناسایی شد.",
     "The setup form below is pre-filled with the values from the config file." : "فرم تنظیمات زیر با مقادیر موجود در فایل پیکربندی از قبل پر شده است.",
+    "Security warning" : "اخطار امنیتی",
     "Create administration account" : "ایجاد حساب کاربری مدیریت.",
     "Administration account name" : "نام حساب کاربری مدیریت.",
     "Administration account password" : "رمز عبور حساب کاربری مدیریت.",
@@ -353,6 +352,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Please specify the port number along with the host name (e.g., localhost:5432).",
     "Database host" : "هاست پایگاه داده",
     "localhost" : "لوکال‌هاست",
+    "Installing …" : "درحال نصب...",
     "Install" : "نصب",
     "Need help?" : "کمک لازم دارید ؟",
     "See the documentation" : "مشاهده‌ی مستندات",
@@ -361,6 +361,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "مرورگر شما پشتیبانی نمی‌شود. لطفاً به نسخه جدیدتر یا نسخه پشتیبانی‌شده ارتقا دهید.",
     "Continue with this unsupported browser" : "با این مرورگر پشتیبانی‌نشده ادامه دهید",
     "Supported versions" : "نسخه‌های پشتیبانی شده",
+    "Search {types} …" : "جستجوی {types}...",
     "Choose {file}" : "انتخاب {file}",
     "Choose" : "انتخاب کردن",
     "Copy to {target}" : "رونوشت به {target}",
@@ -380,10 +381,7 @@ OC.L10N.register(
     "(all selected)" : "(همه انتخاب شده اند)",
     "({count} selected)" : "({count} انتخاب شده)",
     "Error loading file exists template" : "خطا در بارگزاری فایل قالب",
-    "Saving …" : "در حال ذخیره",
-    "Groups" : "گروه ها",
-    "Group list is empty" : "سیاههٔ گروه‌ها خالیست",
-    "Unable to retrieve the group list" : "ناتوان در گرفتن سیاهٔ گروه‌ها",
+    "Saving …" : "ذخیره کردن …",
     "seconds ago" : "ثانیه‌ها پیش",
     "Connection to server lost" : "اتصال به سرور از دست رفته است",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["%nمشکل بارگذاری صفحه، بارگیری مجدد در  ثانیه","%nمشکل بارگذاری صفحه، بارگیری مجدد در  ثانیه"],
@@ -398,6 +396,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "برای جستجوی پروژه‌های موجود تایپ کنید",
     "New in" : "جدید در",
     "View changelog" : "مشاهده تغییرات",
+    "No action available" : "هیچ عملی قابل انجام نیست",
+    "Error fetching contact actions" : "خطا در دریافت فعالیتهای تماس",
     "Close \"{dialogTitle}\" dialog" : "بستن گفتگوی «{dialogTitle}»",
     "Email length is at max (255)" : "طول ایمیل حداکثر (۲۵۵) است",
     "Clipboard not available, please copy manually" : "کلیپ بورد در دسترس نیست، لطفا به صورت دستی کپی کنید",
@@ -433,6 +433,18 @@ OC.L10N.register(
     "Skip to navigation of app" : "پرش به ناوبری برنامه",
     "Go to %s" : "برو به %s",
     "Get your own free account" : "حساب کاربری رایگان خود را دریافت کنید",
+    "Connect to your account" : "به حساب کاربری خود متصل شوید",
+    "Please log in before granting %1$s access to your %2$s account." : "لطفاً قبل از اعطای دسترسی %1$s به حساب %2$s خود وارد شوید.",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "اگر قصد راه‌اندازی دستگاه یا برنامه جدیدی را ندارید، شخصی در تلاش است تا شما را فریب دهد تا به داده‌هایتان دسترسی پیدا کند. در این صورت ادامه ندهید و به جای آن با مدیر سیستم خود تماس بگیرید.",
+    "App password" : "گذرواژه برنامه",
+    "Grant access" : " مجوز اعطا دسترسی",
+    "Alternative log in using app password" : "ورود جایگزین با استفاده از گذرواژه برنامه",
+    "Account access" : "دسترسی به حساب",
+    "Currently logged in as %1$s (%2$s)." : "در حال حاضر به عنوان %1$s (%2$s) وارد شده‌اید.",
+    "You are about to grant %1$s access to your %2$s account." : "شما در حال اعطای دسترسی %1$s به حساب %2$s خود هستید.",
+    "Account connected" : "حساب کاربری متصل شد",
+    "Your client should now be connected!" : "اکنون مشتری شما باید متصل شده باشد!",
+    "You can close this window." : "می‌توانید این پنجره را ببندید.",
     "Previous" : "قبلی",
     "This share is password-protected" : "این اشتراک توسط رمز عبور محافظت می شود",
     "The password is wrong or expired. Please try again or request a new one." : "رمز عبور اشتباه است یا منقضی شده است. لطفا دوباره تلاش کنید یا رمز عبور جدیدی درخواست دهید.",
@@ -471,41 +483,32 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "این نمونه %s در حال حاضر در حالت نگهداری است که ممکن است مدتی طول بکشد.",
     "This page will refresh itself when the instance is available again." : "این صفحه پس از در دسترس قرار گرفتن مجدد نمونه، خود را بازخوانی خواهد کرد.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "اگر این پیغام همچنان وجود داشت یا به صورت غیر منتظره ظاهر شد با مدیر سیستم تماس بگیرید.",
+    "No temporary profile picture available, try again" : "تصویر پروفایل موقت در حال حاضر در دسترس نیست ، دوباره تلاش کنید ",
+    "No crop data provided" : "هیچ داده برش داده شده ارائه نشده است",
+    "No valid crop data provided" : "هیچ داده برش داده شده معتبر ارائه نشده است",
+    "Crop is not square" : "بخش بریده شده مربع نیست",
     "Error occurred while checking server setup" : "خطا در هنگام چک کردن راه‌اندازی سرور رخ داده است",
     "For more details see the {linkstart}documentation ↗{linkend}." : "برای جزئیات بیشتر به {linkstart}مستندات ↗{linkend} مراجعه کنید.",
-    "unknown text" : "متن نامعلوم",
-    "Hello world!" : "سلام دنیا!",
-    "sunny" : "آفتابی",
-    "Hello {name}, the weather is {weather}" : "سلام {name}, هوا  {weather} است",
-    "Hello {name}" : "سلام {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>این نتایج جستجوی شماست <script>alert(1)</script> </strong>",
-    "new" : "جدید",
-    "_download %n file_::_download %n files_" : ["دانلود %n فایل","دانلود %n فایل"],
-    "Direct link copied to clipboard" : "لینک مستقیم در کلیپ‌بورد کپی شد.",
-    "Searching …" : "جستجوکردن …",
-    "Logging in …" : "ورود به سیستم ...",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "از این آی پی چندین بار تلاش ناموفق برای ورود انجام شده است فلذا برای ورود مجدد حداقل ۳۰ ثانیه باید صبر کنید.",
-    "Loading apps …" : "در حال بارگذاری برنامه ها... .",
-    "Installing apps …" : "در حال نصب برنامه.",
-    "Loading your contacts …" : "بارگیری مخاطبین شما ...",
-    "Looking for {term} …" : "به دنبال {term} …",
-    "Search contacts …" : "جستجو مخاطبین ...",
-    "Loading more results …" : "در حال بارگذاری نتایج بیشتر ... .",
-    "Search {types} …" : "جستجوی {types}...",
-    "Saving …" : "ذخیره کردن …",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "چت، تماس‌های ویدیویی، اشتراک‌گذاری صفحه، جلسات آنلاین و کنفرانس وب – در مرورگر شما و با برنامه‌های موبایل.",
+    "You have not added any info yet" : "شما هنوز هیچ اطلاعاتی اضافه نکرده اید",
+    "{user} has not added any info yet" : "{user} هنوز هیچ اطلاعاتی اضافه نکرده است",
+    "Error opening the user status modal, try hard refreshing the page" : "خطا در باز کردن مودال وضعیت کاربر، سعی کنید صفحه را به شدت تازه‌سازی کنید",
+    "Edit Profile" : "ویرایش نمایه",
+    "The headline and about sections will show up here" : "بخش‌های سربرگ و درباره در اینجا نمایش داده خواهند شد",
     "Very weak password" : "رمز عبور بسیار ضعیف",
     "Weak password" : "رمز عبور ضعیف",
     "So-so password" : "رمز عبور متوسط",
     "Good password" : "رمز عبور خوب",
     "Strong password" : "رمز عبور قوی",
-    "No action available" : "هیچ عملی قابل انجام نیست",
-    "Error fetching contact actions" : "خطا در دریافت فعالیتهای تماس",
     "Non-existing tag #{tag}" : "برچسب غیر موجود #{tag}",
     "Restricted" : "محدود شده",
+    "Invisible" : "غیر قابل مشاهده",
     "Delete" : "حذف",
     "Rename" : "تغییرنام",
     "Collaborative tags" : "برچسب های همکاری",
     "No tags found" : "هیچ برچسبی یافت نشد",
+    "Profile not found" : "نمایه، یافت نشد",
+    "The profile does not exist." : "این نمایه وجود ندارد.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "فایلها و فهرست های داده های شما قابل از اینترنت قابل دسترسی هستند، چونکه فایل htacces. کار نمی کند.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "برای اطلاعات در مورد نحوه پیکربندی صحیح سرور خود، لطفاً <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">مستندات</a> را مشاهده کنید.",
     "<strong>Create an admin account</strong>" : "<strong>ایجاد یک حساب کاربری مدیر</strong>",
@@ -516,9 +519,6 @@ OC.L10N.register(
     "Configure the database" : "پایگاه داده برنامه ریزی شدند",
     "Only %s is available." : "تنها %s موجود است.",
     "Database account" : "حساب پایگاه داده",
-    "Installing …" : "درحال نصب...",
-    "Please log in before granting %1$s access to your %2$s account." : "لطفاً قبل از اعطای دسترسی %1$s به حساب %2$s خود وارد شوید.",
-    "Currently logged in as %1$s (%2$s)." : "در حال حاضر به عنوان %1$s (%2$s) وارد شده‌اید.",
-    "You are about to grant %1$s access to your %2$s account." : "شما در حال اعطای دسترسی %1$s به حساب %2$s خود هستید."
+    "Direct link copied to clipboard" : "لینک مستقیم در کلیپ‌بورد کپی شد."
 },
 "nplurals=2; plural=(n > 1);");
