@@ -38,7 +38,6 @@ OC.L10N.register(
     "Internal error" : "Sisäinen virhe",
     "Not found" : "Ei löytynyt",
     "Bad request" : "Virheellinen pyyntö",
-    "Input text is too long" : "Syöteteksti on liian pitkä",
     "Requested task type does not exist" : "Pyydettyä tehtävätyyppiä ei ole olemassa",
     "Image not found" : "Kuvaa ei löytynyt",
     "No translation provider available" : "Käännöksen palveluntarjoaja ei ole saatavilla",
@@ -161,6 +160,14 @@ OC.L10N.register(
     "Matroska video" : "Matroska-video",
     "Windows Media video" : "Windows Media -video",
     "AVI video" : "AVI-video",
+    "unknown text" : "tuntematon teksti",
+    "Hello world!" : "Hei maailma!",
+    "sunny" : "aurinkoinen",
+    "Hello {name}, the weather is {weather}" : "Hei {name}, sää on {weather}",
+    "Hello {name}" : "Hei {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Nämä ovat hakutulokset<script>alert(1)</script></strong>",
+    "new" : "uusi",
+    "_download %n file_::_download %n files_" : ["lataa %n tiedosto","lataa %n tiedostoa"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Päivitys on meneillään. Poistuminen tältä sivulta saattaa keskeyttää toimenpiteen joissain käyttöympäristöissä.",
     "Update to {version}" : "Päivitä versioon {version}",
     "An error occurred." : "Tapahtui virhe.",
@@ -169,15 +176,12 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Päivitys ei onnistunut. Raportoisitko tämän ongelman <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-yhteisölle</a>.",
     "Continue to {productName}" : "Jatka {productName}iin",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Päivitys onnistui. Ohjataan {productName}iin %n sekunnin kuluttua.","Päivitys onnistui. Ohjataan {productName}iin %n sekunnin kuluttua."],
-    "Done" : "Valmis",
     "Applications menu" : "Sovellusten valikko",
     "Apps" : "Sovellukset",
     "More apps" : "Lisää sovelluksia",
     "_{count} notification_::_{count} notifications_" : ["{count} ilmoitus","{count} ilmoitusta"],
     "No" : "Ei",
     "Yes" : "Kyllä",
-    "App password" : "Sovellussalasana",
-    "Grant access" : "Myönnä pääsy",
     "Failed to add the public link to your Nextcloud" : "Julkisen linkin lisääminen Nextcloudiisi epäonnistui",
     "Federated user" : "Federoitu käyttäjä",
     "user@your-nextcloud.org" : "käyttäjä@oma-nextcloud.org",
@@ -191,7 +195,7 @@ OC.L10N.register(
     "Search in current app" : "Etsi nykyisessä sovelluksessa",
     "Clear search" : "Tyhjennä haku",
     "Search everywhere" : "Etsi kaikkialta",
-    "Searching …" : "Haetaan …",
+    "Searching …" : "Haetaan…",
     "Start typing to search" : "Aloita kirjoittaminen hakeaksesi",
     "No matching results" : "Ei tuloksia",
     "Today" : "Tänään",
@@ -211,10 +215,11 @@ OC.L10N.register(
     "Load more results" : "Lataa lisää tuloksia",
     "Search in" : "Etsi kohteesta",
     "Log in" : "Kirjaudu sisään",
-    "Logging in …" : "Kirjaudutaan …",
+    "Logging in …" : "Kirjaudutaan sisään...",
     "Log in to {productName}" : "Kirjaudu palveluun {productName}",
     "Wrong login or password." : "Väärä käyttäjätunnus tai salasana.",
     "This account is disabled" : "Tämä tili on poistettu käytöstä",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Useita virheellisiä kirjautumisyrityksiä havaittiin IP-osoitteestasi. Siksi seuraava yritys sallitaan vasta 30 sekunnin päästä.",
     "Account name or email" : "Tilin nimi tai sähköpostiosoite",
     "Account name" : "Tilin nimi",
     "Server side authentication failed!" : "Palvelimen puoleinen tunnistautuminen epäonnistui!",
@@ -224,7 +229,6 @@ OC.L10N.register(
     "An internal error occurred." : "Tapahtui sisäinen virhe.",
     "Please try again or contact your administrator." : "Yritä uudestaan tai ota yhteys ylläpitäjään.",
     "Password" : "Salasana",
-    "Remember me" : "Muista minut",
     "Log in with a device" : "Kirjaudu laitteella",
     "Login or email" : "Käyttäjätunnus tai sähköposti",
     "Your account is not setup for passwordless login." : "Käyttäjääsi ei ole kytketty käyttämään salasanatonta kirjautumista.",
@@ -247,24 +251,20 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Asiakirjat, laskentataulukot ja esitykset yhteistyönä, taustavoimana Collabora Online.",
     "Distraction free note taking app." : "Häiriötön mustiinpanosovellus.",
     "Recommended apps" : "Suositellut sovellukset",
-    "Loading apps …" : "Ladataan sovelluksia …",
+    "Loading apps …" : "Ladataan sovelluksia…",
     "Could not fetch list of apps from the App Store." : "Sovelluskaupasta ei voitu noutaa listaa sovelluksista.",
     "App download or installation failed" : "Sovelluksen lataus tai asennus epäonnistui",
     "Cannot install this app because it is not compatible" : "Tätä sovellusta ei voi asentaa, koska se ei ole yhteensopiva",
     "Cannot install this app" : "Tätä sovellusta ei voi asentaa",
     "Skip" : "Ohita",
-    "Installing apps …" : "Asennetaan sovelluksia …",
+    "Installing apps …" : "Asennetaan sovelluksia…",
     "Install recommended apps" : "Asenna suositellut sovellukset",
-    "Online" : "Online",
-    "Away" : "Poissa",
-    "Busy" : "Varattu",
-    "Do not disturb" : "Älä häiritse",
-    "Mute all notifications" : "Mykistä kaikki ilmoitukset",
-    "Invisible" : "Näkymätön",
-    "Appear offline" : "Näytä olevan poissa",
     "Settings menu" : "Asetusvalikko",
+    "Loading your contacts …" : "Ladataan yhteystietojasi…",
+    "Looking for {term} …" : "Etsii {term}…",
     "Search contacts" : "Etsi yhteystietoja",
     "Reset search" : "Tyhjennä haku",
+    "Search contacts …" : "Etsi yhteystietoja…",
     "Could not load your contacts" : "Yhteystietojasi ei voitu ladata",
     "No contacts found" : "Yhteystietoja ei löytynyt",
     "Show all contacts" : "Näytä kaikki kontaktit",
@@ -276,20 +276,12 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Haettaessa tyyppiä {type} tapahtui virhe.",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Haku alkaa kun aloitat kirjoittamisen. Tuloksiin on mahdollista siirtyä nuolinäppäimillä",
     "Search for {name} only" : "Etsi vain {name}",
-    "Loading more results …" : "Ladataan lisää tuloksia …",
+    "Loading more results …" : "Ladataan lisää tuloksia…",
     "Forgot password?" : "Unohditko salasanasi?",
     "Back to login form" : "Takaisin kirjautumisnäkymään",
     "Back" : "Takaisin",
     "Login form is disabled." : "Kirjautumislomake on poistettu käytöstä.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloudin kirjautumislomake on poistettu käytöstä. Käytä toista kirjautumistapaa tai ota yhteys ylläpitoon.",
-    "Connect to your account" : "Yhdistä tiliisi",
-    "Security warning" : "Turvallisuusvaroitus",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Jos et ole asentamassa uutta laitetta tai sovellusta, joku yrittää huijata sinut antamaan käyttöoikeudet tietoihisi. Tässä tapauksessa älä jatka, ota yhteys järjestelmänvalvojaan.",
-    "Alternative log in using app password" : "Vaihtoehtoinen kirjautuminen käyttäen sovellussalasanaa",
-    "Account connected" : "Tili yhdistetty",
-    "Your client should now be connected!" : "Päätteesi pitäisi olla yhdistetty!",
-    "You can close this window." : "Voit sulkea tämän ikkunan.",
-    "Account access" : "Tilin käyttö",
     "More actions" : "Lisää toimintoja",
     "User menu" : "Käyttäjävalikko",
     "Your guest name: {user}" : "Vierasnimesi: {user}",
@@ -304,13 +296,13 @@ OC.L10N.register(
     "Unknown password strength" : "Tuntematon salasanan vahvuus",
     "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Datahakemistosi ja tiedostosi ovat mitä luultavimmin muiden nähtävissä Internetistä, koska <code>.htaccess</code>-tiedosto ei toimi.",
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Lisätietoja oikeaoppisesta palvelimen määrityksestä on saatavilla {linkStart}dokumentaatiossa{linkEnd}",
+    "Security warning" : "Turvallisuusvaroitus",
     "Create administration account" : "Luo ylläpitäjätili",
     "Administration account name" : "Ylläpitäjätilin nimi",
     "Administration account password" : "Ylläpitäjätilin salasana",
     "Storage & database" : "Tallennus ja tietokanta",
     "Data folder" : "Datakansio",
     "Database configuration" : "Tietokannan kokoonpano",
-    "Database type" : "Tietokannan tyyppi",
     "Only {firstAndOnlyDatabase} is available." : "Vain {firstAndOnlyDatabase} on käytettävissä.",
     "Install and activate additional PHP modules to choose other database types." : "Asenna ja aktivoi erillisiä PHP-moduuleja valitaksesi muita tietokantatyyppejä.",
     "For more details check out the documentation." : "Lue lisätiedot ohjeista.",
@@ -318,14 +310,13 @@ OC.L10N.register(
     "You chose SQLite as database." : "Valitsit SQLiten tietokannaksi.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite tulisi ottaa käyttöön vain minimaalisissa kehitysympäristöissä. Tuotantokäyttöön suosittelemme toista tietokantaratkaisua.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Jos käytät asiakasohjelmia tiedostojen synkronointiin, SQLiten käyttöä ei suositella.",
-    "Database connection" : "Tietokantayhteys",
     "Database user" : "Tietokannan käyttäjä",
     "Database password" : "Tietokannan salasana",
     "Database name" : "Tietokannan nimi",
     "Database tablespace" : "Tietokannan taulukkotila",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Määritä portin numero tietokantapalvelimen yhteydessä (esim. localhost:5432).",
     "Database host" : "Tietokantapalvelin",
-    "Installing …" : "Asennetaan …",
+    "Installing …" : "Asennetaan …",
     "Install" : "Asenna",
     "Need help?" : "Tarvitsetko apua?",
     "See the documentation" : "Tutustu ohjeisiin",
@@ -334,7 +325,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Selaimesi ei ole tuettu. Päivitä uudempaan versioon tai muuhun tuettuun selaimeen.",
     "Continue with this unsupported browser" : "Jatka tällä tuen ulkopuolella olevalla selaimella",
     "Supported versions" : "Tuetut versiot",
-    "Search {types} …" : "Etsi {types} …",
+    "Search {types} …" : "Etsi {types}…",
     "Choose {file}" : "Valitse {file}",
     "Choose" : "Valitse",
     "Copy to {target}" : "Kopioi kohteeseen {target}",
@@ -354,10 +345,7 @@ OC.L10N.register(
     "(all selected)" : "(kaikki valittu)",
     "({count} selected)" : "({count} valittu)",
     "Error loading file exists template" : "Virhe ladatessa mallipohjaa",
-    "Saving …" : "Tallennetaan …",
-    "Groups" : "Ryhmät",
-    "Group list is empty" : "Ryhmälista on tyhjä",
-    "Unable to retrieve the group list" : "Ryhmälistaa ei voitu noutaa",
+    "Saving …" : "Tallennetaan…",
     "seconds ago" : "sekunteja sitten",
     "Connection to server lost" : "Yhteys palvelimelle katkesi",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Ongelma sivun lataamisessa, päivitetään %n sekunnin kuluttua","Ongelma sivun lataamisessa, päivitetään %n sekunnin kuluttua"],
@@ -372,6 +360,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "Kirjoita etsiäksesi olemassa olevia projekteja",
     "New in" : "Uutta versiossa",
     "View changelog" : "Katso muutosloki",
+    "No action available" : "Toimintoa ei saatavilla",
+    "Error fetching contact actions" : "Virhe yhteystiedon toimintojen haussa",
     "Close \"{dialogTitle}\" dialog" : "Sulje \"{dialogTitle}\"-ikkuna",
     "Email length is at max (255)" : "Sähköpostin pituus on maksimissaan (255)",
     "Clipboard not available, please copy manually" : "Leikepöytä ei ole saatavilla, kopioi manuaalisesti",
@@ -408,6 +398,16 @@ OC.L10N.register(
     "Skip to navigation of app" : "Hyppää sovelluksen navigointiin.",
     "Go to %s" : "Siirry %s§",
     "Get your own free account" : "Hanki ilmainen tili itsellesi",
+    "Connect to your account" : "Yhdistä tiliisi",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Jos et ole asentamassa uutta laitetta tai sovellusta, joku yrittää huijata sinut antamaan käyttöoikeudet tietoihisi. Tässä tapauksessa älä jatka, ota yhteys järjestelmänvalvojaan.",
+    "App password" : "Sovellussalasana",
+    "Grant access" : "Myönnä pääsy",
+    "Alternative log in using app password" : "Vaihtoehtoinen kirjautuminen käyttäen sovellussalasanaa",
+    "Account access" : "Tilin käyttö",
+    "Currently logged in as %1$s (%2$s)." : "Kirjautuneena käyttäjänä %1$s (%2$s).",
+    "Account connected" : "Tili yhdistetty",
+    "Your client should now be connected!" : "Päätteesi pitäisi olla yhdistetty!",
+    "You can close this window." : "Voit sulkea tämän ikkunan.",
     "Previous" : "Edellinen",
     "This share is password-protected" : "Jako on salasanasuojattu",
     "The password is wrong or expired. Please try again or request a new one." : "Salasana on väärä tai vanhentunut. Yritä uudelleen tai pyydä uusi salasana.",
@@ -445,41 +445,31 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Tämä %s-instanssi on parhaillaan huoltotilassa, huollossa saattaa kestää hetki.",
     "This page will refresh itself when the instance is available again." : "Tämä sivu päivittyy itsestään, kun instanssi on jälleen käytettävissä.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Ota yhteys järjestelmän ylläpitäjään, jos tämä viesti ilmenee uudelleen tai odottamatta.",
+    "No temporary profile picture available, try again" : "Väliaikaista profiilikuvaa ei ole käytettävissä, yritä uudelleen",
+    "No crop data provided" : "Leikkaustietoa ei annettu",
+    "No valid crop data provided" : "Kelvollisia leikkaustietoja ei määritetty",
+    "Crop is not square" : "Leikkaus ei ole neliö",
     "Error occurred while checking server setup" : "Virhe palvelimen määrityksiä tarkistaessa",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Lue lisätietoja {linkstart}dokumentaatiosta ↗{linkend}.",
-    "unknown text" : "tuntematon teksti",
-    "Hello world!" : "Hei maailma!",
-    "sunny" : "aurinkoinen",
-    "Hello {name}, the weather is {weather}" : "Hei {name}, sää on {weather}",
-    "Hello {name}" : "Hei {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Nämä ovat hakutulokset<script>alert(1)</script></strong>",
-    "new" : "uusi",
-    "_download %n file_::_download %n files_" : ["lataa %n tiedosto","lataa %n tiedostoa"],
-    "Direct link copied to clipboard" : "Suora linkki kopioitu työpöydälle",
-    "Searching …" : "Haetaan…",
-    "Logging in …" : "Kirjaudutaan sisään...",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Useita virheellisiä kirjautumisyrityksiä havaittiin IP-osoitteestasi. Siksi seuraava yritys sallitaan vasta 30 sekunnin päästä.",
-    "Loading apps …" : "Ladataan sovelluksia…",
-    "Installing apps …" : "Asennetaan sovelluksia…",
-    "Loading your contacts …" : "Ladataan yhteystietojasi…",
-    "Looking for {term} …" : "Etsii {term}…",
-    "Search contacts …" : "Etsi yhteystietoja…",
-    "Loading more results …" : "Ladataan lisää tuloksia…",
-    "Search {types} …" : "Etsi {types}…",
-    "Saving …" : "Tallennetaan…",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Keskustelu, videopuhelut, näytön jako, verkkotapaamiset ja web-konferenssit - selaimessasi ja puhelinsovelluksilla.",
+    "You have not added any info yet" : "Et ole lisännyt tietoja vielä",
+    "{user} has not added any info yet" : "{user} ei ole lisännyt tietoja vielä",
+    "Edit Profile" : "Muokkaa profiilia",
+    "The headline and about sections will show up here" : "Otsikko ja listätieto-osiot näkyvät tässä",
     "Very weak password" : "Erittäin heikko salasana",
     "Weak password" : "Heikko salasana",
     "So-so password" : "Kohtalainen salasana",
     "Good password" : "Hyvä salasana",
     "Strong password" : "Vahva salasana",
-    "No action available" : "Toimintoa ei saatavilla",
-    "Error fetching contact actions" : "Virhe yhteystiedon toimintojen haussa",
     "Non-existing tag #{tag}" : "Ei olemassa oleva tunniste #{tag}",
     "Restricted" : "Rajoitettu",
+    "Invisible" : "Näkymätön",
     "Delete" : "Poista",
     "Rename" : "Nimeä uudelleen",
     "Collaborative tags" : "Yhteistyölliset tunnisteet",
     "No tags found" : "Tunnisteita ei löytynyt",
+    "Profile not found" : "Profiilia ei löytynyt",
+    "The profile does not exist." : "Profiilia ei ole olemassa",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Datakansiosi ja tiedostosi ovat mitä luultavimmin muiden nähtävissä Internetistä, koska .htaccess-tiedosto ei toimi.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Lisätietoja palvelimen kunnollisista asetuksista on <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">ohjeissa</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Luo ylläpitäjän tili</strong>",
@@ -490,7 +480,6 @@ OC.L10N.register(
     "Configure the database" : "Määritä tietokanta",
     "Only %s is available." : "Vain %s on käytettävissä.",
     "Database account" : "Tietokantatili",
-    "Installing …" : "Asennetaan …",
-    "Currently logged in as %1$s (%2$s)." : "Kirjautuneena käyttäjänä %1$s (%2$s)."
+    "Direct link copied to clipboard" : "Suora linkki kopioitu työpöydälle"
 },
 "nplurals=2; plural=(n != 1);");
