@@ -49,7 +49,6 @@ OC.L10N.register(
     "No translation provider available" : "Aucun fournisseur de traduction n’est disponible",
     "Could not detect language" : "Impossible de détecter la langue",
     "Unable to translate" : "Impossible de traduire",
-    "No valid filters provided" : "Aucun filtre valide fourni",
     "[%d / %d]: %s" : "[%d / %d] : %s",
     "Repair step:" : "Étape de réparation :",
     "Repair info:" : "Informations de réparation :",
@@ -197,6 +196,14 @@ OC.L10N.register(
     "Matroska video" : "Vidéo Matroska",
     "Windows Media video" : "Vidéo Windows Media",
     "AVI video" : "Vidéo AVI",
+    "unknown text" : "texte inconnu",
+    "Hello world!" : "Hello world!",
+    "sunny" : "ensoleillé",
+    "Hello {name}, the weather is {weather}" : "Bonjour {name}, le temps est {weather}",
+    "Hello {name}" : "Bonjour {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Voici les résultats de votre recherche<script>alert(1)</script></strong>",
+    "new" : "nouveau ",
+    "_download %n file_::_download %n files_" : ["télécharger %n fichier","télécharger %n fichiers","télécharger %n fichiers"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "La mise à jour est en cours, quitter la page peut interrompre le processus dans de nombreux environnements.",
     "Update to {version}" : "Mettre à jour vers {version}",
     "An error occurred." : "Une erreur est survenue.",
@@ -226,9 +233,8 @@ OC.L10N.register(
     "Search in current app" : "Recherche dans l'application courante",
     "Clear search" : "Effacer la recherche",
     "Search everywhere" : "Chercher partout",
-    "Searching …" : "Recherche …",
+    "Searching …" : "Recherche…",
     "Start typing to search" : "Commencez à taper pour lancer la recherche",
-    "Minimum search length is {minSearchLength} characters" : "La longueur minimale de recherche est de {minSearchLength} caractères",
     "No matching results" : "Aucun résultat correspondant",
     "Today" : "Aujourd’hui",
     "Last 7 days" : "7 derniers jours",
@@ -248,7 +254,7 @@ OC.L10N.register(
     "Load more results" : "Charger plus de résultats",
     "Search in" : "Rechercher dans",
     "Log in" : "Se connecter",
-    "Logging in …" : "Connexion en cours…",
+    "Logging in …" : "Connexion…",
     "Log in to {productName}" : "Se connecter à {productName}",
     "Wrong login or password." : "Mauvais identifiant ou mot de passe.",
     "This account is disabled" : "Ce compte est désactivé",
@@ -285,21 +291,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documents, feuilles de calculs ou présentations créées sur Collabora Online.",
     "Distraction free note taking app." : "Application de prise de notes sans distraction.",
     "Recommended apps" : "Applications recommandées",
-    "Loading apps …" : "Chargement des applis …",
+    "Loading apps …" : "Chargement des applis…",
     "Could not fetch list of apps from the App Store." : "Impossible de récupérer la liste des applications depuis le magasin d’applications",
     "App download or installation failed" : "Échec lors du téléchargement ou de l’installation de l’application",
     "Cannot install this app because it is not compatible" : "Impossible d’installer cette app parce qu’elle n’est pas compatible",
     "Cannot install this app" : "Impossible d’installer cette app",
     "Skip" : "Ignorer",
-    "Installing apps …" : "Installation des applis en cours ...",
+    "Installing apps …" : "Installation des applis en cours...",
     "Install recommended apps" : "Installer les applications recommandées",
     "Avatar of {displayName}" : "Avatar de {displayName}",
     "Settings menu" : "Menu des paramètres",
-    "Loading your contacts …" : "Chargement de vos contacts ...",
-    "Looking for {term} …" : "Recherche de {term}  ...",
+    "Loading your contacts …" : "Chargement de vos contacts...",
+    "Looking for {term} …" : "Recherche de {term} ...",
     "Search contacts" : "Rechercher des contacts",
     "Reset search" : "Réinitialiser la recherche",
-    "Search contacts …" : "Rechercher un contact.. .",
+    "Search contacts …" : "Rechercher un contact...",
     "Could not load your contacts" : "Impossible de charger vos contacts",
     "No contacts found" : "Aucun contact trouvé",
     "Show all contacts" : "Afficher tous les contacts",
@@ -311,7 +317,7 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Une erreur est survenue lors de la recherche de {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "La recherche démarre dès que vous commencez à taper et les résultats peuvent être atteints avec les flèches du clavier",
     "Search for {name} only" : "Rechercher pour {name} uniquement",
-    "Loading more results …" : "Chargement de plus de résultats …",
+    "Loading more results …" : "Chargement de plus de résultats …",
     "Forgot password?" : "Mot de passe oublié ?",
     "Back to login form" : "Retour au formulaire de connexion",
     "Back" : "Retour",
@@ -355,7 +361,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Veuillez spécifier le numéro du port avec le nom de l’hôte (par exemple, localhost:5432).",
     "Database host" : "Hôte de la base de données",
     "localhost" : "localhost",
-    "Installing …" : "Installation …",
+    "Installing …" : "Installation...",
     "Install" : "Installer",
     "Need help?" : "Besoin d’aide ?",
     "See the documentation" : "Lire la documentation",
@@ -364,7 +370,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Votre navigateur n'est pas pris en charge. Veuillez passer à une version plus récente ou à un navigateur supporté.",
     "Continue with this unsupported browser" : "Continuer avec ce navigateur non pris en charge",
     "Supported versions" : "Versions supportées",
-    "Search {types} …" : "Rechercher {types} …",
+    "Search {types} …" : "Rechercher {types}…",
     "Choose {file}" : "Choisir {file}",
     "Choose" : "Choisir",
     "Copy to {target}" : "Copier vers {target}",
@@ -384,7 +390,7 @@ OC.L10N.register(
     "(all selected)" : "(tous sélectionnés)",
     "({count} selected)" : "({count} sélectionné(s))",
     "Error loading file exists template" : "Erreur lors du chargement du modèle de fichier existant",
-    "Saving …" : "Enregistrement  …",
+    "Saving …" : "Enregistrement...",
     "seconds ago" : "Il y a quelques secondes",
     "Connection to server lost" : "La connexion au serveur a été perdue",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problème de chargement de la page, actualisation dans %n seconde","Problème de chargement de la page, actualisation dans %n secondes","Problème de chargement de la page, actualisation dans %n secondes"],
@@ -399,6 +405,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "Saisissez du texte pour rechercher un projet existant",
     "New in" : "Nouveau dans",
     "View changelog" : "Voir le journal des modifications",
+    "No action available" : "Aucune action disponible",
+    "Error fetching contact actions" : "Erreur lors de la recherche d'actions de contact",
     "Close \"{dialogTitle}\" dialog" : "Fermer la boîte de dialogue « {dialogTitle} »",
     "Email length is at max (255)" : "La longueur de l'e-mail est au maximum (255)",
     "Clipboard not available, please copy manually" : "Le presse-papier n'est pas disponible, veuillez copier manuellement",
@@ -486,34 +494,23 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Cette instance de %s est en cours de maintenance, cela peut prendre du temps.",
     "This page will refresh itself when the instance is available again." : "Cette page se rafraîchira d'elle-même lorsque le serveur sera de nouveau disponible.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Veuillez contacter votre administrateur système si ce message persiste ou apparaît de façon inattendue.",
+    "No temporary profile picture available, try again" : "Aucune image de profil temporaire disponible, essayez à nouveau",
+    "No crop data provided" : "Aucune donnée de recadrage fournie",
+    "No valid crop data provided" : "Aucune donnée valide de recadrage fournie",
+    "Crop is not square" : "Le recadrage n’est pas carré",
     "Error occurred while checking server setup" : "Une erreur est survenue lors de la vérification de la configuration du serveur",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Pour plus d’information, voir la {linkstart}documentation ↗{linkend}.",
-    "unknown text" : "texte inconnu",
-    "Hello world!" : "Hello world!",
-    "sunny" : "ensoleillé",
-    "Hello {name}, the weather is {weather}" : "Bonjour {name}, le temps est {weather}",
-    "Hello {name}" : "Bonjour {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Voici les résultats de votre recherche<script>alert(1)</script></strong>",
-    "new" : "nouveau ",
-    "_download %n file_::_download %n files_" : ["télécharger %n fichier","télécharger %n fichiers","télécharger %n fichiers"],
-    "Direct link copied to clipboard" : "Lien direct copié dans le presse-papiers",
-    "Searching …" : "Recherche…",
-    "Logging in …" : "Connexion…",
-    "Loading apps …" : "Chargement des applis…",
-    "Installing apps …" : "Installation des applis en cours...",
-    "Loading your contacts …" : "Chargement de vos contacts...",
-    "Looking for {term} …" : "Recherche de {term} ...",
-    "Search contacts …" : "Rechercher un contact...",
-    "Loading more results …" : "Chargement de plus de résultats …",
-    "Search {types} …" : "Rechercher {types}…",
-    "Saving …" : "Enregistrement...",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Discussions, appels vidéo, partage d’écran, réunions en ligne et conférences web – depuis votre navigateur et les applications mobiles.",
+    "You have not added any info yet" : "Vous n’avez pas ajouté d’informations pour le moment",
+    "{user} has not added any info yet" : "{user} n’a pas ajouté d’informations pour le moment",
+    "Error opening the user status modal, try hard refreshing the page" : "Erreur lors de l'ouverture du modal du statut de l'utilisateur, essayez d'actualiser la page",
+    "Edit Profile" : "Modifier le profil",
+    "The headline and about sections will show up here" : "Le titre et la section « À propos » apparaîtront ici",
     "Very weak password" : "Mot de passe très faible",
     "Weak password" : "Mot de passe faible",
     "So-so password" : "Mot de passe tout juste acceptable",
     "Good password" : "Mot de passe de sécurité suffisante",
     "Strong password" : "Mot de passe fort",
-    "No action available" : "Aucune action disponible",
-    "Error fetching contact actions" : "Erreur lors de la recherche d'actions de contact",
     "Non-existing tag #{tag}" : "Étiquette #{tag} inexistante",
     "Restricted" : "Restreint",
     "Invisible" : "Invisible",
@@ -521,6 +518,8 @@ OC.L10N.register(
     "Rename" : "Renommer",
     "Collaborative tags" : "Étiquettes collaboratives ",
     "No tags found" : "Aucune étiquette n’a été trouvée",
+    "Profile not found" : "Profile introuvable",
+    "The profile does not exist." : "Le profile n'existe pas.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Votre répertoire de données est certainement accessible depuis internet car le fichier .htaccess ne fonctionne pas.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pour les informations de configuration de votre serveur, veuillez lire la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Créer un compte administrateur</strong>",
@@ -531,6 +530,6 @@ OC.L10N.register(
     "Configure the database" : "Configurer la base de données",
     "Only %s is available." : "Seul(e) %s est disponible.",
     "Database account" : "Compte de base de données",
-    "Installing …" : "Installation..."
+    "Direct link copied to clipboard" : "Lien direct copié dans le presse-papiers"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
