@@ -42,7 +42,6 @@ OC.L10N.register(
     "Not found" : "Ní bhfuarthas",
     "Node is locked" : "Tá an nód faoi ghlas",
     "Bad request" : "Drochiarratas",
-    "Input text is too long" : "Tá an téacs ionchuir rófhada",
     "Requested task type does not exist" : "Níl an cineál taisc iarrtha ann",
     "Necessary language model provider is not available" : "Níl soláthraí múnla teanga riachtanach ar fáil",
     "No text to image provider is available" : "Níl aon soláthraí téacs go híomhá ar fáil",
@@ -50,7 +49,6 @@ OC.L10N.register(
     "No translation provider available" : "Níl aon soláthraí aistriúcháin ar fáil",
     "Could not detect language" : "Níorbh fhéidir teanga a bhrath",
     "Unable to translate" : "Ní féidir aistriú",
-    "No valid filters provided" : "Níor soláthraíodh aon scagairí bailí",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Céim deisiúcháin:",
     "Repair info:" : "Eolas deisiúcháin:",
@@ -198,6 +196,14 @@ OC.L10N.register(
     "Matroska video" : "Físeán Matroska",
     "Windows Media video" : "Físeán Windows Media",
     "AVI video" : "Físeán AVI",
+    "unknown text" : "téacs anaithnid",
+    "Hello world!" : "Dia duit, a dhomhan!",
+    "sunny" : "Grianmhar",
+    "Hello {name}, the weather is {weather}" : "Dia duit {name}, tá an aimsir {weather}",
+    "Hello {name}" : "Dia duit {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Seo iad do thorthaí cuardaigh<script>foláireamh(1)</script></strong>",
+    "new" : "nua",
+    "_download %n file_::_download %n files_" : ["íoslódáil %n comhad","íoslódáil %n comhaid","íoslódáil %n comhaid","íoslódáil %n comhaid","íoslódáil %n comhaid"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Tá an nuashonrú ar siúl, agus d'fhéadfadh go gcuirfí isteach ar an bpróiseas i dtimpeallachtaí áirithe dá bhfágfaí an leathanach seo.",
     "Update to {version}" : "Nuashonraigh go {version}",
     "An error occurred." : "Tharla earráid.",
@@ -227,9 +233,8 @@ OC.L10N.register(
     "Search in current app" : "Cuardaigh san aip reatha",
     "Clear search" : "Glan cuardach",
     "Search everywhere" : "Cuardaigh i ngach áit",
-    "Searching …" : "Ag cuardach …",
+    "Searching …" : "Ag cuardach…",
     "Start typing to search" : "Tosaigh ag clóscríobh chun cuardach a dhéanamh",
-    "Minimum search length is {minSearchLength} characters" : "Is é {minSearchLength} carachtar an fad cuardaigh íosta",
     "No matching results" : "Gan torthaí meaitseála",
     "Today" : "Inniu",
     "Last 7 days" : "7 lá seo caite",
@@ -249,7 +254,7 @@ OC.L10N.register(
     "Load more results" : "Íoslódáil níos mó torthaí",
     "Search in" : "Cuardaigh isteach",
     "Log in" : "Logáil isteach",
-    "Logging in …" : "Ag logáil isteach …",
+    "Logging in …" : "Ag logáil isteach…",
     "Log in to {productName}" : "Logáil isteach ar {productName}",
     "Wrong login or password." : "Logáil isteach mícheart nó pasfhocal.",
     "This account is disabled" : "Tá an cuntas seo díchumasaithe",
@@ -263,7 +268,6 @@ OC.L10N.register(
     "An internal error occurred." : "Tharla earráid inmheánach.",
     "Please try again or contact your administrator." : "Bain triail eile as nó déan teagmháil le do riarthóir.",
     "Password" : "Pasfhocal",
-    "Remember me" : "Cuimhnigh orm",
     "Log in with a device" : "Logáil isteach le gléas",
     "Login or email" : "Logáil isteach nó ríomhphost",
     "Your account is not setup for passwordless login." : "Níl do chuntas socraithe le haghaidh logáil isteach gan pasfhocal.",
@@ -287,21 +291,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Doiciméid chomhoibríocha, scarbhileoga agus cur i láthair, tógtha ar Collabora Online.",
     "Distraction free note taking app." : "Clár chun nótaí a tharraingt saor in aisce,.",
     "Recommended apps" : "Aipeanna molta",
-    "Loading apps …" : "Ag lódáil aipeanna …",
+    "Loading apps …" : "Aipeanna á lódáil…",
     "Could not fetch list of apps from the App Store." : "Níorbh fhéidir liosta aipeanna a fháil ón App Store.",
     "App download or installation failed" : "Theip ar íoslódáil nó suiteáil an aip",
     "Cannot install this app because it is not compatible" : "Ní féidir an aip seo a shuiteáil toisc nach bhfuil sé comhoiriúnach",
     "Cannot install this app" : "Ní féidir an aip seo a shuiteáil",
     "Skip" : "Scipeáil",
-    "Installing apps …" : "Ag suiteáil aipeanna …",
+    "Installing apps …" : "Aipeanna á suiteáil…",
     "Install recommended apps" : "Suiteáil aipeanna molta",
     "Avatar of {displayName}" : "Avatar de {displayName}",
     "Settings menu" : "Roghchlár socruithe",
-    "Loading your contacts …" : "Ag lódáil do theagmhálaithe …",
-    "Looking for {term} …" : "Ag lorg {term} …",
+    "Loading your contacts …" : "Do theagmhálaithe á lódáil…",
+    "Looking for {term} …" : "Ag lorg {term} …",
     "Search contacts" : "Cuardaigh teagmhálaithe",
     "Reset search" : "Athshocraigh cuardach",
-    "Search contacts …" : "Cuardaigh teagmhálaithe …",
+    "Search contacts …" : "Cuardaigh teagmhálaithe…",
     "Could not load your contacts" : "Níorbh fhéidir do theagmhálaithe a lódáil",
     "No contacts found" : "Níor aimsíodh aon teagmhálaí",
     "Show all contacts" : "Taispeáin gach teagmháil",
@@ -313,7 +317,7 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Tharla earráid agus {type} á chuardach",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Tosaíonn an cuardach nuair a thosaíonn tú ag clóscríobh agus is féidir na torthaí a bhaint amach leis na heochracha saigheada",
     "Search for {name} only" : "Déan cuardach ar {name} amháin",
-    "Loading more results …" : "Tuilleadh torthaí á lódáil …",
+    "Loading more results …" : "Tuilleadh torthaí á lódáil…",
     "Forgot password?" : "Dearmad ar pasfhocal?",
     "Back to login form" : "Ar ais go dtí an fhoirm logáil isteach",
     "Back" : "Ar ais",
@@ -343,7 +347,6 @@ OC.L10N.register(
     "Storage & database" : "Stóráil agus bunachar sonraí",
     "Data folder" : "Fillteán sonraí",
     "Database configuration" : "Cumraíocht bunachar sonraí",
-    "Database type" : "Cineál bunachar sonraí",
     "Only {firstAndOnlyDatabase} is available." : "Níl ach {firstAndOnlyDatabase} ar fáil.",
     "Install and activate additional PHP modules to choose other database types." : "Suiteáil agus gníomhachtaigh modúil PHP breise chun cineálacha bunachar sonraí eile a roghnú.",
     "For more details check out the documentation." : "Le haghaidh tuilleadh sonraí féach ar an doiciméadú.",
@@ -351,7 +354,6 @@ OC.L10N.register(
     "You chose SQLite as database." : "Roghnaigh tú SQLite mar bhunachar sonraí.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "Níor cheart SQLite a úsáid ach amháin le haghaidh cásanna íosta agus forbartha. Le haghaidh táirgeadh molaimid inneall bunachar sonraí difriúil.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Má úsáideann tú cliaint chun comhaid a shioncronú, ní miste go mór úsáid SQLite.",
-    "Database connection" : "Nasc bunachar sonraí",
     "Database user" : "Úsáideoir bunachar sonraí",
     "Database password" : "Pasfhocal bunachar sonraí",
     "Database name" : "Ainm bunachar sonraí",
@@ -359,7 +361,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Sonraigh le do thoil uimhir an phoirt mar aon le hainm an óstaigh (m.sh., localhost: 5432).",
     "Database host" : "Óstach bunachar sonraí",
     "localhost" : "áitiúil-óstach",
-    "Installing …" : "Ag suiteáil …",
+    "Installing …" : "Suiteáil…",
     "Install" : "Suiteáil",
     "Need help?" : "Teastaionn Cabhair?",
     "See the documentation" : "Féach ar an doiciméadú",
@@ -368,7 +370,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Ní thacaítear le do bhrabhsálaí. Uasghrádaigh go leagan níos nuaí nó go leagan a dtacaítear leis le do thoil.",
     "Continue with this unsupported browser" : "Lean ar aghaidh leis an mbrabhsálaí seo nach dtacaítear leis",
     "Supported versions" : "Leaganacha tacaithe",
-    "Search {types} …" : "Cuardaigh {types} …",
+    "Search {types} …" : "Cuardaigh {types} …",
     "Choose {file}" : "Roghnaigh {file}",
     "Choose" : "Roghnaigh",
     "Copy to {target}" : "Cóipeáil chuig {target}",
@@ -388,7 +390,7 @@ OC.L10N.register(
     "(all selected)" : "(roghnaithe go léir)",
     "({count} selected)" : "({count} roghnaithe)",
     "Error loading file exists template" : "Earráid agus an comhad á lódáil tá an teimpléad ann",
-    "Saving …" : "Shábháil …",
+    "Saving …" : "Shábháil …",
     "seconds ago" : "soicind ó shin",
     "Connection to server lost" : "Ceangal leis an bhfreastalaí caillte",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind ","Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind ","Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind ","Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind ","Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind "],
@@ -403,6 +405,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "Clóscríobh chun tionscadail atá ann cheana a chuardach",
     "New in" : "Nua isteach",
     "View changelog" : "Féach ar loga na n-athruithe",
+    "No action available" : "Níl aon ghníomh ar fáil",
+    "Error fetching contact actions" : "Earráid agus gníomhartha teagmhála á bhfáil",
     "Close \"{dialogTitle}\" dialog" : "Dún dialóg \"{dialogTitle}\".",
     "Email length is at max (255)" : "Tá fad an ríomhphoist ag uasmhéid (255)",
     "Clipboard not available, please copy manually" : "Níl an gearrthaisce ar fáil, cóipeáil de láimh",
@@ -490,34 +494,23 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Tá an cás %s seo i mód cothabhála faoi láthair, agus seans go dtógfaidh sé sin tamall.",
     "This page will refresh itself when the instance is available again." : "Athnóidh an leathanach seo é féin nuair a bheidh an t-ásc ar fáil arís.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Déan teagmháil le riarthóir do chórais má leanann an teachtaireacht seo nó má thaispeánfar gan choinne.",
+    "No temporary profile picture available, try again" : "Níl aon phictiúr próifíle sealadach ar fáil, bain triail eile as",
+    "No crop data provided" : "Níor soláthraíodh aon sonraí bairr",
+    "No valid crop data provided" : "Níor soláthraíodh aon sonraí bailí bairr",
+    "Crop is not square" : "Níl an barr cearnach",
     "Error occurred while checking server setup" : "Tharla earráid agus socrú an fhreastalaí á sheiceáil",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Le haghaidh tuilleadh sonraí féach an {linkstart}doiciméadú ↗{linkend}.",
-    "unknown text" : "téacs anaithnid",
-    "Hello world!" : "Dia duit, a dhomhan!",
-    "sunny" : "Grianmhar",
-    "Hello {name}, the weather is {weather}" : "Dia duit {name}, tá an aimsir {weather}",
-    "Hello {name}" : "Dia duit {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Seo iad do thorthaí cuardaigh<script>foláireamh(1)</script></strong>",
-    "new" : "nua",
-    "_download %n file_::_download %n files_" : ["íoslódáil %n comhad","íoslódáil %n comhaid","íoslódáil %n comhaid","íoslódáil %n comhaid","íoslódáil %n comhaid"],
-    "Direct link copied to clipboard" : "Cóipeáladh nasc díreach chuig an ngearrthaisce",
-    "Searching …" : "Ag cuardach…",
-    "Logging in …" : "Ag logáil isteach…",
-    "Loading apps …" : "Aipeanna á lódáil…",
-    "Installing apps …" : "Aipeanna á suiteáil…",
-    "Loading your contacts …" : "Do theagmhálaithe á lódáil…",
-    "Looking for {term} …" : "Ag lorg {term} …",
-    "Search contacts …" : "Cuardaigh teagmhálaithe…",
-    "Loading more results …" : "Tuilleadh torthaí á lódáil…",
-    "Search {types} …" : "Cuardaigh {types} …",
-    "Saving …" : "Shábháil …",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Comhrá, físghlaonna, comhroinnt scáileáin, cruinnithe ar líne agus comhdháil gréasáin – i do bhrabhsálaí agus le haipeanna móibíleacha.",
+    "You have not added any info yet" : "Níl aon fhaisnéis curtha agat fós",
+    "{user} has not added any info yet" : "Níor chuir {user} aon fhaisnéis leis fós",
+    "Error opening the user status modal, try hard refreshing the page" : "Earráid agus an modh stádas úsáideora á oscailt, déan iarracht an leathanach a athnuachan go dian",
+    "Edit Profile" : "Cuir Próifíl in Eagar",
+    "The headline and about sections will show up here" : "Taispeánfar an ceannlíne agus na hailt faoi anseo",
     "Very weak password" : "Pasfhocal an-lag",
     "Weak password" : "Pasfhocal lag",
     "So-so password" : "mar sin-sin pasfhocal",
     "Good password" : "pasfhocal maith",
     "Strong password" : "Pasfhocal láidir",
-    "No action available" : "Níl aon ghníomh ar fáil",
-    "Error fetching contact actions" : "Earráid agus gníomhartha teagmhála á bhfáil",
     "Non-existing tag #{tag}" : "Clib nach bhfuil ann #{tag}",
     "Restricted" : "Srianta",
     "Invisible" : "Dofheicthe",
@@ -525,6 +518,8 @@ OC.L10N.register(
     "Rename" : "Athainmnigh",
     "Collaborative tags" : "Clibeanna comhoibríocha",
     "No tags found" : "Níor aimsíodh clibeanna",
+    "Profile not found" : "Próifíl gan aimsiú",
+    "The profile does not exist." : "Níl an phróifíl ann.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Is dócha go bhfuil do eolaire sonraí agus comhaid inrochtana ón idirlíon toisc nach n-oibríonn an comhad .htaccess.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Chun tuilleadh faisnéise a fháil faoi conas do fhreastalaí a chumrú i gceart, féach ar an <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">doiciméad</a>le do thoil. ",
     "<strong>Create an admin account</strong>" : "<strong>Cruthaigh cuntas riaracháin</strong>",
@@ -535,6 +530,6 @@ OC.L10N.register(
     "Configure the database" : "Cumraigh an bunachar sonraí",
     "Only %s is available." : "Níl ach %s ar fáil.",
     "Database account" : "Cuntas bunachar sonraí",
-    "Installing …" : "Suiteáil…"
+    "Direct link copied to clipboard" : "Cóipeáladh nasc díreach chuig an ngearrthaisce"
 },
 "nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
