@@ -42,7 +42,6 @@ OC.L10N.register(
     "Not found" : "Nem található",
     "Node is locked" : "A csomópont zárolva van",
     "Bad request" : "Hibás kérés",
-    "Input text is too long" : "A bementi szöveg túl hosszú",
     "Requested task type does not exist" : "A kért feladattípus nem létezik",
     "Necessary language model provider is not available" : "A szükséges nyelvimodell-szolgáltató nem érhető el",
     "No text to image provider is available" : "Nem érhető el szövegből képet előállító szolgáltató",
@@ -50,7 +49,6 @@ OC.L10N.register(
     "No translation provider available" : "Nem érhető el fordítási szolgáltató",
     "Could not detect language" : "Nem sikerült észlelni a nyelvet",
     "Unable to translate" : "Nem fordítható le",
-    "No valid filters provided" : "Nincs érvényes szűrő megadva",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Javítási lépés:",
     "Repair info:" : "Javítási információ:",
@@ -198,6 +196,14 @@ OC.L10N.register(
     "Matroska video" : "Matroska-videó",
     "Windows Media video" : "Windows Media-videó",
     "AVI video" : "AVI-videó",
+    "unknown text" : "ismeretlen szöveg",
+    "Hello world!" : "Helló világ!",
+    "sunny" : "napos",
+    "Hello {name}, the weather is {weather}" : "Üdv {name}, {weather} időnk van",
+    "Hello {name}" : "Üdv {name}!",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Ezek a találatok<script>alert(1)</script></strong>",
+    "new" : "új",
+    "_download %n file_::_download %n files_" : ["%n fájl letöltése","%n fájl letöltése"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "A frissítés folyamatban van, az oldal elhagyása egyes környezetekben megszakíthatja a folyamatot.",
     "Update to {version}" : "Frissítés erre: {version}",
     "An error occurred." : "Hiba történt.",
@@ -206,15 +212,12 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "A frissítés sikertelen. Jelezze a problémát a <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud közösségnek</a>.",
     "Continue to {productName}" : "Tovább erre: {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["A frissítés sikeres volt. %n másodperc múlva át lesz irányítva a következőhöz: {productName}.","A frissítés sikeres volt. %n másodperc múlva át lesz irányítva a következőhöz: {productName}."],
-    "Done" : "Kész",
     "Applications menu" : "Alkalmazások menü",
     "Apps" : "Alkalmazások",
     "More apps" : "További alkalmazások",
     "_{count} notification_::_{count} notifications_" : ["{count} értesítés","{count} értesítés"],
     "No" : "Nem",
     "Yes" : "Igen",
-    "App password" : "Alkalmazásjelszó",
-    "Grant access" : "Hozzáférés megadása",
     "The remote URL must include the user." : "A távoli webcímnek tartalmaznia kell a felhasználót.",
     "Invalid remote URL." : "Érvénytelen távoli webcím.",
     "Failed to add the public link to your Nextcloud" : "Nem sikerült hozzáadni a nyilvános hivatkozást a Nexcloudjához",
@@ -230,16 +233,14 @@ OC.L10N.register(
     "Search in current app" : "Keresés a jelenlegi alkalmazásban",
     "Clear search" : "Keresés törlése",
     "Search everywhere" : "Keresés mindenhol",
-    "Searching …" : "Keresés…",
+    "Searching …" : "Keresés…",
     "Start typing to search" : "Kezdjen el gépelni a kereséshez",
-    "Minimum search length is {minSearchLength} characters" : "A legkisebb keresési hossz {minSearchLength} karakteres",
     "No matching results" : "Nincs találat",
     "Today" : "Ma",
     "Last 7 days" : "Előző 7 nap",
     "Last 30 days" : "Előző 30 nap",
     "This year" : "Ezen az éven",
     "Last year" : "Előző év",
-    "Between {startDate} and {endDate}" : "{startDate} és {endDate} között",
     "Unified search" : "Egyesített keresés",
     "Search apps, files, tags, messages" : "Alkalmazások, fájlok, címkék és üzenetek keresése",
     "Places" : "Helyek",
@@ -252,10 +253,11 @@ OC.L10N.register(
     "Load more results" : "További találatok betöltése",
     "Search in" : "Keresés ebben:",
     "Log in" : "Bejelentkezés",
-    "Logging in …" : "Bejelentkezés…",
+    "Logging in …" : "Bejelentkezés…",
     "Log in to {productName}" : "Bejelentkezés ebbe: {productName}",
     "Wrong login or password." : "Hibás bejelentkezés vagy jelszó.",
     "This account is disabled" : "Ez a fiók le van tiltva",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Többszöri sikertelen bejelentkezési kísérletet észleltünk az IP-címéről. A legközelebbi kísérlete így 30 másodperccel késleltetve lesz.",
     "Account name or email" : "Fióknév vagy e-mail-cím",
     "Account name" : "Fiók neve",
     "Server side authentication failed!" : "A kiszolgálóoldali hitelesítés sikertelen.",
@@ -265,7 +267,6 @@ OC.L10N.register(
     "An internal error occurred." : "Belső hiba történt.",
     "Please try again or contact your administrator." : "Próbálja meg újra, vagy vegye fel a kapcsolatot a rendszergazdával.",
     "Password" : "Jelszó",
-    "Remember me" : "Emlékeztetés később",
     "Log in with a device" : "Bejelentkezés eszközzel",
     "Login or email" : "Bejelentkezés vagy e-mail",
     "Your account is not setup for passwordless login." : "A fiókja nincs beállítva jelszómentes bejelentkezésre.",
@@ -289,28 +290,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Közösen szerkeszthető dokumentumok, táblázatok és bemutatók, a Collabora Online-ra építve.",
     "Distraction free note taking app." : "Figyelemelterelés nélküli jegyzetelési alkalmazás.",
     "Recommended apps" : "Ajánlott alkalmazások",
-    "Loading apps …" : "Alkalmazások betöltése…",
+    "Loading apps …" : "Alkalmazások betöltése…",
     "Could not fetch list of apps from the App Store." : "Az alkalmazások listája nem kérhető le az alkalmazástárból.",
     "App download or installation failed" : "Alkalmazás letöltése vagy telepítése sikertelen",
     "Cannot install this app because it is not compatible" : "Az alkalmazás nem telepíthető, mert nem kompatibilis",
     "Cannot install this app" : "Az alkalmazás nem telepíthető",
     "Skip" : "Kihagyás",
-    "Installing apps …" : "Alkalmazások telepítése…",
+    "Installing apps …" : "Alkalmazások telepítése…",
     "Install recommended apps" : "Javasolt alkalmazások telepítése",
-    "Online" : "Elérhető",
-    "Away" : "Távol",
-    "Busy" : "Foglalt",
-    "Do not disturb" : "Ne zavarjanak",
-    "Mute all notifications" : "Összes értesítés némítása",
-    "Invisible" : "Láthatatlan",
-    "Appear offline" : "Megjelenés nem kapcsolódottként",
     "Avatar of {displayName}" : "{displayName} profilképe",
     "Settings menu" : "Beállítások menü",
-    "Loading your contacts …" : "Névjegyek betöltése…",
-    "Looking for {term} …" : "{term} keresése…",
+    "Loading your contacts …" : "Névjegyek betöltése…",
+    "Looking for {term} …" : "{term} keresése…",
     "Search contacts" : "Névjegyek keresése",
     "Reset search" : "Keresés visszaállítása",
-    "Search contacts …" : "Névjegyek keresése…",
+    "Search contacts …" : "Névjegyek keresése…",
     "Could not load your contacts" : "Nem lehet betölteni a névjegyeit",
     "No contacts found" : "Nem találhatók névjegyek",
     "Show all contacts" : "Összes névjegy megjelenítése",
@@ -322,23 +316,14 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Hiba történt a(z) {type} keresése sorá",
     "Search starts once you start typing and results may be reached with the arrow keys" : "A keresés elindul, ha elkezd gépelni, és a találatok a nyílbillentyűkkel érhetők el",
     "Search for {name} only" : "Keresés csak a(z) {name} kifejezésre",
-    "Loading more results …" : "További találatok betöltése…",
+    "Loading more results …" : "További találatok betöltése…",
     "Forgot password?" : "Elfelejtett jelszó?",
     "Back to login form" : "Vissza a bejelentkezési űrlaphoz",
     "Back" : "Vissza",
     "Login form is disabled." : "A bejelentkezési űrlap letiltva.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "A Nextcloud bejelentkezési űrlap le van tiltva. Használjon más bejelentkezési lehetőséget, ha van ilyen, vagy lépjen kapcsolatba az adminisztrációval.",
-    "Connect to your account" : "Kapcsolódás a fiókjához",
-    "Security warning" : "Biztonsági figyelmeztetés",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ha nem új eszközt vagy alkalmazást próbál beállítani, akkor valaki megpróbálja becsapni, hogy hozzáférést biztosítson számára az adatokhoz. Ebben az esetben ne folytassa, hanem lépjen kapcsolatba a rendszergazdával.",
-    "Alternative log in using app password" : "Alternatív bejelentkezés alkalmazásjelszó segítségével",
-    "Account connected" : "Fiók csatlakoztatva",
-    "Your client should now be connected!" : "A kliens most már kapcsolódik.",
-    "You can close this window." : "Bezárhatja ezt az ablakot.",
-    "Account access" : "Fiókhozzáférés",
     "More actions" : "További műveletek",
     "User menu" : "Felhasználói menü",
-    "Your guest name: {user}" : "A vendég neve: {user}",
     "You are currently not identified." : "Jelenleg nincs azonosítva.",
     "Set public name" : "Nyilvános név beállítása",
     "Change public name" : "Nyilvános név módosítása",
@@ -353,13 +338,13 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "A kiszolgáló helyes beállításához {linkStart}tekintse meg a dokumentációt{linkEnd}",
     "Autoconfig file detected" : "Autoconfig fájl felismerve",
     "The setup form below is pre-filled with the values from the config file." : "A lenti beállítási űrlap a konfigurációs fájlban lévő értékekkel van előre kitöltve.",
+    "Security warning" : "Biztonsági figyelmeztetés",
     "Create administration account" : "Rendszergazdai fiók létrehozása",
     "Administration account name" : "Rendszergazdai fiók neve",
     "Administration account password" : "Rendszergazdai fiók jelszava",
     "Storage & database" : "Tárhely és adatbázis",
     "Data folder" : "Adatmappa",
     "Database configuration" : "Adatbázis-beállítások",
-    "Database type" : "Adatbázistípus",
     "Only {firstAndOnlyDatabase} is available." : "Csak a(z) {firstAndOnlyDatabase} érhető el.",
     "Install and activate additional PHP modules to choose other database types." : "Telepítse és aktiválja a bővített PHP modulokat, hogy tudjon más adatbázis típust is kiválasztani.",
     "For more details check out the documentation." : "További részletekért nézze meg a dokumentációt.",
@@ -367,7 +352,6 @@ OC.L10N.register(
     "You chose SQLite as database." : "SQLite adatbázist választott.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "Az SQLite-ot csak minimális és fejlesztési célú példányok esetén szabad használni. Éles működés esetén más adatbázis-kezelőt ajánlunk.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ha klienseket használt a fájlszinkronizáláshoz, akkor az SQLite használata erősen ellenjavallt.",
-    "Database connection" : "Adatbázis-kapcsolat",
     "Database user" : "Adatbázis-felhasználó",
     "Database password" : "Adatbázisjelszó",
     "Database name" : "Adatbázis neve",
@@ -375,7 +359,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Adja meg a port számát a kiszolgáló neve után (például localhost:5432).",
     "Database host" : "Adatbázis-kiszolgáló",
     "localhost" : "localhost",
-    "Installing …" : "Telepítés…",
+    "Installing …" : "Telepítés…",
     "Install" : "Telepítés",
     "Need help?" : "Segítségre van szüksége?",
     "See the documentation" : "Nézze meg a dokumentációt",
@@ -384,7 +368,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "A böngészője nem támogatott. Frissítsen újabb verzióra, vagy váltson egy támogatott böngészőre.",
     "Continue with this unsupported browser" : "Folytatás ezzel a nem támogatott böngészővel",
     "Supported versions" : "Támogatott verziók",
-    "Search {types} …" : "{types} keresése…",
+    "Search {types} …" : "{types} keresése…",
     "Choose {file}" : "{file} kiválasztása",
     "Choose" : "Válasszon",
     "Copy to {target}" : "Másolás ide: {target}",
@@ -404,10 +388,7 @@ OC.L10N.register(
     "(all selected)" : "(összes kiválasztva)",
     "({count} selected)" : "({count} kiválasztva)",
     "Error loading file exists template" : "Hiba a „fájl már létezik” sablon betöltésekor",
-    "Saving …" : "Mentés…",
-    "Groups" : "Csoportok",
-    "Group list is empty" : "A csoportlista üres",
-    "Unable to retrieve the group list" : "A csoportlista betöltése sikertelen",
+    "Saving …" : "Mentés…",
     "seconds ago" : "pár másodperce",
     "Connection to server lost" : "A kapcsolat megszakadt a kiszolgálóval",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Probléma az oldal betöltésekor, újratöltés %n másodperc múlva","Probléma az oldal betöltésekor, újratöltés %n másodperc múlva"],
@@ -422,6 +403,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "Gépeljen a meglévő projektet kereséséhez",
     "New in" : "Újdonságok a következőben:",
     "View changelog" : "Változásnapló megtekintése",
+    "No action available" : "Nincs elérhető művelet",
+    "Error fetching contact actions" : "Hiba a kapcsolati műveletek lekérésekor",
     "Close \"{dialogTitle}\" dialog" : "A(z) „{dialogTitle}” párbeszédablak bezárása",
     "Email length is at max (255)" : "Az e-mail-cím hossza elérte a maximumot (255)",
     "Clipboard not available, please copy manually" : "A vágólap nem érhető el, másolja kézileg",
@@ -458,6 +441,18 @@ OC.L10N.register(
     "Skip to navigation of app" : "Ugrás az alkalmazás navigációjához",
     "Go to %s" : "Ugrás ide: %s",
     "Get your own free account" : "Szerezzen saját ingyenes fiókot",
+    "Connect to your account" : "Kapcsolódás a fiókjához",
+    "Please log in before granting %1$s access to your %2$s account." : "Lépjen be mielőtthozzáférést biztosít a(z) %1$s kliensnek a(z) %2$s fiókjához.",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ha nem új eszközt vagy alkalmazást próbál beállítani, akkor valaki megpróbálja becsapni, hogy hozzáférést biztosítson számára az adatokhoz. Ebben az esetben ne folytassa, hanem lépjen kapcsolatba a rendszergazdával.",
+    "App password" : "Alkalmazásjelszó",
+    "Grant access" : "Hozzáférés megadása",
+    "Alternative log in using app password" : "Alternatív bejelentkezés alkalmazásjelszó segítségével",
+    "Account access" : "Fiókhozzáférés",
+    "Currently logged in as %1$s (%2$s)." : "Jelenleg bejelentkezve: %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Hozzáférést készül biztosítani %1$s számára ehhez a fiókjához: %2$s.",
+    "Account connected" : "Fiók csatlakoztatva",
+    "Your client should now be connected!" : "A kliens most már kapcsolódik.",
+    "You can close this window." : "Bezárhatja ezt az ablakot.",
     "Previous" : "Előző",
     "This share is password-protected" : "Ez a megosztás jelszóval védett",
     "The password is wrong or expired. Please try again or request a new one." : "A jelszó hibás vagy lejárt. Próbálja újra, vagy kérjen újat.",
@@ -497,41 +492,32 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Ez a %s példány éppen karbantartási üzemmódban van, amely eltarthat egy darabig.",
     "This page will refresh itself when the instance is available again." : "Ez az oldal frissíteni fogja magát, amint a példány ismét elérhető lesz.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Ha ez az üzenet mindig vagy váratlanul megjelenik, akkor keresse fel a rendszergazdáját.",
+    "No temporary profile picture available, try again" : "Nem érhető el átmeneti profilkép, próbálja újra",
+    "No crop data provided" : "Nincs levágási adat megadva",
+    "No valid crop data provided" : "Nincs érvényes levágási adat megadva",
+    "Crop is not square" : "A levágás nem négyzet alakú",
     "Error occurred while checking server setup" : "Hiba történt a kiszolgálóbeállítások ellenőrzésekor",
     "For more details see the {linkstart}documentation ↗{linkend}." : "További részletekért lásd a {linkstart}dokumentációt↗{linkend}.",
-    "unknown text" : "ismeretlen szöveg",
-    "Hello world!" : "Helló világ!",
-    "sunny" : "napos",
-    "Hello {name}, the weather is {weather}" : "Üdv {name}, {weather} időnk van",
-    "Hello {name}" : "Üdv {name}!",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Ezek a találatok<script>alert(1)</script></strong>",
-    "new" : "új",
-    "_download %n file_::_download %n files_" : ["%n fájl letöltése","%n fájl letöltése"],
-    "Direct link copied to clipboard" : "Közvetlen hivatkozás a vágólapra másolva",
-    "Searching …" : "Keresés…",
-    "Logging in …" : "Bejelentkezés…",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Többszöri sikertelen bejelentkezési kísérletet észleltünk az IP-címéről. A legközelebbi kísérlete így 30 másodperccel késleltetve lesz.",
-    "Loading apps …" : "Alkalmazások betöltése…",
-    "Installing apps …" : "Alkalmazások telepítése…",
-    "Loading your contacts …" : "Névjegyek betöltése…",
-    "Looking for {term} …" : "{term} keresése…",
-    "Search contacts …" : "Névjegyek keresése…",
-    "Loading more results …" : "További találatok betöltése…",
-    "Search {types} …" : "{types} keresése…",
-    "Saving …" : "Mentés…",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Csevegés, videóhívások, képernyőmegosztás, online megbeszélések és webes konferencia – a böngészőjében és mobilalkalmazásokkal.",
+    "You have not added any info yet" : "Még nem adott meg semmilyen információt",
+    "{user} has not added any info yet" : "{user} még nem adott meg semmilyen információt",
+    "Error opening the user status modal, try hard refreshing the page" : "Hiba a felhasználói állapot párbeszédablak megnyitásakor, próbálja meg az oldal kényszerített újratöltését",
+    "Edit Profile" : "Profil szerkesztése",
+    "The headline and about sections will show up here" : "A címsor és a névjegy szakaszok itt fognak megjelenni",
     "Very weak password" : "Nagyon gyenge jelszó",
     "Weak password" : "Gyenge jelszó",
     "So-so password" : "Nem túl jó jelszó",
     "Good password" : "Megfelelő jelszó",
     "Strong password" : "Erős jelszó",
-    "No action available" : "Nincs elérhető művelet",
-    "Error fetching contact actions" : "Hiba a kapcsolati műveletek lekérésekor",
     "Non-existing tag #{tag}" : "Nem létező címke #{tag}",
     "Restricted" : "Korlátozott",
+    "Invisible" : "Láthatatlan",
     "Delete" : "Törlés",
     "Rename" : "Átnevezés",
     "Collaborative tags" : "Együttműködési címkék",
     "No tags found" : "Nem találhatók címkék",
+    "Profile not found" : "Nem található profil",
+    "The profile does not exist." : "A profil nem létezik.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Az adatkönyvtár és a benne levő fájlok valószínűleg közvetlenül is elérhetők az internetről, mert a .htaccess fájl nem érvényesül.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "További információkért a szervered helyes beállításához nézd meg a <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentációt</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Rendszergazdai fiók létrehozása</strong>",
@@ -542,9 +528,6 @@ OC.L10N.register(
     "Configure the database" : "Adatbázis konfigurálása",
     "Only %s is available." : "Csak %s érhető el.",
     "Database account" : "Adatbázisfiók",
-    "Installing …" : "Telepítés…",
-    "Please log in before granting %1$s access to your %2$s account." : "Lépjen be mielőtthozzáférést biztosít a(z) %1$s kliensnek a(z) %2$s fiókjához.",
-    "Currently logged in as %1$s (%2$s)." : "Jelenleg bejelentkezve: %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Hozzáférést készül biztosítani %1$s számára ehhez a fiókjához: %2$s."
+    "Direct link copied to clipboard" : "Közvetlen hivatkozás a vágólapra másolva"
 },
 "nplurals=2; plural=(n != 1);");
