@@ -59,6 +59,14 @@ OC.L10N.register(
     "Already up to date" : "Sudah yang terbaru",
     "Unknown" : "Tidak diketahui",
     "PNG image" : "Gambar PNG",
+    "unknown text" : "teks tidak diketahui",
+    "Hello world!" : "Halo dunia!",
+    "sunny" : "cerah",
+    "Hello {name}, the weather is {weather}" : "Halo {name}, saat ini {weather}",
+    "Hello {name}" : "Halo {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Ini adalah hasil pencarian Anda<script>alert(1)</script></strong>",
+    "new" : "baru",
+    "_download %n file_::_download %n files_" : ["unduh %n berkas"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Pembaruan sedang dalam proses, meninggalkan halaman ini mungkin dapat mengganggu proses di beberapa lingkungan.",
     "Update to {version}" : "Perbarui ke {version}",
     "An error occurred." : "Terjadi kesalahan.",
@@ -78,6 +86,7 @@ OC.L10N.register(
     "People" : "Orang",
     "Load more results" : "Muat lebih banyak hasil",
     "Log in" : "Masuk",
+    "Logging in …" : "Log masuk...",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Terdeteksi multipel percobaan log masuk tidak valid dari IP Anda. Pencekalan log masuk berikutnya dilakukan hingga 30 detik.",
     "Server side authentication failed!" : "Otentikasi dari sisi server gagal!",
     "Please contact your administrator." : "Silakan hubungi administrator Anda.",
@@ -102,14 +111,19 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "Simpan info teman dan kolega Anda dalam satu tempat, tanpa membocorkan privat mereka.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplikasi klien email sederhana, terintegrasi dengan Berkas, Kontak, dan Kalender.",
     "Recommended apps" : "Aplikasi terekomendasi",
+    "Loading apps …" : "Memuat aplikasi ...",
     "Could not fetch list of apps from the App Store." : "Tidak dapat mengambil daftar aplikasi dari App Store.",
     "App download or installation failed" : "Unduh aplikasi atau gagal instalasi",
     "Cannot install this app because it is not compatible" : "Tidak dapat memasang aplikasi ini karena tidak kompatibel",
     "Cannot install this app" : "Tidak dapat memasang aplikasi ini",
     "Skip" : "Lewati",
+    "Installing apps …" : "menginstal aplikasi ...",
     "Install recommended apps" : "Instal aplikasi yang disarankan",
     "Settings menu" : "Menu Pengaturan",
+    "Loading your contacts …" : "Memuat kontak Anda ...",
+    "Looking for {term} …" : "Mencari {term}",
     "Reset search" : "Ulang pencarian",
+    "Search contacts …" : "Cari kontak ...",
     "Could not load your contacts" : "Tidak dapat memuat kontak Anda",
     "No contacts found" : "Kontak tidak ditemukan",
     "Show all contacts" : "Tampilkan semua kontak",
@@ -119,6 +133,7 @@ OC.L10N.register(
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Harap masukkan {minSearchLength} karakter atau lebih untuk mencari"],
     "An error occurred while searching for {type}" : "Terjadi kesalahan saat mencari {type}",
     "Search for {name} only" : "Cari {name} saja",
+    "Loading more results …" : "Memuat hasil lainnya…",
     "Forgot password?" : "Lupa kata sandi?",
     "Back" : "Kembali",
     "Security warning" : "Peringatan keamanan",
@@ -136,9 +151,11 @@ OC.L10N.register(
     "Database tablespace" : "Tablespace basis data",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Harap tentukan nomor port beserta nama host (contoh., localhost:5432).",
     "Database host" : "Host basis data",
+    "Installing …" : "Memasang …",
     "Install" : "Pasang",
     "Need help?" : "Butuh bantuan?",
     "See the documentation" : "Lihat dokumentasi",
+    "Search {types} …" : "Cari {types} …",
     "Choose" : "Pilih",
     "Copy" : "Salin",
     "Move" : "Pindah",
@@ -155,6 +172,7 @@ OC.L10N.register(
     "(all selected)" : "(semua terpilih)",
     "({count} selected)" : "({count} terpilih)",
     "Error loading file exists template" : "Kesalahan memuat templat berkas yang sudah ada",
+    "Saving …" : "Menyimpan ...",
     "seconds ago" : "beberapa detik yang lalu",
     "Connection to server lost" : "Koneksi ke server gagal",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Tidak dapat memuat laman, muat ulang dalam %n detik"],
@@ -169,6 +187,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "Ketik untuk mencari proyek eksis",
     "New in" : "Terbaru",
     "View changelog" : "Lihat log pembaruan",
+    "No action available" : "Aksi tidak tersedia",
+    "Error fetching contact actions" : "Galat mengambil aksi kontak",
     "Personal" : "Pribadi",
     "Accounts" : "Accounts",
     "Admin" : "Admin",
@@ -245,31 +265,20 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Instansi %s ini sedang dalam modus pemeliharaan, mungkin memerlukan beberapa saat.",
     "This page will refresh itself when the instance is available again." : "Laman ini akan dimuat otomatis saat instalasi kembali tersedia.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Hubungi administrator sistem Anda jika pesan ini terus muncul atau muncul tiba-tiba.",
+    "No temporary profile picture available, try again" : "Tidak ada gambar profil sementara yang tersedia, coba lagi",
+    "No crop data provided" : "Tidak ada data krop tersedia",
+    "No valid crop data provided" : "Tidak ada data valid untuk dipangkas",
+    "Crop is not square" : "Pangkas ini tidak persegi",
     "Error occurred while checking server setup" : "Kesalahan tidak terduga saat memeriksa setelan server",
-    "unknown text" : "teks tidak diketahui",
-    "Hello world!" : "Halo dunia!",
-    "sunny" : "cerah",
-    "Hello {name}, the weather is {weather}" : "Halo {name}, saat ini {weather}",
-    "Hello {name}" : "Halo {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Ini adalah hasil pencarian Anda<script>alert(1)</script></strong>",
-    "new" : "baru",
-    "_download %n file_::_download %n files_" : ["unduh %n berkas"],
-    "Logging in …" : "Log masuk...",
-    "Loading apps …" : "Memuat aplikasi ...",
-    "Installing apps …" : "menginstal aplikasi ...",
-    "Loading your contacts …" : "Memuat kontak Anda ...",
-    "Looking for {term} …" : "Mencari {term}",
-    "Search contacts …" : "Cari kontak ...",
-    "Loading more results …" : "Memuat hasil lainnya…",
-    "Search {types} …" : "Cari {types} …",
-    "Saving …" : "Menyimpan ...",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Mengobrol, panggilan video, berbagi layar, rapat daring, dan konferensi web - melalui peramban dan menggunakan aplikasi pada gawai.",
+    "You have not added any info yet" : "Anda belum menambahkan info apa pun",
+    "{user} has not added any info yet" : "{user} belum menambahkan info apa pun",
+    "Edit Profile" : "Sunting profil",
     "Very weak password" : "Kata sandi sangat lemah",
     "Weak password" : "Kata sandi lemah",
     "So-so password" : "Kata sandi lumayan",
     "Good password" : "Kata sandi baik",
     "Strong password" : "Kata sandi kuat",
-    "No action available" : "Aksi tidak tersedia",
-    "Error fetching contact actions" : "Galat mengambil aksi kontak",
     "Non-existing tag #{tag}" : "Tag tidak ada #{tag}",
     "Restricted" : "Terbatas",
     "Invisible" : "Tersembunyi",
@@ -277,11 +286,12 @@ OC.L10N.register(
     "Rename" : "Ubah nama",
     "Collaborative tags" : "Tag kolaboratif",
     "No tags found" : "Tag tidak ditemukan",
+    "Profile not found" : "Profil tidak ditemukan",
+    "The profile does not exist." : "Profil tidak ada.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Kemungkinan direktori data dan berkas Anda dapat diakses dari internet karena berkas .htaccess tidak berfungsi.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informasi bagaimana kesesuaian konfigurasi peladen Anda, silakan lihat <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentasi</a>.",
     "Show password" : "Tampilkan kata sandi",
     "Configure the database" : "Konfigurasikan basis data",
-    "Only %s is available." : "Hanya %s yang tersedia",
-    "Installing …" : "Memasang …"
+    "Only %s is available." : "Hanya %s yang tersedia"
 },
 "nplurals=1; plural=0;");
