@@ -75,6 +75,13 @@ OC.L10N.register(
     "Already up to date" : "Jau ir jaunākā",
     "Unknown" : "Nezināms",
     "LDIF address book" : "LDIF adrešu grāmata",
+    "unknown text" : "nezināms teksts",
+    "Hello world!" : "Sveika, pasaule!",
+    "sunny" : "saulains",
+    "Hello {name}, the weather is {weather}" : "Sveiciens, {name}, laikapstākļi ir {weather}",
+    "Hello {name}" : "Sveiciens, {name}",
+    "new" : "jauns",
+    "_download %n file_::_download %n files_" : ["lejupielādēt %n datņu","lejupielādēt %n datni","lejupielādēt %n datnes"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Notiek atjaunināšana, šīs lapas pamešana dažās vidēs var pārtraukt to.",
     "Update to {version}" : "Atjaunināt uz {version}",
     "An error occurred." : "Atgadījās kļūda.",
@@ -82,15 +89,12 @@ OC.L10N.register(
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Atjaunināšana bija nesekmīga. Vairāk informācijas par šo sarežģījumu ir skatāma <a href=\"{url}\">mūsu foruma ierakstā</a> .",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Atjaunināšana bija nesekmība. Lūgums ziņot par šo nepilnību <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud kopienai</a>.",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Atjaunināšana bija veiksmīga. Notiks pārvirzīšana uz {productName} pēc %n sekundēm.","Atjaunināšana bija veiksmīga. Notiks pārvirzīšana uz {productName} pēc %n sekundes.","Atjaunināšana bija sekmīga. Pēc %nsekundēm notiks pārvirzīšana uz {productName}."],
-    "Done" : "Pabeigts",
     "Applications menu" : "Lietotņu izvēlne",
     "Apps" : "Lietotnes",
     "More apps" : "Vairāk lietotņu",
     "_{count} notification_::_{count} notifications_" : ["{count} paziņojumu","{count}paziņojums","{count}paziņojumi"],
     "No" : "Nē",
     "Yes" : "Jā",
-    "App password" : "Lietotnes parole",
-    "Grant access" : "Piešķirt piekļuvi",
     "Failed to add the public link to your Nextcloud" : "Neizdevās pievienot publisku saiti Tavam Nextcloud",
     "Please copy the link manually:" : "Lūgums pašrocīgi ievietot saiti starpliktuvē:",
     "Pick start date" : "Izvēlēties sākuma datumu",
@@ -99,6 +103,7 @@ OC.L10N.register(
     "Search in current app" : "Meklēt pašreizējā lietotnē",
     "Clear search" : "Notīrīt meklēšanu",
     "Search everywhere" : "Meklēt visur",
+    "Searching …" : "Meklē...",
     "Start typing to search" : "Sākt rakstīt, lai meklētu",
     "No matching results" : "Nav atbilstoša iznākuma",
     "Today" : "Šodien",
@@ -112,9 +117,11 @@ OC.L10N.register(
     "Load more results" : "Ielādēt vairāk iznākumu",
     "Search in" : "Meklēt",
     "Log in" : "Pieteikties",
+    "Logging in …" : "Notiek pieteikšanās …",
     "Log in to {productName}" : "Pieteikties {productName}",
     "Wrong login or password." : "Nepareizs lietotājvārds vai parole.",
     "This account is disabled" : "Šis konts ir atspējots",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Mēs esam noteikuši vairākus nederīgus pieteikšanās mēģinājumus no šīs IP adreses, tādējādi nākamā pieteikšanās ir ierobežota līdz 30 sekundēm.",
     "Account name or email" : "Konta nosaukums vai e-pasta adrese",
     "Account name" : "Konta nosaukums",
     "Server side authentication failed!" : "Servera autentifikācija neizdevās!",
@@ -143,26 +150,22 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "Turiet savus kolēģus un draugus vienuviet, neizpludinot viņu privāto informāciju.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Vienkāršā e-pasta lietotne labi apvienota ar Datnēm, Kontaktiem un Kalendāru.",
     "Recommended apps" : "Ieteiktās lietotnes",
+    "Loading apps …" : "Notiek lietotņu ielāde ...",
     "App download or installation failed" : "Lietotnes lejupielāde vai uzstādīšana neizdevās",
     "Cannot install this app" : "Nevarēja uzstādīt šo lietotni",
     "Skip" : "Izlaist",
-    "Busy" : "Aizņemts",
-    "Invisible" : "Neredzama",
+    "Installing apps …" : "Notiek lietotņu instalēšana ...",
     "Settings menu" : "Iestatījumu izvēlne",
+    "Loading your contacts …" : "Notiek kontaktpersonu ielāde...",
+    "Looking for {term} …" : "Meklē {term} …",
+    "Search contacts …" : "Meklēt kontaktpersonu",
     "Could not load your contacts" : "Nevarēja ielādēt visas kontaktpersonas",
     "No contacts found" : "Nav atrasta ne viena kontaktpersona",
     "Install the Contacts app" : "Jāuzstāda Kontaktpersonu lietotne",
     "Search" : "Meklēt",
     "Forgot password?" : "Aizmirsta parole?",
     "Back" : "Atpakaļ",
-    "Connect to your account" : "Savienoties ar savu kontu",
     "Security warning" : "Drošības brīdinājums",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ja nemēģini iestatīt jaunu ierīci vai lietotni, kāds mēģina apmānīt Tevi, lai Tu piešķirtu piekļuvi saviem datiem. Tādā gadījumā neturpini, un tā vietā sazinies ar savas sistēmas pārvaldītāju!",
-    "Alternative log in using app password" : "Tā vietā pieteikties ar lietotnes paroli",
-    "Account connected" : "Konts sasaistīts",
-    "Your client should now be connected!" : "Klientam tagad vajadzētu būt sasaistītam.",
-    "You can close this window." : "Šo logu var aizvērt.",
-    "Account access" : "Piekļuve kontam",
     "Storage & database" : "Krātuve & datubāze",
     "Data folder" : "Datu mape",
     "Install and activate additional PHP modules to choose other database types." : "Jāuzstāda un jāaktivē papildu PHP moduļi, lai izvēlētos citus datubāžu veidus.",
@@ -195,9 +198,7 @@ OC.L10N.register(
     "(all selected)" : "(visas atlasītās)",
     "({count} selected)" : "({count} iezīmēti)",
     "Error loading file exists template" : "Kļūda esošas datnes veidnes ielādēšanā",
-    "Groups" : "Grupas",
-    "Group list is empty" : "Grupu saraksts ir tukšš",
-    "Unable to retrieve the group list" : "Nevarēja saņemt grupu sarakstu",
+    "Saving …" : "Saglabā ...",
     "seconds ago" : "pirms vairākām sekundēm",
     "Connection to server lost" : "Zaudēts savienojums ar serveri",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problēma ielādējot lapu, pārlādēšana pēc %n sekundēm","Problēma ielādējot lapu, pārlādēšana pēc %n sekundēm","Problēma ielādējot lapu, pārlādēšana pēc %n sekundēm"],
@@ -211,6 +212,8 @@ OC.L10N.register(
     "Connect items to a project to make them easier to find" : "Savienojiet vienumus ar projektu, lai tos būtu vieglāk atrast",
     "New in" : "Jauns",
     "View changelog" : "Skatīt izmaiņu sarakstu",
+    "No action available" : "Nav pieejamu darbību",
+    "Error fetching contact actions" : "Kļūda rodot kontaktpersonām piemērojamās darbības",
     "Personal" : "Personīgi",
     "Accounts" : "Konti",
     "Admin" : "Pārvaldītājs",
@@ -232,6 +235,18 @@ OC.L10N.register(
     "Line: %s" : "Līnija: %s",
     "Trace" : "Izsekot",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Šīs lietotnes pareizai darbībai ir nepieciešams JavaScript. Lūgums {linkstart}ieslēgt JavasScript{linkend} un pārlādēt lapu.",
+    "Connect to your account" : "Savienoties ar savu kontu",
+    "Please log in before granting %1$s access to your %2$s account." : "Lūgums pieteikties pirms piekļuves piešķiršanas %1$s savam %2$s kontam.",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ja nemēģini iestatīt jaunu ierīci vai lietotni, kāds mēģina apmānīt Tevi, lai Tu piešķirtu piekļuvi saviem datiem. Tādā gadījumā neturpini, un tā vietā sazinies ar savas sistēmas pārvaldītāju!",
+    "App password" : "Lietotnes parole",
+    "Grant access" : "Piešķirt piekļuvi",
+    "Alternative log in using app password" : "Tā vietā pieteikties ar lietotnes paroli",
+    "Account access" : "Piekļuve kontam",
+    "Currently logged in as %1$s (%2$s)." : "Pašreiz pieteicies kā %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Tu grasies piešķirt %1$s piekļuvi savam %2$s kontam.",
+    "Account connected" : "Konts sasaistīts",
+    "Your client should now be connected!" : "Klientam tagad vajadzētu būt sasaistītam.",
+    "You can close this window." : "Šo logu var aizvērt.",
     "Previous" : "Iepriekšējā",
     "This share is password-protected" : "Šis kopīgojums ir aizsargāts ar paroli",
     "Email address" : "E-pasta adrese",
@@ -256,33 +271,24 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Šis %s serveris pašlaik darbojas uzturēšanas režīmā, tas var ilgt kādu laiku.",
     "This page will refresh itself when the instance is available again." : "Šī lapa atsvaidzināsies, kad Nextcloud būs atkal pieejams.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Jāsazinās ar sistēmas pārvaldītāju, ja šis ziņojums nepazūd vai parādījās negaidīti",
+    "No temporary profile picture available, try again" : "Nav pieejams profila pagaidu attēls, jāmēģina vēlreiz",
+    "No crop data provided" : "Nav norādīti apgriešanas dati",
+    "No valid crop data provided" : "Nav norādīti derīgi apgriešanas dati",
+    "Crop is not square" : "Griezums nav kvadrāts",
     "Error occurred while checking server setup" : "Servera pārbaudīšanas laikā atgadījās kļūda",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Vairāk informācijas ir skatāma {linkstart}dokumentācijā ↗{linkend}.",
-    "unknown text" : "nezināms teksts",
-    "Hello world!" : "Sveika, pasaule!",
-    "sunny" : "saulains",
-    "Hello {name}, the weather is {weather}" : "Sveiciens, {name}, laikapstākļi ir {weather}",
-    "Hello {name}" : "Sveiciens, {name}",
-    "new" : "jauns",
-    "_download %n file_::_download %n files_" : ["lejupielādēt %n datņu","lejupielādēt %n datni","lejupielādēt %n datnes"],
-    "Searching …" : "Meklē...",
-    "Logging in …" : "Notiek pieteikšanās …",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Mēs esam noteikuši vairākus nederīgus pieteikšanās mēģinājumus no šīs IP adreses, tādējādi nākamā pieteikšanās ir ierobežota līdz 30 sekundēm.",
-    "Loading apps …" : "Notiek lietotņu ielāde ...",
-    "Installing apps …" : "Notiek lietotņu instalēšana ...",
-    "Loading your contacts …" : "Notiek kontaktpersonu ielāde...",
-    "Looking for {term} …" : "Meklē {term} …",
-    "Search contacts …" : "Meklēt kontaktpersonu",
-    "Saving …" : "Saglabā ...",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Tērzēšana, videozvani, ekrāna kopīgošana, tiešsaistes sapulces un tīmekļa apspriedes - pārlūkā un viedierīču lietotnēs.",
+    "You have not added any info yet" : "Vēl nav pievienota nekāda informācija",
+    "{user} has not added any info yet" : "{user} vēl nav pievienojis nekādu informāciju ",
+    "Edit Profile" : "Labot profilu",
     "Very weak password" : "Ļoti vāja parole",
     "Weak password" : "Vāja parole",
     "So-so password" : "Viduvēja parole",
     "Good password" : "Laba parole",
     "Strong password" : "Spēcīga parole",
-    "No action available" : "Nav pieejamu darbību",
-    "Error fetching contact actions" : "Kļūda rodot kontaktpersonām piemērojamās darbības",
     "Non-existing tag #{tag}" : "Neesoša birka #{tag}",
     "Restricted" : "Ierobežota",
+    "Invisible" : "Neredzama",
     "Delete" : "Izdzēst",
     "Rename" : "Pārdēvēt",
     "Collaborative tags" : "Sadarbības birkas",
@@ -292,9 +298,6 @@ OC.L10N.register(
     "Toggle password visibility" : "Pārslēgt paroles redzamību",
     "Configure the database" : "Konfigurēt datubāzi",
     "Only %s is available." : "Tikai %s ir pieejams.",
-    "Database account" : "Datubāzes konts",
-    "Please log in before granting %1$s access to your %2$s account." : "Lūgums pieteikties pirms piekļuves piešķiršanas %1$s savam %2$s kontam.",
-    "Currently logged in as %1$s (%2$s)." : "Pašreiz pieteicies kā %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Tu grasies piešķirt %1$s piekļuvi savam %2$s kontam."
+    "Database account" : "Datubāzes konts"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
