@@ -56,6 +56,14 @@ OC.L10N.register(
     "The following apps have been disabled: %s" : "Las aplicacions seguentas son estadas desactivadas : %s",
     "Already up to date" : "Ja a jorn",
     "Unknown" : "Desconegut",
+    "unknown text" : "tèxt desconegut",
+    "Hello world!" : "Adieu monde !",
+    "sunny" : "ensolelhat",
+    "Hello {name}, the weather is {weather}" : "Adiu {name}, lo temps es {weather}",
+    "Hello {name}" : "Adiu {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Vaquí vòstres resultats de recèrca<script>alert(1)</script></strong>",
+    "new" : "nòu",
+    "_download %n file_::_download %n files_" : ["telecargar %n fichièr","telecargar %n fichièrs"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "La mesa a jorn es en cors, quitar aquesta pagina poiriá interrompre lo processús dins d’unes environaments.",
     "Update to {version}" : "Metre a jorn a {version}",
     "An error occurred." : "Una error s’es producha.",
@@ -68,14 +76,16 @@ OC.L10N.register(
     "_{count} notification_::_{count} notifications_" : ["{count} notificacion","{count} notificacions"],
     "No" : "No",
     "Yes" : "Yes",
-    "Grant access" : "Donar accès",
+    "Searching …" : "Recèrca…",
     "Start typing to search" : "Començatz de picar per recercar",
     "Today" : "Uèi",
     "Date" : "Data",
     "People" : "Gent",
     "Load more results" : "Cargar mai de resultats",
     "Log in" : "Connexion",
+    "Logging in …" : "Identificacion…",
     "Log in to {productName}" : "Se connectar a {productName}",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Avèm detectat mantun ensag invalid de connexion a partir de vòstra IP. Per consequent vòstra connexion venenta serà en pausa per 30 segondas.",
     "Account name or email" : "Nom d’utilizaire o email",
     "Server side authentication failed!" : "Autentificacion costat servidor fracassada !",
     "Please contact your administrator." : "Mercés de contactar vòstre administrator.",
@@ -99,21 +109,19 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "Gardatz vòstres companhs e amics a un sòl lòc sens divulgar lor vida privada.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicacion simpla e simpatica de corrièl integrada a Fichièrs, Contactes e Calendièr.",
     "Recommended apps" : "Aplicacions recomandadas",
+    "Loading apps …" : "Cargament aplicacions…",
     "App download or installation failed" : "Telecargament o installacion de l’aplicacion fracassada",
     "Cannot install this app because it is not compatible" : "Impossibla d’installar aquesta app perque es pas compatibla",
     "Cannot install this app" : "Impossible d’installar aquesta app",
     "Skip" : "Sautar",
+    "Installing apps …" : "Installacion aplicacions…",
     "Install recommended apps" : "Installar las aplicacions recomandadas",
-    "Online" : "En linha",
-    "Away" : "Absent",
-    "Busy" : "Ocupat",
-    "Do not disturb" : "Me desturbes pas",
-    "Mute all notifications" : "Amudir totas las notificacions",
-    "Invisible" : "Invisible",
-    "Appear offline" : "Aparéisser fòra linha",
     "Settings menu" : "Menú paramètres",
+    "Loading your contacts …" : "Cargaments dels contactes…",
+    "Looking for {term} …" : "Recèrca de {term}…",
     "Search contacts" : "Cercar pels contactes",
     "Reset search" : "Escafar la recèrca",
+    "Search contacts …" : "Cercar pels contactes…",
     "Could not load your contacts" : "Cargament impossible de vòstres contactes",
     "No contacts found" : "Cap de contact pas trobat",
     "Install the Contacts app" : "Installar l’aplicacion Contactes",
@@ -121,18 +129,12 @@ OC.L10N.register(
     "No results for {query}" : "Cap de resultat per {query}",
     "An error occurred while searching for {type}" : "Una error s’es producha en cercant {type}",
     "Search for {name} only" : "Cercar sonque {name}",
+    "Loading more results …" : "Cargament de mai de resultats…",
     "Forgot password?" : "Senhal oblidat ?",
     "Back" : "Retorn",
     "Login form is disabled." : "Lo formulari de connexion es desactivat.",
-    "Connect to your account" : "Connectatz-vos a vòstre compte",
-    "Security warning" : "Avertiment de seguretat",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se ensajatz pas de configurar un periferic novèl o una aplicacion novèla, qualqu’un ensaja de vos far donar accès a vòstras donadas. En aqueste cas, contunhetz pas e contactatz vòstre administrator sistèma.",
-    "Alternative log in using app password" : "Connexion alternativa en utilizant un senhal d’aplicacion",
-    "Account connected" : "Compte connectat",
-    "Your client should now be connected!" : "Vòstre client deu èsser connectat ara !",
-    "You can close this window." : "Podètz tampar aquesta fenèstra.",
-    "Account access" : "Accès compte",
     "More actions" : "Mai d’accions",
+    "Security warning" : "Avertiment de seguretat",
     "Storage & database" : "Emmagazinatge & basa de donada",
     "Data folder" : "Dossièr de donadas",
     "Install and activate additional PHP modules to choose other database types." : "Installatz e activatz los modules PHP complementaris per causir d’autres tipes de basas de donadas.",
@@ -147,12 +149,14 @@ OC.L10N.register(
     "Database tablespace" : "Tablespace basa de donadas",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Volgatz especificar lo numèro de pòrt aprèp lo nom d’òste (ex : localhost:5432).",
     "Database host" : "Òste basa de donadas",
+    "Installing …" : "Installacion...",
     "Install" : "Installar",
     "Need help?" : "Besonh d’ajuda ?",
     "See the documentation" : "Vejatz la documentacion",
     "{name} version {version} and above" : "{name} version {version} e ulterior",
     "This browser is not supported" : "Aqueste navigador es pas pres en carga",
     "Supported versions" : "Versions presas en carga",
+    "Search {types} …" : "Recèrca {types}…",
     "Choose" : "Causir",
     "Copy" : "Copiar",
     "Move" : "Move",
@@ -168,8 +172,7 @@ OC.L10N.register(
     "Continue" : "Contunhar",
     "(all selected)" : "(totes seleccionats)",
     "({count} selected)" : "({count} seleccionats)",
-    "Group list is empty" : "La lista de grop es voida",
-    "Unable to retrieve the group list" : "Recuperacion de la lista de grops impossibla",
+    "Saving …" : "Enregistrament…",
     "seconds ago" : "fa qualques segondas",
     "Connection to server lost" : "Connexion al servidor perduda",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problèma de cargar de la pagina, actualizacion d’aquí %n seconda","Problèma de cargar de la pagina, actualizacion d’aquí %n secondas"],
@@ -183,6 +186,8 @@ OC.L10N.register(
     "Connect items to a project to make them easier to find" : "Connectatz d’elements a un projècte per lo rendre mai simples de trobar",
     "New in" : "Nòu dins",
     "View changelog" : "Veire jornal de modificacions",
+    "No action available" : "Cap d’accion pas disponibla",
+    "Error fetching contact actions" : "Error en recuperacion las accions contacte",
     "Personal" : "Personal",
     "Accounts" : "Accounts",
     "Admin" : "Admin",
@@ -213,6 +218,17 @@ OC.L10N.register(
     "Skip to navigation of app" : "Passar a la navegacion d’aplications",
     "Go to %s" : "Anar a %s",
     "Get your own free account" : "Obtenètz vòstre pròpri compte gratuit",
+    "Connect to your account" : "Connectatz-vos a vòstre compte",
+    "Please log in before granting %1$s access to your %2$s account." : "Autentificatz-vos abans de donnar l’accès a %1$s a vòstre compte %2$s.",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se ensajatz pas de configurar un periferic novèl o una aplicacion novèla, qualqu’un ensaja de vos far donar accès a vòstras donadas. En aqueste cas, contunhetz pas e contactatz vòstre administrator sistèma.",
+    "Grant access" : "Donar accès",
+    "Alternative log in using app password" : "Connexion alternativa en utilizant un senhal d’aplicacion",
+    "Account access" : "Accès compte",
+    "Currently logged in as %1$s (%2$s)." : "Actualament connectat coma %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Sètz a mand de donar accès a vòstra compte %2$s a %1$s.",
+    "Account connected" : "Compte connectat",
+    "Your client should now be connected!" : "Vòstre client deu èsser connectat ara !",
+    "You can close this window." : "Podètz tampar aquesta fenèstra.",
     "Previous" : "Precedent",
     "This share is password-protected" : "Aqueste partiment es protegit per un senhal",
     "Email address" : "Adreça mail",
@@ -246,48 +262,31 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "L’instància %s es actualament en mòde manteniment, pòt trigar.",
     "This page will refresh itself when the instance is available again." : "Aquesta pagina s’actualizarà soleta quand l’instància serà disponibla de nòu.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contactatz l’administrator sistèma s’aqueste messatge ten d’aparéisser o apareis sens rason.",
+    "No temporary profile picture available, try again" : "Cap d’imatge de perfil temporari pas disponible, tornatz ensajar",
+    "No crop data provided" : "Cap de donada de produccion",
+    "No valid crop data provided" : "Cap de donada pas valida pas provesida",
+    "Crop is not square" : "Lo retalhatge es pas carrat",
     "Error occurred while checking server setup" : "Error producha pendent la verificacion de l’installacion del servidor",
-    "unknown text" : "tèxt desconegut",
-    "Hello world!" : "Adieu monde !",
-    "sunny" : "ensolelhat",
-    "Hello {name}, the weather is {weather}" : "Adiu {name}, lo temps es {weather}",
-    "Hello {name}" : "Adiu {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Vaquí vòstres resultats de recèrca<script>alert(1)</script></strong>",
-    "new" : "nòu",
-    "_download %n file_::_download %n files_" : ["telecargar %n fichièr","telecargar %n fichièrs"],
-    "Searching …" : "Recèrca…",
-    "Logging in …" : "Identificacion…",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Avèm detectat mantun ensag invalid de connexion a partir de vòstra IP. Per consequent vòstra connexion venenta serà en pausa per 30 segondas.",
-    "Loading apps …" : "Cargament aplicacions…",
-    "Installing apps …" : "Installacion aplicacions…",
-    "Loading your contacts …" : "Cargaments dels contactes…",
-    "Looking for {term} …" : "Recèrca de {term}…",
-    "Search contacts …" : "Cercar pels contactes…",
-    "Loading more results …" : "Cargament de mai de resultats…",
-    "Search {types} …" : "Recèrca {types}…",
-    "Saving …" : "Enregistrament…",
+    "Edit Profile" : "Modificar perfil",
     "Very weak password" : "Senhal plan feble",
     "Weak password" : "Senhal feble",
     "So-so password" : "Senhal mejan",
     "Good password" : "Bon senhal",
     "Strong password" : "Senhal fòrt",
-    "No action available" : "Cap d’accion pas disponibla",
-    "Error fetching contact actions" : "Error en recuperacion las accions contacte",
     "Non-existing tag #{tag}" : "Etiqueta inexistenta #{tag}",
     "Restricted" : "Restrencha",
+    "Invisible" : "Invisible",
     "Delete" : "Suprimir",
     "Rename" : "Renomenar",
     "Collaborative tags" : "Etiquetas collaborativas",
     "No tags found" : "Cap d’etiqueta pas trobada",
+    "Profile not found" : "Perfil pas trobat",
+    "The profile does not exist." : "Lo perfil existís pas.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Vòstre repertòri de donadas e vòstres fichièrs son probablament accessibles a partir d’internet pr’amor que lo fichièr .htaccess fonciona pas.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Per d’informacions per corrèctament configurar vòstre servidor, consultatz la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentacion</a>.",
     "Show password" : "Mostrar lo senhal",
     "Toggle password visibility" : "Alternar la visibilitat del senhal",
     "Configure the database" : "Configurar la basa de donadas",
-    "Only %s is available." : "Sonque %s es disponible.",
-    "Installing …" : "Installacion...",
-    "Please log in before granting %1$s access to your %2$s account." : "Autentificatz-vos abans de donnar l’accès a %1$s a vòstre compte %2$s.",
-    "Currently logged in as %1$s (%2$s)." : "Actualament connectat coma %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Sètz a mand de donar accès a vòstra compte %2$s a %1$s."
+    "Only %s is available." : "Sonque %s es disponible."
 },
 "nplurals=2; plural=(n > 1);");
