@@ -42,7 +42,6 @@ OC.L10N.register(
     "Not found" : "Não  encontrado",
     "Node is locked" : "O nó está bloqueado",
     "Bad request" : "Pedido incorreto",
-    "Input text is too long" : "O texto de entrada é muito longo.",
     "Requested task type does not exist" : "O tipo de tarefa solicitado não existe",
     "Necessary language model provider is not available" : "O fornecedor do modelo linguístico necessário não está disponível",
     "No text to image provider is available" : "Não está disponível nenhum fornecedor de texto para imagem",
@@ -50,7 +49,6 @@ OC.L10N.register(
     "No translation provider available" : "Nenhum fornecedor de tradução disponível",
     "Could not detect language" : "Não foi possível detetar o idioma",
     "Unable to translate" : "Não é possível traduzir",
-    "No valid filters provided" : "Não foram fornecidos filtros válidos",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Etapa da reparação:",
     "Repair info:" : "Informação da reparação:",
@@ -198,6 +196,14 @@ OC.L10N.register(
     "Matroska video" : "Vídeo Matroska",
     "Windows Media video" : "Vídeo Windows Media",
     "AVI video" : "Vídeo AVI",
+    "unknown text" : "texto desconhecido",
+    "Hello world!" : "Olá, mundo!",
+    "sunny" : "soalheiro",
+    "Hello {name}, the weather is {weather}" : "Olá {name}, o tempo está {weather}",
+    "Hello {name}" : "Olá {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Resultados da pesquisa<script>alert(1)</script></strong>",
+    "new" : "novo",
+    "_download %n file_::_download %n files_" : ["transferir %n ficheiro","transferir %n ficheiros","transferir %n ficheiros"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "A atualização está em progresso. Se sair desta página poderá interromper o processo em alguns ambientes.",
     "Update to {version}" : "Atualizar para {version}",
     "An error occurred." : "Ocorreu um erro.",
@@ -206,15 +212,12 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "A atualização não foi bem sucedida. Por favor, reporte este problema à <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidade de Nextcloud</a>.",
     "Continue to {productName}" : "Continuar para {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["A atualização foi concluída. A redirecionar para {productName} dentro de %n segundo.","A atualização foi concluída. A redirecionar para {productName} dentro de %n segundos.","A atualização foi concluída. A redirecionar para {productName} dentro de %n segundos."],
-    "Done" : "Concluído",
     "Applications menu" : "Menu de Aplicações",
     "Apps" : "Aplicações",
     "More apps" : "Mais aplicações",
     "_{count} notification_::_{count} notifications_" : ["{count} notificação","{count} notificações","{count} notificações"],
     "No" : "Não",
     "Yes" : "Sim",
-    "App password" : "Palavra‑passe de aplicação",
-    "Grant access" : "Conceder acesso",
     "The remote URL must include the user." : "O URL remoto tem de incluir o utilizador.",
     "Invalid remote URL." : "URL remoto inválido.",
     "Failed to add the public link to your Nextcloud" : "Não foi possível adicionar a hiperligação pública ao seu Nextcloud",
@@ -230,16 +233,14 @@ OC.L10N.register(
     "Search in current app" : "Pesquisar na aplicação atual",
     "Clear search" : "Limpar pesquisa",
     "Search everywhere" : "Pesquisar em todo o lado",
-    "Searching …" : "A procurar…",
+    "Searching …" : "A procurar…",
     "Start typing to search" : "Comece a digitar para procurar",
-    "Minimum search length is {minSearchLength} characters" : "O comprimento mínimo da pesquisa é de {minSearchLength} caracteres.",
     "No matching results" : "Sem resultados correspondentes",
     "Today" : "Hoje",
     "Last 7 days" : "Últimos 7 dias",
     "Last 30 days" : "Últimos 30 dias",
     "This year" : "Este ano",
     "Last year" : "Ano passado",
-    "Between {startDate} and {endDate}" : "Entre {startDate} e {endDate}",
     "Unified search" : "Pesquisa unificada",
     "Search apps, files, tags, messages" : "Pesquisar aplicações, ficheiros, etiquetas, mensagens",
     "Places" : "Locais",
@@ -252,10 +253,11 @@ OC.L10N.register(
     "Load more results" : "Mostrar mais resultados",
     "Search in" : "Pesquisar em",
     "Log in" : "Iniciar sessão",
-    "Logging in …" : "A iniciar a sessão...",
+    "Logging in …" : "A iniciar a sessão...",
     "Log in to {productName}" : "Inicie sessão em {productName}",
     "Wrong login or password." : "Início de sessão ou palavra‑passe incorretos.",
     "This account is disabled" : "Esta conta está desativada",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Nós detetamos múltiplas tentativas falhadas de autenticação com o seu IP. Por isso, a sua próxima autenticação será adiada até 30 segundos. ",
     "Account name or email" : "Nome da conta ou email",
     "Account name" : "Nome da conta",
     "Server side authentication failed!" : "Autenticação do lado do servidor falhou!",
@@ -265,7 +267,6 @@ OC.L10N.register(
     "An internal error occurred." : "Ocorreu um erro interno.",
     "Please try again or contact your administrator." : "Por favor, tente novamente ou contacte o seu administrador.",
     "Password" : "Palavra-passe",
-    "Remember me" : "Lembre-se de mim",
     "Log in with a device" : "Iniciar sessão com um dispositivo",
     "Login or email" : "Utilizador ou email",
     "Your account is not setup for passwordless login." : "A sua conta não está configurada para autenticação sem palavra-passe.",
@@ -289,28 +290,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documentos, folhas de cálculo e apresentações colaborativas baseadas no Collabora Online.",
     "Distraction free note taking app." : "Aplicação de notas sem distrações.",
     "Recommended apps" : "Aplicações recomendadas",
-    "Loading apps …" : "A carregar aplicações...",
+    "Loading apps …" : "A carregar aplicações...",
     "Could not fetch list of apps from the App Store." : "Não foi possível obter a lista de aplicações da App Store.",
     "App download or installation failed" : "A transferência ou a instalação desta aplicação falhou",
     "Cannot install this app because it is not compatible" : "Não é possível instalar esta aplicação por não ser compatível",
     "Cannot install this app" : "Não é possível instalar esta aplicação",
     "Skip" : "Ignorar",
-    "Installing apps …" : "A instalar aplicações ...",
+    "Installing apps …" : "A instalar aplicações ...",
     "Install recommended apps" : "Instalar aplicações recomendadas",
-    "Online" : "On-line",
-    "Away" : "Ausente",
-    "Busy" : "Ocupado",
-    "Do not disturb" : "Não incomodar",
-    "Mute all notifications" : "Desativar todas as notificações",
-    "Invisible" : "Invisível ",
-    "Appear offline" : "Aparecer offline",
     "Avatar of {displayName}" : "Avatar de {displayName}",
     "Settings menu" : "Menu de definições",
-    "Loading your contacts …" : "A carregar os seus contactos...",
-    "Looking for {term} …" : "A procurar por {term} …",
+    "Loading your contacts …" : "A carregar os seus contactos...",
+    "Looking for {term} …" : "A procurar por {term} …",
     "Search contacts" : "Pesquisar contactos",
     "Reset search" : "Redefinir pesquisa",
-    "Search contacts …" : "Procurar contactos...",
+    "Search contacts …" : "Procurar contactos...",
     "Could not load your contacts" : "Não foi possível carregar os seus contactos",
     "No contacts found" : "Não foram encontrados contactos",
     "Show all contacts" : "Mostrar todos os contactos",
@@ -322,20 +316,12 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Ocorreu um erro enquanto pesquisava por {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "A pesquisa começa quando começar a escrever e os resultados podem ser percorridos com as teclas de seta",
     "Search for {name} only" : "Pesquisar apenas por {name}",
-    "Loading more results …" : "A carregar mais resultados...",
+    "Loading more results …" : "A carregar mais resultados...",
     "Forgot password?" : "Senha esquecida?",
     "Back to login form" : "Voltar ao formulário de início de sessão",
     "Back" : "Anterior",
     "Login form is disabled." : "O formulário de início de sessão está desativado.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "O formulário de início de sessão do Nextcloud está desativado. Utilize outra opção de início de sessão, se disponível, ou contacte a administração.",
-    "Connect to your account" : "Ligar à sua conta",
-    "Security warning" : "Aviso de segurança",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se não está a tentar configurar um novo dispositivo ou aplicação, alguém pode estar a tentar aceder à sua conta. Não prossiga e contacte o administrador do sistema.",
-    "Alternative log in using app password" : "Início de sessão alternativo usando palavra‑passe de aplicação",
-    "Account connected" : "Conta ligada",
-    "Your client should now be connected!" : "O seu cliente deveria agora estar ligado!",
-    "You can close this window." : "Pode fechar esta janela.",
-    "Account access" : "Acesso à conta",
     "More actions" : "Mais ações",
     "User menu" : "Menu do utilizador",
     "Your guest name: {user}" : "O seu nome de convidado: {user}",
@@ -353,13 +339,13 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Para saber como configurar corretamente o seu servidor, {linkStart}consulte a documentação{linkEnd}",
     "Autoconfig file detected" : "Ficheiro de configuração automática detetado",
     "The setup form below is pre-filled with the values from the config file." : "O formulário de configuração abaixo foi preenchido com os valores do ficheiro de configuração.",
+    "Security warning" : "Aviso de segurança",
     "Create administration account" : "Criar conta de administração",
     "Administration account name" : "Nome da conta de administração",
     "Administration account password" : "Palavra‑passe da conta de administração",
     "Storage & database" : "Armazenamento e base de dados",
     "Data folder" : "Pasta de dados",
     "Database configuration" : "Configuração da base de dados",
-    "Database type" : "Tipo de base de dados",
     "Only {firstAndOnlyDatabase} is available." : "Apenas {firstAndOnlyDatabase} está disponível.",
     "Install and activate additional PHP modules to choose other database types." : "Instale e ative os módulos PHP adicionais para escolher outros tipos de base de dados.",
     "For more details check out the documentation." : "Para mais detalhes consulte a documentação.",
@@ -367,7 +353,6 @@ OC.L10N.register(
     "You chose SQLite as database." : "Escolheu SQLite como base de dados",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "A SQLite só deve ser usada em instâncias mínimas e de desenvolvimento. Para produção, recomendamos um motor de base de dados diferente.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Se utiliza clientes para a sincronização de ficheiros, a utilização de SQLite é altamente desencorajada.",
-    "Database connection" : "Ligação com a base de dados",
     "Database user" : "Utilizador da base de dados",
     "Database password" : "Palavra-passe da base de dados",
     "Database name" : "Nome da base de dados",
@@ -375,7 +360,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor, especifique o número da porta com o nome do anfitrião (por exemplo, localhost:5432).",
     "Database host" : "Anfitrião da base de dados",
     "localhost" : "localhost",
-    "Installing …" : "A instalar...",
+    "Installing …" : "A instalar...",
     "Install" : "Instalar",
     "Need help?" : "Precisa de ajuda?",
     "See the documentation" : "Consulte a documentação",
@@ -384,7 +369,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "O seu navegador não é suportado. Por favor, atualize para uma versão mais recente ou para um suportado.",
     "Continue with this unsupported browser" : "Continuar com este navegador não suportado",
     "Supported versions" : "Versões suportadas",
-    "Search {types} …" : "Pesquisar {types}...",
+    "Search {types} …" : "Pesquisar {types}...",
     "Choose {file}" : "Escolher {file}",
     "Choose" : "Escolher",
     "Copy to {target}" : "Copiar para {target}",
@@ -404,10 +389,7 @@ OC.L10N.register(
     "(all selected)" : "(todos selecionados)",
     "({count} selected)" : "({count} selecionados)",
     "Error loading file exists template" : "Ocorreu um erro ao carregar o ficheiro do modelo existente",
-    "Saving …" : "A guardar ...",
-    "Groups" : "Grupos",
-    "Group list is empty" : "Lista de grupo vazia",
-    "Unable to retrieve the group list" : "Não foi possível recolher a lista de grupo",
+    "Saving …" : "A guardar...",
     "seconds ago" : "segundos atrás",
     "Connection to server lost" : "Ligação perdida ao servidor",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema a carregar a página. A recarregar em %n segundo","Problema ao carregar a página. A recarregar em  %n segundos","Problema ao carregar a página. A recarregar em %n segundos"],
@@ -422,6 +404,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "Digite para procurar por projetos existentes",
     "New in" : "Novo em",
     "View changelog" : "Ver registo de alterações",
+    "No action available" : "Nenhuma ação disponível",
+    "Error fetching contact actions" : "Erro ao obter ações dos contactos",
     "Close \"{dialogTitle}\" dialog" : "Fechar diálogo \"{dialogTitle}\"",
     "Email length is at max (255)" : "O tamanho do email atingiu o máximo (255)",
     "Clipboard not available, please copy manually" : "Área de transferência indisponível, copie manualmente",
@@ -458,6 +442,18 @@ OC.L10N.register(
     "Skip to navigation of app" : "Ir para a navegação da aplicação",
     "Go to %s" : "Ir para %s",
     "Get your own free account" : "Obtenha a sua própria conta grátis",
+    "Connect to your account" : "Ligar à sua conta",
+    "Please log in before granting %1$s access to your %2$s account." : "Por favor, autentique-se antes de permitir o acesso de %1$s à sua conta %2$s.",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se não está a tentar configurar um novo dispositivo ou aplicação, alguém pode estar a tentar aceder à sua conta. Não prossiga e contacte o administrador do sistema.",
+    "App password" : "Palavra‑passe de aplicação",
+    "Grant access" : "Conceder acesso",
+    "Alternative log in using app password" : "Início de sessão alternativo usando palavra‑passe de aplicação",
+    "Account access" : "Acesso à conta",
+    "Currently logged in as %1$s (%2$s)." : "Atualmente com sessão iniciada como %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Está prestes a permitir que %1$s aceda à sua conta %2$s. ",
+    "Account connected" : "Conta ligada",
+    "Your client should now be connected!" : "O seu cliente deveria agora estar ligado!",
+    "You can close this window." : "Pode fechar esta janela.",
     "Previous" : "Anterior",
     "This share is password-protected" : "Esta partilha está protegida por palavra-passe",
     "The password is wrong or expired. Please try again or request a new one." : "A palavra‑passe está errada ou expirou. Tente novamente ou solicite uma nova.",
@@ -497,41 +493,32 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instância %s está atualmente no modo de manutenção, o que poderá demorar algum tempo.",
     "This page will refresh itself when the instance is available again." : "Esta página irá ser atualizada quando a instância ficar novamente disponível.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte o seu administrador do sistema se esta mensagem persistir ou apareceu inesperadamente.",
+    "No temporary profile picture available, try again" : "Nenhuma imagem de perfil temporária disponível, tente novamente",
+    "No crop data provided" : "Não foram fornecidos dados de recorte",
+    "No valid crop data provided" : "Não foram indicados dados de recorte válidos",
+    "Crop is not square" : "O recorte não é quadrado",
     "Error occurred while checking server setup" : "Ocorreu um erro durante a verificação da configuração do servidor",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Para mais pormenores, consultar o {linkstart}documentação ↗{linkend}.",
-    "unknown text" : "texto desconhecido",
-    "Hello world!" : "Olá, mundo!",
-    "sunny" : "soalheiro",
-    "Hello {name}, the weather is {weather}" : "Olá {name}, o tempo está {weather}",
-    "Hello {name}" : "Olá {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Resultados da pesquisa<script>alert(1)</script></strong>",
-    "new" : "novo",
-    "_download %n file_::_download %n files_" : ["transferir %n ficheiro","transferir %n ficheiros","transferir %n ficheiros"],
-    "Direct link copied to clipboard" : "Ligação direta copiada para a área de transferência",
-    "Searching …" : "A procurar…",
-    "Logging in …" : "A iniciar a sessão...",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Nós detetamos múltiplas tentativas falhadas de autenticação com o seu IP. Por isso, a sua próxima autenticação será adiada até 30 segundos. ",
-    "Loading apps …" : "A carregar aplicações...",
-    "Installing apps …" : "A instalar aplicações ...",
-    "Loading your contacts …" : "A carregar os seus contactos...",
-    "Looking for {term} …" : "A procurar por {term} …",
-    "Search contacts …" : "Procurar contactos...",
-    "Loading more results …" : "A carregar mais resultados...",
-    "Search {types} …" : "Pesquisar {types}...",
-    "Saving …" : "A guardar...",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Conversação, videochamadas, partilha de ecrã, reuniões online e conferências web – no navegador e em aplicações móveis.",
+    "You have not added any info yet" : "Ainda não adicionou qualquer informação ",
+    "{user} has not added any info yet" : "{user} ainda não adicionou qualquer informação",
+    "Error opening the user status modal, try hard refreshing the page" : "Erro ao abrir o modal de estado do utilizador; tente atualizar a página forçadamente",
+    "Edit Profile" : "Editar perfil",
+    "The headline and about sections will show up here" : "Os campos de título e sobre aparecerão aqui",
     "Very weak password" : "Palavra-passe muito fraca",
     "Weak password" : "Palavra-passe fraca",
     "So-so password" : "Palavra-passe aceitável",
     "Good password" : "Palavra-passe boa",
     "Strong password" : "Palavra-passe forte",
-    "No action available" : "Nenhuma ação disponível",
-    "Error fetching contact actions" : "Erro ao obter ações dos contactos",
     "Non-existing tag #{tag}" : "Etiqueta não existente #{tag}",
     "Restricted" : "Restrito",
+    "Invisible" : "Invisível ",
     "Delete" : "Eliminar",
     "Rename" : "Renomear",
     "Collaborative tags" : "Etiquetas colaborativas",
     "No tags found" : "Não foram encontradas etiquetas",
+    "Profile not found" : "Perfil não encontrado",
+    "The profile does not exist." : "O perfil não existe.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "A pasta de dados e os respetivos ficheiros estão provavelmente acessíveis a partir da internet pois o ficheiro .htaccess não funciona.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para obter informações de como configurar corretamente o servidor, veja em: <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentação</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Criar uma conta de administrador</strong>",
@@ -542,9 +529,6 @@ OC.L10N.register(
     "Configure the database" : "Configure a base de dados",
     "Only %s is available." : "Só está disponível %s.",
     "Database account" : "Conta da base de dados",
-    "Installing …" : "A instalar...",
-    "Please log in before granting %1$s access to your %2$s account." : "Por favor, autentique-se antes de permitir o acesso de %1$s à sua conta %2$s.",
-    "Currently logged in as %1$s (%2$s)." : "Atualmente com sessão iniciada como %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Está prestes a permitir que %1$s aceda à sua conta %2$s. "
+    "Direct link copied to clipboard" : "Ligação direta copiada para a área de transferência"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
