@@ -75,6 +75,14 @@ OC.L10N.register(
     "The following apps have been disabled: %s" : "Următoarele aplicații au fost dezactivate: %s",
     "Already up to date" : "Deja actualizat",
     "Unknown" : "Necunoscut",
+    "unknown text" : "text necunoscut",
+    "Hello world!" : "Hello world!",
+    "sunny" : "însorit",
+    "Hello {name}, the weather is {weather}" : "Bună {name}, vremea este {weather}",
+    "Hello {name}" : "Salut {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Acestea sunt rezultatele căutării tale<script>alert(1)</script></strong>",
+    "new" : "nou",
+    "_download %n file_::_download %n files_" : ["descarcă %n fișier","descarcă %n fișiere","descarcă %n fișiere"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Actualizarea este în desfășurare, părăsirea acestei pagini ar putea întrerupe procesul în anumite medii.",
     "Update to {version}" : "Actualizare la {version}",
     "An error occurred." : "A apărut o eroare.",
@@ -95,6 +103,7 @@ OC.L10N.register(
     "Pick end date" : "Selectează o dată de sfârșit",
     "Search in date range" : "Caută în intervalul",
     "Search everywhere" : "Caută oriunde",
+    "Searching …" : "Căutare ...",
     "Start typing to search" : "Tastați pentru căutare",
     "No matching results" : "Niciun rezultat găsit",
     "Today" : "Azi",
@@ -113,6 +122,7 @@ OC.L10N.register(
     "Load more results" : "Încarcă mai multe rezultate",
     "Search in" : "Caută în",
     "Log in" : "Autentificare",
+    "Logging in …" : "Se autentifică...",
     "Log in to {productName}" : "Logare la {productName}",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Au fost detectate mai multe încercări de logare eșuate de la adresa dumneavoastră IP. De aceea, următoarea încercare va fi încetinită până la 30 de secunde.",
     "Account name or email" : "Cont utilizator sau email",
@@ -141,16 +151,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documente colaborative, foi de calcul și prezentări, create în Collabora Online.",
     "Distraction free note taking app." : "Aplicație simplă pentru note",
     "Recommended apps" : "Aplicații recomandate",
+    "Loading apps …" : "Se încarcă aplicațiile ...",
     "Could not fetch list of apps from the App Store." : "Nu s-a putut prelua lista aplicațiilor din App Store.",
     "App download or installation failed" : "Descărcarea și instalarea aplicației a eșuat",
     "Cannot install this app because it is not compatible" : "Nu se poate instala aplicația deoarece este incompatibilă",
     "Cannot install this app" : "Nu se poate instala această aplicație",
     "Skip" : "Sari peste",
+    "Installing apps …" : "Se instalează aplicațiile ...",
     "Install recommended apps" : "Instalați aplicațiile recomandate",
     "Avatar of {displayName}" : "Avatarul {displayName}",
     "Settings menu" : "Meniul Setări",
+    "Loading your contacts …" : "Se încarcă contactele ...",
+    "Looking for {term} …" : "Se caută  {term} …",
     "Search contacts" : "Cautare contacte",
     "Reset search" : "Resetează căutarea",
+    "Search contacts …" : "Caută contacte ...",
     "Could not load your contacts" : "Nu pot încarca contactele",
     "No contacts found" : "Nu s-au găsit contacte",
     "Show all contacts" : "Arată toate contactele",
@@ -162,6 +177,7 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Eroare la căutarea pentru {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Căutarea începe când tastați și navigarea în rezultate se face cu tastele săgeți",
     "Search for {name} only" : "Caută doar {name} ",
+    "Loading more results …" : "Se încarcă mai multe rezultate ...",
     "Forgot password?" : "Ai uitat parola?",
     "Back to login form" : "Înapoi la forma de login",
     "Back" : "Înapoi",
@@ -182,6 +198,7 @@ OC.L10N.register(
     "Database tablespace" : "Tabela de spațiu a bazei de date",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Specifică și numărul portului pe lângă hostname (ex: localhost;5432).",
     "Database host" : "Bază date",
+    "Installing …" : "Se instalează ...",
     "Install" : "Instalează",
     "Need help?" : "Ai nevoie de ajutor?",
     "See the documentation" : "Vezi documentația",
@@ -190,6 +207,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Browserul este incompatibil. Faceți upgrade la o versiune nouă.",
     "Continue with this unsupported browser" : "Continuă cu browserul incompatibil",
     "Supported versions" : "Versiuni compatibile",
+    "Search {types} …" : "Căutare {types} …",
     "Choose {file}" : "Selectați {file}",
     "Choose" : "Alege",
     "Copy to {target}" : "Copiază la {target}",
@@ -209,6 +227,7 @@ OC.L10N.register(
     "(all selected)" : "(toate selectate)",
     "({count} selected)" : "({count} selectate)",
     "Error loading file exists template" : "Eroare la încărcarea fișierelor șablon",
+    "Saving …" : "Se salvează",
     "seconds ago" : "secunde în urmă",
     "Connection to server lost" : "S-a pierdut conexiunea la server",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Probleme la încărcarea paginii, se reîncarcă într-o secundă","Probleme la încărcarea paginii, se reîncarcă în câteva secunde","Probleme la încărcarea paginii, se reîncarcă în %n secunde"],
@@ -223,6 +242,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "Tastați pentru căutarea proiectelor",
     "New in" : "Nou în",
     "View changelog" : "Vezi changelog",
+    "No action available" : "Nici o acțiune disponibilă",
+    "Error fetching contact actions" : "A apărut o eroare la preluarea activităților privind contactele",
     "Close \"{dialogTitle}\" dialog" : "Închide dialogul \"{dialogTitle}\"",
     "Personal" : "Personal",
     "Accounts" : "Conturi",
@@ -304,33 +325,23 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Instanța %s este acum în modul de mentenanță, ceea ce ar putea dura o vreme.",
     "This page will refresh itself when the instance is available again." : "Această pagină se va actualiza automat când instanța va fi disponibilă din nou.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contactează-ți administratorul de sistem dacă acest mesaj persistă sau a apărut neașteptat.",
+    "No temporary profile picture available, try again" : "Nu este disponibilă nicio imagine temporară a profilului, încearcă din nou",
+    "No crop data provided" : "Nu există informație pentru operațiunea crop",
+    "No valid crop data provided" : "Nu există informație validă pentru operațiunea crop",
+    "Crop is not square" : "Selecția nu este pătrată",
     "Error occurred while checking server setup" : "A apărut o eroare la verificarea configurației serverului",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Pentru mai multe detalii vedeți {linkstart}documentația ↗{linkend}.",
-    "unknown text" : "text necunoscut",
-    "Hello world!" : "Hello world!",
-    "sunny" : "însorit",
-    "Hello {name}, the weather is {weather}" : "Bună {name}, vremea este {weather}",
-    "Hello {name}" : "Salut {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Acestea sunt rezultatele căutării tale<script>alert(1)</script></strong>",
-    "new" : "nou",
-    "_download %n file_::_download %n files_" : ["descarcă %n fișier","descarcă %n fișiere","descarcă %n fișiere"],
-    "Searching …" : "Căutare ...",
-    "Logging in …" : "Se autentifică...",
-    "Loading apps …" : "Se încarcă aplicațiile ...",
-    "Installing apps …" : "Se instalează aplicațiile ...",
-    "Loading your contacts …" : "Se încarcă contactele ...",
-    "Looking for {term} …" : "Se caută  {term} …",
-    "Search contacts …" : "Caută contacte ...",
-    "Loading more results …" : "Se încarcă mai multe rezultate ...",
-    "Search {types} …" : "Căutare {types} …",
-    "Saving …" : "Se salvează",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chat, apeluri video, partajare ecran, întâlniri online și videoconferințe - în browser și cu aplicația mobilă.",
+    "You have not added any info yet" : "Nu ați adăugat nicio informație",
+    "{user} has not added any info yet" : "{user} nu a adăugat nicio informație",
+    "Error opening the user status modal, try hard refreshing the page" : "Eroare la deschiderea status utilizator, încercați refresh",
+    "Edit Profile" : "Editare profil",
+    "The headline and about sections will show up here" : "Secțiunile titlu și despre vor fi afișate aici",
     "Very weak password" : "Parolă foarte slabă",
     "Weak password" : "Parolă slabă",
     "So-so password" : "Parolă medie",
     "Good password" : "Parolă bună",
     "Strong password" : "Parolă puternică",
-    "No action available" : "Nici o acțiune disponibilă",
-    "Error fetching contact actions" : "A apărut o eroare la preluarea activităților privind contactele",
     "Non-existing tag #{tag}" : "Etichetă inexistentă #{tag}",
     "Restricted" : "Restricționat",
     "Invisible" : "Invizibil",
@@ -338,13 +349,14 @@ OC.L10N.register(
     "Rename" : "Redenumește",
     "Collaborative tags" : "Etichete colaborative",
     "No tags found" : "Nu au fost găsite etichete",
+    "Profile not found" : "Profil inexistent",
+    "The profile does not exist." : "Profilul nu există",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Directorul tău de date și fișiere sunt probabil accesibile de pe Internet, deoarece fișierul .htaccess nu funcționează.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pentru informații despre configurarea corectă a serverului, vedeți <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentația</a>.",
     "Show password" : "Arată parola",
     "Toggle password visibility" : "Vizibilitate parolă",
     "Configure the database" : "Configurează baza de date",
     "Only %s is available." : "Doar %s este disponibil.",
-    "Database account" : "Cont bază de date",
-    "Installing …" : "Se instalează ..."
+    "Database account" : "Cont bază de date"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
