@@ -197,6 +197,14 @@ OC.L10N.register(
     "Matroska video" : "Matroska видео",
     "Windows Media video" : "Windows Media видео",
     "AVI video" : "AVI видео",
+    "unknown text" : "непознат текст",
+    "Hello world!" : "Здраво свете!",
+    "sunny" : "сунчано",
+    "Hello {name}, the weather is {weather}" : "Здраво {name}, време је {weather}",
+    "Hello {name}" : "Здраво {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Ово су резултати Ваше претраге<script>alert(1)</script></strong>",
+    "new" : "ново",
+    "_download %n file_::_download %n files_" : ["преузми %n фајл","преузми %n фајла","преузми %n фајлова"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Ажурирање је у току. У неким окружењима, напуштање ове стране може да прекине овај процес.",
     "Update to {version}" : "Ажурирај на {version}",
     "An error occurred." : "Дошло је до грешке.",
@@ -226,7 +234,7 @@ OC.L10N.register(
     "Search in current app" : "Претражи у тренутној апликацији",
     "Clear search" : "Обриши претрагу",
     "Search everywhere" : "Претражи свуда",
-    "Searching …" : "Тражи се …",
+    "Searching …" : "Тражим…",
     "Start typing to search" : "Почните да куцате да бисте претраживали",
     "Minimum search length is {minSearchLength} characters" : "Минимална дужина претраге је {minSearchLength} карактера",
     "No matching results" : "Претрага није дала резултате",
@@ -248,7 +256,7 @@ OC.L10N.register(
     "Load more results" : "Учитај још резултата",
     "Search in" : "Претражи у",
     "Log in" : "Пријава",
-    "Logging in …" : "Пријављивање …",
+    "Logging in …" : "Пријављивање …",
     "Log in to {productName}" : "Пријавите се на {productName}",
     "Wrong login or password." : "Погрешно име за пријаву или лозинка",
     "This account is disabled" : "Овај налог је искључен",
@@ -285,28 +293,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Заједнички документи, табеле и презентације, изграђени на Collabora Online.",
     "Distraction free note taking app." : "Апликација за вођење бележака без ометања.",
     "Recommended apps" : "Препоручене апликације",
-    "Loading apps …" : "Учитавају се апликације …",
+    "Loading apps …" : "Учитавам апликације…",
     "Could not fetch list of apps from the App Store." : "Листа апликација није могла да се преузме са продавнице апликација.",
     "App download or installation failed" : "Скидање или инсталирање апликације није успело",
     "Cannot install this app because it is not compatible" : "Ова апликација не може да се инсталира јер није компатибилна",
     "Cannot install this app" : "Ова апликација не може да се инсталира",
     "Skip" : "Preskoči",
-    "Installing apps …" : "Инсталирају се апликације …",
+    "Installing apps …" : "Инсталирам апликације…",
     "Install recommended apps" : "Инсталирајте препоручене апликације",
-    "Online" : "На мрежи",
-    "Away" : "Одсутан",
-    "Busy" : "Заузет",
-    "Do not disturb" : "Не узнемиравај",
-    "Mute all notifications" : "Искључи сва обавештења",
-    "Invisible" : "Невидљива",
-    "Appear offline" : "Прикажи као ван мреже",
     "Avatar of {displayName}" : "Аватар корисника {displayName}",
     "Settings menu" : "Мени подешавања",
-    "Loading your contacts …" : "Учитавају се ваши контакти …",
-    "Looking for {term} …" : "Тражи се {term}  …",
+    "Loading your contacts …" : "Учитавам контакте ...",
+    "Looking for {term} …" : "Тражим {term} …",
     "Search contacts" : "Претрага контакта",
     "Reset search" : "Ресетуј претрагу",
-    "Search contacts …" : "Претрага контаката …",
+    "Search contacts …" : "Претражи контакте ...",
     "Could not load your contacts" : "Не могу да учитам Ваше контакте",
     "No contacts found" : "Контакти нису нађени",
     "Show all contacts" : "Прикажи све контакте",
@@ -318,7 +319,7 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Десила се грешка приликом тражења за {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Претрага започиње чим почнете да куцате и до резултата долазите курсорским тастерима",
     "Search for {name} only" : "Тражи само за {name}",
-    "Loading more results …" : "Учитава се још резултата …",
+    "Loading more results …" : "Учитавам још резултата…",
     "Forgot password?" : "Заборавили сте лозинку?",
     "Back to login form" : "Назад на формулар за пријаву",
     "Back" : "Назад",
@@ -348,7 +349,6 @@ OC.L10N.register(
     "Storage & database" : "Складиште и база података",
     "Data folder" : "Фасцикла за податке",
     "Database configuration" : "Конфигурација базе података",
-    "Database type" : "Тип базе података",
     "Only {firstAndOnlyDatabase} is available." : "Доступна је само {firstAndOnlyDatabase}.",
     "Install and activate additional PHP modules to choose other database types." : "Инсталирајте и активирајте додатне „ПХП“ модуле за одабир других база података.",
     "For more details check out the documentation." : "За више детаља погледајте документацију.",
@@ -356,7 +356,6 @@ OC.L10N.register(
     "You chose SQLite as database." : "Одабрали сте SQLite за базу података.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite треба да се користи само за најмање инстанце или за инстанце за развој. За продукцију, препоручујемо други тип база података.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Коришћење SQLite базе података нарочите није препоручљиво ако користите клијенте за синхронизацију фајлова.",
-    "Database connection" : "Веза са базом података",
     "Database user" : "Корисник базе",
     "Database password" : "Лозинка базе",
     "Database name" : "Назив базе",
@@ -364,7 +363,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Наведите и број порта у имену домаћина (нпр. localhost:5432).",
     "Database host" : "Домаћин базе",
     "localhost" : "локални хост",
-    "Installing …" : "Инсталира се …",
+    "Installing …" : "Инсталирам ...",
     "Install" : "Инсталирај",
     "Need help?" : "Треба вам помоћ?",
     "See the documentation" : "Погледајте документацију",
@@ -373,7 +372,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Ваш веб читач није подржан. Молимо вас да га ажурирате на новију верзију, или да инсталирате подржани читач.",
     "Continue with this unsupported browser" : "Настави са овим неподржаним читачем",
     "Supported versions" : "Подржане верзије",
-    "Search {types} …" : "Претрага {types} …",
+    "Search {types} …" : "Претражи {types}…",
     "Choose {file}" : "Изабери {file}",
     "Choose" : "Изаберите",
     "Copy to {target}" : "Копирај у {target}",
@@ -393,7 +392,7 @@ OC.L10N.register(
     "(all selected)" : "(све изабрано)",
     "({count} selected)" : "(изабрано: {count})",
     "Error loading file exists template" : "Грешка при учитавању шаблона „Фајл постоји“",
-    "Saving …" : "Чувам …",
+    "Saving …" : "Чувам…",
     "seconds ago" : "пре пар секунди",
     "Connection to server lost" : "Изгубљена је веза са сервером",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Грешка приликом учитавања стране, пробам поново за %n секунду","Грешка приликом учитавања стране, пробам поново за %n секунде","Грешка приликом учитавања стране, пробам поново за %n секунди"],
@@ -408,6 +407,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "Крените да куцате да тражите постојеће пројекте",
     "New in" : "Ново у",
     "View changelog" : "Погледајте дневник измена",
+    "No action available" : "Нема доступне радње",
+    "Error fetching contact actions" : "Грешка приликом дохватања акција над контактима",
     "Close \"{dialogTitle}\" dialog" : "Затвори дијалог „{dialogTitle}”",
     "Email length is at max (255)" : "Дужина и-мејла је максимална (255)",
     "Clipboard not available, please copy manually" : "Клипборд није доступан, молимо вас да ручно копирате",
@@ -495,40 +496,32 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Овај %s је тренутно у режиму одржавања што може потрајати.",
     "This page will refresh itself when the instance is available again." : "Ова страница ће се сама освежити када инстанца постане поново доступна.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Контактирајте администратора ако се порука понавља или се неочекивано појавила.",
+    "No temporary profile picture available, try again" : "Нема привремене слике профила. Покушајте поново",
+    "No crop data provided" : "Нема података о опсецању",
+    "No valid crop data provided" : "Нема исправних података о опсецању",
+    "Crop is not square" : "Опсецање није квадратног облика",
     "Error occurred while checking server setup" : "Дошло је до грешке при провери поставки сервера",
     "For more details see the {linkstart}documentation ↗{linkend}." : "За више детаља погледајте {linkstart}документацију ↗{linkend}.",
-    "unknown text" : "непознат текст",
-    "Hello world!" : "Здраво свете!",
-    "sunny" : "сунчано",
-    "Hello {name}, the weather is {weather}" : "Здраво {name}, време је {weather}",
-    "Hello {name}" : "Здраво {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Ово су резултати Ваше претраге<script>alert(1)</script></strong>",
-    "new" : "ново",
-    "_download %n file_::_download %n files_" : ["преузми %n фајл","преузми %n фајла","преузми %n фајлова"],
-    "Direct link copied to clipboard" : "Директни линк је копиран у клипборд",
-    "Searching …" : "Тражим…",
-    "Logging in …" : "Пријављивање …",
-    "Loading apps …" : "Учитавам апликације…",
-    "Installing apps …" : "Инсталирам апликације…",
-    "Loading your contacts …" : "Учитавам контакте ...",
-    "Looking for {term} …" : "Тражим {term} …",
-    "Search contacts …" : "Претражи контакте ...",
-    "Loading more results …" : "Учитавам још резултата…",
-    "Search {types} …" : "Претражи {types}…",
-    "Saving …" : "Чувам…",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Ћаскање, видео позиви, дељење екрана, састанци на интернету & веб конференције – на десктоп рачунару и преко мобилних апликација.",
+    "You have not added any info yet" : "Још увек нисте додали никакве информације",
+    "{user} has not added any info yet" : "{user} још увек није унео никакве информације",
+    "Error opening the user status modal, try hard refreshing the page" : "Грешка приликом отварања модалног прозора за статус корисника, покушајте да освежите страну уз брисање кеша",
+    "Edit Profile" : "Уреди профил",
+    "The headline and about sections will show up here" : "Овде ће се појавити насловна линија и одељак „о”",
     "Very weak password" : "Веома слаба лозинка",
     "Weak password" : "Слаба лозинка",
     "So-so password" : "Осредња лозинка",
     "Good password" : "Добра лозинка",
     "Strong password" : "Јака лозинка",
-    "No action available" : "Нема доступне радње",
-    "Error fetching contact actions" : "Грешка приликом дохватања акција над контактима",
     "Non-existing tag #{tag}" : "Непостојећа ознака #{tag}",
     "Restricted" : "Ограничена",
+    "Invisible" : "Невидљива",
     "Delete" : "Обриши",
     "Rename" : "Преименуј",
     "Collaborative tags" : "Oзнаке сарадње",
     "No tags found" : "Ознаке нису нађене",
+    "Profile not found" : "Није пронађен профил",
+    "The profile does not exist." : "Профил не постоји.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ваш директоријум са подацима и фајлови су вероватно доступни са интернета јер .htaccess не ради.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "За информације како да правилно подесите Ваш сервер, погледајте <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацију</a>.",
     "<strong>Create an admin account</strong>" : " <strong>Направи административни налог</strong>",
@@ -539,6 +532,6 @@ OC.L10N.register(
     "Configure the database" : "Подешавање базе",
     "Only %s is available." : "Само %s је доступна.",
     "Database account" : "Налог базе података",
-    "Installing …" : "Инсталирам ..."
+    "Direct link copied to clipboard" : "Директни линк је копиран у клипборд"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
