@@ -42,7 +42,6 @@ OC.L10N.register(
     "Not found" : "Haipatikani",
     "Node is locked" : "Nodi imefungwa",
     "Bad request" : "Uombaji mbaya",
-    "Input text is too long" : "Maandishi ya ingizo ni marefu sana",
     "Requested task type does not exist" : "Uandikaji wa jukumu lililoombwa haupatikani",
     "Necessary language model provider is not available" : "Mgavi muhimu wa aina ya lugha hapatikani",
     "No text to image provider is available" : "Hakuna maandishi yaliyopo kwa mgavi wa taswira",
@@ -50,7 +49,6 @@ OC.L10N.register(
     "No translation provider available" : "Hakuna mgavi wa tafsiri aliyepo",
     "Could not detect language" : "Haikuweza kugundua lugha",
     "Unable to translate" : "Haiwezi kutafsiri",
-    "No valid filters provided" : "Hakuna vichujio halali vilivyotolewa",
     "[%d / %d]: %s" : "[%d/%d]: %s",
     "Repair step:" : "Rekwbisha hatua:",
     "Repair info:" : "Rekebisha taarifa",
@@ -198,6 +196,14 @@ OC.L10N.register(
     "Matroska video" : "Picha mjongeo ya Matroska",
     "Windows Media video" : "Picha mjongeo ya Windows Media",
     "AVI video" : "Picha mjongeo ya AVI",
+    "unknown text" : "andiko lisilojulikana",
+    "Hello world!" : "Halo dunia!",
+    "sunny" : "a jua",
+    "Hello {name}, the weather is {weather}" : "Halo{name}, hali ya hewa ni {weather}",
+    "Hello {name}" : "Halo {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Haya ni matokeo ya utafutaji wako<script>toa taarifa(1)</script></strong>",
+    "new" : "mpya",
+    "_download %n file_::_download %n files_" : ["download %n file","pakua faili %n "],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Usasishaji unaendelea, kuacha ukurasa huu kunaweza kukatiza mchakato katika baadhi ya mazingira",
     "Update to {version}" : "Sasisha kwenda {version}",
     "An error occurred." : "Hitilafu imetokea",
@@ -206,15 +212,12 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Uasasishaji umefanikiwa. Tafadhali toa taarifa ya jambo hili kwenye <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Jamii ya Nextcloud</a>.",
     "Continue to {productName}" : "Endelea katika {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["The update was successful. Redirecting you to {productName} in %n second."," Usasishaji umekamilika. Elekeza upya katika {productName} ndani ya %n sekunde."],
-    "Done" : "Imefanyika",
     "Applications menu" : "Mwongozo wa maombi",
     "Apps" : "Maombi",
     "More apps" : "Apps zaidi",
     "_{count} notification_::_{count} notifications_" : ["{count} notification","{count} taarifa"],
     "No" : "Hapana",
     "Yes" : "Ndiyo",
-    "App password" : "Nenosiri la program",
-    "Grant access" : "Toa ufikiaji",
     "The remote URL must include the user." : "Rimoti ya URL lazima ijumuishe mtumiaji",
     "Invalid remote URL." : "Rimoti ya URL si halali",
     "Failed to add the public link to your Nextcloud" : "Imeshindwa kuongeza kiungio cha jamii kwenye Nextcloud yako",
@@ -230,9 +233,8 @@ OC.L10N.register(
     "Search in current app" : "Tafuta katika app ya hivi karibuni",
     "Clear search" : "Futa utafutaji",
     "Search everywhere" : "Tafuta kila mahali",
-    "Searching …" : "Inatafuta …",
+    "Searching …" : "Inatafuta",
     "Start typing to search" : "Anza kuandika ili kutafuta",
-    "Minimum search length is {minSearchLength} characters" : "Kima cha chini cha urefu wa utafutaji ni vibambo {minSearchLength}",
     "No matching results" : "Hakuna matokeo yanayolingana",
     "Today" : "Leo",
     "Last 7 days" : "Siku 7 zilizopita",
@@ -252,10 +254,11 @@ OC.L10N.register(
     "Load more results" : "Pakia matokeo zaidi",
     "Search in" : "Tafuta katika",
     "Log in" : "Ingia",
-    "Logging in …" : "Inaingia  …",
+    "Logging in …" : "Inaingia",
     "Log in to {productName}" : "Ingia kwa {productName}",
     "Wrong login or password." : "Makosa ya uingiaji au nenosiri",
     "This account is disabled" : "Akaunti hii haijawezeshwa ",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Tumegundua majaribio mengi batili ya kuingia kutoka kwa IP yako. Kwa hivyo kuingia kwako kunakofuata kunasisitizwa hadi sekunde 30.",
     "Account name or email" : "Jina la akaunti au barua pepe",
     "Account name" : "Jina la akaunti",
     "Server side authentication failed!" : "Uthibitishaji wa upande wa seva umeshindwa",
@@ -265,7 +268,6 @@ OC.L10N.register(
     "An internal error occurred." : "Hitilafu ya ndani imetokea",
     "Please try again or contact your administrator." : "Tafadhali jaribu tena au wasiliana na msimamizi wako",
     "Password" : "Nenosiri",
-    "Remember me" : "Nikumbuke",
     "Log in with a device" : "Ingia na kifaa",
     "Login or email" : "Ingia au barua pepe",
     "Your account is not setup for passwordless login." : "Akaunti yako haijapangiliwa uingiaji bila nenosiri",
@@ -289,28 +291,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Hati shirikishi, lahajedwali na mawasilisho, yaliyoundwa kwenye Collabora mtandaoni.",
     "Distraction free note taking app." : "Programu ya kuchukua nukuu bila usumbufu.",
     "Recommended apps" : "Program iliyopendekezwa",
-    "Loading apps …" : "Inapakia programu …",
+    "Loading apps …" : "Inapakia program",
     "Could not fetch list of apps from the App Store." : "Haiwezi kuleta orodha ya maombi kutoka katika stoo ya maombi",
     "App download or installation failed" : "Upakuaji au usanikishaji wa program umeshindikana",
     "Cannot install this app because it is not compatible" : "Haiwezi kusakinisha program hii kwa sababu si sambamba",
     "Cannot install this app" : "Haiwezi kusakinisha program hii",
     "Skip" : "Ruka",
-    "Installing apps …" : "Inasakinisha programu …",
+    "Installing apps …" : "Inasakinisha program",
     "Install recommended apps" : "Sakinisha program zilizopendekezwa",
-    "Online" : "Mtandaoni",
-    "Away" : "Mbali",
-    "Busy" : "Bize",
-    "Do not disturb" : "Acha kusumbua",
-    "Mute all notifications" : "Zima arifu zote",
-    "Invisible" : "Haionekani",
-    "Appear offline" : "Tokea nje ya mtandao",
     "Avatar of {displayName}" : "Avatar ya {displayName}",
     "Settings menu" : "Pangilia mwongozo",
-    "Loading your contacts …" : "Inapakia mawasiliano yako  …",
-    "Looking for {term} …" : "Inatafuta {term}  …",
+    "Loading your contacts …" : "Inapakia mawasiliano yako",
+    "Looking for {term} …" : "Inatafuta {term}",
     "Search contacts" : "Tafuta mawasiliano",
     "Reset search" : "Pangilia utafutaji",
-    "Search contacts …" : "Tafuta mawasiliano  …",
+    "Search contacts …" : "Tafuta mawasiliano...",
     "Could not load your contacts" : "Haikuweza kupakia mawasiliano yako",
     "No contacts found" : "Hakuna mawasiliano yaliyopatikana",
     "Show all contacts" : "Onesha mawasiliano yote",
@@ -322,20 +317,12 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Hitilafu imetokea wakati ikitafuta {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Utafutaji huanza mara moja unapoanza kuandika na matokeo yanaweza kufikiwa na funguo za mishale",
     "Search for {name} only" : "Tafuta tu {name}",
-    "Loading more results …" : "Inapakia matokeo zaidi …",
+    "Loading more results …" : "Inapakia matokeo zaidi",
     "Forgot password?" : "Umesahau nenosiri?",
     "Back to login form" : "Rudi kwenye fomu ya uingiaji",
     "Back" : "Rudi",
     "Login form is disabled." : "Fomu ya uingiaji haikuwezeshwa",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Fomu ya kuingia ya Nextcloud imezimwa. Tumia chaguo jingine la kuingia ikiwa linapatikana au wasiliana na utawala wako.",
-    "Connect to your account" : "Unganisha kwenye akaunti yako",
-    "Security warning" : "Onyo la usalama",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Iwapo hujaribu kusanidi kifaa au programu mpya, mtu anajaribu kukuhadaa ili umpe idhini ya kufikia data yako. Katika kesi hii usiendelee na badala yake wasiliana na msimamizi wa mfumo wako.\n ",
-    "Alternative log in using app password" : "Uingiaji mbadala kutumia nenosiri la program",
-    "Account connected" : "Akaunti imeunganishwa",
-    "Your client should now be connected!" : "Mteja wako anapaswa kuunganishwa sasa",
-    "You can close this window." : "Unaweza kufunga window hii",
-    "Account access" : "Ufikiaji wa akaunti",
     "More actions" : "Vitendo zaidi",
     "User menu" : "Mwongozo wa mtumiaji",
     "Your guest name: {user}" : "Jina la mgeni wako: {user}",
@@ -353,13 +340,13 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Kwa maelezo ya jinsi ya kusanidi seva yako ipasavyo, tafadhali {linkStart} tazama hati {linkEnd}",
     "Autoconfig file detected" : "Faili ya usanidi otomatiki imegunduliwa",
     "The setup form below is pre-filled with the values from the config file." : "Fomu iliyopo hapa chini imejaa thamani kutoka kwa faili ya usanidi.",
+    "Security warning" : "Onyo la usalama",
     "Create administration account" : "Tengeneza akaunti ya msimamizi",
     "Administration account name" : "Jina la akaunti ya msimamizi",
     "Administration account password" : "Nenosiri la akaunti ya msimamizi",
     "Storage & database" : "Uhifadhi na kanzidata",
     "Data folder" : "Kisanduku cha data",
     "Database configuration" : "Usanidi wa kanzi data",
-    "Database type" : "Aina ya hifadhidata",
     "Only {firstAndOnlyDatabase} is available." : "Yupo tu {firstAndOnlyDatabase}",
     "Install and activate additional PHP modules to choose other database types." : "Sakinisha na uwashe moduli za ziada za PHP ili kuchagua aina zingine za hifadhidata",
     "For more details check out the documentation." : "Kwa maelezo zaidi angalia nyaraka ",
@@ -367,7 +354,6 @@ OC.L10N.register(
     "You chose SQLite as database." : "Umechagua SQLite kama kanzidata",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite inapaswa kutumika tu kwa hali ndogo na za ukuzaji. Kwa ajili ya uzalishaji tunapendekeza mazingira tofauti ya hifadhidata.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ikiwa unatumia wateja kusawazisha faili, utumiaji wa SQLite umekatishwa tamaa sana.",
-    "Database connection" : "Muunganisho wa hifadhidata",
     "Database user" : "Mtumiaji wa kanzidata",
     "Database password" : "Nenosiri la kanzidata",
     "Database name" : "Jina la kanzidata",
@@ -375,7 +361,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Tafadhali bainisha nambari ya mlango pamoja na jina la mwenyeji (k.m., mwenyeji wa eneo:5432).",
     "Database host" : "Mwenyeji wa kanzidata",
     "localhost" : "mwenyeji wa eneo",
-    "Installing …" : "Inasakinisha ...",
+    "Installing …" : "Inasakinisha",
     "Install" : "Sakinisha",
     "Need help?" : "Unahitaji masaada?",
     "See the documentation" : "Angalia mkusanyiko wa nyaraka",
@@ -384,7 +370,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Kivinjari chako hakitumiki. Tafadhali boresha hadi toleo jipya au kivinjari kinachotumika",
     "Continue with this unsupported browser" : "Endelea na kivinjari kisichotumika",
     "Supported versions" : "Toleo linalotumika",
-    "Search {types} …" : "Tafuta{types} ...",
+    "Search {types} …" : "Tafuta {types}...",
     "Choose {file}" : "Chagua {file}",
     "Choose" : "Chagua",
     "Copy to {target}" : "Nakili kwenda {target}",
@@ -404,8 +390,7 @@ OC.L10N.register(
     "(all selected)" : "(yote yamechaguliwa)",
     "({count} selected)" : "({count} imechaguliwa)",
     "Error loading file exists template" : "Hitilafu kupakia faili kiolezo kilichopo",
-    "Saving …" : "Inahifadhi …",
-    "Groups" : "Makundi",
+    "Saving …" : "Inahifadhi...",
     "seconds ago" : "sukunde zilizopita",
     "Connection to server lost" : "Muunganiko kwenye seva umepotea",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem loading page, reloading in %n second","Tatizo kupakia ukurasa, pakia upya %n sekunde"],
@@ -420,6 +405,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "Andika kutafuta kwa miradi iliyopo",
     "New in" : "Mpya katika",
     "View changelog" : "Tazama logi ya mabadiliko",
+    "No action available" : "Hakuna kitendo kilichopo",
+    "Error fetching contact actions" : "Hitilafu kuleta matendo ya mawasiliano",
     "Close \"{dialogTitle}\" dialog" : "Funga \"{dialogTitle}\" mazungumzo",
     "Email length is at max (255)" : "Urefu wa barua pepe uko katika kuwango cha (255)",
     "Clipboard not available, please copy manually" : "Ubao wa kunakili haupatikani, tafadhali nakili wewe mwenyewe",
@@ -456,6 +443,18 @@ OC.L10N.register(
     "Skip to navigation of app" : "Ruka hadi kwenye usogezaji wa program",
     "Go to %s" : "Nenda kwenye %s",
     "Get your own free account" : "Pata akaunti yako ya bure",
+    "Connect to your account" : "Unganisha kwenye akaunti yako",
+    "Please log in before granting %1$s access to your %2$s account." : "Tafadhali ingia kabla ya kutoa %1$s ufikiaji kwenye akaunti yako %2$s",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Iwapo hujaribu kusanidi kifaa au programu mpya, mtu anajaribu kukuhadaa ili umpe idhini ya kufikia data yako. Katika kesi hii usiendelee na badala yake wasiliana na msimamizi wa mfumo wako.\n ",
+    "App password" : "Nenosiri la program",
+    "Grant access" : "Toa ufikiaji",
+    "Alternative log in using app password" : "Uingiaji mbadala kutumia nenosiri la program",
+    "Account access" : "Ufikiaji wa akaunti",
+    "Currently logged in as %1$s (%2$s)." : "Sasa umeingia kama %1$s (%2$s)",
+    "You are about to grant %1$s access to your %2$s account." : "Unakaribia kutoa %1$s uingiaji %2$skwenye akaunti yako",
+    "Account connected" : "Akaunti imeunganishwa",
+    "Your client should now be connected!" : "Mteja wako anapaswa kuunganishwa sasa",
+    "You can close this window." : "Unaweza kufunga window hii",
     "Previous" : "Iliyopita",
     "This share is password-protected" : "Ushirikishaji huu unalindwa na nenosiri",
     "The password is wrong or expired. Please try again or request a new one." : "Nenosiri si sahihi au limeisha muda wake. Tafadhali jaribu tena au uombe mpya.",
@@ -495,41 +494,32 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "%s kwa sasa ni katika hali ya matengenezo, ambayo inaweza kuchukua muda. ",
     "This page will refresh itself when the instance is available again." : "Ukurasa huu utajipumzisha upya wakati mfano unapatikana tena.\n ",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Wasiliana na msimamizi wa mfumo wako ikiwa ujumbe huu utaendelea au ulionekana bila kutarajiwa.",
+    "No temporary profile picture available, try again" : "Hakuna picha ya muda ya wasifu inayopatikana, jaribu tena",
+    "No crop data provided" : "Hakuna data iliyokatwa iliyotolewa",
+    "No valid crop data provided" : "Hakuna data halali iliyokatwa iliyotolewa",
+    "Crop is not square" : "Ukataji si mraba",
     "Error occurred while checking server setup" : "Hitilafu imetokea wakati ikiangalia mpangilio wa seva",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Kwa maelezo zaidi ona {linkstart}uwasilishaji nyaraka {linkend}",
-    "unknown text" : "andiko lisilojulikana",
-    "Hello world!" : "Halo dunia!",
-    "sunny" : "a jua",
-    "Hello {name}, the weather is {weather}" : "Halo{name}, hali ya hewa ni {weather}",
-    "Hello {name}" : "Halo {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Haya ni matokeo ya utafutaji wako<script>toa taarifa(1)</script></strong>",
-    "new" : "mpya",
-    "_download %n file_::_download %n files_" : ["download %n file","pakua faili %n "],
-    "Direct link copied to clipboard" : "Kiungio cha moja kwa moja kimenakiliwa kwenye ubao wa kunakili",
-    "Searching …" : "Inatafuta",
-    "Logging in …" : "Inaingia",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Tumegundua majaribio mengi batili ya kuingia kutoka kwa IP yako. Kwa hivyo kuingia kwako kunakofuata kunasisitizwa hadi sekunde 30.",
-    "Loading apps …" : "Inapakia program",
-    "Installing apps …" : "Inasakinisha program",
-    "Loading your contacts …" : "Inapakia mawasiliano yako",
-    "Looking for {term} …" : "Inatafuta {term}",
-    "Search contacts …" : "Tafuta mawasiliano...",
-    "Loading more results …" : "Inapakia matokeo zaidi",
-    "Search {types} …" : "Tafuta {types}...",
-    "Saving …" : "Inahifadhi...",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Kupiga gumzo, simu za picha mjongeo, kushiriki skrini, mikutano ya mtandaoni na mikutano ya wavuti - katika kivinjari chako na programu za simu.",
+    "You have not added any info yet" : "Hujaongeza taarifa yoyote bado",
+    "{user} has not added any info yet" : "{user} hajaongeza taarifa yoyote bado",
+    "Error opening the user status modal, try hard refreshing the page" : "Hitilafu imetokea wakati wa kufungua modi ya hali ya mtumiaji, jaribu kuonyesha upya ukurasa kwa bidii",
+    "Edit Profile" : "Hariri wasifu",
+    "The headline and about sections will show up here" : "Kichwa cha habari na sehemu kuhusu zitaonekana hapa",
     "Very weak password" : "Nenosiri dhaifu sana",
     "Weak password" : "Nenosiri dhaifu",
     "So-so password" : "Nenosiri la so-so",
     "Good password" : "Nenosiri zuri",
     "Strong password" : "Nenosiri imara",
-    "No action available" : "Hakuna kitendo kilichopo",
-    "Error fetching contact actions" : "Hitilafu kuleta matendo ya mawasiliano",
     "Non-existing tag #{tag}" : "Lebo isiyokuwepo #{tag}",
     "Restricted" : "Imezuiliwa",
+    "Invisible" : "Haionekani",
     "Delete" : "Futa",
     "Rename" : "Ipe jina jipya",
     "Collaborative tags" : "Lebo zinazoshirikiana",
     "No tags found" : "Hakuna lebo zilizopatikana",
+    "Profile not found" : "Wasifu haupatikani",
+    "The profile does not exist." : "Wasifu haupo",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Saraka yako ya data na faili pengine zinaweza kufikiwa kutoka kwa mtandao kwa sababu faili ya .htaccess haifanyi kazi.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Kwa taarifa jinsi ya kusanidi seva yako vizuri, tafadhali angalia <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">onesho la nyaraka</a>",
     "<strong>Create an admin account</strong>" : "<strong>tengeneza akaunti ya msimsmizi</strong>",
@@ -540,9 +530,6 @@ OC.L10N.register(
     "Configure the database" : "Sanidi hifadhidata",
     "Only %s is available." : "Yupo tu %s",
     "Database account" : "Akaunti ya kanzidata",
-    "Installing …" : "Inasakinisha",
-    "Please log in before granting %1$s access to your %2$s account." : "Tafadhali ingia kabla ya kutoa %1$s ufikiaji kwenye akaunti yako %2$s",
-    "Currently logged in as %1$s (%2$s)." : "Sasa umeingia kama %1$s (%2$s)",
-    "You are about to grant %1$s access to your %2$s account." : "Unakaribia kutoa %1$s uingiaji %2$skwenye akaunti yako"
+    "Direct link copied to clipboard" : "Kiungio cha moja kwa moja kimenakiliwa kwenye ubao wa kunakili"
 },
 "nplurals=2; plural=(n != 1);");
