@@ -76,6 +76,14 @@ OC.L10N.register(
     "The following apps have been disabled: %s" : "Những ứng dụng sau đây đã bị tắt: %s",
     "Already up to date" : "Đã được cập nhật bản mới nhất",
     "Unknown" : "Không xác định",
+    "unknown text" : "văn bản không rõ",
+    "Hello world!" : "Hello world!",
+    "sunny" : "nắng",
+    "Hello {name}, the weather is {weather}" : "Xin chào {name}, thời tiết hiện nay {weather}",
+    "Hello {name}" : "Xin chào {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Đây là kết quả tìm kiếm của bạn<script>cảnh báo (1)</script></strong>",
+    "new" : "mới",
+    "_download %n file_::_download %n files_" : ["tải về%ntệp"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Quá trình cập nhật đang được tiến hành, đóng trang này có thể làm gián đoạn quá trình.",
     "Update to {version}" : "Cập nhật lên {version}",
     "An error occurred." : "Đã xảy ra lỗi.",
@@ -100,6 +108,7 @@ OC.L10N.register(
     "Search in date range" : "Tìm trong khoảng ngày",
     "Search in current app" : "Tìm trong ứng dụng hiện tại",
     "Search everywhere" : "Tìm ở bất kì đâu",
+    "Searching …" : "Đang tìm kiếm ...",
     "Start typing to search" : "Nhập để tìm kiếm",
     "No matching results" : "Không có kết quả trùng khớp",
     "Today" : "Hôm nay",
@@ -116,6 +125,7 @@ OC.L10N.register(
     "Load more results" : "Tải thêm kết quả",
     "Search in" : "Tìm kiếm trong",
     "Log in" : "Đăng nhập",
+    "Logging in …" : "Đang đăng nhập",
     "Log in to {productName}" : "Đăng nhập vào {productName}",
     "Wrong login or password." : "Tên người dùng hoặc mật khẩu sai.",
     "This account is disabled" : "Tài khoản này không còn khả dụng",
@@ -149,16 +159,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Tài liệu, bảng tính và bản trình bày cộng tác, được xây dựng trên Collabora Online.",
     "Distraction free note taking app." : "Ứng dụng ghi chú không gây xao lãng.",
     "Recommended apps" : "Ứng dụng được đề xuất",
+    "Loading apps …" : "Đang tải ứng dụng ...",
     "Could not fetch list of apps from the App Store." : "Không thể tìm nạp danh sách ứng dụng từ App Store.",
     "App download or installation failed" : "Tải xuống hoặc cài đặt ứng dụng không thành công",
     "Cannot install this app because it is not compatible" : "Không thể cài đặt ứng dụng này vì nó không tương thích",
     "Cannot install this app" : "Không thể cài đặt ứng dụng này",
     "Skip" : "Bỏ qua",
+    "Installing apps …" : "Đang cài đặt ứng dụng ...",
     "Install recommended apps" : "Cài đặt các ứng dụng được đề xuất",
     "Avatar of {displayName}" : "Ảnh đại diện của {displayName}",
     "Settings menu" : "Trình đơn thiết lập",
+    "Loading your contacts …" : "Đang tải liên hệ của bạn ...",
+    "Looking for {term} …" : "Đang tìm kiếm {term} ...",
     "Search contacts" : "Tìm kiếm liên hệ",
     "Reset search" : "Đặt lại tìm kiếm",
+    "Search contacts …" : "Tìm liên hệ ...",
     "Could not load your contacts" : "Không thể tải liên hệ của bạn",
     "No contacts found" : "Không tìm thấy liên hệ nào",
     "Show all contacts" : "Hiện tất cả liên hệ",
@@ -170,6 +185,7 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Đã xảy ra lỗi khi tìm kiếm {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Tìm kiếm bắt đầu khi bạn bắt đầu nhập và có thể đạt được kết quả bằng các phím mũi tên",
     "Search for {name} only" : "Chỉ tìm kiếm {name}",
+    "Loading more results …" : "Tải thêm kết quả ...",
     "Forgot password?" : "Quên mật khẩu sao?",
     "Back to login form" : "Quay lại trang đăng nhập",
     "Back" : "Quay lại",
@@ -191,6 +207,7 @@ OC.L10N.register(
     "Database tablespace" : "Cơ sở dữ liệu tablespace",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Vui lòng xác định số cổng cùng với tên máy chủ lưu trữ (ví dụ: localhost: 5432).",
     "Database host" : "Database host",
+    "Installing …" : "Đang cài đặt",
     "Install" : "Cài đặt",
     "Need help?" : "Cần hỗ trợ ?",
     "See the documentation" : "Xem tài liệu",
@@ -199,6 +216,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Trình duyệt của bạn không được hỗ trợ. Vui lòng nâng cấp lên phiên bản mới hơn hoặc phiên bản được hỗ trợ.",
     "Continue with this unsupported browser" : "Tiếp tục với trình duyệt không được hỗ trợ này",
     "Supported versions" : "Các phiên bản được hỗ trợ",
+    "Search {types} …" : "Tìm kiếm {types} ...",
     "Choose {file}" : "Chọn {file}",
     "Choose" : "Chọn",
     "Copy to {target}" : "Sao chép vào {target}",
@@ -218,6 +236,7 @@ OC.L10N.register(
     "(all selected)" : "(Tất cả các lựa chọn)",
     "({count} selected)" : "({count} được chọn)",
     "Error loading file exists template" : "Lỗi khi tải tập tin mẫu đã tồn tại",
+    "Saving …" : "Đang lưu ...",
     "seconds ago" : "vài giây trước",
     "Connection to server lost" : "Kết nối tới máy chủ bị mất",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Xảy ra lỗi khi tải trang, tải lại trong %n giây"],
@@ -232,6 +251,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "Nhập để tìm kiếm các dự án hiện có",
     "New in" : "Mới trong",
     "View changelog" : "Xem nhật ký thay đổi",
+    "No action available" : "Không có hành động nào",
+    "Error fetching contact actions" : "Lỗi khi nạp liên hệ",
     "Close \"{dialogTitle}\" dialog" : "Đóng hộp thoại \"{dialogTitle}\"",
     "Email length is at max (255)" : "Độ dài Email đã đạt giới hạn (255 ký tự)",
     "Personal" : "Cá nhân",
@@ -317,34 +338,23 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Bản cài đặt%s hiện tại đang trong chế độ \"bảo trì\", do vậy có thể bạn cần phải đợi thêm chút ít thời gian.",
     "This page will refresh itself when the instance is available again." : "Trang này sẽ tự làm mới khi phiên bản khả dụng trở lại.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Liên hệ với người quản trị nếu lỗi này vẫn tồn tại hoặc xuất hiện bất ngờ.",
+    "No temporary profile picture available, try again" : "Ảnh cá nhân tạm thời không có giá trị, hãy thử lại",
+    "No crop data provided" : "Không có dữ liệu nguồn được cung cấp",
+    "No valid crop data provided" : "Dữ liệu trích xuất không hợp lệ",
+    "Crop is not square" : "Trích xuất không chuẩn",
     "Error occurred while checking server setup" : "Có lỗi xảy ra khi kiểm tra thiết lập máy chủ",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Để biết thêm chi tiết, hãy xem tài liệu ↗ {linkstart} {linkend}.",
-    "unknown text" : "văn bản không rõ",
-    "Hello world!" : "Hello world!",
-    "sunny" : "nắng",
-    "Hello {name}, the weather is {weather}" : "Xin chào {name}, thời tiết hiện nay {weather}",
-    "Hello {name}" : "Xin chào {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Đây là kết quả tìm kiếm của bạn<script>cảnh báo (1)</script></strong>",
-    "new" : "mới",
-    "_download %n file_::_download %n files_" : ["tải về%ntệp"],
-    "Direct link copied to clipboard" : "URL đã được sao chép vào bộ nhớ tạm",
-    "Searching …" : "Đang tìm kiếm ...",
-    "Logging in …" : "Đang đăng nhập",
-    "Loading apps …" : "Đang tải ứng dụng ...",
-    "Installing apps …" : "Đang cài đặt ứng dụng ...",
-    "Loading your contacts …" : "Đang tải liên hệ của bạn ...",
-    "Looking for {term} …" : "Đang tìm kiếm {term} ...",
-    "Search contacts …" : "Tìm liên hệ ...",
-    "Loading more results …" : "Tải thêm kết quả ...",
-    "Search {types} …" : "Tìm kiếm {types} ...",
-    "Saving …" : "Đang lưu ...",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Trò chuyện, cuộc gọi video, chia sẻ màn hình, cuộc họp trực tuyến và hội nghị trên web - trong trình duyệt của bạn và với các ứng dụng dành cho thiết bị di động.",
+    "You have not added any info yet" : "Bạn chưa thêm bất kỳ thông tin nào",
+    "{user} has not added any info yet" : "{user} chưa thêm bất kỳ thông tin nào",
+    "Error opening the user status modal, try hard refreshing the page" : "Lỗi khi mở phương thức trạng thái người dùng, hãy thử làm mới trang",
+    "Edit Profile" : "Chỉnh sửa hồ sơ",
+    "The headline and about sections will show up here" : "Dòng tiêu đề và phần giới thiệu sẽ hiển thị ở đây",
     "Very weak password" : "Mật khẩu rất yếu",
     "Weak password" : "Mật khẩu yếu",
     "So-so password" : "Mật khẩu tạm được",
     "Good password" : "Mật khẩu tốt",
     "Strong password" : "Mật khẩu mạnh",
-    "No action available" : "Không có hành động nào",
-    "Error fetching contact actions" : "Lỗi khi nạp liên hệ",
     "Non-existing tag #{tag}" : "Thẻ không tồn tại # {tag}",
     "Restricted" : "Bị giới hạn",
     "Invisible" : "Vô hình",
@@ -352,6 +362,8 @@ OC.L10N.register(
     "Rename" : "Sửa tên",
     "Collaborative tags" : "Thẻ cộng tác",
     "No tags found" : "Không tìm thấy thẻ",
+    "Profile not found" : "Không tìm thấy hồ sơ",
+    "The profile does not exist." : "Hồ sơ không tồn tại.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Thư mục và file dữ liệu của bạn có thể được truy cập từ internet bởi vì file .htaccess không hoạt động",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Để biết thông tin về cách cấu hình đúng máy chủ của bạn, vui lòng xem <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">tài liệu</a>.",
     "Show password" : "Hiện mật khẩu",
@@ -359,6 +371,6 @@ OC.L10N.register(
     "Configure the database" : "Cấu hình cơ sở dữ liệu",
     "Only %s is available." : "Chỉ %s khả dụng.",
     "Database account" : "Tài khoản CSDL",
-    "Installing …" : "Đang cài đặt"
+    "Direct link copied to clipboard" : "URL đã được sao chép vào bộ nhớ tạm"
 },
 "nplurals=1; plural=0;");
