@@ -42,7 +42,6 @@ OC.L10N.register(
     "Not found" : "未找到",
     "Node is locked" : "节点已锁定",
     "Bad request" : "请求错误",
-    "Input text is too long" : "输入文本太长",
     "Requested task type does not exist" : "请求的任务类型不存在",
     "Necessary language model provider is not available" : "无必要的语言模型提供程序",
     "No text to image provider is available" : "没有可用的文字转图片提供者",
@@ -198,6 +197,14 @@ OC.L10N.register(
     "Matroska video" : "Matroska 视频",
     "Windows Media video" : "Windows 媒体视频",
     "AVI video" : "AVI 视频",
+    "unknown text" : "未知文字",
+    "Hello world!" : "你好，世界！",
+    "sunny" : "晴",
+    "Hello {name}, the weather is {weather}" : "您好 {name}，今天天气是 {weather}",
+    "Hello {name}" : "您好 {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>这是您的搜索结果<script>警告（1）</script></strong>",
+    "new" : "新建",
+    "_download %n file_::_download %n files_" : ["下载 %n 个文件"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "正在更新，在某些环境下离开当前页面可能会中断。",
     "Update to {version}" : "升级到 {version}",
     "An error occurred." : "发生错误。",
@@ -206,16 +213,12 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "升级失败。请将此问题报告给 <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud社区</a>。",
     "Continue to {productName}" : "继续到 {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["更新成功，%n 秒后你将重定向到 {productName}。"],
-    "Done" : "完成",
-    "Scan QR code to log in" : "扫描二维码登录",
     "Applications menu" : "应用程序菜单",
     "Apps" : "应用",
     "More apps" : "更多的应用程序",
     "_{count} notification_::_{count} notifications_" : ["{count} 条通知"],
     "No" : "否",
     "Yes" : "是",
-    "App password" : "应用密码",
-    "Grant access" : "授权访问",
     "The remote URL must include the user." : "远程 URL 必须包含用户。",
     "Invalid remote URL." : "无效远程 URL。",
     "Failed to add the public link to your Nextcloud" : "无法将公开链接添加到您的 Nextcloud",
@@ -230,8 +233,8 @@ OC.L10N.register(
     "Search in date range" : "在日期范围内进行搜索",
     "Search in current app" : "在当前应用程序中搜索",
     "Clear search" : "清除搜索",
-    "Search everywhere" : "全局搜索",
-    "Searching …" : "正在搜索 …",
+    "Search everywhere" : "在所有位置搜索",
+    "Searching …" : "正在搜索 ...",
     "Start typing to search" : "开始输入以搜索",
     "Minimum search length is {minSearchLength} characters" : "最小搜索长度为 {minSearchLength} 个字符",
     "No matching results" : "无匹配结果",
@@ -252,13 +255,12 @@ OC.L10N.register(
     "Results" : "结果",
     "Load more results" : "加载更多结果",
     "Search in" : "搜索",
-    "Partial matches" : "部分匹配",
     "Log in" : "登录",
-    "Logging in …" : "正在登录 …",
+    "Logging in …" : "正在登录……",
     "Log in to {productName}" : "登录到 {productName}",
     "Wrong login or password." : "账号或密码错误",
     "This account is disabled" : "此账号已停用",
-    "Too many incorrect login attempts. Please try again in 30 seconds." : "错误登录尝试次数过多，请在 30 秒后重试。",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "我们检测到你的 IP 进行了多次无效登录尝试。因此，你的下一次登录将被延迟 30 秒。",
     "Account name or email" : "账号名称或电子邮箱",
     "Account name" : "账号名称",
     "Server side authentication failed!" : "服务端身份验证失败！",
@@ -268,7 +270,6 @@ OC.L10N.register(
     "An internal error occurred." : "发生了内部错误。",
     "Please try again or contact your administrator." : "请重试或联系您的管理员。",
     "Password" : "密码",
-    "Remember me" : "记住我",
     "Log in with a device" : "使用设备登录",
     "Login or email" : "账号或电子邮箱",
     "Your account is not setup for passwordless login." : "你的账号未设置无密码登录。",
@@ -292,28 +293,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "基于 Collabora Online 的文档、表格与演示文档。",
     "Distraction free note taking app." : "无干扰的笔记记录应用。",
     "Recommended apps" : "推荐的应用",
-    "Loading apps …" : "正在加载应用 …",
+    "Loading apps …" : "正在加载应用…",
     "Could not fetch list of apps from the App Store." : "无法从应用商店获取应用列表",
     "App download or installation failed" : "应用下载或安装失败",
     "Cannot install this app because it is not compatible" : "无法安装此应用，因它不兼容",
     "Cannot install this app" : "无法安装此应用",
     "Skip" : "跳过",
-    "Installing apps …" : "正在安装应用 …",
+    "Installing apps …" : "正在安装应用...",
     "Install recommended apps" : "安装推荐的应用",
-    "Online" : "在线",
-    "Away" : "离开",
-    "Busy" : "忙碌",
-    "Do not disturb" : "勿扰",
-    "Mute all notifications" : "静音所有通知",
-    "Invisible" : "隐藏",
-    "Appear offline" : "显示为离线",
     "Avatar of {displayName}" : "{displayName} 的头像",
     "Settings menu" : "设置菜单",
-    "Loading your contacts …" : "正在加载您的联系人 …",
-    "Looking for {term} …" : "正在寻找 {term} …",
+    "Loading your contacts …" : "正在加载您的联系人……",
+    "Looking for {term} …" : "正在查找{term} ……",
     "Search contacts" : "搜索联系人",
     "Reset search" : "重置搜索",
-    "Search contacts …" : "搜索联系人 …",
+    "Search contacts …" : "搜索联系人……",
     "Could not load your contacts" : "无法加载您的联系人",
     "No contacts found" : "无法找到联系人",
     "Show all contacts" : "显示所有联系人",
@@ -325,20 +319,12 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "搜索 {type} 时出错",
     "Search starts once you start typing and results may be reached with the arrow keys" : "一旦开始输入，搜索就会开始，你可以使用方向键切换到结果。",
     "Search for {name} only" : "仅搜索 {name}",
-    "Loading more results …" : "正在加载更多结果 …",
+    "Loading more results …" : "加载更多结果...",
     "Forgot password?" : "忘记密码？",
     "Back to login form" : "回到登录表单",
     "Back" : "返回",
     "Login form is disabled." : "登录表单已禁用",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud 登录表单已禁用。如果可以，请使用其他登录选项或联系你的管理人员。",
-    "Connect to your account" : "连接到您的账号",
-    "Security warning" : "安全警告",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "如果您不打算设置新设备或应用程序，则有人试图欺骗您，以授予他们访问数据的权限。 在这种情况下，请勿继续操作，而应与系统管理员联系。",
-    "Alternative log in using app password" : "使用应用密码进行登录",
-    "Account connected" : "账号已连接",
-    "Your client should now be connected!" : "您的客户端现在应该可以连接了！",
-    "You can close this window." : "您可以关闭此窗口。",
-    "Account access" : "账号访问",
     "More actions" : "更多操作 ",
     "User menu" : "用户菜单",
     "Your guest name: {user}" : "您的访客名称：{user}",
@@ -356,13 +342,13 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "有关如何正确配置服务器的信息，{linkStart}请参阅文档{linkEnd}",
     "Autoconfig file detected" : "检测到自动配置文件",
     "The setup form below is pre-filled with the values from the config file." : "下方设置表单预先填写了配置文件中的值。",
+    "Security warning" : "安全警告",
     "Create administration account" : "创建管理员账号",
     "Administration account name" : "管理员账号名称",
     "Administration account password" : "管理员账号密码",
     "Storage & database" : "存储与数据库",
     "Data folder" : "数据目录",
     "Database configuration" : "数据库配置",
-    "Database type" : "数据库类型",
     "Only {firstAndOnlyDatabase} is available." : "只有 {firstAndOnlyDatabase} 可用。",
     "Install and activate additional PHP modules to choose other database types." : "安装并激活额外的 PHP 模块以选择其他数据库类型。",
     "For more details check out the documentation." : "请查阅文档获得详细信息。",
@@ -370,7 +356,6 @@ OC.L10N.register(
     "You chose SQLite as database." : "您选择 SQLite 作为数据库。",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite 应只用于最小化和开发实例。生产环境我们推荐使用不同的数据库后端。",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "如果您使用文件同步客户端，强烈不建议使用 SQLite。",
-    "Database connection" : "数据库连接",
     "Database user" : "数据库用户",
     "Database password" : "数据库密码",
     "Database name" : "数据库名",
@@ -378,7 +363,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "请填写主机名称和端口号（例如，localhost:5432）。",
     "Database host" : "数据库主机",
     "localhost" : "本地主机",
-    "Installing …" : "正在安装 …",
+    "Installing …" : "正在安装...",
     "Install" : "安装",
     "Need help?" : "需要帮助？",
     "See the documentation" : "查看文档",
@@ -387,7 +372,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "您的浏览器不受支持。请升级至较新或受支持的版本。",
     "Continue with this unsupported browser" : "继续使用该过时的浏览器",
     "Supported versions" : "支持的版本",
-    "Search {types} …" : "搜索 {types} …",
+    "Search {types} …" : "搜索 {types} …",
     "Choose {file}" : "选择 {file}",
     "Choose" : "选择",
     "Copy to {target}" : "复制到 {target}",
@@ -407,10 +392,7 @@ OC.L10N.register(
     "(all selected)" : "（选中全部）",
     "({count} selected)" : "（选择了 {count} 个）",
     "Error loading file exists template" : "加载文件存在性模板失败",
-    "Saving …" : "正在保存 …",
-    "Groups" : "用户组",
-    "Group list is empty" : "群组列表为空",
-    "Unable to retrieve the group list" : "无法获取分组列表",
+    "Saving …" : "正在保存…",
     "seconds ago" : "几秒前",
     "Connection to server lost" : "与服务器的连接断开",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["加载页面出现问题，将在%n秒后重新加载"],
@@ -425,6 +407,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "输入以搜索已有项目",
     "New in" : "新品",
     "View changelog" : "查看更新记录",
+    "No action available" : "无可用操作",
+    "Error fetching contact actions" : "查找联系人时出错",
     "Close \"{dialogTitle}\" dialog" : "关闭“{dialogTitle}”对话",
     "Email length is at max (255)" : "邮箱长度达到最大（255）",
     "Clipboard not available, please copy manually" : "剪贴板不可用，请手动复制",
@@ -461,6 +445,18 @@ OC.L10N.register(
     "Skip to navigation of app" : "跳过应用向导",
     "Go to %s" : "转至 %s",
     "Get your own free account" : "获取自己的免费账号",
+    "Connect to your account" : "连接到您的账号",
+    "Please log in before granting %1$s access to your %2$s account." : "在授权 %1$s 访问您的账号 %2$s 之前，请先登录。",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "如果您不打算设置新设备或应用程序，则有人试图欺骗您，以授予他们访问数据的权限。 在这种情况下，请勿继续操作，而应与系统管理员联系。",
+    "App password" : "应用密码",
+    "Grant access" : "授权访问",
+    "Alternative log in using app password" : "使用应用密码进行登录",
+    "Account access" : "账号访问",
+    "Currently logged in as %1$s (%2$s)." : "当前正以 %1$s (%2$s) 身份登陆。",
+    "You are about to grant %1$s access to your %2$s account." : "您正在授权 %1$s 访问您的账号 %2$s 。",
+    "Account connected" : "账号已连接",
+    "Your client should now be connected!" : "您的客户端现在应该可以连接了！",
+    "You can close this window." : "您可以关闭此窗口。",
     "Previous" : "上一个",
     "This share is password-protected" : "这个共享是被密码保护的",
     "The password is wrong or expired. Please try again or request a new one." : "密码错误的或已经过期。请重试或申请一个新的。",
@@ -500,41 +496,32 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "该实例 %s 当前处于维护模式，这将花费一些时间。",
     "This page will refresh itself when the instance is available again." : "当实例再次可用时，页面会自动刷新。",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "如果这个消息一直存在或不停出现，请联系您的系统管理员。",
+    "No temporary profile picture available, try again" : "没有临时个人页图片可用，请重试",
+    "No crop data provided" : "没有提供剪裁数据",
+    "No valid crop data provided" : "没有提供有效的裁剪数据",
+    "Crop is not square" : "裁剪的不是正方形",
     "Error occurred while checking server setup" : "检查服务器设置时出错",
     "For more details see the {linkstart}documentation ↗{linkend}." : "了解更多详情，请参见{linkstart}文档 ↗{linkend}。",
-    "unknown text" : "未知文字",
-    "Hello world!" : "你好，世界！",
-    "sunny" : "晴",
-    "Hello {name}, the weather is {weather}" : "您好 {name}，今天天气是 {weather}",
-    "Hello {name}" : "您好 {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>这是您的搜索结果<script>警告（1）</script></strong>",
-    "new" : "新建",
-    "_download %n file_::_download %n files_" : ["下载 %n 个文件"],
-    "Direct link copied to clipboard" : "直链已复制至粘贴板",
-    "Searching …" : "正在搜索 ...",
-    "Logging in …" : "正在登录……",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "我们检测到你的 IP 进行了多次无效登录尝试。因此，你的下一次登录将被延迟 30 秒。",
-    "Loading apps …" : "正在加载应用…",
-    "Installing apps …" : "正在安装应用...",
-    "Loading your contacts …" : "正在加载您的联系人……",
-    "Looking for {term} …" : "正在查找{term} ……",
-    "Search contacts …" : "搜索联系人……",
-    "Loading more results …" : "加载更多结果...",
-    "Search {types} …" : "搜索 {types} …",
-    "Saving …" : "正在保存…",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "在浏览器和移动设备应用中进行聊天，视频通话，屏幕共享，线上见面和网络会议。",
+    "You have not added any info yet" : "您尚未添加任何信息",
+    "{user} has not added any info yet" : "{user} 尚未添加任何信息",
+    "Error opening the user status modal, try hard refreshing the page" : "打开用户状态模块时出错，请努力刷新页面",
+    "Edit Profile" : "编辑个人资料",
+    "The headline and about sections will show up here" : "标题和关于部分将显示在此处",
     "Very weak password" : "非常弱的密码",
     "Weak password" : "弱密码",
     "So-so password" : "一般强度的密码",
     "Good password" : "较强的密码",
     "Strong password" : "强密码",
-    "No action available" : "无可用操作",
-    "Error fetching contact actions" : "查找联系人时出错",
     "Non-existing tag #{tag}" : "标签 #{tag} 不存在",
     "Restricted" : "受限",
+    "Invisible" : "隐藏",
     "Delete" : "删除",
     "Rename" : "重命名",
     "Collaborative tags" : "协作标签",
     "No tags found" : "标签未找到",
+    "Profile not found" : "未找到个人资料",
+    "The profile does not exist." : "个人资料不存在",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "因为 .htaccess 文件没有工作，您的数据目录和文件可从互联网被访问。",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "关于如何正确配置服务器，请参见<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">文档</a>。",
     "<strong>Create an admin account</strong>" : "<strong>创建管理员账号</strong>",
@@ -545,9 +532,6 @@ OC.L10N.register(
     "Configure the database" : "配置数据库",
     "Only %s is available." : "仅 %s 可用。",
     "Database account" : "数据库账号",
-    "Installing …" : "正在安装...",
-    "Please log in before granting %1$s access to your %2$s account." : "在授权 %1$s 访问您的账号 %2$s 之前，请先登录。",
-    "Currently logged in as %1$s (%2$s)." : "当前正以 %1$s (%2$s) 身份登陆。",
-    "You are about to grant %1$s access to your %2$s account." : "您正在授权 %1$s 访问您的账号 %2$s 。"
+    "Direct link copied to clipboard" : "直链已复制至粘贴板"
 },
 "nplurals=1; plural=0;");
