@@ -4,12 +4,19 @@ OC.L10N.register(
     "Cannot write into \"config\" directory!" : "Немагчыма запісаць у каталог \"config\"!",
     "This can usually be fixed by giving the web server write access to the config directory." : "Звычайна гэта можна выправіць, даўшы вэб-серверу доступ на запіс у каталог config.",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Але, калі вы [хочаце пакінуць файл config.php толькі для чытання, задайце ў ім для параметра \"config_is_read_only\" значэнне true.",
+    "The page could not be found on the server." : "Не ўдалося знайсці старонку на серверы.",
+    "%s email verification" : "Спраўджанне электроннай пошты %s",
     "Email verification" : "Спраўджанне электроннай пошты",
+    "Click the following button to confirm your email." : "Націсніце на кнопку, каб пацвердзіць адрас электроннай пошты.",
+    "Click the following link to confirm your email." : "Націсніце на спасылку, каб пацвердзіць адрас электроннай пошты.",
+    "Confirm your email" : "Пацвердзіце адрас электроннай пошты",
     "Other activities" : "Іншая актыўнасць",
     "%1$s and %2$s" : "%1$s і %2$s",
     "%1$s, %2$s and %3$s" : "%1$s, %2$s і %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s і %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s і %5$s",
+    "PHP %s or higher is required." : "Патрабуецца PHP версіі %s або вышэй.",
+    "PHP with a version lower than %s is required." : "Патрабуецца PHP версіі ніжэйшай за %s.",
     "The following architectures are supported: %s" : "Падтрымліваюцца наступныя архітэктуры: %s",
     "The following databases are supported: %s" : "Падтрымліваюцца наступныя базы даных: %s",
     "The command line tool %s could not be found" : "Інструмент каманднага радка %s не знойдзены",
@@ -23,6 +30,7 @@ OC.L10N.register(
     "Avatar image is not square" : "Відарыс аватара не квадратны",
     "Files" : "Файлы",
     "View profile" : "Праглядзець профіль",
+    "same time" : "той жа час",
     "_%nh_::_%nh_" : ["%n г","%n г","%n г","%n г"],
     "_%nm_::_%nm_" : ["%n хв","%n хв","%n хв","%n хв"],
     "Local time: %s" : "Мясцовы час: %s",
@@ -46,9 +54,14 @@ OC.L10N.register(
     "in a few seconds" : "праз некалькі секунд",
     "seconds ago" : "с таму",
     "Empty file" : "Пусты файл",
+    "File is too large to convert" : "Файл занадта вялікі для канвертавання",
     "Could not convert file" : "Не атрымалася канвертаваць файл",
     "%1$s (renamed)" : "%1$s (перайменаваны)",
     "renamed file" : "перайменаваны файл",
+    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" - гэта забароненая назва файла або папкі.",
+    "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" - гэта забаронены прэфікс да назвы файла або папкі.",
+    "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" не дазваляецца ў назве файла або папкі.",
+    "\"%1$s\" is a forbidden file type." : "\"%1$s\" - гэта забаронены тып файла.",
     "Filenames must not end with \"%1$s\"." : "Назвы файлаў не могуць заканчвацца на \"%1$s\".",
     "File already exists" : "Файл ужо існуе",
     "Failed to create file from template" : "Не ўдалося стварыць файл з шаблона",
@@ -79,6 +92,7 @@ OC.L10N.register(
     "Address" : "Адрас",
     "Profile picture" : "Аватар профілю",
     "About" : "Пра сябе",
+    "Display name" : "Імя для паказу",
     "Headline" : "Загаловак",
     "Organization" : "Арганізацыя",
     "Role" : "Роля",
@@ -86,6 +100,8 @@ OC.L10N.register(
     "Unknown account" : "Невядомы ўліковы запіс",
     "Additional settings" : "Дадатковыя налады",
     "Open %s" : "Адкрыць %s",
+    "%1$s via %2$s" : "%1$s праз %2$s",
+    "You cannot share your root folder" : "Нельга абагуліць каранёвую папку",
     "Public upload is not allowed" : "Публічнае запампоўванне забаронена",
     "Sharing is disabled" : "Абагульванне адключана",
     "Group \"%s\" does not exist" : "Група \"%s\" не існуе",
@@ -137,6 +153,7 @@ OC.L10N.register(
     "Dec." : "Снеж",
     "The Login is already being used" : "Лагін ужо выкарыстоўваецца",
     "Could not create account" : "Не ўдалося стварыць уліковы запіс",
+    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "У лагіне дазволеныя толькі наступныя сімвалы: \"a-z\", \"A-Z\", \"0-9\", прабелы і \"_.@-'\"",
     "Login contains whitespace at the beginning or at the end" : "Лагін змяшчае прабелы ў пачатку або ў канцы",
     "Login must not consist of dots only" : "Лагін не можа змяшчаць толькі кропкі",
     "Username is too long" : "Імя карыстальніка занадта доўгае",
@@ -145,18 +162,30 @@ OC.L10N.register(
     "a safe home for all your data" : "бяспечны дом для ўсіх вашых даных",
     "Application is not enabled" : "Праграма не ўключана",
     "Authentication error" : "Памылка аўтэнтыфікацыі",
+    "Token expired. Please reload page." : "Токен пратэрмінаваны. Перазагрузіце старонку.",
+    "No database drivers (sqlite, mysql, or postgresql) installed." : "Драйверы баз даных (sqlite, mysql або postgresql) не ўсталяваныя.",
     "Cannot write into \"config\" directory." : "Немагчыма запісаць у каталог \"config\".",
     "Cannot create \"data\" directory." : "Немагчыма стварыць каталог \"data\".",
     "Setting locale to %s failed." : "Не ўдалося задаць лакаль %s.",
     "Please install one of these locales on your system and restart your web server." : "Усталюйце адну з гэтых лакаляў у вашай сістэме і перазапусціце вэб-сервер.",
     "PHP module %s not installed." : "Модуль PHP %s не ўсталяваны.",
     "Please ask your server administrator to install the module." : "Папрасіце адміністратара сервера ўсталяваць модуль.",
+    "Please ask your server administrator to check the Nextcloud configuration." : "Папрасіце адміністратара сервера праверыць канфігурацыю Nextcloud.",
+    "Authentication failed, wrong token or provider ID given" : "Памылка аўтэнтыфікацыі, няправільны токен або ідэнтыфікатар пастаўшчыка",
     "Storage is temporarily not available" : "Сховішча часова недаступна",
     "Images" : "Відарысы",
     "Question" : "Пытанне",
+    "The answer to the question" : "Адказ на пытанне",
+    "Audio chat" : "Аўдыячат",
+    "Chat history" : "Гісторыя чата",
+    "Audio input" : "Аўдыяўваход",
+    "Conversation token" : "Токен размовы",
+    "A token representing the conversation." : "Токен, які прадстаўляе размову.",
+    "The new conversation token" : "Новы токен размовы",
     "Number of images" : "Колькасць відарысаў",
     "Chat" : "Чат",
     "Chat with the assistant" : "Чат з памочнікам",
+    "Available tools" : "Даступныя інструменты",
     "Generate a headline" : "Згенерыраваць загаловак",
     "Generates a possible headline for a text." : "Генерыруе магчымы загаловак для тэксту.",
     "Original text" : "Арыгінальны тэкст",
@@ -168,6 +197,7 @@ OC.L10N.register(
     "Write a text that you want the assistant to simplify" : "Напішыце тэкст, які вы хочаце, каб памочнік спрасціў",
     "Simplified text" : "Спрошчаны тэкст",
     "The simplified text" : "Спрошчаны тэкст",
+    "Topics" : "Тэмы",
     "Translate" : "Перакласці",
     "Translate text from one language to another" : "Пераклад тэксту з адной мовы на іншую",
     "Origin text" : "Арыгінальны тэкст",
