@@ -93,6 +93,8 @@ OC.L10N.register(
     "Destination does not exist" : "Placeringen findes ikke",
     "Destination is not creatable" : "Placeringen kan ikke oprettes",
     "Dot files are not allowed" : "Filer med punktummer er ikke tilladt",
+    "%1$s (renamed)" : "%1$s (omdøbt)",
+    "renamed file" : "omdøbt fil",
     "\"%1$s\" is a forbidden file or folder name." : "\" %1$s\" er et forbudt fil- eller mappenavn.",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "\" %1$s\" er et forbudt præfiks for fil- eller mappenavne.",
     "\"%1$s\" is not allowed inside a file or folder name." : "\" %1$s\" er ikke tilladt inde i et fil- eller mappenavn.",
@@ -127,6 +129,8 @@ OC.L10N.register(
     "Settings" : "Indstillinger",
     "Log out" : "Log ud",
     "Accounts" : "Konti",
+    "Bluesky" : "Bluesky",
+    "View %s on Bluesky" : "Vis %s på Bluesky",
     "Email" : "E-mail",
     "Mail %s" : "Mail %s",
     "Fediverse" : "Fediverse",
@@ -273,6 +277,7 @@ OC.L10N.register(
     "A valid Login must be provided" : "Et gyldigt login skal angives",
     "Login contains whitespace at the beginning or at the end" : "Login indeholder mellemrum i begyndelsen eller slutningen",
     "Login must not consist of dots only" : "Login må ikke kun bestå af prikker",
+    "Username is too long" : "Brugernavn er for langt",
     "Login is invalid because files already exist for this user" : "Login er ugyldigt, fordi filer allerede eksisterer for denne bruger",
     "Account disabled" : "Konto deaktiveret",
     "Login canceled by app" : "Login annulleret af app",
@@ -285,8 +290,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Kan ikke skrive til mappen \"config\".",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Dette kan som regel ordnes ved at give webserveren skrive adgang til config mappen. Se %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Men hvis du foretrækker at bibeholde config.php skrivebeskyttet, så sæt parameter \"config_is_read_only\" til true i filen. Se %s",
-    "Cannot write into \"apps\" directory." : "Kan ikke skrive til mappen \"apps\".",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Dette kan som regel rettes ved at give webserveren skriveadgang til apps-mappen eller slå appstore fra i config-filen.",
     "Cannot create \"data\" directory." : "Kan ikke oprette mappen \"data\".",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Dette kan som regel ordnes ved at give webserveren skrive adgang til rod mappen. Se %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Rettigheder kan som regel rettes ved at give webserveren skriveadgang til rodmappen. Se %s.",
@@ -297,8 +300,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Du bedes anmode din serveradministrator om at installere modulet.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP-indstillingen \"%s\" er ikke angivet til \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Ændring af denne indstilling i php.ini vil tillade Nextcloud at køre igen",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> er angivet til <code>%s</code>, i stedet for den forventede værdi <code>0</code>",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "For at rette dette problem, sæt <code>mbstring.func_overload</code> til <code>0</code> i din php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP er tilsyneladende sat op til at fjerne indlejrede doc-blokke. Dette vil gøre adskillige kerneprogrammer utilgængelige.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dette er sansynligvis forårsaget af et accelerator eller cache som Zend OPcache eller eAccelerator",
     "PHP modules have been installed, but they are still listed as missing?" : "Der er installeret PHP-moduler, men de fremstår stadig som fraværende?",
@@ -323,18 +324,36 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Lagerplads er midlertidigt ikke tilgængeligt",
     "Storage connection timeout. %s" : "Lageret svarer ikke. %s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "For at tillade at denne kontrol køres så skal du sikre dig at din webserver kan forbinde til sig selv. Derfor skal den kunne opløse og forbinde til mindst en af dets `trusted_domains` eller `overwrite.cli.url`. Denne fejl kan være resultatet af en server-side DNS mismatch eller udadgående firewall regel.",
+    "Analyze images" : "Analysér billeder",
+    "Ask a question about the given images." : "Stil et spørgsmål om de givne billeder.",
     "Images" : "Billeder",
+    "Images to ask a question about" : "Billeder til at stille et spørgsmål om",
     "Question" : "Spørgsmål",
+    "What to ask about the images." : "Hvad kan du spørge om i forhold til billederne.",
     "Generated response" : "Genereret respons",
+    "The answer to the question" : "Svaret på sprøgsmålet",
+    "Audio chat" : "Lydchat",
+    "Voice chat with the assistant" : "Stemmechat med assistenten",
     "System prompt" : "Systemprompt",
     "Define rules and assumptions that the assistant should follow during the conversation." : "Definer regler og antagelser, som assistenten skal følge under samtalen.",
+    "Chat voice message" : "Chatstemme beskeder",
+    "Describe a task that you want the assistant to do or ask a question." : "Beskriv en opgave som du ønsker at assistenten skal lave eller stil et spørgsmål.",
     "Chat history" : "Chathistorik",
+    "The history of chat messages before the current message, starting with a message by the user." : "Historikken for chatbeskeder inden den aktuelle besked, startende med en besked fra brugeren.",
+    "Input transcript" : "Input transskribering",
+    "Transcription of the audio input" : "Transskription af lydinput",
+    "Response voice message" : "Respons lydbesked",
+    "The generated voice response as part of the conversation" : "Den genererede lydrespons som del af samtalen",
+    "Output transcript" : "Output transskription",
+    "Transcription of the audio output" : "Transskriptionen af lydoutputtet ",
     "Transcribe audio" : "Transskriber lyd",
     "Transcribe the things said in an audio" : "Transskriber de ting, der siges i en lydfil",
     "Audio input" : "Lydinput",
     "The audio to transcribe" : "Lyden der skal transskriberes",
     "Transcription" : "Transskription",
     "The transcribed text" : "Den transskriberede tekst",
+    "Chat by voice with an agent" : "Chat med en agent med stemmen",
+    "Describe a task that you want the agent to do or ask a question." : "Beskriv en opgave som du ønsker at agenten skal løse eller stil et spørgsmål.",
     "Confirmation" : "Bekræftelse",
     "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Om tidligere forespurgte handlinger skal bekræftes: 0 for nægtelse og 1 for bekræftelse.",
     "Conversation token" : "Samtaletoken",
@@ -368,6 +387,11 @@ OC.L10N.register(
     "How many images to generate" : "Hvor mange billeder skal genereres",
     "Output images" : "Output billeder",
     "The generated images" : "De genererede billeder",
+    "Generate speech" : "Generér tale",
+    "Generate speech from a transcript" : "Generér tale ud fra en transskription",
+    "Write transcript that you want the assistant to generate speech from" : "Skriv transskribering som du ønsker at assistenten skal generere tale ud fra ",
+    "Output speech" : "Output tale",
+    "The generated speech" : "Den genererede tale",
     "Free text to text prompt" : "Fritekst til tekstprompt",
     "Runs an arbitrary prompt through a language model that returns a reply" : "Kører en vilkårlig prompt gennem en sprogmodel, der returnerer et svar",
     "Describe a task that you want the assistant to do or ask a question" : "Beskriv en opgave, som du ønsker at assistenten udføre eller stil et spørgsmål",
@@ -447,6 +471,10 @@ OC.L10N.register(
     "Organisation" : "Organisation",
     "File is currently busy, please try again later" : "Filen er i øjeblikket optaget - forsøg igen senere",
     "Cannot download file" : "Kan ikke downloade filen",
+    "Cannot write into \"apps\" directory." : "Kan ikke skrive til mappen \"apps\".",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Dette kan som regel rettes ved at give webserveren skriveadgang til apps-mappen eller slå appstore fra i config-filen.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> er angivet til <code>%s</code>, i stedet for den forventede værdi <code>0</code>",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "For at rette dette problem, sæt <code>mbstring.func_overload</code> til <code>0</code> i din php.ini.",
     "Login is too long" : "Login er for lang"
 },
 "nplurals=2; plural=(n != 1);");
