@@ -469,10 +469,12 @@ OC.L10N.register(
     "Summarizes text by reducing its length without losing key information." : "Περιγράφει συνοπτικά το κείμενο μειώνοντας το μήκος του χωρίς να χάνονται βασικές πληροφορίες.",
     "Extracts topics from a text and outputs them separated by commas." : "Εξάγει θέματα από ένα κείμενο και τα εμφανίζει χωρισμένα με κόμματα.",
     "Organisation" : "Οργανισμός",
-    "Login is too long" : "Το όνομα χρήστη είναι πολύ μεγάλο",
+    "File is currently busy, please try again later" : "Το αρχείο χρησιμοποιείται αυτή τη στιγμή, παρακαλούμε προσπαθήστε αργότερα",
+    "Cannot download file" : "Δεν είναι δυνατή η λήψη του αρχείου",
     "Cannot write into \"apps\" directory." : "Δεν είναι δυνατή η εγγραφή στον κατάλογο \"apps\".",
     "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Αυτό μπορεί συνήθως να διορθωθεί δίνοντας στον διακομιστή ιστού πρόσβαση εγγραφής στον κατάλογο apps ή απενεργοποιώντας το App Store στο αρχείο διαμόρφωσης config.",
     "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "Το <code>mbstring.func_overload</code> έχει ορισθεί σε <code>%s</code> αντί για την αναμενόμενη τιμή <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Για να διορθώσετε αυτό το πρόβλημα ορίστε το <code>mbstring.func_overload</code> σε <code>0</code> στο αρχείο php.ini."
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Για να διορθώσετε αυτό το πρόβλημα ορίστε το <code>mbstring.func_overload</code> σε <code>0</code> στο αρχείο php.ini.",
+    "Login is too long" : "Το όνομα χρήστη είναι πολύ μεγάλο"
 },
 "nplurals=2; plural=(n != 1);");
