@@ -7,13 +7,15 @@
  */
 namespace OC\Files\Cache;
 
-use Doctrine\DBAL\Exception\UniqueConstraintViolationException;
 use OC\DB\Exceptions\DbalException;
 use OC\DB\QueryBuilder\Sharded\ShardDefinition;
+use OC\Files\Cache\Wrapper\CacheJail;
+use OC\Files\Cache\Wrapper\CacheWrapper;
 use OC\Files\Search\SearchComparison;
 use OC\Files\Search\SearchQuery;
 use OC\Files\Storage\Wrapper\Encryption;
 use OC\SystemConfig;
+use OCP\DB\Exception;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\Files\Cache\CacheEntryInsertedEvent;
@@ -171,7 +173,7 @@ class Cache implements ICache {
 			$data['storage_mtime'] = $data['mtime'];
 		}
 		if (isset($data['f_permissions'])) {
-			$data['scan_permissions'] ??= $data['f_permissions'];
+			$data['scan_permissions'] = $data['f_permissions'];
 		}
 		$data['permissions'] = (int)$data['permissions'];
 		if (isset($data['creation_time'])) {
@@ -247,7 +249,7 @@ class Cache implements ICache {
 	 * @param array $data
 	 *
 	 * @return int file id
-	 * @throws \RuntimeException
+	 * @throws \RuntimeException|Exception
 	 */
 	public function insert($file, array $data) {
 		// normalize file
@@ -287,7 +289,7 @@ class Cache implements ICache {
 				$builder->setValue($column, $builder->createNamedParameter($value));
 			}
 
-			if ($builder->execute()) {
+			if ($builder->executeStatement()) {
 				$fileId = $builder->getLastInsertId();
 
 				if (count($extensionValues)) {
@@ -307,15 +309,19 @@ class Cache implements ICache {
 				$this->eventDispatcher->dispatchTyped($event);
 				return $fileId;
 			}
-		} catch (UniqueConstraintViolationException $e) {
-			// entry exists already
-			if ($this->connection->inTransaction()) {
-				$this->connection->commit();
-				$this->connection->beginTransaction();
+		} catch (Exception $e) {
+			if ($e->getReason() === Exception::REASON_UNIQUE_CONSTRAINT_VIOLATION) {
+				// entry exists already
+				if ($this->connection->inTransaction()) {
+					$this->connection->commit();
+					$this->connection->beginTransaction();
+				}
+			} else {
+				throw $e;
 			}
 		}
 
-		// The file was created in the mean time
+		// The file was created in the meantime
 		if (($id = $this->getId($file)) > -1) {
 			$this->update($id, $data);
 			return $id;
@@ -374,8 +380,11 @@ class Cache implements ICache {
 					$query->setValue($column, $query->createNamedParameter($value));
 				}
 
-				$query->execute();
-			} catch (UniqueConstraintViolationException $e) {
+				$query->executeStatement();
+			} catch (Exception $e) {
+				if ($e->getReason() !== Exception::REASON_UNIQUE_CONSTRAINT_VIOLATION) {
+					throw $e;
+				}
 				$query = $this->getQueryBuilder();
 				$query->update('filecache_extended')
 					->whereFileId($id)
@@ -646,6 +655,13 @@ class Cache implements ICache {
 		return $this->storage->instanceOfStorage(Encryption::class);
 	}
 
+	protected function shouldEncrypt(string $targetPath): bool {
+		if (!$this->storage->instanceOfStorage(Encryption::class)) {
+			return false;
+		}
+		return $this->storage->shouldEncrypt($targetPath);
+	}
+
 	/**
 	 * Move a file or folder in the cache
 	 *
@@ -668,8 +684,8 @@ class Cache implements ICache {
 
 			$shardDefinition = $this->connection->getShardDefinition('filecache');
 			if (
-				$shardDefinition &&
-				$shardDefinition->getShardForKey($sourceCache->getNumericStorageId()) !== $shardDefinition->getShardForKey($this->getNumericStorageId())
+				$shardDefinition
+				&& $shardDefinition->getShardForKey($sourceCache->getNumericStorageId()) !== $shardDefinition->getShardForKey($this->getNumericStorageId())
 			) {
 				$this->moveFromStorageSharded($shardDefinition, $sourceCache, $sourceData, $targetPath);
 				return;
@@ -775,7 +791,6 @@ class Cache implements ICache {
 			$this->connection->commit();
 
 			if ($sourceCache->getNumericStorageId() !== $this->getNumericStorageId()) {
-				\OCP\Server::get(\OCP\Files\Config\IUserMountCache::class)->clear();
 				$this->eventDispatcher->dispatchTyped(new CacheEntryRemovedEvent($this->storage, $sourcePath, $sourceId, $sourceCache->getNumericStorageId()));
 				$event = new CacheEntryInsertedEvent($this->storage, $targetPath, $sourceId, $this->getNumericStorageId());
 				$this->eventDispatcher->dispatch(CacheInsertEvent::class, $event);
@@ -1165,7 +1180,9 @@ class Cache implements ICache {
 		$data = $this->cacheEntryToArray($sourceEntry);
 
 		// when moving from an encrypted storage to a non-encrypted storage remove the `encrypted` mark
-		if ($sourceCache instanceof Cache && $sourceCache->hasEncryptionWrapper() && !$this->hasEncryptionWrapper()) {
+		if ($sourceCache instanceof Cache
+			&& $sourceCache->hasEncryptionWrapper()
+			&& !$this->shouldEncrypt($targetPath)) {
 			$data['encrypted'] = 0;
 		}
 
@@ -1216,8 +1233,16 @@ class Cache implements ICache {
 	}
 
 	private function moveFromStorageSharded(ShardDefinition $shardDefinition, ICache $sourceCache, ICacheEntry $sourceEntry, $targetPath): void {
+		$sourcePath = $sourceEntry->getPath();
+		while ($sourceCache instanceof CacheWrapper) {
+			if ($sourceCache instanceof CacheJail) {
+				$sourcePath = $sourceCache->getSourcePath($sourcePath);
+			}
+			$sourceCache = $sourceCache->getCache();
+		}
+
 		if ($sourceEntry->getMimeType() === ICacheEntry::DIRECTORY_MIMETYPE) {
-			$fileIds = $this->getChildIds($sourceCache->getNumericStorageId(), $sourceEntry->getPath());
+			$fileIds = $this->getChildIds($sourceCache->getNumericStorageId(), $sourcePath);
 		} else {
 			$fileIds = [];
 		}
@@ -1235,9 +1260,9 @@ class Cache implements ICache {
 		// when moving from an encrypted storage to a non-encrypted storage remove the `encrypted` mark
 		$removeEncryptedFlag = ($sourceCache instanceof Cache && $sourceCache->hasEncryptionWrapper()) && !$this->hasEncryptionWrapper();
 
-		$sourcePathLength = strlen($sourceEntry->getPath());
+		$sourcePathLength = strlen($sourcePath);
 		foreach ($cacheItems as &$cacheItem) {
-			if ($cacheItem['path'] === $sourceEntry->getPath()) {
+			if ($cacheItem['path'] === $sourcePath) {
 				$cacheItem['path'] = $targetPath;
 				$cacheItem['parent'] = $this->getParentId($targetPath);
 				$cacheItem['name'] = basename($cacheItem['path']);
