@@ -1,34 +1,16 @@
 <?php
 
 declare(strict_types=1);
-
 /**
- * @copyright Copyright (c) 2016, ownCloud, Inc.
- *
- * @author Joas Schilling <coding@schilljs.com>
- *
- * @license AGPL-3.0
- *
- * This code is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program. If not, see <http://www.gnu.org/licenses/>
- *
+ * SPDX-FileCopyrightText: 2016-2024 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2016 ownCloud, Inc.
+ * SPDX-License-Identifier: AGPL-3.0-only
  */
 namespace OCP\Notification;
 
-/**
- * Interface IAction
- *
- * @since 9.0.0
- */
+use OCP\AppFramework\Attribute\Consumable;
+
+#[Consumable(since: '9.0.0')]
 interface IAction {
 	/**
 	 * @since 17.0.0
@@ -54,8 +36,9 @@ interface IAction {
 	/**
 	 * @param string $label
 	 * @return $this
-	 * @throws \InvalidArgumentException if the label is invalid
+	 * @throws InvalidValueException if the label is invalid
 	 * @since 9.0.0
+	 * @since 30.0.0 throws {@see InvalidValueException} instead of \InvalidArgumentException
 	 */
 	public function setLabel(string $label): IAction;
 
@@ -68,8 +51,9 @@ interface IAction {
 	/**
 	 * @param string $label
 	 * @return $this
-	 * @throws \InvalidArgumentException if the label is invalid
+	 * @throws InvalidValueException if the label is invalid
 	 * @since 9.0.0
+	 * @since 30.0.0 throws {@see InvalidValueException} instead of \InvalidArgumentException
 	 */
 	public function setParsedLabel(string $label): IAction;
 
@@ -82,7 +66,6 @@ interface IAction {
 	/**
 	 * @param bool $primary
 	 * @return $this
-	 * @throws \InvalidArgumentException if $primary is invalid
 	 * @since 9.0.0
 	 */
 	public function setPrimary(bool $primary): IAction;
@@ -97,8 +80,9 @@ interface IAction {
 	 * @param string $link
 	 * @param string $requestType
 	 * @return $this
-	 * @throws \InvalidArgumentException if the link is invalid
+	 * @throws InvalidValueException if the link is invalid
 	 * @since 9.0.0
+	 * @since 30.0.0 throws {@see InvalidValueException} instead of \InvalidArgumentException
 	 */
 	public function setLink(string $link, string $requestType): IAction;
 
